///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// 
// Copyright Nurve Networks LLC 2008
// 
// Filename: XGS_AVR_INDY500_NTSC_01.c
//
// Original Author: Andre' LaMothe
// 
// Last Modified: 11.14.08
//
//
// BUGS: NTSC sprite mode 6 seems to have a bug in it that occurs when tiles are drawn next to each other with
// large differing indices sometimes. For example, if your tile map has a 1 and 10 next to each other then sometimes
// is caused the code to lock up, in other words the ASM driver is stepping on something from the C runtime. I haven't
// had time to find this bug, but I suspect in the rendering code that computes address of tile date something is getting
// overwritten in some cases, a carry flag is getting reset, or something subtle since the bug is rare, but its making me
// mad! So beware, if when using the NTSC tile mode 6 with sprites the driver seems to lock up try playing with your 
// tile map to find the offending pattern of data and change it. The moment I find the bug, new drivers will be updated
// on the site of course.
//
// Overview: This is a simple demo of a simple tile mode with with sprites for NTSC modes. The demo shows off defining
// tiles, vertical smooth scrolling and using sprites (the car is composed of two sprites). Also, the demo shows how to 
// make a continuous vertical scrolling world by creating a "seamless" road tile map that is many screen long and the 
// last screen is a copy of the first screen, so the tile map can be reset without visual anomaly.
//
//    |-----|
//    |  X  |  First map is the same as last map
//    |     |                   
//    |-----|                   |
//    |  A  |                   |              
//    |     |                   |                                 
//    |-----|                   |              
//    |  B  |                   |             
//    |     |                   |              
//    |-----|                   |              
//    |  C  |                   |              
//    |     |                   |              
//    |-----|                   |              
//    |  .  |                   |              
//    |  .  |                   |              
//    |-----|                   |              
//    |  X  |                   |              
//    |     |<------------------/
//    |-----|
//
//  When viewport reaches the last map then then the view is reset to the first map, and the user perceives a continuous
//  scrolling environment.
//
//
// Controls: Gamepad
//
//    Dpad Right/Left  - Steer right/left.
//    Dpad Up          - Gas.
//    Dpad Down        - Brake.
//
// Demo must be linked with following source files (in addition to primary file):
// 
// XGS_AVR_SYSTEM_V010.c              - System variables.
// XGS_AVR_NTSC_TILE_MODE6_V010.s     - ASM tile mapped driver with sprites.
// XGS_AVR_GFX_LIB_V010.c             - Graphics library which includes bitmapped graphics functions, etc.
// XGS_AVR_GAMEPAD_DRV_V010.c         - Gamepad driver.
//
// Note: header files for all sources must be in current working directory, so compiler can find the,
// 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// INCLUDES ///////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// define chip type here
#define __AVR_ATmega644__

// define CPU frequency in Mhz here if not defined in Makefile, this is used for conditional compilation, so needs
// to be first, before other XGS includes, also note there is a copy of this constant in XGS_AVR_SYSTEM_V010, so if you 
// change it here, also change it in the header to make certain everthing is sync'ed
#define F_CPU 28636360UL

#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <math.h>
#include <avr/eeprom.h>
#include <avr/io.h>
#include <avr/sleep.h>

#include <util/delay.h>
#include <avr/interrupt.h>
#include <avr/pgmspace.h>
#include <inttypes.h>
#include <compat/twi.h>
#include <avr/pgmspace.h>

// include local XGS API header files
#include "XGS_AVR_SYSTEM_V010.h"
#include "XGS_AVR_GAMEPAD_DRV_V010.h"

// include header file for video driver
#include "XGS_AVR_NTSC_TILE_MODE6_V010.h"
#include "XGS_AVR_GFX_LIB_V010.h"

#include "lms_pigsuxb_demo_sprites.h"

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// DEFINES AND MACROS /////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// number of sprites
#define NUM_TILE_BITMAPS     12

// shorthand defines for tile map colors, for manually entering bitmaps by hand!
#define _I      NTSC_BLACK // any symbol that makes it easy to see the bitmap!!
#define C0      NTSC_BLACK

#define CR      NTSC_RED
#define CG      NTSC_GREEN
#define CN      (NTSC_GREEN + 0x10)
#define CB      NTSC_BLUE
#define CY      (NTSC_YELLOW + 0x10)
#define CO      NTSC_ORANGE
#define CP      NTSC_PURPLE
#define CV      NTSC_VIOLET
#define CW      NTSC_WHITE

#define C1      NTSC_GRAY0
#define C2      NTSC_GRAY1
#define C3      NTSC_GRAY2
#define C4      NTSC_GRAY3
#define C5      NTSC_GRAY4
#define C6      NTSC_GRAY5
#define C7      NTSC_GRAY6
#define C8      NTSC_GRAY7
#define C9      NTSC_GRAY8

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// GLOBALS/////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// the "endless" raceway :) This track is 3 tile maps, the last tile map is a copy of the first, so seemless scrolling
// can be achieved
volatile UCHAR tile_map[TILE_MAP_WIDTH * 3*TILE_MAP_HEIGHT + 1 ] = 
{

//  Column
//  0  1  2  3  4  5  6  7  8  9  10 11 12 13 14 15 16 17  

     1, 1, 3, 5, 5, 5, 5, 7, 5, 5, 5, 6, 5, 5, 5, 3, 1, 1,     // row 0
     1, 1, 3, 5, 5, 5, 5, 7, 5, 5, 5, 6, 5, 5, 5, 3, 1, 1,     // row 1
     1, 1, 3, 5, 5, 5, 5, 7, 5, 5, 5, 5, 5, 5, 5, 3, 1, 1,     // row 2
     1, 1, 3, 5, 5, 5, 5, 7, 5, 5, 5, 5, 5, 5, 5, 3, 1, 1,     // row 3
     1, 1, 3, 5, 5, 5, 5, 7, 5, 5, 5, 6, 5, 5, 5, 3, 1, 1,     // row 4
     1, 1, 3, 5,11, 5, 5, 7, 5, 5, 5, 6, 5, 5, 5, 3, 1, 1,     // row 5
     1, 1, 3, 5, 5, 5, 5, 7, 5, 5, 5, 5, 5, 5, 5, 3, 1, 1,     // row 6
     1, 1, 3, 5, 5, 5, 5, 9, 5, 5, 5, 5, 5, 5, 5, 3,10, 1,     // row 7
     1, 1, 3, 5, 5, 5, 5, 7, 5, 5, 5, 6, 5, 5,11, 3, 1, 1,     // row 8
    10, 1, 3, 5, 5, 5, 5, 9, 5, 5, 5, 6, 5, 5, 5, 3, 1, 1,     // row 9
     1, 1, 3, 5, 5, 5, 5, 7, 5, 5, 5, 5, 5, 5, 5, 3, 1, 1,     // row 10
     1, 1, 3, 5, 5, 5, 5, 9, 5, 5, 5, 5, 5, 5, 5, 3, 1, 1,     // row 11
     1, 1, 3, 5, 5, 5, 5, 7, 5, 5, 5, 6, 5, 5, 5, 3, 1, 1,     // row 12

     1, 1, 3, 5, 5, 5, 5, 9, 5, 5, 5, 6, 5, 5, 5, 3, 1, 1,     // row 0
     1,10, 3, 5, 5, 5, 5, 7, 5, 5, 5, 5, 5, 5, 5, 3, 1, 1,     // row 1
     1, 1, 3, 5, 5, 5, 5, 9, 5, 5, 5, 5, 5, 5, 5, 3, 1, 1,     // row 2
     1, 1, 3, 5, 5, 5, 5, 7, 5, 5, 5, 6, 5, 5, 5, 3,10, 1,     // row 3
     1, 1, 3, 5, 5, 5, 5, 9, 5, 5, 5, 6, 5, 5, 5, 3, 1, 1,     // row 4
     1, 1, 3, 5, 5, 5, 5, 7, 5, 5, 5, 5, 5, 5, 5, 3, 1, 1,     // row 5
     1, 1, 3, 5, 5, 5, 5, 9, 5, 5, 5, 5, 5, 5, 5, 3, 1, 1,     // row 6
     1, 1, 3, 5, 5, 5, 5, 7, 5, 5, 5, 6, 5, 5, 5, 3, 1, 1,     // row 7
    10, 1, 3, 5, 5, 5, 5, 9, 5, 5, 5, 6, 5, 5, 5, 3, 1, 1,     // row 8
     1, 1, 3, 5, 5, 5, 5, 7, 5, 5, 5, 5, 5, 5, 5, 3, 1, 1,     // row 9
     1, 1, 3, 5, 5, 5, 5, 9, 5, 5, 5, 5, 5,11, 5, 3, 1, 1,     // row 10
     1, 1, 3, 5, 5, 5, 5, 7, 5, 5, 5, 6, 5, 5, 5, 3,10, 1,     // row 11
     1, 1, 3, 5, 5, 5, 5, 9, 5, 5, 5, 5, 5, 5, 5, 3, 1, 1,     // row 12

     1, 1, 3, 5, 5, 5, 5, 7, 5, 5, 5, 6, 5, 5, 5, 3, 1, 1,     // row 0
     1, 1, 3, 5, 5, 5, 5, 7, 5, 5, 5, 6, 5, 5, 5, 3, 1, 1,     // row 1
     1, 1, 3, 5, 5, 5, 5, 7, 5, 5, 5, 5, 5, 5, 5, 3, 1, 1,     // row 2
     1, 1, 3, 5, 5, 5, 5, 7, 5, 5, 5, 5, 5, 5, 5, 3, 1, 1,     // row 3
     1, 1, 3, 5, 5, 5, 5, 7, 5, 5, 5, 6, 5, 5, 5, 3, 1, 1,     // row 4
     1, 1, 3, 5,11, 5, 5, 7, 5, 5, 5, 6, 5, 5, 5, 3, 1, 1,     // row 5
     1, 1, 3, 5, 5, 5, 5, 7, 5, 5, 5, 5, 5, 5, 5, 3, 1, 1,     // row 6
     1, 1, 3, 5, 5, 5, 5, 9, 5, 5, 5, 5, 5, 5, 5, 3,10, 1,     // row 7
     1, 1, 3, 5, 5, 5, 5, 7, 5, 5, 5, 6, 5, 5,11, 3, 1, 1,     // row 8
    10, 1, 3, 5, 5, 5, 5, 9, 5, 5, 5, 6, 5, 5, 5, 3, 1, 1,     // row 9
     1, 1, 3, 5, 5, 5, 5, 7, 5, 5, 5, 5, 5, 5, 5, 3, 1, 1,     // row 10
     1, 1, 3, 5, 5, 5, 5, 9, 5, 5, 5, 5, 5, 5, 5, 3, 1, 1,     // row 11
     1, 1, 3, 5, 5, 5, 5, 7, 5, 5, 5, 6, 5, 5, 5, 3, 1, 1,     // row 12

};

// these are the 8x8 tiles for the road, they are coded with constants from above to make it 
// easier to type, in some cases, I start with ASCII "artwork" then use the editor's replace function
// to replace characters with color codes. At some point you would want to use a PC based tool to 
// do this for you, but this manual bitmap art is kind fun for a handful of tiles!
volatile UCHAR tile_bitmaps[NUM_TILE_BITMAPS * TILE_BITMAP_SIZE + 1 ] = 
{
    // blank
    _I,_I,_I,_I,_I,_I,_I,_I,
    _I,_I,_I,_I,_I,_I,_I,_I,
    _I,_I,_I,_I,_I,_I,_I,_I,
    _I,_I,_I,_I,_I,_I,_I,_I,
    _I,_I,_I,_I,_I,_I,_I,_I,
    _I,_I,_I,_I,_I,_I,_I,_I,
    _I,_I,_I,_I,_I,_I,_I,_I,
    _I,_I,_I,_I,_I,_I,_I,_I,


    // grass version 1
    CG,CG,CG,CG,CG,CG,CG,CG, 
    CG,CN,CG,CG,CN,CG,CG,CG, 
    CG,CG,CG,CG,CG,CG,CG,CG, 
    CG,CG,CG,CN,CG,CG,CN,CG, 
    CN,CG,CG,CG,CG,CG,CG,CG, 
    CG,CG,CG,CG,CG,CG,CG,CG, 
    CG,CN,CG,CG,CG,CG,CG,CN, 
    CG,CG,CG,CG,CN,CG,CG,CG, 


    // grass version 2
    CG,CG,CG,CG,CG,CG,CG,CG, 
    CG,CG,CG,CG,CG,CG,CG,CG, 
    CG,CG,CG,CG,CG,CG,CG,CG, 
    CG,CG,CG,CG,CG,CG,CG,CG, 
    CG,CG,CG,CG,CG,CG,CG,CG, 
    CG,CG,CG,CG,CG,CG,CG,CG, 
    CG,CG,CG,CG,CG,CG,CG,CG, 
    CG,CG,CG,CG,CG,CG,CG,CG, 


    // red/white road marker 1
    CW,CW,CW,CW,CW,CW,CW,CW,
    CW,CW,CW,CW,CW,CW,CW,CW,
    CW,CW,CW,CW,CW,CW,CW,CW,
    CW,CW,CW,CW,CW,CW,CW,CW,
    CR,CR,CR,CR,CR,CR,CR,CR,
    CR,CR,CR,CR,CR,CR,CR,CR,
    CR,CR,CR,CR,CR,CR,CR,CR,
    CR,CR,CR,CR,CR,CR,CR,CR,


    // yellow/gray road marker 2
    CY,CY,CY,CY,CY,CY,CY,CY,
    CY,CY,CY,CY,CY,CY,CY,CY,
    CY,CY,CY,CY,CY,CY,CY,CY,
    CY,CY,CY,CY,CY,CY,CY,CY,
    C2,C2,C2,C2,C2,C2,C2,C2,
    C2,C2,C2,C2,C2,C2,C2,C2,
    C2,C2,C2,C2,C2,C2,C2,C2,
    C2,C2,C2,C2,C2,C2,C2,C2,

    // road 1 no white line
    C5,C5,C5,C5,C5,C5,C5,C5,
    C5,C5,C5,C5,C5,C5,C5,C5,
    C5,C5,C5,C5,C5,C5,C5,C5,
    C5,C5,C5,C5,C5,C5,C5,C5,
    C5,C5,C5,C5,C5,C5,C5,C5,
    C5,C5,C5,C5,C5,C5,C5,C5,
    C5,C5,C5,C5,C5,C5,C5,C5,
    C5,C5,C5,C5,C5,C5,C5,C5,

    // road 2 with white line
    C5,C5,C5,CW,CW,C5,C5,C5,
    C5,C5,C5,CW,CW,C5,C5,C5,
    C5,C5,C5,CW,CW,C5,C5,C5,
    C5,C5,C5,CW,CW,C5,C5,C5,
    C5,C5,C5,CW,CW,C5,C5,C5,
    C5,C5,C5,CW,CW,C5,C5,C5,
    C5,C5,C5,CW,CW,C5,C5,C5,
    C5,C5,C5,CW,CW,C5,C5,C5,

    // road 3 with double yellow line
    C5,CY,CY,C5,C5,CY,CY,C5,
    C5,CY,CY,C5,C5,CY,CY,C5,
    C5,CY,CY,C5,C5,CY,CY,C5,
    C5,CY,CY,C5,C5,CY,CY,C5,
    C5,CY,CY,C5,C5,CY,CY,C5,
    C5,CY,CY,C5,C5,CY,CY,C5,
    C5,CY,CY,C5,C5,CY,CY,C5,
    C5,CY,CY,C5,C5,CY,CY,C5,

    // road 4 with double yellow broken right line
    C5,CY,CY,C5,C5,C5,C5,C5,
    C5,CY,CY,C5,C5,C5,C5,C5,
    C5,CY,CY,C5,C5,C5,C5,C5,
    C5,CY,CY,C5,C5,C5,C5,C5,
    C5,CY,CY,C5,C5,C5,C5,C5,
    C5,CY,CY,C5,C5,C5,C5,C5,
    C5,CY,CY,C5,C5,C5,C5,C5,
    C5,CY,CY,C5,C5,C5,C5,C5,

    // road 5 with double yellow broken left line
    C5,C5,C5,C5,C5,CY,CY,C5,
    C5,C5,C5,C5,C5,CY,CY,C5,
    C5,C5,C5,C5,C5,CY,CY,C5,
    C5,C5,C5,C5,C5,CY,CY,C5,
    C5,C5,C5,C5,C5,CY,CY,C5,
    C5,C5,C5,C5,C5,CY,CY,C5,
    C5,C5,C5,C5,C5,CY,CY,C5,
    C5,C5,C5,C5,C5,CY,CY,C5,


    // rock version 1
    CG,CG,CG,CG,CG,CG,CG,CG,
    CG,CG,CG,CG,CG,CG,CG,CG,
    CG,CG,CG,CG,CG,CG,CG,CG,
    CG,CG,CG,C5,C5,C7,CG,CG,
    CG,C5,C5,C5,C5,C5,C7,CG,
    C5,C5,C5,C5,C5,C5,C5,C7,
    CG,C4,C5,C5,C5,C5,C4,CG,
    C4,C4,C4,C4,C4,C4,CG,CG,


    // oil slick version 1
    C5,C5,C5,C5,C5,C5,C5,C5,
    C5,C5,C3,C3,C3,C5,C5,C5,
    C5,C3,C3,C3,C3,C3,C5,C5,
    C5,C3,C3,C3,C3,C3,C5,C5,
    C3,C3,C3,C3,C3,C3,C3,C5,
    C3,C3,C3,C3,C3,C3,C5,C5,
    C5,C3,C3,C3,C3,C3,C3,C5,
    C5,C5,C3,C3,C3,C3,C5,C5,

};


///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// MAIN ///////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

int main(void)
{
int gamepad;          // used to hold gamepad call results
int x,y,indx,color;   // general working vars
int temp_x, temp_y;   // temps

// initialize the tile map related pointers
// assign the driver's working pointers to our local data structures
tile_map_ptr       = tile_map;
tile_bitmaps_ptr   = tile_bitmaps;

// set up clipping region eventhough, "clipping" is more of a bitmapped rendering concern, the clipping extents
// can be used in various tile and sprite operations in the future, so can't hurt to set up the variables
g_clip_min_x = 0;
g_clip_max_x = SCREEN_WIDTH-1;
g_clip_min_y = 0;
g_clip_max_y = SCREEN_HEIGHT-1;

// initialize rendering real-time variables
g_screen_width  = SCREEN_WIDTH;
g_screen_height = SCREEN_HEIGHT;

// this is new, we need to set up the global tile map width and height, so they are in variable form
g_tile_map_width  = TILE_MAP_WIDTH;
g_tile_map_height = TILE_MAP_HEIGHT;

// set the logical width to the tile map size (no horizontal scrolling this time)
tile_map_logical_width = TILE_MAP_WIDTH;

// initialize the video driver and GFX engine
GFX_Init( VIDEO_INTERRUPT_RATE );

// set the sleeping mode up and enable it
set_sleep_mode( SLEEP_MODE_IDLE );
sleep_enable();

// initialize the gamepad driver, this is not necessary of course, but we are going to use the gamepad to move 
// a sprite around
Gamepad_Init();

// tile engine test
while(1)
    {
    // now goto sleep and wait for interrupt
    sleep_cpu();

    // update everything only during the following time/event...
    if (curr_line >= END_ACTIVE_SCAN && curr_line < (END_ACTIVE_SCAN+2) )
        {
        // read gamepads
        gamepad = Gamepad_Read(GAMEPAD0);

        // move car with gamepade right/left
        if ( gamepad & GAMEPAD_RIGHT ) 
           {
           sprite_table[0].x += 1;
        
           // collision with right wall
           if (sprite_table[0].x >= 114)
              {
              temp_x = RAND_RANGE(1,3);
              sprite_table[0].x -= temp_x;
              } // end if

           } // end if

        if ( gamepad & GAMEPAD_LEFT ) 
           {
           sprite_table[0].x -= 1;

           // collision with right wall
           if (sprite_table[0].x <= 68)
              {
              temp_x = RAND_RANGE(1,3);
              sprite_table[0].x += temp_x;
              } // end if

           } // end if

// NOTE: the vertical scrolling sections below are designed to allow you to play with the scrolling, if we really
// wanted to make a driving game, then this would all be collected into a single function obviously and cleaned up
// and then based on a "speed" variable the system would scrol up or down and at the proper rate. But, the code 
// below allows you to automatically scroll and manually scroll, you can play with the fragments, comment
// things out, etc. The point here is to smooth scroll you use the fine scrolling register until it overflows then
// you reset and course scroll one tile row.

         // this code just scrolls automatically to make it look like the car is driving
         if (--tile_map_vscroll < 0)
            {
            // reset scroll register
            tile_map_vscroll = 7;

            if (tile_map_ptr == tile_map)
                tile_map_ptr = (tile_map + 26*tile_map_logical_width);
        
            // now course scroll vertically
            tile_map_ptr -= tile_map_logical_width;
            } // end if


        // smooth scroll screen vertically with UP/DOWN buttons, act like gas and brakes
        if ( gamepad & GAMEPAD_DOWN)
             {
             if (++tile_map_vscroll > 7)
                {
                // reset scroll register
                tile_map_vscroll = 0;

                // now course scroll vertically
                tile_map_ptr += tile_map_logical_width;

                if (tile_map_ptr >= (tile_map + 26*tile_map_logical_width) )
                   tile_map_ptr = tile_map ;

                } // end if
             } // end if

        if (gamepad & GAMEPAD_UP)
             {
             if (--tile_map_vscroll < 0)
                {
                // reset scroll register
                tile_map_vscroll = 7;

                if (tile_map_ptr == tile_map)
                    tile_map_ptr = (tile_map + 26*tile_map_logical_width);
                
                // now course scroll vertically
                tile_map_ptr -= tile_map_logical_width;
                } // end if

             } // end if

        } // end if video scanline 

     } // end while

} // end main

