///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// 
// Copyright Nurve Networks LLC 2008
// 
// Filename: REM_AVR_NTSC_DOOM_FLOOR_8_V010.S
//
// Original Author: Remi Veilleux
// 
// Last Modified: 02.08.09
// 
// Description: 88x210 resolution NTSC driver floor caster

// The source image is 64x32 'full color' 8-bit
// Perspective texture mapping, floor and ceiling at 60 FPS
// Giving: 88 x 210 = 18480 pixels per screen
// 18480 * 60 = 1108800 texels per second
// However, the C code calculates half scanline perspective per frame
// (not enough CPU clocks available during vblank) 

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// SET PROCESSOR TYPE (must come first)
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#ifndef __AVR_ATmega644__
#define __AVR_ATmega644__
#endif

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// INCLUDES 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
#include <avr/interrupt.h> 
#include <avr/io.h>

#include "REM_AVR_NTSC_DOOM_FLOOR_8_V010.h"
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// DEFINES 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#undef __SFR_OFFSET
#define __SFR_OFFSET 0 // needed for macro, also fixes so you can use register names directly and NOT need macro _SFR_IO_ADDR( x )

// with the current D/A converter range 0 .. 15, 1 = 62mV
#define NTSC_SYNC     (0x0F)     // 0V  
#define NTSC_CBURST0  (0x40)


///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// MACROS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// this macro delays any number of clocks, even 0, up to a maximum of 775
.macro  DELAYX clocks
// Shorter optimized code for short delay:
.if (\clocks) == 0
.elseif (\clocks) == 1
	nop
.elseif  (\clocks) == 2
	ld		r16, X
.elseif  (\clocks) == 3
	ld		r16, X
	nop
.elseif  (\clocks) == 4
	ld		r16, X
	ld		r16, X
.elseif  (\clocks) == 5
	ld		r16, X
	ld		r16, X
	nop
.elseif  (\clocks) == 6
	ld		r16, X
	ld		r16, X
	ld		r16, X
.elseif  (\clocks) == 7
	ld		r16, X
	ld		r16, X
	ld		r16, X
	nop
.elseif  (\clocks) == 8
	call	DELAY_0CLOCK	// 4+4
.elseif  (\clocks) == 9
	call	DELAY_1CLOCK	// 4+4 + 1
.elseif  (\clocks) == 10
	call	DELAY_2CLOCK	// 4+4 + 2
.elseif  (\clocks) >= 11
	// This flexbile delay proc waits a multiple of 3 clocks
    ldi     r16, (\clocks-8)/3        // (0: accounted in brne)
	call	DELAY_VARIABLE3CLOCK	// 4+4
	// Compensate remaining (1 or 2 clocks)
	.if (\clocks-8) % 3 == 1
		nop
	.elseif  (\clocks-8) % 3 == 2
		ld		r16, X
	.endif
.endif
.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// LOCAL INITIALIZED VARIABLES (SRAM)
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.section .data

// This image takes 64 * 32 = 2048 bytes of SRAM
// NOTE: This include MUST BE AT THE START of SRAM because code will assume that
// lo8(rv_avr_rotozoom64x32_v010) is 0
#include "rv_avr_rotozoom64x32_v010.h"

overscan_color:			.byte NTSC_BLACK
.global overscan_color   // read/write: 8-bit NTSC color used for overscan 

hscroll:				.byte 0
.global hscroll

vscroll:				.byte 0
.global vscroll

framecount:				.byte 0,0 // 16-bit UINT frame counter
.global framecount

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// current video line
curr_line:                .byte 0,0    
.global curr_line        // read only, current physical line

// current raster line 0..167
curr_raster_line:         .byte 0
.global curr_raster_line // read only, current logical raster line

.section .bss

// Each array item takes 8 bytes * NTSC_SCREEN_HEIGHT
// NTSC_SCREEN_HEIGHT = 240
// 240 * 8 = 1920 bytes of SRAM
floorlines:					.rept NTSC_SCREEN_HEIGHT
							.byte 0,0 // startx
							.byte 0,0 // add_x
							.byte 0,0 // starty
							.byte 0,0 // add_y
							.endr
.global floorlines

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// ASM FUNCTIONS 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////



.section .text

// asm entry point

.global	TIMER1_COMPA_vect  
TIMER1_COMPA_vect:

Save_Regs:

    // save working registers on stack
    push    r0              // (2)        
    push    r1              // (2)        
    push    r2              // (2)        
    
    push    r16             // (2)
    push    r17             // (2)

    push    r18             // (2)
    push    r19             // (2)

    push    r20             // (2)
    push    r21             // (2)

    push    r22             // (2)
    push    r23             // (2)

    push    r24             // (2)
    push    r25             // (2)

    push    r26             // (2)   X
    push    r27             // (2)

    push    r28             // (2)   Y
    push    r29             // (2)

    push    r30             // (2)   Z
    push    r31             // (2)

    in      r0, SREG        // (2)
    push    r0              // (2) save the status register

                            // (32) clocks for stack push

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

NTSC_Start:

    // load r25:24 with curr_line
    lds     r24, curr_line                  // (2)
    lds     r25, curr_line+1                // (2)      

NTSC_Video_State_Test1:

    // if (curr_line < offset) then NTSC_Draw_Blank_Line
    ldi     r16, hi8(NTSC_VERTICAL_OFFSET)  // (1)
    cpi     r24, lo8(NTSC_VERTICAL_OFFSET)  // (1)
    cpc     r25, r16                        // (1)
    brlo    NTSC_Draw_Blank_Line_Top        // (1/2) NTSC_Start: (9) clocks -> jump, jump need due to code out of range for branch

// elseif
NTSC_Video_State_Test2:    

    // if (curr_line < ( screen height + offset) ) then NTSC_Draw_Active_Line
    ldi     r16, hi8(NTSC_SCREEN_HEIGHT + NTSC_VERTICAL_OFFSET)  // (1) 
    cpi     r24, lo8(NTSC_SCREEN_HEIGHT + NTSC_VERTICAL_OFFSET)  // (1)
    cpc     r25, r16                                             // (1)

    //brlo    NTSC_Draw_Active_Line  // (1/2) 

    brsh    NTSC_Video_State_Test3   // (1/2)
    jmp     NTSC_Draw_Active_Line    // (3)     NTSC_Start: (15) clocks -> jump, jump need due to code out of range for branch

// elseif
NTSC_Video_State_Test3:    

    // if (curr_line < 258) then NTSC_Draw_Blank_Line
    ldi     r16, hi8(258)            // (1) 
    cpi     r24, lo8(258)            // (1)
    cpc     r25, r16                 // (1)
    brlo    NTSC_Draw_Blank_Line_Bot // (1/2)   NTSC_Start: (18) clocks -> jump, jump need due to code out of range for branch

// elseif
NTSC_Video_State_Test4:    

    // if (curr_line < 262) then NTSC_Draw_Vsync_Line
    ldi     r16, hi8(262)            // (1) 
    cpi     r24, lo8(262)            // (1)
    cpc     r25, r16                 // (1)
    brlo    NTSC_Draw_Vsync_Line     // (1/2)   NTSC_Start: (22) clocks -> jump, jump need due to code out of range for branch
    // else should never get here...

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

NTSC_Draw_Blank_Line_Top: 

    // equalize delay from conditional line fork
	DELAYX (18 - 9)


NTSC_Draw_Blank_Line_Bot: 

    // equalize delay from conditional line fork
    DELAYX (22 - 18)

    // enable hsync, set video to black
    ldi     r16, NTSC_SYNC           // (1)
    out     PORTA, r16               // (1)

    // test if this is the top of frame here, we need to initialize the rendering kernel
    // if (curr_line == 0) then NTSC_Reset_Kernel
    ldi     r16, hi8(0)              // (1)
    cpi     r24, lo8(0)              // (1)
    cpc     r25, r16                 // (1)

    // now based on flags set above, jump to normal blank line or reset 
    breq    NTSC_Reset_Kernel        // (1/2)

    // else delay hsync time (this will be filled with processing in later versions)

    // 16 color clocks sync (128 clocks), this needs to be adjusted correctly to take above computation into consideration
    DELAYX (16*CLOCKS_PER_PIXEL + 20)
    
    // disble hsync, maintain black
    ldi     r16, NTSC_BLACK          // (1)
    out     PORTA, r16               // (1)

    // now color burst
    DELAYX (2*CLOCKS_PER_PIXEL)
    
    ldi     r16, NTSC_CBURST0               // (1)
    out     PORTA, r16                      // (1)

    // now color burst
    DELAYX (10*CLOCKS_PER_PIXEL)

    // back to black HSYNC off
    lds     r16, overscan_color             // (2) // RV: added 1 clock here
    out     PORTA, r16                      // (1)

    jmp     NTSC_Next_Line           // (3)    

NTSC_Reset_Kernel:
    // reset all data structures each frame at line 0

    // initialize any variables for algorithm    

    // initialize curr_raster_line for next frame, 
    ldi     r16, 0                           // (1)
    sts     curr_raster_line, r16                 // (2)

    // 16 color clocks sync (128 clocks), this needs to be adjusted correctly to take above computation into consideration
    DELAYX (16*CLOCKS_PER_PIXEL + (20 - 12))

    // disble hsync, maintain black
    ldi     r16, NTSC_BLACK                 // (1)
    out     PORTA, r16                      // (1)

    jmp     NTSC_Next_Line                  // (3)

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  
NTSC_Draw_Vsync_Line:

    // invert hsync and maintain sync for 4-6 lines
    ldi     r16, NTSC_BLACK   // (1)
    out     PORTA, r16        // (1)

    // delay for hsync pulse length 

    // 16 color clocks sync (128 clocks)
    DELAYX (16*CLOCKS_PER_PIXEL)
    
    // disble hsync, but maintain vsync and black
    ldi     r16, NTSC_SYNC   // (1)
    out     PORTA, r16       // (1)

    jmp     NTSC_Next_Line   // (3)

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

// enter
NTSC_Draw_Active_Line:

    // delay to equalize initial line fork
    .rept (22 - 12)
    nop
    .endr

    // enable hsync, set RGB to black (want approximately 16 color clocks for sync
    ldi     r16, NTSC_SYNC                  // (1)
    out     PORTA, r16                      // (1)

	DELAYX (8*16 + 18) // waste some time

    // turn HSYNC off
    ldi     r16, NTSC_BLACK                 // (1)
    out     PORTA, r16                      // (1)

	DELAYX (1*16) // waste some time


    ldi     r16, NTSC_CBURST0               // (1)
    out     PORTA, r16                      // (1)

	DELAYX (5*16) // waste some time


    // back to black HSYNC off
	// RV: Here we can set 'left horizontal overscan' color
    lds     r16, overscan_color                 // (2) RV: added 1 clock here!
    out     PORTA, r16                      // (1)

	DELAYX (3*16) // waste some time

	// r0:r1 = curr_raster_line * 8
    lds     YL, curr_raster_line
	ldi		YH, 8
	mul		YL, YH

	// Fetch 16-bit value from floorlines[curr_raster_line]
    ldi     YL, lo8( floorlines )
    ldi     YH, hi8( floorlines )
	add		YL, r0
	adc		YH, r1

	// r16:r17 = x (16-bit)
	ld		r16, Y+
	ld		r17, Y+

	// r18:r19 = x_add (16-bit)
	ld		r18, Y+
	ld		r19, Y+

	// r22:r23 = y (16-bit)
	ld		r22, Y+
	ld		r23, Y+
	// r26:r27 = y_add (16-bit)
	ld		r26, Y+
	ld		r27, Y+

	// setup some constants: 
	// r29=0
	// r2=64
	// r20:r21 = 16-bit address of rv_avr_floor64x32_v010
	ldi		r29, 0
	ldi		r31, 64
	mov 	r2, r31

	// ultra full screen: almost no horizontal overscan, and no vertical overscan
	// We have about 1326 clocks to display horizontal line

	// total clock per pixel: 15
    .rept 88
		//x += x_add;
		add		r16, r18  // 1
		adc		r17, r19  // 1
		// r17 = ((x>>8)&63)
		andi	r17, 63 // 1

		//y += y_add;
		add		r22, r26  // 1
		adc		r23, r27  // 1
		// r23 = ((y>>8)&31) * src_stride : src_stride is 64
		andi	r23, 31 // 1
		mul		r23, r2 // 2
		// result in r0:r1 

		// add r21 (x) into r0 (y)
		add		r0, r17 // 1
		//adc		r1, r29 // 1 // unneeded: doesn't seem to affect image quality

    	// note: lo8(rv_avr_rotozoom64x32_v010) is assume to be 0
    	ldi     ZH, hi8(rv_avr_rotozoom64x32_v010) // 1
		mov		ZL, r0 // 1
		adc		ZH, r1 // 1

		ld		r0, Z // 2
		out     PORTA, r0 // 1
    .endr 

    // at this point, last pixel must display for n clocks = normal pixel time, do some work, delay the difference

    // delay remainder (pixel time - any work above - time to black below)
    DELAYX (14)

    // set video back to black
    lds     r16, overscan_color             // (2)
    out     PORTA, r16                      // (1)

    // increment curr_raster_line
	lds     r20, curr_raster_line
    inc     r20                             // (1)
    sts     curr_raster_line, r20                // (2)

    jmp     NTSC_Next_Line                  // (3)

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

NTSC_Next_Line:

    // curr_line++
    adiw    r24, 1                 // (2)

    // if (curr_line >= 262) curr_line = 0
    ldi     r16, hi8(262)          // (1) 
    cpi     r24, lo8(262)          // (1)
    cpc     r25, r16               // (1)
    brne    NTSC_End_Line          // (1/2)

    // curr_line = 0
    ldi     r24, 0                 // (1)
    ldi     r25, 0                 // (1)

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

NTSC_End_Line:

    // save registers back to curr_line in SRAM for exit back to C/C++ caller
    sts     curr_line,   r24       // (2)
    sts     curr_line+1, r25       // (2)

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

Restore_Regs:

    // restore the status register
    pop     r0          // (2)
    out     SREG, r0    // (1)        

    // restore working registers
    pop     r31         // (2), Z
    pop     r30         // (2)

    pop     r29         // (2), Y
    pop     r28         // (2)

    pop     r27         // (2), X
    pop     r26         // (2)

    pop     r25         // (2)
    pop     r24         // (2)

    pop     r23         // (2)
    pop     r22         // (2)

    pop     r21         // (2)
    pop     r20         // (2)

    pop     r19         // (2)
    pop     r18         // (2)

    pop     r17         // (2)
    pop     r16         // (2)

    pop     r2          // (2)
    pop     r1          // (2)
    pop     r0          // (2)

  
    reti                // (5) return from interrupt and reset interupt flag, total time of restore 38 clocks for restore

DELAY_2CLOCK:
	nop		// 1
DELAY_1CLOCK:
	nop		// 1
DELAY_0CLOCK:
	ret

DELAY_VARIABLE3CLOCK:
	dec r16 	// 1
	brne DELAY_VARIABLE3CLOCK	// 2
	ret

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// END ASM FUNCTIONS 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
sintable:
// -127 to +127 sintable
//.byte 0,3,6,9,12,15,18,21,24,27,30,33,36,39,42,45,48,51,54,57,59,62,65,67,70,73,75,78,80,82,85,87,89,91,94,96,98,100,102,103,105,107,108,110,112,113,114,116,117,118,119,120,121,122,123,123,124,125,125,126,126,126,126,126,127,126,126,126,126,126,125,125,124,123,123,122,121,120,119,118,117,116,114,113,112,110,108,107,105,103,102,100,98,96,94,91,89,87,85,82,80,78,75,73,70,67,65,62,59,57,54,51,48,45,42,39,36,33,30,27,24,21,18,15,12,9,6,3,0,-3,-6,-9,-12,-15,-18,-21,-24,-27,-30,-33,-36,-39,-42,-45,-48,-51,-54,-57,-59,-62,-65,-67,-70,-73,-75,-78,-80,-82,-85,-87,-89,-91,-94,-96,-98,-100,-102,-103,-105,-107,-108,-110,-112,-113,-114,-116,-117,-118,-119,-120,-121,-122,-123,-123,-124,-125,-125,-126,-126,-126,-126,-126,-127,-126,-126,-126,-126,-126,-125,-125,-124,-123,-123,-122,-121,-120,-119,-118,-117,-116,-114,-113,-112,-110,-108,-107,-105,-103,-102,-100,-98,-96,-94,-91,-89,-87,-85,-82,-80,-78,-75,-73,-70,-67,-65,-62,-59,-57,-54,-51,-48,-45,-42,-39,-36,-33,-30,-27,-24,-21,-18,-15,-12,-9,-6,-3

// -127 to +127 sintable
// Export a 512 elements sintable
.byte 0,1,3,4,6,7,9,10,12,13,15,17,18,20,21,23,24,26,27,29,30,32,33,35,36,38,39,41,42,44,45,47,48,50,51,52,54,55,57,58,59,61,62,63,65,66,67,69,70,71,73,74,75,76,78,79,80,81,82,84,85,86,87,88,89,90,91,93,94,95,96,97,98,99,100,101,102,102,103,104,105,106,107,108,108,109,110,111,112,112,113,114,114,115,116,116,117,117,118,119,119,120,120,121,121,121,122,122,123,123,123,124,124,124,125,125,125,125,126,126,126,126,126,126,126,126,126,126,127,126,126,126,126,126,126,126,126,126,126,125,125,125,125,124,124,124,123,123,123,122,122,121,121,121,120,120,119,119,118,117,117,116,116,115,114,114,113,112,112,111,110,109,108,108,107,106,105,104,103,102,102,101,100,99,98,97,96,95,94,93,91,90,89,88,87,86,85,84,82,81,80,79,78,76,75,74,73,71,70,69,67,66,65,63,62,61,59,58,57,55,54,52,51,50,48,47,45,44,42,41,39,38,36,35,33,32,30,29,27,26,24,23,21,20,18,17,15,13,12,10,9,7,6,4,3,1,0,-1,-3,-4,-6,-7,-9,-10,-12,-13,-15,-17,-18,-20,-21,-23,-24,-26,-27,-29,-30,-32,-33,-35,-36,-38,-39,-41,-42,-44,-45,-47,-48,-50,-51,-52,-54,-55,-57,-58,-59,-61,-62,-63,-65,-66,-67,-69,-70,-71,-73,-74,-75,-76,-78,-79,-80,-81,-82,-84,-85,-86,-87,-88,-89,-90,-91,-93,-94,-95,-96,-97,-98,-99,-100,-101,-102,-102,-103,-104,-105,-106,-107,-108,-108,-109,-110,-111,-112,-112,-113,-114,-114,-115,-116,-116,-117,-117,-118,-119,-119,-120,-120,-121,-121,-121,-122,-122,-123,-123,-123,-124,-124,-124,-125,-125,-125,-125,-126,-126,-126,-126,-126,-126,-126,-126,-126,-126,-127,-126,-126,-126,-126,-126,-126,-126,-126,-126,-126,-125,-125,-125,-125,-124,-124,-124,-123,-123,-123,-122,-122,-121,-121,-121,-120,-120,-119,-119,-118,-117,-117,-116,-116,-115,-114,-114,-113,-112,-112,-111,-110,-109,-108,-108,-107,-106,-105,-104,-103,-102,-102,-101,-100,-99,-98,-97,-96,-95,-94,-93,-91,-90,-89,-88,-87,-86,-85,-84,-82,-81,-80,-79,-78,-76,-75,-74,-73,-71,-70,-69,-67,-66,-65,-63,-62,-61,-59,-58,-57,-55,-54,-52,-51,-50,-48,-47,-45,-44,-42,-41,-39,-38,-36,-35,-33,-32,-30,-29,-27,-26,-24,-23,-21,-20,-18,-17,-15,-13,-12,-10,-9,-7,-6,-4,-3,-1


// 0 to 255 sintable
//.byte 128,131,134,137,140,143,146,149,152,155,158,161,164,167,170,173,176,179,182,185,187,190,193,195,198,201,203,206,208,210,213,215,217,219,222,224,226,228,230,231,233,235,236,238,240,241,242,244,245,246,247,248,249,250,251,251,252,253,253,254,254,254,254,254,255,254,254,254,254,254,253,253,252,251,251,250,249,248,247,246,245,244,242,241,240,238,236,235,233,231,230,228,226,224,222,219,217,215,213,210,208,206,203,201,198,195,193,190,187,185,182,179,176,173,170,167,164,161,158,155,152,149,146,143,140,137,134,131,128,125,122,119,116,113,110,107,104,101,98,95,92,89,86,83,80,77,74,71,69,66,63,61,58,55,53,50,48,46,43,41,39,37,34,32,30,28,26,25,23,21,20,18,16,15,14,12,11,10,9,8,7,6,5,5,4,3,3,2,2,2,2,2,1,2,2,2,2,2,3,3,4,5,5,6,7,8,9,10,11,12,14,15,16,18,20,21,23,25,26,28,30,32,34,37,39,41,43,46,48,50,53,55,58,61,63,66,69,71,74,77,80,83,86,89,92,95,98,101,104,107,110,113,116,119,122,125

.global sintable

// Export a 16384 elements costable
costable:
.word 32767,32766,32766,32766,32766,32766,32766,32766,32766,32766,32766,32766,32766,32766,32766,32766,32766,32766,32766,32766,32766,32765,32765,32765,32765,32765,32765,32765,32765,32764,32764,32764,32764,32764,32764,32764,32763,32763,32763,32763,32763,32762,32762,32762,32762,32762,32761,32761,32761,32761,32760,32760,32760,32760,32759,32759,32759,32759,32758,32758,32758,32758,32757,32757,32757,32756,32756,32756,32755,32755,32755,32754,32754,32754,32753,32753,32753,32752,32752,32751,32751,32751,32750,32750,32750,32749,32749,32748,32748,32747,32747,32747,32746,32746,32745,32745,32744,32744,32743,32743,32742,32742,32741,32741,32740,32740,32739,32739,32738,32738,32737,32737,32736,32736,32735,32735,32734,32734,32733,32732,32732,32731,32731,32730,32729,32729,32728,32728
.word 32727,32726,32726,32725,32725,32724,32723,32723,32722,32721,32721,32720,32719,32719,32718,32717,32717,32716,32715,32714,32714,32713,32712,32712,32711,32710,32709,32709,32708,32707,32706,32706,32705,32704,32703,32703,32702,32701,32700,32699,32699,32698,32697,32696,32695,32694,32694,32693,32692,32691,32690,32689,32688,32688,32687,32686,32685,32684,32683,32682,32681,32680,32680,32679,32678,32677,32676,32675,32674,32673,32672,32671,32670,32669,32668,32667,32666,32665,32664,32663,32662,32661,32660,32659,32658,32657,32656,32655,32654,32653,32652,32651,32650,32649,32648,32647,32646,32645,32644,32642,32641,32640,32639,32638,32637,32636,32635,32634,32632,32631,32630,32629,32628,32627,32625,32624,32623,32622,32621,32620,32618,32617,32616,32615,32614,32612,32611,32610
.word 32609,32607,32606,32605,32604,32602,32601,32600,32599,32597,32596,32595,32594,32592,32591,32590,32588,32587,32586,32584,32583,32582,32580,32579,32578,32576,32575,32574,32572,32571,32570,32568,32567,32565,32564,32563,32561,32560,32558,32557,32556,32554,32553,32551,32550,32548,32547,32546,32544,32543,32541,32540,32538,32537,32535,32534,32532,32531,32529,32528,32526,32525,32523,32522,32520,32519,32517,32515,32514,32512,32511,32509,32508,32506,32504,32503,32501,32500,32498,32496,32495,32493,32492,32490,32488,32487,32485,32483,32482,32480,32478,32477,32475,32473,32472,32470,32468,32467,32465,32463,32462,32460,32458,32456,32455,32453,32451,32450,32448,32446,32444,32443,32441,32439,32437,32435,32434,32432,32430,32428,32426,32425,32423,32421,32419,32417,32416,32414
.word 32412,32410,32408,32406,32404,32403,32401,32399,32397,32395,32393,32391,32389,32387,32386,32384,32382,32380,32378,32376,32374,32372,32370,32368,32366,32364,32362,32360,32358,32356,32354,32352,32350,32348,32346,32344,32342,32340,32338,32336,32334,32332,32330,32328,32326,32324,32322,32320,32318,32316,32314,32312,32310,32307,32305,32303,32301,32299,32297,32295,32293,32291,32288,32286,32284,32282,32280,32278,32275,32273,32271,32269,32267,32265,32262,32260,32258,32256,32254,32251,32249,32247,32245,32242,32240,32238,32236,32233,32231,32229,32227,32224,32222,32220,32218,32215,32213,32211,32208,32206,32204,32201,32199,32197,32194,32192,32190,32187,32185,32183,32180,32178,32176,32173,32171,32168,32166,32164,32161,32159,32156,32154,32152,32149,32147,32144,32142,32139
.word 32137,32134,32132,32130,32127,32125,32122,32120,32117,32115,32112,32110,32107,32105,32102,32100,32097,32095,32092,32089,32087,32084,32082,32079,32077,32074,32072,32069,32066,32064,32061,32059,32056,32053,32051,32048,32046,32043,32040,32038,32035,32032,32030,32027,32024,32022,32019,32016,32014,32011,32008,32006,32003,32000,31998,31995,31992,31989,31987,31984,31981,31979,31976,31973,31970,31968,31965,31962,31959,31957,31954,31951,31948,31945,31943,31940,31937,31934,31931,31929,31926,31923,31920,31917,31914,31911,31909,31906,31903,31900,31897,31894,31891,31889,31886,31883,31880,31877,31874,31871,31868,31865,31862,31859,31856,31854,31851,31848,31845,31842,31839,31836,31833,31830,31827,31824,31821,31818,31815,31812,31809,31806,31803,31800,31797,31794,31791,31788
.word 31785,31781,31778,31775,31772,31769,31766,31763,31760,31757,31754,31751,31748,31744,31741,31738,31735,31732,31729,31726,31723,31719,31716,31713,31710,31707,31704,31700,31697,31694,31691,31688,31684,31681,31678,31675,31672,31668,31665,31662,31659,31655,31652,31649,31646,31642,31639,31636,31633,31629,31626,31623,31619,31616,31613,31610,31606,31603,31600,31596,31593,31590,31586,31583,31580,31576,31573,31569,31566,31563,31559,31556,31553,31549,31546,31542,31539,31536,31532,31529,31525,31522,31518,31515,31512,31508,31505,31501,31498,31494,31491,31487,31484,31480,31477,31473,31470,31466,31463,31459,31456,31452,31449,31445,31442,31438,31435,31431,31428,31424,31420,31417,31413,31410,31406,31403,31399,31395,31392,31388,31385,31381,31377,31374,31370,31366,31363,31359
.word 31356,31352,31348,31345,31341,31337,31334,31330,31326,31323,31319,31315,31311,31308,31304,31300,31297,31293,31289,31285,31282,31278,31274,31270,31267,31263,31259,31255,31252,31248,31244,31240,31236,31233,31229,31225,31221,31217,31214,31210,31206,31202,31198,31194,31191,31187,31183,31179,31175,31171,31167,31164,31160,31156,31152,31148,31144,31140,31136,31132,31128,31124,31121,31117,31113,31109,31105,31101,31097,31093,31089,31085,31081,31077,31073,31069,31065,31061,31057,31053,31049,31045,31041,31037,31033,31029,31025,31021,31017,31013,31009,31005,31001,30996,30992,30988,30984,30980,30976,30972,30968,30964,30960,30955,30951,30947,30943,30939,30935,30931,30927,30922,30918,30914,30910,30906,30902,30897,30893,30889,30885,30881,30876,30872,30868,30864,30860,30855
.word 30851,30847,30843,30838,30834,30830,30826,30821,30817,30813,30809,30804,30800,30796,30791,30787,30783,30778,30774,30770,30766,30761,30757,30753,30748,30744,30739,30735,30731,30726,30722,30718,30713,30709,30705,30700,30696,30691,30687,30683,30678,30674,30669,30665,30660,30656,30652,30647,30643,30638,30634,30629,30625,30620,30616,30611,30607,30602,30598,30593,30589,30584,30580,30575,30571,30566,30562,30557,30553,30548,30544,30539,30535,30530,30525,30521,30516,30512,30507,30503,30498,30493,30489,30484,30480,30475,30470,30466,30461,30456,30452,30447,30442,30438,30433,30429,30424,30419,30415,30410,30405,30400,30396,30391,30386,30382,30377,30372,30368,30363,30358,30353,30349,30344,30339,30334,30330,30325,30320,30315,30311,30306,30301,30296,30291,30287,30282,30277
.word 30272,30267,30263,30258,30253,30248,30243,30238,30234,30229,30224,30219,30214,30209,30205,30200,30195,30190,30185,30180,30175,30170,30165,30160,30156,30151,30146,30141,30136,30131,30126,30121,30116,30111,30106,30101,30096,30091,30086,30081,30076,30071,30066,30061,30056,30051,30046,30041,30036,30031,30026,30021,30016,30011,30006,30001,29996,29991,29986,29981,29976,29971,29966,29961,29955,29950,29945,29940,29935,29930,29925,29920,29915,29909,29904,29899,29894,29889,29884,29879,29873,29868,29863,29858,29853,29848,29842,29837,29832,29827,29822,29816,29811,29806,29801,29795,29790,29785,29780,29774,29769,29764,29759,29753,29748,29743,29738,29732,29727,29722,29717,29711,29706,29701,29695,29690,29685,29679,29674,29669,29663,29658,29653,29647,29642,29637,29631,29626
.word 29621,29615,29610,29604,29599,29594,29588,29583,29577,29572,29567,29561,29556,29550,29545,29539,29534,29529,29523,29518,29512,29507,29501,29496,29490,29485,29479,29474,29468,29463,29457,29452,29446,29441,29435,29430,29424,29419,29413,29408,29402,29397,29391,29385,29380,29374,29369,29363,29358,29352,29346,29341,29335,29330,29324,29318,29313,29307,29302,29296,29290,29285,29279,29273,29268,29262,29256,29251,29245,29239,29234,29228,29222,29217,29211,29205,29200,29194,29188,29183,29177,29171,29165,29160,29154,29148,29142,29137,29131,29125,29119,29114,29108,29102,29096,29091,29085,29079,29073,29067,29062,29056,29050,29044,29038,29033,29027,29021,29015,29009,29003,28997,28992,28986,28980,28974,28968,28962,28956,28951,28945,28939,28933,28927,28921,28915,28909,28903
.word 28897,28891,28886,28880,28874,28868,28862,28856,28850,28844,28838,28832,28826,28820,28814,28808,28802,28796,28790,28784,28778,28772,28766,28760,28754,28748,28742,28736,28730,28724,28718,28712,28706,28700,28694,28687,28681,28675,28669,28663,28657,28651,28645,28639,28633,28627,28620,28614,28608,28602,28596,28590,28584,28578,28571,28565,28559,28553,28547,28541,28534,28528,28522,28516,28510,28503,28497,28491,28485,28479,28472,28466,28460,28454,28447,28441,28435,28429,28423,28416,28410,28404,28397,28391,28385,28379,28372,28366,28360,28353,28347,28341,28335,28328,28322,28316,28309,28303,28297,28290,28284,28278,28271,28265,28259,28252,28246,28239,28233,28227,28220,28214,28208,28201,28195,28188,28182,28176,28169,28163,28156,28150,28143,28137,28131,28124,28118,28111
.word 28105,28098,28092,28085,28079,28072,28066,28059,28053,28046,28040,28033,28027,28020,28014,28007,28001,27994,27988,27981,27975,27968,27962,27955,27948,27942,27935,27929,27922,27916,27909,27902,27896,27889,27883,27876,27869,27863,27856,27850,27843,27836,27830,27823,27816,27810,27803,27797,27790,27783,27777,27770,27763,27757,27750,27743,27736,27730,27723,27716,27710,27703,27696,27690,27683,27676,27669,27663,27656,27649,27642,27636,27629,27622,27615,27609,27602,27595,27588,27582,27575,27568,27561,27554,27548,27541,27534,27527,27520,27513,27507,27500,27493,27486,27479,27472,27466,27459,27452,27445,27438,27431,27424,27418,27411,27404,27397,27390,27383,27376,27369,27362,27355,27349,27342,27335,27328,27321,27314,27307,27300,27293,27286,27279,27272,27265,27258,27251
.word 27244,27237,27230,27223,27216,27209,27202,27195,27188,27181,27174,27167,27160,27153,27146,27139,27132,27125,27118,27111,27104,27097,27090,27083,27076,27068,27061,27054,27047,27040,27033,27026,27019,27012,27005,26997,26990,26983,26976,26969,26962,26955,26948,26940,26933,26926,26919,26912,26905,26897,26890,26883,26876,26869,26861,26854,26847,26840,26833,26825,26818,26811,26804,26797,26789,26782,26775,26768,26760,26753,26746,26739,26731,26724,26717,26709,26702,26695,26688,26680,26673,26666,26658,26651,26644,26636,26629,26622,26615,26607,26600,26593,26585,26578,26570,26563,26556,26548,26541,26534,26526,26519,26512,26504,26497,26489,26482,26475,26467,26460,26452,26445,26437,26430,26423,26415,26408,26400,26393,26385,26378,26371,26363,26356,26348,26341,26333,26326
.word 26318,26311,26303,26296,26288,26281,26273,26266,26258,26251,26243,26236,26228,26221,26213,26205,26198,26190,26183,26175,26168,26160,26153,26145,26137,26130,26122,26115,26107,26099,26092,26084,26077,26069,26061,26054,26046,26039,26031,26023,26016,26008,26000,25993,25985,25977,25970,25962,25954,25947,25939,25931,25924,25916,25908,25901,25893,25885,25878,25870,25862,25854,25847,25839,25831,25824,25816,25808,25800,25793,25785,25777,25769,25762,25754,25746,25738,25730,25723,25715,25707,25699,25691,25684,25676,25668,25660,25652,25645,25637,25629,25621,25613,25605,25598,25590,25582,25574,25566,25558,25550,25543,25535,25527,25519,25511,25503,25495,25487,25480,25472,25464,25456,25448,25440,25432,25424,25416,25408,25400,25392,25384,25376,25369,25361,25353,25345,25337
.word 25329,25321,25313,25305,25297,25289,25281,25273,25265,25257,25249,25241,25233,25225,25217,25209,25201,25193,25185,25177,25169,25161,25152,25144,25136,25128,25120,25112,25104,25096,25088,25080,25072,25064,25056,25047,25039,25031,25023,25015,25007,24999,24991,24983,24974,24966,24958,24950,24942,24934,24926,24917,24909,24901,24893,24885,24877,24868,24860,24852,24844,24836,24827,24819,24811,24803,24795,24786,24778,24770,24762,24753,24745,24737,24729,24720,24712,24704,24696,24687,24679,24671,24663,24654,24646,24638,24630,24621,24613,24605,24596,24588,24580,24571,24563,24555,24546,24538,24530,24521,24513,24505,24496,24488,24480,24471,24463,24455,24446,24438,24430,24421,24413,24404,24396,24388,24379,24371,24362,24354,24346,24337,24329,24320,24312,24304,24295,24287
.word 24278,24270,24261,24253,24244,24236,24228,24219,24211,24202,24194,24185,24177,24168,24160,24151,24143,24134,24126,24117,24109,24100,24092,24083,24075,24066,24058,24049,24041,24032,24023,24015,24006,23998,23989,23981,23972,23964,23955,23946,23938,23929,23921,23912,23903,23895,23886,23878,23869,23860,23852,23843,23835,23826,23817,23809,23800,23791,23783,23774,23766,23757,23748,23740,23731,23722,23714,23705,23696,23688,23679,23670,23661,23653,23644,23635,23627,23618,23609,23601,23592,23583,23574,23566,23557,23548,23539,23531,23522,23513,23504,23496,23487,23478,23469,23461,23452,23443,23434,23426,23417,23408,23399,23390,23382,23373,23364,23355,23346,23337,23329,23320,23311,23302,23293,23284,23276,23267,23258,23249,23240,23231,23223,23214,23205,23196,23187,23178
.word 23169,23160,23151,23143,23134,23125,23116,23107,23098,23089,23080,23071,23062,23053,23045,23036,23027,23018,23009,23000,22991,22982,22973,22964,22955,22946,22937,22928,22919,22910,22901,22892,22883,22874,22865,22856,22847,22838,22829,22820,22811,22802,22793,22784,22775,22766,22757,22748,22739,22730,22721,22712,22703,22694,22685,22675,22666,22657,22648,22639,22630,22621,22612,22603,22594,22585,22575,22566,22557,22548,22539,22530,22521,22512,22502,22493,22484,22475,22466,22457,22448,22438,22429,22420,22411,22402,22393,22383,22374,22365,22356,22347,22338,22328,22319,22310,22301,22292,22282,22273,22264,22255,22245,22236,22227,22218,22209,22199,22190,22181,22172,22162,22153,22144,22135,22125,22116,22107,22097,22088,22079,22070,22060,22051,22042,22032,22023,22014
.word 22004,21995,21986,21977,21967,21958,21949,21939,21930,21921,21911,21902,21893,21883,21874,21864,21855,21846,21836,21827,21818,21808,21799,21789,21780,21771,21761,21752,21743,21733,21724,21714,21705,21695,21686,21677,21667,21658,21648,21639,21629,21620,21611,21601,21592,21582,21573,21563,21554,21544,21535,21525,21516,21506,21497,21488,21478,21469,21459,21450,21440,21431,21421,21412,21402,21392,21383,21373,21364,21354,21345,21335,21326,21316,21307,21297,21288,21278,21268,21259,21249,21240,21230,21221,21211,21202,21192,21182,21173,21163,21154,21144,21134,21125,21115,21106,21096,21086,21077,21067,21057,21048,21038,21029,21019,21009,21000,20990,20980,20971,20961,20951,20942,20932,20922,20913,20903,20893,20884,20874,20864,20855,20845,20835,20825,20816,20806,20796
.word 20787,20777,20767,20758,20748,20738,20728,20719,20709,20699,20689,20680,20670,20660,20650,20641,20631,20621,20611,20602,20592,20582,20572,20562,20553,20543,20533,20523,20513,20504,20494,20484,20474,20464,20455,20445,20435,20425,20415,20406,20396,20386,20376,20366,20356,20346,20337,20327,20317,20307,20297,20287,20277,20268,20258,20248,20238,20228,20218,20208,20198,20188,20179,20169,20159,20149,20139,20129,20119,20109,20099,20089,20079,20070,20060,20050,20040,20030,20020,20010,20000,19990,19980,19970,19960,19950,19940,19930,19920,19910,19900,19890,19880,19870,19860,19850,19840,19830,19820,19810,19800,19790,19780,19770,19760,19750,19740,19730,19720,19710,19700,19690,19680,19670,19660,19650,19640,19630,19620,19610,19599,19589,19579,19569,19559,19549,19539,19529
.word 19519,19509,19499,19488,19478,19468,19458,19448,19438,19428,19418,19408,19397,19387,19377,19367,19357,19347,19337,19326,19316,19306,19296,19286,19276,19266,19255,19245,19235,19225,19215,19205,19194,19184,19174,19164,19154,19143,19133,19123,19113,19103,19092,19082,19072,19062,19051,19041,19031,19021,19011,19000,18990,18980,18970,18959,18949,18939,18929,18918,18908,18898,18888,18877,18867,18857,18846,18836,18826,18816,18805,18795,18785,18774,18764,18754,18744,18733,18723,18713,18702,18692,18682,18671,18661,18651,18640,18630,18620,18609,18599,18589,18578,18568,18558,18547,18537,18526,18516,18506,18495,18485,18475,18464,18454,18443,18433,18423,18412,18402,18392,18381,18371,18360,18350,18339,18329,18319,18308,18298,18287,18277,18267,18256,18246,18235,18225,18214
.word 18204,18193,18183,18173,18162,18152,18141,18131,18120,18110,18099,18089,18078,18068,18057,18047,18036,18026,18015,18005,17994,17984,17973,17963,17952,17942,17931,17921,17910,17900,17889,17879,17868,17858,17847,17837,17826,17815,17805,17794,17784,17773,17763,17752,17742,17731,17720,17710,17699,17689,17678,17668,17657,17646,17636,17625,17615,17604,17593,17583,17572,17562,17551,17540,17530,17519,17509,17498,17487,17477,17466,17455,17445,17434,17423,17413,17402,17392,17381,17370,17360,17349,17338,17328,17317,17306,17296,17285,17274,17264,17253,17242,17232,17221,17210,17199,17189,17178,17167,17157,17146,17135,17124,17114,17103,17092,17082,17071,17060,17049,17039,17028,17017,17006,16996,16985,16974,16964,16953,16942,16931,16920,16910,16899,16888,16877,16867,16856
.word 16845,16834,16824,16813,16802,16791,16780,16770,16759,16748,16737,16726,16716,16705,16694,16683,16672,16662,16651,16640,16629,16618,16607,16597,16586,16575,16564,16553,16542,16532,16521,16510,16499,16488,16477,16466,16455,16445,16434,16423,16412,16401,16390,16379,16368,16358,16347,16336,16325,16314,16303,16292,16281,16270,16260,16249,16238,16227,16216,16205,16194,16183,16172,16161,16150,16139,16128,16117,16107,16096,16085,16074,16063,16052,16041,16030,16019,16008,15997,15986,15975,15964,15953,15942,15931,15920,15909,15898,15887,15876,15865,15854,15843,15832,15821,15810,15799,15788,15777,15766,15755,15744,15733,15722,15711,15700,15689,15678,15667,15656,15645,15634,15623,15612,15601,15590,15579,15568,15556,15545,15534,15523,15512,15501,15490,15479,15468,15457
.word 15446,15435,15424,15412,15401,15390,15379,15368,15357,15346,15335,15324,15313,15301,15290,15279,15268,15257,15246,15235,15224,15213,15201,15190,15179,15168,15157,15146,15135,15123,15112,15101,15090,15079,15068,15056,15045,15034,15023,15012,15001,14989,14978,14967,14956,14945,14934,14922,14911,14900,14889,14878,14866,14855,14844,14833,14822,14810,14799,14788,14777,14766,14754,14743,14732,14721,14709,14698,14687,14676,14665,14653,14642,14631,14620,14608,14597,14586,14575,14563,14552,14541,14530,14518,14507,14496,14484,14473,14462,14451,14439,14428,14417,14406,14394,14383,14372,14360,14349,14338,14326,14315,14304,14293,14281,14270,14259,14247,14236,14225,14213,14202,14191,14179,14168,14157,14145,14134,14123,14111,14100,14089,14077,14066,14055,14043,14032,14021
.word 14009,13998,13986,13975,13964,13952,13941,13930,13918,13907,13895,13884,13873,13861,13850,13839,13827,13816,13804,13793,13782,13770,13759,13747,13736,13725,13713,13702,13690,13679,13667,13656,13645,13633,13622,13610,13599,13587,13576,13565,13553,13542,13530,13519,13507,13496,13485,13473,13462,13450,13439,13427,13416,13404,13393,13381,13370,13358,13347,13335,13324,13312,13301,13290,13278,13267,13255,13244,13232,13221,13209,13198,13186,13175,13163,13152,13140,13129,13117,13106,13094,13082,13071,13059,13048,13036,13025,13013,13002,12990,12979,12967,12956,12944,12933,12921,12909,12898,12886,12875,12863,12852,12840,12829,12817,12805,12794,12782,12771,12759,12748,12736,12724,12713,12701,12690,12678,12666,12655,12643,12632,12620,12609,12597,12585,12574,12562,12550
.word 12539,12527,12516,12504,12492,12481,12469,12458,12446,12434,12423,12411,12399,12388,12376,12365,12353,12341,12330,12318,12306,12295,12283,12271,12260,12248,12236,12225,12213,12201,12190,12178,12166,12155,12143,12131,12120,12108,12096,12085,12073,12061,12050,12038,12026,12015,12003,11991,11980,11968,11956,11944,11933,11921,11909,11898,11886,11874,11862,11851,11839,11827,11816,11804,11792,11780,11769,11757,11745,11734,11722,11710,11698,11687,11675,11663,11651,11640,11628,11616,11604,11593,11581,11569,11557,11546,11534,11522,11510,11499,11487,11475,11463,11451,11440,11428,11416,11404,11393,11381,11369,11357,11345,11334,11322,11310,11298,11286,11275,11263,11251,11239,11227,11216,11204,11192,11180,11168,11157,11145,11133,11121,11109,11098,11086,11074,11062,11050
.word 11038,11027,11015,11003,10991,10979,10967,10956,10944,10932,10920,10908,10896,10884,10873,10861,10849,10837,10825,10813,10801,10790,10778,10766,10754,10742,10730,10718,10706,10695,10683,10671,10659,10647,10635,10623,10611,10600,10588,10576,10564,10552,10540,10528,10516,10504,10492,10481,10469,10457,10445,10433,10421,10409,10397,10385,10373,10361,10349,10338,10326,10314,10302,10290,10278,10266,10254,10242,10230,10218,10206,10194,10182,10170,10159,10147,10135,10123,10111,10099,10087,10075,10063,10051,10039,10027,10015,10003,9991,9979,9967,9955,9943,9931,9919,9907,9895,9883,9871,9859,9847,9835,9823,9811,9799,9787,9775,9763,9751,9739,9727,9715,9703,9691,9679,9667,9655,9643,9631,9619,9607,9595,9583,9571,9559,9547,9535,9523
.word 9511,9499,9487,9475,9463,9451,9439,9427,9415,9403,9391,9379,9367,9355,9343,9331,9319,9307,9295,9283,9270,9258,9246,9234,9222,9210,9198,9186,9174,9162,9150,9138,9126,9114,9102,9090,9077,9065,9053,9041,9029,9017,9005,8993,8981,8969,8957,8945,8932,8920,8908,8896,8884,8872,8860,8848,8836,8824,8812,8799,8787,8775,8763,8751,8739,8727,8715,8703,8690,8678,8666,8654,8642,8630,8618,8606,8593,8581,8569,8557,8545,8533,8521,8509,8496,8484,8472,8460,8448,8436,8424,8411,8399,8387,8375,8363,8351,8339,8326,8314,8302,8290,8278,8266,8253,8241,8229,8217,8205,8193,8180,8168,8156,8144,8132,8120,8107,8095,8083,8071,8059,8047,8034,8022,8010,7998,7986,7973
.word 7961,7949,7937,7925,7912,7900,7888,7876,7864,7851,7839,7827,7815,7803,7790,7778,7766,7754,7742,7729,7717,7705,7693,7681,7668,7656,7644,7632,7619,7607,7595,7583,7571,7558,7546,7534,7522,7509,7497,7485,7473,7461,7448,7436,7424,7412,7399,7387,7375,7363,7350,7338,7326,7314,7301,7289,7277,7265,7252,7240,7228,7216,7203,7191,7179,7167,7154,7142,7130,7117,7105,7093,7081,7068,7056,7044,7032,7019,7007,6995,6982,6970,6958,6946,6933,6921,6909,6897,6884,6872,6860,6847,6835,6823,6811,6798,6786,6774,6761,6749,6737,6724,6712,6700,6688,6675,6663,6651,6638,6626,6614,6601,6589,6577,6564,6552,6540,6528,6515,6503,6491,6478,6466,6454,6441,6429,6417,6404
.word 6392,6380,6367,6355,6343,6330,6318,6306,6293,6281,6269,6256,6244,6232,6219,6207,6195,6182,6170,6158,6145,6133,6121,6108,6096,6084,6071,6059,6047,6034,6022,6010,5997,5985,5972,5960,5948,5935,5923,5911,5898,5886,5874,5861,5849,5836,5824,5812,5799,5787,5775,5762,5750,5738,5725,5713,5700,5688,5676,5663,5651,5639,5626,5614,5601,5589,5577,5564,5552,5539,5527,5515,5502,5490,5478,5465,5453,5440,5428,5416,5403,5391,5378,5366,5354,5341,5329,5316,5304,5292,5279,5267,5254,5242,5230,5217,5205,5192,5180,5168,5155,5143,5130,5118,5106,5093,5081,5068,5056,5043,5031,5019,5006,4994,4981,4969,4957,4944,4932,4919,4907,4894,4882,4870,4857,4845,4832,4820
.word 4807,4795,4783,4770,4758,4745,4733,4720,4708,4696,4683,4671,4658,4646,4633,4621,4608,4596,4584,4571,4559,4546,4534,4521,4509,4496,4484,4472,4459,4447,4434,4422,4409,4397,4384,4372,4359,4347,4335,4322,4310,4297,4285,4272,4260,4247,4235,4222,4210,4198,4185,4173,4160,4148,4135,4123,4110,4098,4085,4073,4060,4048,4035,4023,4011,3998,3986,3973,3961,3948,3936,3923,3911,3898,3886,3873,3861,3848,3836,3823,3811,3798,3786,3773,3761,3748,3736,3724,3711,3699,3686,3674,3661,3649,3636,3624,3611,3599,3586,3574,3561,3549,3536,3524,3511,3499,3486,3474,3461,3449,3436,3424,3411,3399,3386,3374,3361,3349,3336,3324,3311,3299,3286,3274,3261,3249,3236,3224
.word 3211,3199,3186,3174,3161,3149,3136,3124,3111,3099,3086,3074,3061,3049,3036,3024,3011,2999,2986,2974,2961,2949,2936,2923,2911,2898,2886,2873,2861,2848,2836,2823,2811,2798,2786,2773,2761,2748,2736,2723,2711,2698,2686,2673,2661,2648,2636,2623,2610,2598,2585,2573,2560,2548,2535,2523,2510,2498,2485,2473,2460,2448,2435,2423,2410,2397,2385,2372,2360,2347,2335,2322,2310,2297,2285,2272,2260,2247,2235,2222,2209,2197,2184,2172,2159,2147,2134,2122,2109,2097,2084,2072,2059,2046,2034,2021,2009,1996,1984,1971,1959,1946,1934,1921,1908,1896,1883,1871,1858,1846,1833,1821,1808,1796,1783,1770,1758,1745,1733,1720,1708,1695,1683,1670,1658,1645,1632,1620
.word 1607,1595,1582,1570,1557,1545,1532,1519,1507,1494,1482,1469,1457,1444,1432,1419,1406,1394,1381,1369,1356,1344,1331,1319,1306,1293,1281,1268,1256,1243,1231,1218,1206,1193,1180,1168,1155,1143,1130,1118,1105,1093,1080,1067,1055,1042,1030,1017,1005,992,979,967,954,942,929,917,904,892,879,866,854,841,829,816,804,791,779,766,753,741,728,716,703,691,678,665,653,640,628,615,603,590,578,565,552,540,527,515,502,490,477,464,452,439,427,414,402,389,376,364,351,339,326,314,301,289,276,263,251,238,226,213,201,188,175,163,150,138,125,113,100,87,75,62,50,37,25,12
.word 0,-12,-25,-37,-50,-62,-75,-87,-100,-113,-125,-138,-150,-163,-175,-188,-201,-213,-226,-238,-251,-263,-276,-289,-301,-314,-326,-339,-351,-364,-376,-389,-402,-414,-427,-439,-452,-464,-477,-490,-502,-515,-527,-540,-552,-565,-578,-590,-603,-615,-628,-640,-653,-665,-678,-691,-703,-716,-728,-741,-753,-766,-779,-791,-804,-816,-829,-841,-854,-866,-879,-892,-904,-917,-929,-942,-954,-967,-980,-992,-1005,-1017,-1030,-1042,-1055,-1067,-1080,-1093,-1105,-1118,-1130,-1143,-1155,-1168,-1180,-1193,-1206,-1218,-1231,-1243,-1256,-1268,-1281,-1293,-1306,-1319,-1331,-1344,-1356,-1369,-1381,-1394,-1406,-1419,-1432,-1444,-1457,-1469,-1482,-1494,-1507,-1519,-1532,-1545,-1557,-1570,-1582,-1595
.word -1607,-1620,-1632,-1645,-1658,-1670,-1683,-1695,-1708,-1720,-1733,-1745,-1758,-1770,-1783,-1796,-1808,-1821,-1833,-1846,-1858,-1871,-1883,-1896,-1908,-1921,-1934,-1946,-1959,-1971,-1984,-1996,-2009,-2021,-2034,-2046,-2059,-2072,-2084,-2097,-2109,-2122,-2134,-2147,-2159,-2172,-2184,-2197,-2209,-2222,-2235,-2247,-2260,-2272,-2285,-2297,-2310,-2322,-2335,-2347,-2360,-2372,-2385,-2397,-2410,-2423,-2435,-2448,-2460,-2473,-2485,-2498,-2510,-2523,-2535,-2548,-2560,-2573,-2585,-2598,-2610,-2623,-2636,-2648,-2661,-2673,-2686,-2698,-2711,-2723,-2736,-2748,-2761,-2773,-2786,-2798,-2811,-2823,-2836,-2848,-2861,-2873,-2886,-2898,-2911,-2923,-2936,-2949,-2961,-2974,-2986,-2999,-3011,-3024,-3036,-3049,-3061,-3074,-3086,-3099,-3111,-3124,-3136,-3149,-3161,-3174,-3186,-3199
.word -3211,-3224,-3236,-3249,-3261,-3274,-3286,-3299,-3311,-3324,-3336,-3349,-3361,-3374,-3386,-3399,-3411,-3424,-3436,-3449,-3461,-3474,-3486,-3499,-3511,-3524,-3536,-3549,-3561,-3574,-3586,-3599,-3611,-3624,-3636,-3649,-3661,-3674,-3686,-3699,-3711,-3724,-3736,-3749,-3761,-3773,-3786,-3798,-3811,-3823,-3836,-3848,-3861,-3873,-3886,-3898,-3911,-3923,-3936,-3948,-3961,-3973,-3986,-3998,-4011,-4023,-4035,-4048,-4060,-4073,-4085,-4098,-4110,-4123,-4135,-4148,-4160,-4173,-4185,-4198,-4210,-4222,-4235,-4247,-4260,-4272,-4285,-4297,-4310,-4322,-4335,-4347,-4359,-4372,-4384,-4397,-4409,-4422,-4434,-4447,-4459,-4472,-4484,-4496,-4509,-4521,-4534,-4546,-4559,-4571,-4584,-4596,-4608,-4621,-4633,-4646,-4658,-4671,-4683,-4696,-4708,-4720,-4733,-4745,-4758,-4770,-4783,-4795
.word -4807,-4820,-4832,-4845,-4857,-4870,-4882,-4894,-4907,-4919,-4932,-4944,-4957,-4969,-4981,-4994,-5006,-5019,-5031,-5043,-5056,-5068,-5081,-5093,-5106,-5118,-5130,-5143,-5155,-5168,-5180,-5192,-5205,-5217,-5230,-5242,-5254,-5267,-5279,-5292,-5304,-5316,-5329,-5341,-5354,-5366,-5378,-5391,-5403,-5416,-5428,-5440,-5453,-5465,-5478,-5490,-5502,-5515,-5527,-5539,-5552,-5564,-5577,-5589,-5601,-5614,-5626,-5639,-5651,-5663,-5676,-5688,-5700,-5713,-5725,-5738,-5750,-5762,-5775,-5787,-5799,-5812,-5824,-5836,-5849,-5861,-5874,-5886,-5898,-5911,-5923,-5935,-5948,-5960,-5972,-5985,-5997,-6010,-6022,-6034,-6047,-6059,-6071,-6084,-6096,-6108,-6121,-6133,-6145,-6158,-6170,-6182,-6195,-6207,-6219,-6232,-6244,-6256,-6269,-6281,-6293,-6306,-6318,-6330,-6343,-6355,-6367,-6380
.word -6392,-6404,-6417,-6429,-6441,-6454,-6466,-6478,-6491,-6503,-6515,-6528,-6540,-6552,-6564,-6577,-6589,-6601,-6614,-6626,-6638,-6651,-6663,-6675,-6688,-6700,-6712,-6724,-6737,-6749,-6761,-6774,-6786,-6798,-6811,-6823,-6835,-6847,-6860,-6872,-6884,-6897,-6909,-6921,-6933,-6946,-6958,-6970,-6982,-6995,-7007,-7019,-7032,-7044,-7056,-7068,-7081,-7093,-7105,-7117,-7130,-7142,-7154,-7167,-7179,-7191,-7203,-7216,-7228,-7240,-7252,-7265,-7277,-7289,-7301,-7314,-7326,-7338,-7350,-7363,-7375,-7387,-7399,-7412,-7424,-7436,-7448,-7461,-7473,-7485,-7497,-7509,-7522,-7534,-7546,-7558,-7571,-7583,-7595,-7607,-7619,-7632,-7644,-7656,-7668,-7681,-7693,-7705,-7717,-7729,-7742,-7754,-7766,-7778,-7790,-7803,-7815,-7827,-7839,-7851,-7864,-7876,-7888,-7900,-7912,-7925,-7937,-7949
.word -7961,-7973,-7986,-7998,-8010,-8022,-8034,-8047,-8059,-8071,-8083,-8095,-8107,-8120,-8132,-8144,-8156,-8168,-8180,-8193,-8205,-8217,-8229,-8241,-8253,-8266,-8278,-8290,-8302,-8314,-8326,-8339,-8351,-8363,-8375,-8387,-8399,-8411,-8424,-8436,-8448,-8460,-8472,-8484,-8496,-8509,-8521,-8533,-8545,-8557,-8569,-8581,-8593,-8606,-8618,-8630,-8642,-8654,-8666,-8678,-8690,-8703,-8715,-8727,-8739,-8751,-8763,-8775,-8787,-8799,-8812,-8824,-8836,-8848,-8860,-8872,-8884,-8896,-8908,-8920,-8932,-8945,-8957,-8969,-8981,-8993,-9005,-9017,-9029,-9041,-9053,-9065,-9077,-9090,-9102,-9114,-9126,-9138,-9150,-9162,-9174,-9186,-9198,-9210,-9222,-9234,-9246,-9258,-9270,-9283,-9295,-9307,-9319,-9331,-9343,-9355,-9367,-9379,-9391,-9403,-9415,-9427,-9439,-9451,-9463,-9475,-9487,-9499
.word -9511,-9523,-9535,-9547,-9559,-9571,-9583,-9595,-9607,-9619,-9631,-9643,-9655,-9667,-9679,-9691,-9703,-9715,-9727,-9739,-9751,-9763,-9775,-9787,-9799,-9811,-9823,-9835,-9847,-9859,-9871,-9883,-9895,-9907,-9919,-9931,-9943,-9955,-9967,-9979,-9991,-10003,-10015,-10027,-10039,-10051,-10063,-10075,-10087,-10099,-10111,-10123,-10135,-10147,-10159,-10170,-10182,-10194,-10206,-10218,-10230,-10242,-10254,-10266,-10278,-10290,-10302,-10314,-10326,-10338,-10349,-10361,-10373,-10385,-10397,-10409,-10421,-10433,-10445,-10457,-10469,-10481,-10492,-10504,-10516,-10528,-10540,-10552,-10564,-10576,-10588,-10600,-10611,-10623,-10635,-10647,-10659,-10671,-10683,-10695,-10706,-10718,-10730,-10742,-10754,-10766,-10778,-10790,-10801,-10813,-10825,-10837,-10849,-10861,-10873,-10884,-10896,-10908,-10920,-10932,-10944,-10956,-10967,-10979,-10991,-11003,-11015,-11027
.word -11038,-11050,-11062,-11074,-11086,-11098,-11109,-11121,-11133,-11145,-11157,-11168,-11180,-11192,-11204,-11216,-11227,-11239,-11251,-11263,-11275,-11286,-11298,-11310,-11322,-11334,-11345,-11357,-11369,-11381,-11393,-11404,-11416,-11428,-11440,-11451,-11463,-11475,-11487,-11499,-11510,-11522,-11534,-11546,-11557,-11569,-11581,-11593,-11604,-11616,-11628,-11640,-11651,-11663,-11675,-11687,-11698,-11710,-11722,-11734,-11745,-11757,-11769,-11780,-11792,-11804,-11816,-11827,-11839,-11851,-11862,-11874,-11886,-11898,-11909,-11921,-11933,-11944,-11956,-11968,-11980,-11991,-12003,-12015,-12026,-12038,-12050,-12061,-12073,-12085,-12096,-12108,-12120,-12131,-12143,-12155,-12166,-12178,-12190,-12201,-12213,-12225,-12236,-12248,-12260,-12271,-12283,-12295,-12306,-12318,-12330,-12341,-12353,-12365,-12376,-12388,-12399,-12411,-12423,-12434,-12446,-12458,-12469,-12481,-12492,-12504,-12516,-12527
.word -12539,-12550,-12562,-12574,-12585,-12597,-12609,-12620,-12632,-12643,-12655,-12666,-12678,-12690,-12701,-12713,-12724,-12736,-12748,-12759,-12771,-12782,-12794,-12805,-12817,-12829,-12840,-12852,-12863,-12875,-12886,-12898,-12909,-12921,-12933,-12944,-12956,-12967,-12979,-12990,-13002,-13013,-13025,-13036,-13048,-13059,-13071,-13082,-13094,-13106,-13117,-13129,-13140,-13152,-13163,-13175,-13186,-13198,-13209,-13221,-13232,-13244,-13255,-13267,-13278,-13290,-13301,-13312,-13324,-13335,-13347,-13358,-13370,-13381,-13393,-13404,-13416,-13427,-13439,-13450,-13462,-13473,-13485,-13496,-13507,-13519,-13530,-13542,-13553,-13565,-13576,-13588,-13599,-13610,-13622,-13633,-13645,-13656,-13667,-13679,-13690,-13702,-13713,-13725,-13736,-13747,-13759,-13770,-13782,-13793,-13804,-13816,-13827,-13839,-13850,-13861,-13873,-13884,-13895,-13907,-13918,-13930,-13941,-13952,-13964,-13975,-13986,-13998
.word -14009,-14021,-14032,-14043,-14055,-14066,-14077,-14089,-14100,-14111,-14123,-14134,-14145,-14157,-14168,-14179,-14191,-14202,-14213,-14225,-14236,-14247,-14259,-14270,-14281,-14293,-14304,-14315,-14326,-14338,-14349,-14360,-14372,-14383,-14394,-14406,-14417,-14428,-14439,-14451,-14462,-14473,-14484,-14496,-14507,-14518,-14530,-14541,-14552,-14563,-14575,-14586,-14597,-14608,-14620,-14631,-14642,-14653,-14665,-14676,-14687,-14698,-14709,-14721,-14732,-14743,-14754,-14766,-14777,-14788,-14799,-14810,-14822,-14833,-14844,-14855,-14866,-14878,-14889,-14900,-14911,-14922,-14934,-14945,-14956,-14967,-14978,-14989,-15001,-15012,-15023,-15034,-15045,-15056,-15068,-15079,-15090,-15101,-15112,-15123,-15135,-15146,-15157,-15168,-15179,-15190,-15201,-15213,-15224,-15235,-15246,-15257,-15268,-15279,-15290,-15301,-15313,-15324,-15335,-15346,-15357,-15368,-15379,-15390,-15401,-15413,-15424,-15435
.word -15446,-15457,-15468,-15479,-15490,-15501,-15512,-15523,-15534,-15545,-15556,-15568,-15579,-15590,-15601,-15612,-15623,-15634,-15645,-15656,-15667,-15678,-15689,-15700,-15711,-15722,-15733,-15744,-15755,-15766,-15777,-15788,-15799,-15810,-15821,-15832,-15843,-15854,-15865,-15876,-15887,-15898,-15909,-15920,-15931,-15942,-15953,-15964,-15975,-15986,-15997,-16008,-16019,-16030,-16041,-16052,-16063,-16074,-16085,-16096,-16107,-16117,-16128,-16139,-16150,-16161,-16172,-16183,-16194,-16205,-16216,-16227,-16238,-16249,-16260,-16270,-16281,-16292,-16303,-16314,-16325,-16336,-16347,-16358,-16368,-16379,-16390,-16401,-16412,-16423,-16434,-16445,-16455,-16466,-16477,-16488,-16499,-16510,-16521,-16532,-16542,-16553,-16564,-16575,-16586,-16597,-16607,-16618,-16629,-16640,-16651,-16662,-16672,-16683,-16694,-16705,-16716,-16726,-16737,-16748,-16759,-16770,-16780,-16791,-16802,-16813,-16824,-16834
.word -16845,-16856,-16867,-16877,-16888,-16899,-16910,-16920,-16931,-16942,-16953,-16964,-16974,-16985,-16996,-17007,-17017,-17028,-17039,-17049,-17060,-17071,-17082,-17092,-17103,-17114,-17124,-17135,-17146,-17157,-17167,-17178,-17189,-17199,-17210,-17221,-17232,-17242,-17253,-17264,-17274,-17285,-17296,-17306,-17317,-17328,-17338,-17349,-17360,-17370,-17381,-17392,-17402,-17413,-17423,-17434,-17445,-17455,-17466,-17477,-17487,-17498,-17509,-17519,-17530,-17540,-17551,-17562,-17572,-17583,-17593,-17604,-17615,-17625,-17636,-17646,-17657,-17668,-17678,-17689,-17699,-17710,-17720,-17731,-17742,-17752,-17763,-17773,-17784,-17794,-17805,-17815,-17826,-17837,-17847,-17858,-17868,-17879,-17889,-17900,-17910,-17921,-17931,-17942,-17952,-17963,-17973,-17984,-17994,-18005,-18015,-18026,-18036,-18047,-18057,-18068,-18078,-18089,-18099,-18110,-18120,-18131,-18141,-18152,-18162,-18173,-18183,-18193
.word -18204,-18214,-18225,-18235,-18246,-18256,-18267,-18277,-18287,-18298,-18308,-18319,-18329,-18339,-18350,-18360,-18371,-18381,-18392,-18402,-18412,-18423,-18433,-18443,-18454,-18464,-18475,-18485,-18495,-18506,-18516,-18526,-18537,-18547,-18558,-18568,-18578,-18589,-18599,-18609,-18620,-18630,-18640,-18651,-18661,-18671,-18682,-18692,-18702,-18713,-18723,-18733,-18744,-18754,-18764,-18774,-18785,-18795,-18805,-18816,-18826,-18836,-18846,-18857,-18867,-18877,-18888,-18898,-18908,-18918,-18929,-18939,-18949,-18959,-18970,-18980,-18990,-19000,-19011,-19021,-19031,-19041,-19051,-19062,-19072,-19082,-19092,-19103,-19113,-19123,-19133,-19143,-19154,-19164,-19174,-19184,-19194,-19205,-19215,-19225,-19235,-19245,-19255,-19266,-19276,-19286,-19296,-19306,-19316,-19326,-19337,-19347,-19357,-19367,-19377,-19387,-19397,-19408,-19418,-19428,-19438,-19448,-19458,-19468,-19478,-19488,-19499,-19509
.word -19519,-19529,-19539,-19549,-19559,-19569,-19579,-19589,-19599,-19609,-19620,-19630,-19640,-19650,-19660,-19670,-19680,-19690,-19700,-19710,-19720,-19730,-19740,-19750,-19760,-19770,-19780,-19790,-19800,-19810,-19820,-19830,-19840,-19850,-19860,-19870,-19880,-19890,-19900,-19910,-19920,-19930,-19940,-19950,-19960,-19970,-19980,-19990,-20000,-20010,-20020,-20030,-20040,-20050,-20060,-20070,-20079,-20089,-20099,-20109,-20119,-20129,-20139,-20149,-20159,-20169,-20179,-20188,-20198,-20208,-20218,-20228,-20238,-20248,-20258,-20268,-20277,-20287,-20297,-20307,-20317,-20327,-20337,-20346,-20356,-20366,-20376,-20386,-20396,-20406,-20415,-20425,-20435,-20445,-20455,-20464,-20474,-20484,-20494,-20504,-20513,-20523,-20533,-20543,-20553,-20562,-20572,-20582,-20592,-20602,-20611,-20621,-20631,-20641,-20650,-20660,-20670,-20680,-20689,-20699,-20709,-20719,-20728,-20738,-20748,-20758,-20767,-20777
.word -20787,-20796,-20806,-20816,-20825,-20835,-20845,-20855,-20864,-20874,-20884,-20893,-20903,-20913,-20922,-20932,-20942,-20951,-20961,-20971,-20980,-20990,-21000,-21009,-21019,-21029,-21038,-21048,-21057,-21067,-21077,-21086,-21096,-21106,-21115,-21125,-21134,-21144,-21154,-21163,-21173,-21182,-21192,-21202,-21211,-21221,-21230,-21240,-21249,-21259,-21268,-21278,-21288,-21297,-21307,-21316,-21326,-21335,-21345,-21354,-21364,-21373,-21383,-21393,-21402,-21412,-21421,-21431,-21440,-21450,-21459,-21469,-21478,-21488,-21497,-21506,-21516,-21525,-21535,-21544,-21554,-21563,-21573,-21582,-21592,-21601,-21611,-21620,-21629,-21639,-21648,-21658,-21667,-21677,-21686,-21695,-21705,-21714,-21724,-21733,-21743,-21752,-21761,-21771,-21780,-21789,-21799,-21808,-21818,-21827,-21836,-21846,-21855,-21864,-21874,-21883,-21893,-21902,-21911,-21921,-21930,-21939,-21949,-21958,-21967,-21977,-21986,-21995
.word -22004,-22014,-22023,-22032,-22042,-22051,-22060,-22070,-22079,-22088,-22097,-22107,-22116,-22125,-22135,-22144,-22153,-22162,-22172,-22181,-22190,-22199,-22209,-22218,-22227,-22236,-22245,-22255,-22264,-22273,-22282,-22292,-22301,-22310,-22319,-22328,-22338,-22347,-22356,-22365,-22374,-22383,-22393,-22402,-22411,-22420,-22429,-22438,-22448,-22457,-22466,-22475,-22484,-22493,-22503,-22512,-22521,-22530,-22539,-22548,-22557,-22566,-22575,-22585,-22594,-22603,-22612,-22621,-22630,-22639,-22648,-22657,-22666,-22675,-22685,-22694,-22703,-22712,-22721,-22730,-22739,-22748,-22757,-22766,-22775,-22784,-22793,-22802,-22811,-22820,-22829,-22838,-22847,-22856,-22865,-22874,-22883,-22892,-22901,-22910,-22919,-22928,-22937,-22946,-22955,-22964,-22973,-22982,-22991,-23000,-23009,-23018,-23027,-23036,-23045,-23053,-23062,-23071,-23080,-23089,-23098,-23107,-23116,-23125,-23134,-23143,-23151,-23160
.word -23169,-23178,-23187,-23196,-23205,-23214,-23223,-23231,-23240,-23249,-23258,-23267,-23276,-23284,-23293,-23302,-23311,-23320,-23329,-23337,-23346,-23355,-23364,-23373,-23382,-23390,-23399,-23408,-23417,-23426,-23434,-23443,-23452,-23461,-23469,-23478,-23487,-23496,-23504,-23513,-23522,-23531,-23539,-23548,-23557,-23566,-23574,-23583,-23592,-23601,-23609,-23618,-23627,-23635,-23644,-23653,-23661,-23670,-23679,-23688,-23696,-23705,-23714,-23722,-23731,-23740,-23748,-23757,-23766,-23774,-23783,-23791,-23800,-23809,-23817,-23826,-23835,-23843,-23852,-23860,-23869,-23878,-23886,-23895,-23904,-23912,-23921,-23929,-23938,-23946,-23955,-23964,-23972,-23981,-23989,-23998,-24006,-24015,-24023,-24032,-24041,-24049,-24058,-24066,-24075,-24083,-24092,-24100,-24109,-24117,-24126,-24134,-24143,-24151,-24160,-24168,-24177,-24185,-24194,-24202,-24211,-24219,-24228,-24236,-24244,-24253,-24261,-24270
.word -24278,-24287,-24295,-24304,-24312,-24320,-24329,-24337,-24346,-24354,-24362,-24371,-24379,-24388,-24396,-24404,-24413,-24421,-24430,-24438,-24446,-24455,-24463,-24471,-24480,-24488,-24496,-24505,-24513,-24521,-24530,-24538,-24546,-24555,-24563,-24571,-24580,-24588,-24596,-24605,-24613,-24621,-24630,-24638,-24646,-24654,-24663,-24671,-24679,-24687,-24696,-24704,-24712,-24720,-24729,-24737,-24745,-24753,-24762,-24770,-24778,-24786,-24795,-24803,-24811,-24819,-24827,-24836,-24844,-24852,-24860,-24868,-24877,-24885,-24893,-24901,-24909,-24917,-24926,-24934,-24942,-24950,-24958,-24966,-24974,-24983,-24991,-24999,-25007,-25015,-25023,-25031,-25039,-25047,-25056,-25064,-25072,-25080,-25088,-25096,-25104,-25112,-25120,-25128,-25136,-25144,-25152,-25161,-25169,-25177,-25185,-25193,-25201,-25209,-25217,-25225,-25233,-25241,-25249,-25257,-25265,-25273,-25281,-25289,-25297,-25305,-25313,-25321
.word -25329,-25337,-25345,-25353,-25361,-25369,-25376,-25384,-25392,-25400,-25408,-25416,-25424,-25432,-25440,-25448,-25456,-25464,-25472,-25480,-25487,-25495,-25503,-25511,-25519,-25527,-25535,-25543,-25550,-25558,-25566,-25574,-25582,-25590,-25598,-25605,-25613,-25621,-25629,-25637,-25645,-25652,-25660,-25668,-25676,-25684,-25691,-25699,-25707,-25715,-25723,-25730,-25738,-25746,-25754,-25762,-25769,-25777,-25785,-25793,-25800,-25808,-25816,-25824,-25831,-25839,-25847,-25854,-25862,-25870,-25878,-25885,-25893,-25901,-25908,-25916,-25924,-25931,-25939,-25947,-25954,-25962,-25970,-25977,-25985,-25993,-26000,-26008,-26016,-26023,-26031,-26039,-26046,-26054,-26061,-26069,-26077,-26084,-26092,-26099,-26107,-26115,-26122,-26130,-26137,-26145,-26153,-26160,-26168,-26175,-26183,-26190,-26198,-26205,-26213,-26221,-26228,-26236,-26243,-26251,-26258,-26266,-26273,-26281,-26288,-26296,-26303,-26311
.word -26318,-26326,-26333,-26341,-26348,-26356,-26363,-26371,-26378,-26385,-26393,-26400,-26408,-26415,-26423,-26430,-26437,-26445,-26452,-26460,-26467,-26475,-26482,-26489,-26497,-26504,-26512,-26519,-26526,-26534,-26541,-26548,-26556,-26563,-26570,-26578,-26585,-26593,-26600,-26607,-26615,-26622,-26629,-26636,-26644,-26651,-26658,-26666,-26673,-26680,-26688,-26695,-26702,-26709,-26717,-26724,-26731,-26739,-26746,-26753,-26760,-26768,-26775,-26782,-26789,-26797,-26804,-26811,-26818,-26825,-26833,-26840,-26847,-26854,-26861,-26869,-26876,-26883,-26890,-26897,-26905,-26912,-26919,-26926,-26933,-26940,-26948,-26955,-26962,-26969,-26976,-26983,-26990,-26997,-27005,-27012,-27019,-27026,-27033,-27040,-27047,-27054,-27061,-27068,-27076,-27083,-27090,-27097,-27104,-27111,-27118,-27125,-27132,-27139,-27146,-27153,-27160,-27167,-27174,-27181,-27188,-27195,-27202,-27209,-27216,-27223,-27230,-27237
.word -27244,-27251,-27258,-27265,-27272,-27279,-27286,-27293,-27300,-27307,-27314,-27321,-27328,-27335,-27342,-27349,-27355,-27362,-27369,-27376,-27383,-27390,-27397,-27404,-27411,-27418,-27424,-27431,-27438,-27445,-27452,-27459,-27466,-27472,-27479,-27486,-27493,-27500,-27507,-27513,-27520,-27527,-27534,-27541,-27548,-27554,-27561,-27568,-27575,-27582,-27588,-27595,-27602,-27609,-27615,-27622,-27629,-27636,-27642,-27649,-27656,-27663,-27669,-27676,-27683,-27690,-27696,-27703,-27710,-27716,-27723,-27730,-27736,-27743,-27750,-27757,-27763,-27770,-27777,-27783,-27790,-27797,-27803,-27810,-27816,-27823,-27830,-27836,-27843,-27850,-27856,-27863,-27869,-27876,-27883,-27889,-27896,-27902,-27909,-27916,-27922,-27929,-27935,-27942,-27948,-27955,-27962,-27968,-27975,-27981,-27988,-27994,-28001,-28007,-28014,-28020,-28027,-28033,-28040,-28046,-28053,-28059,-28066,-28072,-28079,-28085,-28092,-28098
.word -28105,-28111,-28118,-28124,-28131,-28137,-28143,-28150,-28156,-28163,-28169,-28176,-28182,-28188,-28195,-28201,-28208,-28214,-28220,-28227,-28233,-28239,-28246,-28252,-28259,-28265,-28271,-28278,-28284,-28290,-28297,-28303,-28309,-28316,-28322,-28328,-28335,-28341,-28347,-28353,-28360,-28366,-28372,-28379,-28385,-28391,-28397,-28404,-28410,-28416,-28423,-28429,-28435,-28441,-28447,-28454,-28460,-28466,-28472,-28479,-28485,-28491,-28497,-28503,-28510,-28516,-28522,-28528,-28534,-28541,-28547,-28553,-28559,-28565,-28571,-28578,-28584,-28590,-28596,-28602,-28608,-28614,-28620,-28627,-28633,-28639,-28645,-28651,-28657,-28663,-28669,-28675,-28681,-28687,-28694,-28700,-28706,-28712,-28718,-28724,-28730,-28736,-28742,-28748,-28754,-28760,-28766,-28772,-28778,-28784,-28790,-28796,-28802,-28808,-28814,-28820,-28826,-28832,-28838,-28844,-28850,-28856,-28862,-28868,-28874,-28880,-28886,-28891
.word -28897,-28903,-28909,-28915,-28921,-28927,-28933,-28939,-28945,-28951,-28956,-28962,-28968,-28974,-28980,-28986,-28992,-28997,-29003,-29009,-29015,-29021,-29027,-29033,-29038,-29044,-29050,-29056,-29062,-29067,-29073,-29079,-29085,-29091,-29096,-29102,-29108,-29114,-29119,-29125,-29131,-29137,-29142,-29148,-29154,-29160,-29165,-29171,-29177,-29183,-29188,-29194,-29200,-29205,-29211,-29217,-29222,-29228,-29234,-29239,-29245,-29251,-29256,-29262,-29268,-29273,-29279,-29285,-29290,-29296,-29302,-29307,-29313,-29318,-29324,-29330,-29335,-29341,-29346,-29352,-29358,-29363,-29369,-29374,-29380,-29385,-29391,-29397,-29402,-29408,-29413,-29419,-29424,-29430,-29435,-29441,-29446,-29452,-29457,-29463,-29468,-29474,-29479,-29485,-29490,-29496,-29501,-29507,-29512,-29518,-29523,-29529,-29534,-29539,-29545,-29550,-29556,-29561,-29567,-29572,-29577,-29583,-29588,-29594,-29599,-29604,-29610,-29615
.word -29621,-29626,-29631,-29637,-29642,-29647,-29653,-29658,-29663,-29669,-29674,-29679,-29685,-29690,-29695,-29701,-29706,-29711,-29717,-29722,-29727,-29732,-29738,-29743,-29748,-29753,-29759,-29764,-29769,-29774,-29780,-29785,-29790,-29795,-29801,-29806,-29811,-29816,-29822,-29827,-29832,-29837,-29842,-29848,-29853,-29858,-29863,-29868,-29873,-29879,-29884,-29889,-29894,-29899,-29904,-29909,-29915,-29920,-29925,-29930,-29935,-29940,-29945,-29950,-29955,-29961,-29966,-29971,-29976,-29981,-29986,-29991,-29996,-30001,-30006,-30011,-30016,-30021,-30026,-30031,-30036,-30041,-30046,-30051,-30056,-30061,-30066,-30071,-30076,-30081,-30086,-30091,-30096,-30101,-30106,-30111,-30116,-30121,-30126,-30131,-30136,-30141,-30146,-30151,-30156,-30160,-30165,-30170,-30175,-30180,-30185,-30190,-30195,-30200,-30205,-30209,-30214,-30219,-30224,-30229,-30234,-30238,-30243,-30248,-30253,-30258,-30263,-30267
.word -30272,-30277,-30282,-30287,-30291,-30296,-30301,-30306,-30311,-30315,-30320,-30325,-30330,-30334,-30339,-30344,-30349,-30353,-30358,-30363,-30368,-30372,-30377,-30382,-30386,-30391,-30396,-30400,-30405,-30410,-30415,-30419,-30424,-30429,-30433,-30438,-30442,-30447,-30452,-30456,-30461,-30466,-30470,-30475,-30480,-30484,-30489,-30493,-30498,-30503,-30507,-30512,-30516,-30521,-30525,-30530,-30535,-30539,-30544,-30548,-30553,-30557,-30562,-30566,-30571,-30575,-30580,-30584,-30589,-30593,-30598,-30602,-30607,-30611,-30616,-30620,-30625,-30629,-30634,-30638,-30643,-30647,-30652,-30656,-30660,-30665,-30669,-30674,-30678,-30683,-30687,-30691,-30696,-30700,-30705,-30709,-30713,-30718,-30722,-30726,-30731,-30735,-30739,-30744,-30748,-30753,-30757,-30761,-30766,-30770,-30774,-30778,-30783,-30787,-30791,-30796,-30800,-30804,-30809,-30813,-30817,-30821,-30826,-30830,-30834,-30838,-30843,-30847
.word -30851,-30855,-30860,-30864,-30868,-30872,-30876,-30881,-30885,-30889,-30893,-30897,-30902,-30906,-30910,-30914,-30918,-30922,-30927,-30931,-30935,-30939,-30943,-30947,-30951,-30955,-30960,-30964,-30968,-30972,-30976,-30980,-30984,-30988,-30992,-30996,-31001,-31005,-31009,-31013,-31017,-31021,-31025,-31029,-31033,-31037,-31041,-31045,-31049,-31053,-31057,-31061,-31065,-31069,-31073,-31077,-31081,-31085,-31089,-31093,-31097,-31101,-31105,-31109,-31113,-31117,-31121,-31124,-31128,-31132,-31136,-31140,-31144,-31148,-31152,-31156,-31160,-31164,-31167,-31171,-31175,-31179,-31183,-31187,-31191,-31194,-31198,-31202,-31206,-31210,-31214,-31217,-31221,-31225,-31229,-31233,-31236,-31240,-31244,-31248,-31252,-31255,-31259,-31263,-31267,-31270,-31274,-31278,-31282,-31285,-31289,-31293,-31297,-31300,-31304,-31308,-31311,-31315,-31319,-31323,-31326,-31330,-31334,-31337,-31341,-31345,-31348,-31352
.word -31356,-31359,-31363,-31366,-31370,-31374,-31377,-31381,-31385,-31388,-31392,-31395,-31399,-31403,-31406,-31410,-31413,-31417,-31420,-31424,-31428,-31431,-31435,-31438,-31442,-31445,-31449,-31452,-31456,-31459,-31463,-31466,-31470,-31473,-31477,-31480,-31484,-31487,-31491,-31494,-31498,-31501,-31505,-31508,-31512,-31515,-31518,-31522,-31525,-31529,-31532,-31536,-31539,-31542,-31546,-31549,-31553,-31556,-31559,-31563,-31566,-31569,-31573,-31576,-31580,-31583,-31586,-31590,-31593,-31596,-31600,-31603,-31606,-31610,-31613,-31616,-31619,-31623,-31626,-31629,-31633,-31636,-31639,-31642,-31646,-31649,-31652,-31655,-31659,-31662,-31665,-31668,-31672,-31675,-31678,-31681,-31684,-31688,-31691,-31694,-31697,-31700,-31704,-31707,-31710,-31713,-31716,-31719,-31723,-31726,-31729,-31732,-31735,-31738,-31741,-31744,-31748,-31751,-31754,-31757,-31760,-31763,-31766,-31769,-31772,-31775,-31778,-31781
.word -31785,-31788,-31791,-31794,-31797,-31800,-31803,-31806,-31809,-31812,-31815,-31818,-31821,-31824,-31827,-31830,-31833,-31836,-31839,-31842,-31845,-31848,-31851,-31854,-31856,-31859,-31862,-31865,-31868,-31871,-31874,-31877,-31880,-31883,-31886,-31889,-31891,-31894,-31897,-31900,-31903,-31906,-31909,-31911,-31914,-31917,-31920,-31923,-31926,-31929,-31931,-31934,-31937,-31940,-31943,-31945,-31948,-31951,-31954,-31957,-31959,-31962,-31965,-31968,-31970,-31973,-31976,-31979,-31981,-31984,-31987,-31989,-31992,-31995,-31998,-32000,-32003,-32006,-32008,-32011,-32014,-32016,-32019,-32022,-32024,-32027,-32030,-32032,-32035,-32038,-32040,-32043,-32046,-32048,-32051,-32053,-32056,-32059,-32061,-32064,-32066,-32069,-32072,-32074,-32077,-32079,-32082,-32084,-32087,-32089,-32092,-32095,-32097,-32100,-32102,-32105,-32107,-32110,-32112,-32115,-32117,-32120,-32122,-32125,-32127,-32130,-32132,-32134
.word -32137,-32139,-32142,-32144,-32147,-32149,-32152,-32154,-32156,-32159,-32161,-32164,-32166,-32168,-32171,-32173,-32176,-32178,-32180,-32183,-32185,-32187,-32190,-32192,-32194,-32197,-32199,-32201,-32204,-32206,-32208,-32211,-32213,-32215,-32218,-32220,-32222,-32224,-32227,-32229,-32231,-32233,-32236,-32238,-32240,-32242,-32245,-32247,-32249,-32251,-32254,-32256,-32258,-32260,-32262,-32265,-32267,-32269,-32271,-32273,-32275,-32278,-32280,-32282,-32284,-32286,-32288,-32291,-32293,-32295,-32297,-32299,-32301,-32303,-32305,-32307,-32310,-32312,-32314,-32316,-32318,-32320,-32322,-32324,-32326,-32328,-32330,-32332,-32334,-32336,-32338,-32340,-32342,-32344,-32346,-32348,-32350,-32352,-32354,-32356,-32358,-32360,-32362,-32364,-32366,-32368,-32370,-32372,-32374,-32376,-32378,-32380,-32382,-32384,-32386,-32387,-32389,-32391,-32393,-32395,-32397,-32399,-32401,-32403,-32404,-32406,-32408,-32410
.word -32412,-32414,-32416,-32417,-32419,-32421,-32423,-32425,-32426,-32428,-32430,-32432,-32434,-32435,-32437,-32439,-32441,-32443,-32444,-32446,-32448,-32450,-32451,-32453,-32455,-32456,-32458,-32460,-32462,-32463,-32465,-32467,-32468,-32470,-32472,-32473,-32475,-32477,-32478,-32480,-32482,-32483,-32485,-32487,-32488,-32490,-32492,-32493,-32495,-32496,-32498,-32500,-32501,-32503,-32504,-32506,-32508,-32509,-32511,-32512,-32514,-32515,-32517,-32519,-32520,-32522,-32523,-32525,-32526,-32528,-32529,-32531,-32532,-32534,-32535,-32537,-32538,-32540,-32541,-32543,-32544,-32546,-32547,-32548,-32550,-32551,-32553,-32554,-32556,-32557,-32558,-32560,-32561,-32563,-32564,-32565,-32567,-32568,-32570,-32571,-32572,-32574,-32575,-32576,-32578,-32579,-32580,-32582,-32583,-32584,-32586,-32587,-32588,-32590,-32591,-32592,-32594,-32595,-32596,-32597,-32599,-32600,-32601,-32602,-32604,-32605,-32606,-32607
.word -32609,-32610,-32611,-32612,-32614,-32615,-32616,-32617,-32618,-32620,-32621,-32622,-32623,-32624,-32625,-32627,-32628,-32629,-32630,-32631,-32632,-32634,-32635,-32636,-32637,-32638,-32639,-32640,-32641,-32642,-32644,-32645,-32646,-32647,-32648,-32649,-32650,-32651,-32652,-32653,-32654,-32655,-32656,-32657,-32658,-32659,-32660,-32661,-32662,-32663,-32664,-32665,-32666,-32667,-32668,-32669,-32670,-32671,-32672,-32673,-32674,-32675,-32676,-32677,-32678,-32679,-32680,-32680,-32681,-32682,-32683,-32684,-32685,-32686,-32687,-32688,-32688,-32689,-32690,-32691,-32692,-32693,-32694,-32694,-32695,-32696,-32697,-32698,-32699,-32699,-32700,-32701,-32702,-32703,-32703,-32704,-32705,-32706,-32706,-32707,-32708,-32709,-32709,-32710,-32711,-32712,-32712,-32713,-32714,-32714,-32715,-32716,-32717,-32717,-32718,-32719,-32719,-32720,-32721,-32721,-32722,-32723,-32723,-32724,-32725,-32725,-32726,-32726
.word -32727,-32728,-32728,-32729,-32729,-32730,-32731,-32731,-32732,-32732,-32733,-32734,-32734,-32735,-32735,-32736,-32736,-32737,-32737,-32738,-32738,-32739,-32739,-32740,-32740,-32741,-32741,-32742,-32742,-32743,-32743,-32744,-32744,-32745,-32745,-32746,-32746,-32747,-32747,-32747,-32748,-32748,-32749,-32749,-32750,-32750,-32750,-32751,-32751,-32751,-32752,-32752,-32753,-32753,-32753,-32754,-32754,-32754,-32755,-32755,-32755,-32756,-32756,-32756,-32757,-32757,-32757,-32758,-32758,-32758,-32758,-32759,-32759,-32759,-32759,-32760,-32760,-32760,-32760,-32761,-32761,-32761,-32761,-32762,-32762,-32762,-32762,-32762,-32763,-32763,-32763,-32763,-32763,-32764,-32764,-32764,-32764,-32764,-32764,-32764,-32765,-32765,-32765,-32765,-32765,-32765,-32765,-32765,-32766,-32766,-32766,-32766,-32766,-32766,-32766,-32766,-32766,-32766,-32766,-32766,-32766,-32766,-32766,-32766,-32766,-32766,-32766,-32766
.word -32767,-32766,-32766,-32766,-32766,-32766,-32766,-32766,-32766,-32766,-32766,-32766,-32766,-32766,-32766,-32766,-32766,-32766,-32766,-32766,-32766,-32765,-32765,-32765,-32765,-32765,-32765,-32765,-32765,-32764,-32764,-32764,-32764,-32764,-32764,-32764,-32763,-32763,-32763,-32763,-32763,-32762,-32762,-32762,-32762,-32762,-32761,-32761,-32761,-32761,-32760,-32760,-32760,-32760,-32759,-32759,-32759,-32759,-32758,-32758,-32758,-32758,-32757,-32757,-32757,-32756,-32756,-32756,-32755,-32755,-32755,-32754,-32754,-32754,-32753,-32753,-32753,-32752,-32752,-32751,-32751,-32751,-32750,-32750,-32750,-32749,-32749,-32748,-32748,-32747,-32747,-32747,-32746,-32746,-32745,-32745,-32744,-32744,-32743,-32743,-32742,-32742,-32741,-32741,-32740,-32740,-32739,-32739,-32738,-32738,-32737,-32737,-32736,-32736,-32735,-32735,-32734,-32734,-32733,-32732,-32732,-32731,-32731,-32730,-32729,-32729,-32728,-32728
.word -32727,-32726,-32726,-32725,-32725,-32724,-32723,-32723,-32722,-32721,-32721,-32720,-32719,-32719,-32718,-32717,-32717,-32716,-32715,-32714,-32714,-32713,-32712,-32712,-32711,-32710,-32709,-32709,-32708,-32707,-32706,-32706,-32705,-32704,-32703,-32703,-32702,-32701,-32700,-32699,-32699,-32698,-32697,-32696,-32695,-32694,-32694,-32693,-32692,-32691,-32690,-32689,-32688,-32688,-32687,-32686,-32685,-32684,-32683,-32682,-32681,-32680,-32680,-32679,-32678,-32677,-32676,-32675,-32674,-32673,-32672,-32671,-32670,-32669,-32668,-32667,-32666,-32665,-32664,-32663,-32662,-32661,-32660,-32659,-32658,-32657,-32656,-32655,-32654,-32653,-32652,-32651,-32650,-32649,-32648,-32647,-32646,-32645,-32644,-32642,-32641,-32640,-32639,-32638,-32637,-32636,-32635,-32634,-32632,-32631,-32630,-32629,-32628,-32627,-32625,-32624,-32623,-32622,-32621,-32620,-32618,-32617,-32616,-32615,-32614,-32612,-32611,-32610
.word -32609,-32607,-32606,-32605,-32604,-32602,-32601,-32600,-32599,-32597,-32596,-32595,-32594,-32592,-32591,-32590,-32588,-32587,-32586,-32584,-32583,-32582,-32580,-32579,-32578,-32576,-32575,-32574,-32572,-32571,-32570,-32568,-32567,-32565,-32564,-32563,-32561,-32560,-32558,-32557,-32556,-32554,-32553,-32551,-32550,-32548,-32547,-32546,-32544,-32543,-32541,-32540,-32538,-32537,-32535,-32534,-32532,-32531,-32529,-32528,-32526,-32525,-32523,-32522,-32520,-32519,-32517,-32515,-32514,-32512,-32511,-32509,-32508,-32506,-32504,-32503,-32501,-32500,-32498,-32496,-32495,-32493,-32492,-32490,-32488,-32487,-32485,-32483,-32482,-32480,-32478,-32477,-32475,-32473,-32472,-32470,-32468,-32467,-32465,-32463,-32462,-32460,-32458,-32456,-32455,-32453,-32451,-32450,-32448,-32446,-32444,-32443,-32441,-32439,-32437,-32435,-32434,-32432,-32430,-32428,-32426,-32425,-32423,-32421,-32419,-32417,-32416,-32414
.word -32412,-32410,-32408,-32406,-32404,-32403,-32401,-32399,-32397,-32395,-32393,-32391,-32389,-32387,-32386,-32384,-32382,-32380,-32378,-32376,-32374,-32372,-32370,-32368,-32366,-32364,-32362,-32360,-32358,-32356,-32354,-32352,-32350,-32348,-32346,-32344,-32342,-32340,-32338,-32336,-32334,-32332,-32330,-32328,-32326,-32324,-32322,-32320,-32318,-32316,-32314,-32312,-32310,-32307,-32305,-32303,-32301,-32299,-32297,-32295,-32293,-32291,-32288,-32286,-32284,-32282,-32280,-32278,-32275,-32273,-32271,-32269,-32267,-32265,-32262,-32260,-32258,-32256,-32254,-32251,-32249,-32247,-32245,-32242,-32240,-32238,-32236,-32233,-32231,-32229,-32227,-32224,-32222,-32220,-32218,-32215,-32213,-32211,-32208,-32206,-32204,-32201,-32199,-32197,-32194,-32192,-32190,-32187,-32185,-32183,-32180,-32178,-32176,-32173,-32171,-32168,-32166,-32164,-32161,-32159,-32156,-32154,-32152,-32149,-32147,-32144,-32142,-32139
.word -32137,-32134,-32132,-32130,-32127,-32125,-32122,-32120,-32117,-32115,-32112,-32110,-32107,-32105,-32102,-32100,-32097,-32095,-32092,-32089,-32087,-32084,-32082,-32079,-32077,-32074,-32072,-32069,-32066,-32064,-32061,-32059,-32056,-32053,-32051,-32048,-32046,-32043,-32040,-32038,-32035,-32032,-32030,-32027,-32024,-32022,-32019,-32016,-32014,-32011,-32008,-32006,-32003,-32000,-31998,-31995,-31992,-31989,-31987,-31984,-31981,-31979,-31976,-31973,-31970,-31968,-31965,-31962,-31959,-31957,-31954,-31951,-31948,-31945,-31943,-31940,-31937,-31934,-31931,-31929,-31926,-31923,-31920,-31917,-31914,-31911,-31909,-31906,-31903,-31900,-31897,-31894,-31891,-31889,-31886,-31883,-31880,-31877,-31874,-31871,-31868,-31865,-31862,-31859,-31856,-31854,-31851,-31848,-31845,-31842,-31839,-31836,-31833,-31830,-31827,-31824,-31821,-31818,-31815,-31812,-31809,-31806,-31803,-31800,-31797,-31794,-31791,-31788
.word -31785,-31781,-31778,-31775,-31772,-31769,-31766,-31763,-31760,-31757,-31754,-31751,-31748,-31744,-31741,-31738,-31735,-31732,-31729,-31726,-31723,-31719,-31716,-31713,-31710,-31707,-31704,-31700,-31697,-31694,-31691,-31688,-31684,-31681,-31678,-31675,-31672,-31668,-31665,-31662,-31659,-31655,-31652,-31649,-31646,-31642,-31639,-31636,-31633,-31629,-31626,-31623,-31619,-31616,-31613,-31610,-31606,-31603,-31600,-31596,-31593,-31590,-31586,-31583,-31580,-31576,-31573,-31569,-31566,-31563,-31559,-31556,-31553,-31549,-31546,-31542,-31539,-31536,-31532,-31529,-31525,-31522,-31518,-31515,-31512,-31508,-31505,-31501,-31498,-31494,-31491,-31487,-31484,-31480,-31477,-31473,-31470,-31466,-31463,-31459,-31456,-31452,-31449,-31445,-31442,-31438,-31435,-31431,-31428,-31424,-31420,-31417,-31413,-31410,-31406,-31403,-31399,-31395,-31392,-31388,-31385,-31381,-31377,-31374,-31370,-31366,-31363,-31359
.word -31356,-31352,-31348,-31345,-31341,-31337,-31334,-31330,-31326,-31323,-31319,-31315,-31311,-31308,-31304,-31300,-31297,-31293,-31289,-31285,-31282,-31278,-31274,-31270,-31267,-31263,-31259,-31255,-31252,-31248,-31244,-31240,-31236,-31233,-31229,-31225,-31221,-31217,-31214,-31210,-31206,-31202,-31198,-31194,-31191,-31187,-31183,-31179,-31175,-31171,-31167,-31164,-31160,-31156,-31152,-31148,-31144,-31140,-31136,-31132,-31128,-31124,-31121,-31117,-31113,-31109,-31105,-31101,-31097,-31093,-31089,-31085,-31081,-31077,-31073,-31069,-31065,-31061,-31057,-31053,-31049,-31045,-31041,-31037,-31033,-31029,-31025,-31021,-31017,-31013,-31009,-31005,-31001,-30996,-30992,-30988,-30984,-30980,-30976,-30972,-30968,-30964,-30960,-30955,-30951,-30947,-30943,-30939,-30935,-30931,-30927,-30922,-30918,-30914,-30910,-30906,-30902,-30897,-30893,-30889,-30885,-30881,-30876,-30872,-30868,-30864,-30860,-30855
.word -30851,-30847,-30843,-30838,-30834,-30830,-30826,-30821,-30817,-30813,-30809,-30804,-30800,-30796,-30791,-30787,-30783,-30778,-30774,-30770,-30765,-30761,-30757,-30753,-30748,-30744,-30739,-30735,-30731,-30726,-30722,-30718,-30713,-30709,-30705,-30700,-30696,-30691,-30687,-30683,-30678,-30674,-30669,-30665,-30660,-30656,-30652,-30647,-30643,-30638,-30634,-30629,-30625,-30620,-30616,-30611,-30607,-30602,-30598,-30593,-30589,-30584,-30580,-30575,-30571,-30566,-30562,-30557,-30553,-30548,-30544,-30539,-30535,-30530,-30525,-30521,-30516,-30512,-30507,-30503,-30498,-30493,-30489,-30484,-30480,-30475,-30470,-30466,-30461,-30456,-30452,-30447,-30442,-30438,-30433,-30429,-30424,-30419,-30415,-30410,-30405,-30400,-30396,-30391,-30386,-30382,-30377,-30372,-30368,-30363,-30358,-30353,-30349,-30344,-30339,-30334,-30330,-30325,-30320,-30315,-30311,-30306,-30301,-30296,-30291,-30287,-30282,-30277
.word -30272,-30267,-30263,-30258,-30253,-30248,-30243,-30238,-30234,-30229,-30224,-30219,-30214,-30209,-30205,-30200,-30195,-30190,-30185,-30180,-30175,-30170,-30165,-30160,-30156,-30151,-30146,-30141,-30136,-30131,-30126,-30121,-30116,-30111,-30106,-30101,-30096,-30091,-30086,-30081,-30076,-30071,-30066,-30061,-30056,-30051,-30046,-30041,-30036,-30031,-30026,-30021,-30016,-30011,-30006,-30001,-29996,-29991,-29986,-29981,-29976,-29971,-29966,-29960,-29955,-29950,-29945,-29940,-29935,-29930,-29925,-29920,-29915,-29909,-29904,-29899,-29894,-29889,-29884,-29879,-29873,-29868,-29863,-29858,-29853,-29848,-29842,-29837,-29832,-29827,-29822,-29816,-29811,-29806,-29801,-29795,-29790,-29785,-29780,-29774,-29769,-29764,-29759,-29753,-29748,-29743,-29738,-29732,-29727,-29722,-29717,-29711,-29706,-29701,-29695,-29690,-29685,-29679,-29674,-29669,-29663,-29658,-29653,-29647,-29642,-29637,-29631,-29626
.word -29621,-29615,-29610,-29604,-29599,-29594,-29588,-29583,-29577,-29572,-29567,-29561,-29556,-29550,-29545,-29539,-29534,-29529,-29523,-29518,-29512,-29507,-29501,-29496,-29490,-29485,-29479,-29474,-29468,-29463,-29457,-29452,-29446,-29441,-29435,-29430,-29424,-29419,-29413,-29408,-29402,-29397,-29391,-29385,-29380,-29374,-29369,-29363,-29358,-29352,-29346,-29341,-29335,-29330,-29324,-29318,-29313,-29307,-29302,-29296,-29290,-29285,-29279,-29273,-29268,-29262,-29256,-29251,-29245,-29239,-29234,-29228,-29222,-29217,-29211,-29205,-29200,-29194,-29188,-29183,-29177,-29171,-29165,-29160,-29154,-29148,-29142,-29137,-29131,-29125,-29119,-29114,-29108,-29102,-29096,-29091,-29085,-29079,-29073,-29067,-29062,-29056,-29050,-29044,-29038,-29033,-29027,-29021,-29015,-29009,-29003,-28997,-28992,-28986,-28980,-28974,-28968,-28962,-28956,-28951,-28945,-28939,-28933,-28927,-28921,-28915,-28909,-28903
.word -28897,-28891,-28886,-28880,-28874,-28868,-28862,-28856,-28850,-28844,-28838,-28832,-28826,-28820,-28814,-28808,-28802,-28796,-28790,-28784,-28778,-28772,-28766,-28760,-28754,-28748,-28742,-28736,-28730,-28724,-28718,-28712,-28706,-28700,-28694,-28687,-28681,-28675,-28669,-28663,-28657,-28651,-28645,-28639,-28633,-28627,-28620,-28614,-28608,-28602,-28596,-28590,-28584,-28578,-28571,-28565,-28559,-28553,-28547,-28541,-28534,-28528,-28522,-28516,-28510,-28503,-28497,-28491,-28485,-28479,-28472,-28466,-28460,-28454,-28447,-28441,-28435,-28429,-28423,-28416,-28410,-28404,-28397,-28391,-28385,-28379,-28372,-28366,-28360,-28353,-28347,-28341,-28335,-28328,-28322,-28316,-28309,-28303,-28297,-28290,-28284,-28278,-28271,-28265,-28259,-28252,-28246,-28239,-28233,-28227,-28220,-28214,-28208,-28201,-28195,-28188,-28182,-28176,-28169,-28163,-28156,-28150,-28143,-28137,-28130,-28124,-28118,-28111
.word -28105,-28098,-28092,-28085,-28079,-28072,-28066,-28059,-28053,-28046,-28040,-28033,-28027,-28020,-28014,-28007,-28001,-27994,-27988,-27981,-27975,-27968,-27962,-27955,-27948,-27942,-27935,-27929,-27922,-27916,-27909,-27902,-27896,-27889,-27883,-27876,-27869,-27863,-27856,-27850,-27843,-27836,-27830,-27823,-27816,-27810,-27803,-27797,-27790,-27783,-27777,-27770,-27763,-27757,-27750,-27743,-27736,-27730,-27723,-27716,-27710,-27703,-27696,-27690,-27683,-27676,-27669,-27663,-27656,-27649,-27642,-27636,-27629,-27622,-27615,-27609,-27602,-27595,-27588,-27582,-27575,-27568,-27561,-27554,-27548,-27541,-27534,-27527,-27520,-27513,-27507,-27500,-27493,-27486,-27479,-27472,-27466,-27459,-27452,-27445,-27438,-27431,-27424,-27418,-27411,-27404,-27397,-27390,-27383,-27376,-27369,-27362,-27355,-27349,-27342,-27335,-27328,-27321,-27314,-27307,-27300,-27293,-27286,-27279,-27272,-27265,-27258,-27251
.word -27244,-27237,-27230,-27223,-27216,-27209,-27202,-27195,-27188,-27181,-27174,-27167,-27160,-27153,-27146,-27139,-27132,-27125,-27118,-27111,-27104,-27097,-27090,-27083,-27076,-27068,-27061,-27054,-27047,-27040,-27033,-27026,-27019,-27012,-27005,-26997,-26990,-26983,-26976,-26969,-26962,-26955,-26948,-26940,-26933,-26926,-26919,-26912,-26905,-26897,-26890,-26883,-26876,-26869,-26861,-26854,-26847,-26840,-26833,-26825,-26818,-26811,-26804,-26797,-26789,-26782,-26775,-26768,-26760,-26753,-26746,-26739,-26731,-26724,-26717,-26709,-26702,-26695,-26688,-26680,-26673,-26666,-26658,-26651,-26644,-26636,-26629,-26622,-26615,-26607,-26600,-26593,-26585,-26578,-26570,-26563,-26556,-26548,-26541,-26534,-26526,-26519,-26512,-26504,-26497,-26489,-26482,-26475,-26467,-26460,-26452,-26445,-26437,-26430,-26423,-26415,-26408,-26400,-26393,-26385,-26378,-26371,-26363,-26356,-26348,-26341,-26333,-26326
.word -26318,-26311,-26303,-26296,-26288,-26281,-26273,-26266,-26258,-26251,-26243,-26236,-26228,-26221,-26213,-26205,-26198,-26190,-26183,-26175,-26168,-26160,-26153,-26145,-26137,-26130,-26122,-26115,-26107,-26099,-26092,-26084,-26077,-26069,-26061,-26054,-26046,-26039,-26031,-26023,-26016,-26008,-26000,-25993,-25985,-25977,-25970,-25962,-25954,-25947,-25939,-25931,-25924,-25916,-25908,-25901,-25893,-25885,-25878,-25870,-25862,-25854,-25847,-25839,-25831,-25824,-25816,-25808,-25800,-25793,-25785,-25777,-25769,-25762,-25754,-25746,-25738,-25730,-25723,-25715,-25707,-25699,-25691,-25684,-25676,-25668,-25660,-25652,-25645,-25637,-25629,-25621,-25613,-25605,-25598,-25590,-25582,-25574,-25566,-25558,-25550,-25543,-25535,-25527,-25519,-25511,-25503,-25495,-25487,-25480,-25472,-25464,-25456,-25448,-25440,-25432,-25424,-25416,-25408,-25400,-25392,-25384,-25376,-25369,-25361,-25353,-25345,-25337
.word -25329,-25321,-25313,-25305,-25297,-25289,-25281,-25273,-25265,-25257,-25249,-25241,-25233,-25225,-25217,-25209,-25201,-25193,-25185,-25177,-25169,-25161,-25152,-25144,-25136,-25128,-25120,-25112,-25104,-25096,-25088,-25080,-25072,-25064,-25056,-25047,-25039,-25031,-25023,-25015,-25007,-24999,-24991,-24983,-24974,-24966,-24958,-24950,-24942,-24934,-24926,-24917,-24909,-24901,-24893,-24885,-24877,-24868,-24860,-24852,-24844,-24836,-24827,-24819,-24811,-24803,-24795,-24786,-24778,-24770,-24762,-24753,-24745,-24737,-24729,-24720,-24712,-24704,-24696,-24687,-24679,-24671,-24663,-24654,-24646,-24638,-24630,-24621,-24613,-24605,-24596,-24588,-24580,-24571,-24563,-24555,-24546,-24538,-24530,-24521,-24513,-24505,-24496,-24488,-24480,-24471,-24463,-24455,-24446,-24438,-24430,-24421,-24413,-24404,-24396,-24388,-24379,-24371,-24362,-24354,-24346,-24337,-24329,-24320,-24312,-24304,-24295,-24287
.word -24278,-24270,-24261,-24253,-24244,-24236,-24228,-24219,-24211,-24202,-24194,-24185,-24177,-24168,-24160,-24151,-24143,-24134,-24126,-24117,-24109,-24100,-24092,-24083,-24075,-24066,-24058,-24049,-24041,-24032,-24023,-24015,-24006,-23998,-23989,-23981,-23972,-23964,-23955,-23946,-23938,-23929,-23921,-23912,-23903,-23895,-23886,-23878,-23869,-23860,-23852,-23843,-23835,-23826,-23817,-23809,-23800,-23791,-23783,-23774,-23766,-23757,-23748,-23740,-23731,-23722,-23714,-23705,-23696,-23688,-23679,-23670,-23661,-23653,-23644,-23635,-23627,-23618,-23609,-23601,-23592,-23583,-23574,-23566,-23557,-23548,-23539,-23531,-23522,-23513,-23504,-23496,-23487,-23478,-23469,-23461,-23452,-23443,-23434,-23426,-23417,-23408,-23399,-23390,-23382,-23373,-23364,-23355,-23346,-23337,-23329,-23320,-23311,-23302,-23293,-23284,-23276,-23267,-23258,-23249,-23240,-23231,-23223,-23214,-23205,-23196,-23187,-23178
.word -23169,-23160,-23151,-23143,-23134,-23125,-23116,-23107,-23098,-23089,-23080,-23071,-23062,-23053,-23045,-23036,-23027,-23018,-23009,-23000,-22991,-22982,-22973,-22964,-22955,-22946,-22937,-22928,-22919,-22910,-22901,-22892,-22883,-22874,-22865,-22856,-22847,-22838,-22829,-22820,-22811,-22802,-22793,-22784,-22775,-22766,-22757,-22748,-22739,-22730,-22721,-22712,-22703,-22694,-22685,-22675,-22666,-22657,-22648,-22639,-22630,-22621,-22612,-22603,-22594,-22585,-22575,-22566,-22557,-22548,-22539,-22530,-22521,-22512,-22503,-22493,-22484,-22475,-22466,-22457,-22448,-22438,-22429,-22420,-22411,-22402,-22393,-22383,-22374,-22365,-22356,-22347,-22338,-22328,-22319,-22310,-22301,-22292,-22282,-22273,-22264,-22255,-22245,-22236,-22227,-22218,-22209,-22199,-22190,-22181,-22172,-22162,-22153,-22144,-22135,-22125,-22116,-22107,-22097,-22088,-22079,-22070,-22060,-22051,-22042,-22032,-22023,-22014
.word -22004,-21995,-21986,-21977,-21967,-21958,-21949,-21939,-21930,-21921,-21911,-21902,-21893,-21883,-21874,-21864,-21855,-21846,-21836,-21827,-21818,-21808,-21799,-21789,-21780,-21771,-21761,-21752,-21743,-21733,-21724,-21714,-21705,-21695,-21686,-21677,-21667,-21658,-21648,-21639,-21629,-21620,-21611,-21601,-21592,-21582,-21573,-21563,-21554,-21544,-21535,-21525,-21516,-21506,-21497,-21488,-21478,-21469,-21459,-21450,-21440,-21431,-21421,-21412,-21402,-21392,-21383,-21373,-21364,-21354,-21345,-21335,-21326,-21316,-21307,-21297,-21288,-21278,-21268,-21259,-21249,-21240,-21230,-21221,-21211,-21201,-21192,-21182,-21173,-21163,-21154,-21144,-21134,-21125,-21115,-21106,-21096,-21086,-21077,-21067,-21057,-21048,-21038,-21029,-21019,-21009,-21000,-20990,-20980,-20971,-20961,-20951,-20942,-20932,-20922,-20913,-20903,-20893,-20884,-20874,-20864,-20855,-20845,-20835,-20825,-20816,-20806,-20796
.word -20787,-20777,-20767,-20758,-20748,-20738,-20728,-20719,-20709,-20699,-20689,-20680,-20670,-20660,-20650,-20641,-20631,-20621,-20611,-20602,-20592,-20582,-20572,-20562,-20553,-20543,-20533,-20523,-20513,-20504,-20494,-20484,-20474,-20464,-20455,-20445,-20435,-20425,-20415,-20406,-20396,-20386,-20376,-20366,-20356,-20346,-20337,-20327,-20317,-20307,-20297,-20287,-20277,-20268,-20258,-20248,-20238,-20228,-20218,-20208,-20198,-20189,-20179,-20169,-20159,-20149,-20139,-20129,-20119,-20109,-20099,-20089,-20079,-20070,-20060,-20050,-20040,-20030,-20020,-20010,-20000,-19990,-19980,-19970,-19960,-19950,-19940,-19930,-19920,-19910,-19900,-19890,-19880,-19870,-19860,-19850,-19840,-19830,-19820,-19810,-19800,-19790,-19780,-19770,-19760,-19750,-19740,-19730,-19720,-19710,-19700,-19690,-19680,-19670,-19660,-19650,-19640,-19630,-19620,-19609,-19599,-19589,-19579,-19569,-19559,-19549,-19539,-19529
.word -19519,-19509,-19499,-19488,-19478,-19468,-19458,-19448,-19438,-19428,-19418,-19408,-19397,-19387,-19377,-19367,-19357,-19347,-19337,-19326,-19316,-19306,-19296,-19286,-19276,-19266,-19255,-19245,-19235,-19225,-19215,-19205,-19194,-19184,-19174,-19164,-19154,-19143,-19133,-19123,-19113,-19103,-19092,-19082,-19072,-19062,-19051,-19041,-19031,-19021,-19011,-19000,-18990,-18980,-18970,-18959,-18949,-18939,-18929,-18918,-18908,-18898,-18888,-18877,-18867,-18857,-18846,-18836,-18826,-18816,-18805,-18795,-18785,-18774,-18764,-18754,-18744,-18733,-18723,-18713,-18702,-18692,-18682,-18671,-18661,-18651,-18640,-18630,-18620,-18609,-18599,-18589,-18578,-18568,-18558,-18547,-18537,-18526,-18516,-18506,-18495,-18485,-18475,-18464,-18454,-18443,-18433,-18423,-18412,-18402,-18392,-18381,-18371,-18360,-18350,-18339,-18329,-18319,-18308,-18298,-18287,-18277,-18267,-18256,-18246,-18235,-18225,-18214
.word -18204,-18193,-18183,-18173,-18162,-18152,-18141,-18131,-18120,-18110,-18099,-18089,-18078,-18068,-18057,-18047,-18036,-18026,-18015,-18005,-17994,-17984,-17973,-17963,-17952,-17942,-17931,-17921,-17910,-17900,-17889,-17879,-17868,-17858,-17847,-17837,-17826,-17815,-17805,-17794,-17784,-17773,-17763,-17752,-17742,-17731,-17720,-17710,-17699,-17689,-17678,-17668,-17657,-17646,-17636,-17625,-17615,-17604,-17593,-17583,-17572,-17562,-17551,-17540,-17530,-17519,-17509,-17498,-17487,-17477,-17466,-17455,-17445,-17434,-17423,-17413,-17402,-17392,-17381,-17370,-17360,-17349,-17338,-17328,-17317,-17306,-17296,-17285,-17274,-17264,-17253,-17242,-17231,-17221,-17210,-17199,-17189,-17178,-17167,-17157,-17146,-17135,-17124,-17114,-17103,-17092,-17082,-17071,-17060,-17049,-17039,-17028,-17017,-17006,-16996,-16985,-16974,-16964,-16953,-16942,-16931,-16920,-16910,-16899,-16888,-16877,-16867,-16856
.word -16845,-16834,-16824,-16813,-16802,-16791,-16780,-16770,-16759,-16748,-16737,-16726,-16716,-16705,-16694,-16683,-16672,-16662,-16651,-16640,-16629,-16618,-16607,-16597,-16586,-16575,-16564,-16553,-16542,-16531,-16521,-16510,-16499,-16488,-16477,-16466,-16455,-16445,-16434,-16423,-16412,-16401,-16390,-16379,-16368,-16358,-16347,-16336,-16325,-16314,-16303,-16292,-16281,-16270,-16260,-16249,-16238,-16227,-16216,-16205,-16194,-16183,-16172,-16161,-16150,-16139,-16128,-16117,-16107,-16096,-16085,-16074,-16063,-16052,-16041,-16030,-16019,-16008,-15997,-15986,-15975,-15964,-15953,-15942,-15931,-15920,-15909,-15898,-15887,-15876,-15865,-15854,-15843,-15832,-15821,-15810,-15799,-15788,-15777,-15766,-15755,-15744,-15733,-15722,-15711,-15700,-15689,-15678,-15667,-15656,-15645,-15634,-15623,-15612,-15601,-15590,-15579,-15568,-15556,-15545,-15534,-15523,-15512,-15501,-15490,-15479,-15468,-15457
.word -15446,-15435,-15424,-15412,-15401,-15390,-15379,-15368,-15357,-15346,-15335,-15324,-15313,-15301,-15290,-15279,-15268,-15257,-15246,-15235,-15224,-15213,-15201,-15190,-15179,-15168,-15157,-15146,-15135,-15123,-15112,-15101,-15090,-15079,-15068,-15056,-15045,-15034,-15023,-15012,-15001,-14989,-14978,-14967,-14956,-14945,-14934,-14922,-14911,-14900,-14889,-14878,-14866,-14855,-14844,-14833,-14822,-14810,-14799,-14788,-14777,-14766,-14754,-14743,-14732,-14721,-14709,-14698,-14687,-14676,-14665,-14653,-14642,-14631,-14620,-14608,-14597,-14586,-14575,-14563,-14552,-14541,-14530,-14518,-14507,-14496,-14484,-14473,-14462,-14451,-14439,-14428,-14417,-14406,-14394,-14383,-14372,-14360,-14349,-14338,-14326,-14315,-14304,-14293,-14281,-14270,-14259,-14247,-14236,-14225,-14213,-14202,-14191,-14179,-14168,-14157,-14145,-14134,-14123,-14111,-14100,-14089,-14077,-14066,-14055,-14043,-14032,-14021
.word -14009,-13998,-13986,-13975,-13964,-13952,-13941,-13930,-13918,-13907,-13896,-13884,-13873,-13861,-13850,-13839,-13827,-13816,-13804,-13793,-13782,-13770,-13759,-13747,-13736,-13725,-13713,-13702,-13690,-13679,-13667,-13656,-13645,-13633,-13622,-13610,-13599,-13587,-13576,-13565,-13553,-13542,-13530,-13519,-13507,-13496,-13485,-13473,-13462,-13450,-13439,-13427,-13416,-13404,-13393,-13381,-13370,-13358,-13347,-13335,-13324,-13312,-13301,-13290,-13278,-13267,-13255,-13244,-13232,-13221,-13209,-13198,-13186,-13175,-13163,-13152,-13140,-13129,-13117,-13106,-13094,-13082,-13071,-13059,-13048,-13036,-13025,-13013,-13002,-12990,-12979,-12967,-12956,-12944,-12933,-12921,-12909,-12898,-12886,-12875,-12863,-12852,-12840,-12829,-12817,-12805,-12794,-12782,-12771,-12759,-12748,-12736,-12724,-12713,-12701,-12690,-12678,-12666,-12655,-12643,-12632,-12620,-12609,-12597,-12585,-12574,-12562,-12550
.word -12539,-12527,-12516,-12504,-12492,-12481,-12469,-12458,-12446,-12434,-12423,-12411,-12399,-12388,-12376,-12365,-12353,-12341,-12330,-12318,-12306,-12295,-12283,-12271,-12260,-12248,-12236,-12225,-12213,-12201,-12190,-12178,-12166,-12155,-12143,-12131,-12120,-12108,-12096,-12085,-12073,-12061,-12050,-12038,-12026,-12015,-12003,-11991,-11980,-11968,-11956,-11944,-11933,-11921,-11909,-11898,-11886,-11874,-11862,-11851,-11839,-11827,-11816,-11804,-11792,-11780,-11769,-11757,-11745,-11734,-11722,-11710,-11698,-11687,-11675,-11663,-11651,-11640,-11628,-11616,-11604,-11593,-11581,-11569,-11557,-11546,-11534,-11522,-11510,-11499,-11487,-11475,-11463,-11451,-11440,-11428,-11416,-11404,-11393,-11381,-11369,-11357,-11345,-11334,-11322,-11310,-11298,-11286,-11275,-11263,-11251,-11239,-11227,-11216,-11204,-11192,-11180,-11168,-11157,-11145,-11133,-11121,-11109,-11098,-11086,-11074,-11062,-11050
.word -11038,-11027,-11015,-11003,-10991,-10979,-10967,-10956,-10944,-10932,-10920,-10908,-10896,-10884,-10873,-10861,-10849,-10837,-10825,-10813,-10801,-10790,-10778,-10766,-10754,-10742,-10730,-10718,-10706,-10695,-10683,-10671,-10659,-10647,-10635,-10623,-10611,-10600,-10588,-10576,-10564,-10552,-10540,-10528,-10516,-10504,-10492,-10481,-10469,-10457,-10445,-10433,-10421,-10409,-10397,-10385,-10373,-10361,-10349,-10338,-10326,-10314,-10302,-10290,-10278,-10266,-10254,-10242,-10230,-10218,-10206,-10194,-10182,-10170,-10159,-10147,-10135,-10123,-10111,-10099,-10087,-10075,-10063,-10051,-10039,-10027,-10015,-10003,-9991,-9979,-9967,-9955,-9943,-9931,-9919,-9907,-9895,-9883,-9871,-9859,-9847,-9835,-9823,-9811,-9799,-9787,-9775,-9763,-9751,-9739,-9727,-9715,-9703,-9691,-9679,-9667,-9655,-9643,-9631,-9619,-9607,-9595,-9583,-9571,-9559,-9547,-9535,-9523
.word -9511,-9499,-9487,-9475,-9463,-9451,-9439,-9427,-9415,-9403,-9391,-9379,-9367,-9355,-9343,-9331,-9319,-9307,-9295,-9283,-9270,-9258,-9246,-9234,-9222,-9210,-9198,-9186,-9174,-9162,-9150,-9138,-9126,-9114,-9102,-9090,-9077,-9065,-9053,-9041,-9029,-9017,-9005,-8993,-8981,-8969,-8957,-8945,-8932,-8920,-8908,-8896,-8884,-8872,-8860,-8848,-8836,-8824,-8812,-8799,-8787,-8775,-8763,-8751,-8739,-8727,-8715,-8703,-8690,-8678,-8666,-8654,-8642,-8630,-8618,-8606,-8593,-8581,-8569,-8557,-8545,-8533,-8521,-8509,-8496,-8484,-8472,-8460,-8448,-8436,-8424,-8411,-8399,-8387,-8375,-8363,-8351,-8339,-8326,-8314,-8302,-8290,-8278,-8266,-8253,-8241,-8229,-8217,-8205,-8193,-8180,-8168,-8156,-8144,-8132,-8120,-8107,-8095,-8083,-8071,-8059,-8047,-8034,-8022,-8010,-7998,-7986,-7973
.word -7961,-7949,-7937,-7925,-7912,-7900,-7888,-7876,-7864,-7851,-7839,-7827,-7815,-7803,-7790,-7778,-7766,-7754,-7742,-7729,-7717,-7705,-7693,-7681,-7668,-7656,-7644,-7632,-7619,-7607,-7595,-7583,-7571,-7558,-7546,-7534,-7522,-7509,-7497,-7485,-7473,-7460,-7448,-7436,-7424,-7412,-7399,-7387,-7375,-7363,-7350,-7338,-7326,-7314,-7301,-7289,-7277,-7265,-7252,-7240,-7228,-7216,-7203,-7191,-7179,-7167,-7154,-7142,-7130,-7117,-7105,-7093,-7081,-7068,-7056,-7044,-7032,-7019,-7007,-6995,-6982,-6970,-6958,-6946,-6933,-6921,-6909,-6897,-6884,-6872,-6860,-6847,-6835,-6823,-6810,-6798,-6786,-6774,-6761,-6749,-6737,-6724,-6712,-6700,-6688,-6675,-6663,-6651,-6638,-6626,-6614,-6601,-6589,-6577,-6564,-6552,-6540,-6528,-6515,-6503,-6491,-6478,-6466,-6454,-6441,-6429,-6417,-6404
.word -6392,-6380,-6367,-6355,-6343,-6330,-6318,-6306,-6293,-6281,-6269,-6256,-6244,-6232,-6219,-6207,-6195,-6182,-6170,-6158,-6145,-6133,-6121,-6108,-6096,-6084,-6071,-6059,-6047,-6034,-6022,-6010,-5997,-5985,-5972,-5960,-5948,-5935,-5923,-5911,-5898,-5886,-5874,-5861,-5849,-5836,-5824,-5812,-5799,-5787,-5775,-5762,-5750,-5738,-5725,-5713,-5700,-5688,-5676,-5663,-5651,-5639,-5626,-5614,-5601,-5589,-5577,-5564,-5552,-5539,-5527,-5515,-5502,-5490,-5478,-5465,-5453,-5440,-5428,-5416,-5403,-5391,-5378,-5366,-5354,-5341,-5329,-5316,-5304,-5292,-5279,-5267,-5254,-5242,-5230,-5217,-5205,-5192,-5180,-5168,-5155,-5143,-5130,-5118,-5106,-5093,-5081,-5068,-5056,-5043,-5031,-5019,-5006,-4994,-4981,-4969,-4957,-4944,-4932,-4919,-4907,-4894,-4882,-4870,-4857,-4845,-4832,-4820
.word -4807,-4795,-4783,-4770,-4758,-4745,-4733,-4720,-4708,-4696,-4683,-4671,-4658,-4646,-4633,-4621,-4608,-4596,-4584,-4571,-4559,-4546,-4534,-4521,-4509,-4496,-4484,-4472,-4459,-4447,-4434,-4422,-4409,-4397,-4384,-4372,-4359,-4347,-4335,-4322,-4310,-4297,-4285,-4272,-4260,-4247,-4235,-4222,-4210,-4198,-4185,-4173,-4160,-4148,-4135,-4123,-4110,-4098,-4085,-4073,-4060,-4048,-4035,-4023,-4011,-3998,-3986,-3973,-3961,-3948,-3936,-3923,-3911,-3898,-3886,-3873,-3861,-3848,-3836,-3823,-3811,-3798,-3786,-3773,-3761,-3749,-3736,-3724,-3711,-3699,-3686,-3674,-3661,-3649,-3636,-3624,-3611,-3599,-3586,-3574,-3561,-3549,-3536,-3524,-3511,-3499,-3486,-3474,-3461,-3449,-3436,-3424,-3411,-3399,-3386,-3374,-3361,-3349,-3336,-3324,-3311,-3299,-3286,-3274,-3261,-3249,-3236,-3224
.word -3211,-3199,-3186,-3174,-3161,-3149,-3136,-3124,-3111,-3099,-3086,-3074,-3061,-3049,-3036,-3024,-3011,-2999,-2986,-2974,-2961,-2949,-2936,-2923,-2911,-2898,-2886,-2873,-2861,-2848,-2836,-2823,-2811,-2798,-2786,-2773,-2761,-2748,-2736,-2723,-2711,-2698,-2686,-2673,-2661,-2648,-2636,-2623,-2610,-2598,-2585,-2573,-2560,-2548,-2535,-2523,-2510,-2498,-2485,-2473,-2460,-2448,-2435,-2423,-2410,-2397,-2385,-2372,-2360,-2347,-2335,-2322,-2310,-2297,-2285,-2272,-2260,-2247,-2235,-2222,-2209,-2197,-2184,-2172,-2159,-2147,-2134,-2122,-2109,-2097,-2084,-2072,-2059,-2046,-2034,-2021,-2009,-1996,-1984,-1971,-1959,-1946,-1934,-1921,-1908,-1896,-1883,-1871,-1858,-1846,-1833,-1821,-1808,-1796,-1783,-1770,-1758,-1745,-1733,-1720,-1708,-1695,-1683,-1670,-1657,-1645,-1632,-1620
.word -1607,-1595,-1582,-1570,-1557,-1545,-1532,-1519,-1507,-1494,-1482,-1469,-1457,-1444,-1432,-1419,-1406,-1394,-1381,-1369,-1356,-1344,-1331,-1319,-1306,-1293,-1281,-1268,-1256,-1243,-1231,-1218,-1206,-1193,-1180,-1168,-1155,-1143,-1130,-1118,-1105,-1093,-1080,-1067,-1055,-1042,-1030,-1017,-1005,-992,-979,-967,-954,-942,-929,-917,-904,-892,-879,-866,-854,-841,-829,-816,-804,-791,-779,-766,-753,-741,-728,-716,-703,-691,-678,-665,-653,-640,-628,-615,-603,-590,-577,-565,-552,-540,-527,-515,-502,-490,-477,-464,-452,-439,-427,-414,-402,-389,-376,-364,-351,-339,-326,-314,-301,-289,-276,-263,-251,-238,-226,-213,-201,-188,-175,-163,-150,-138,-125,-113,-100,-87,-75,-62,-50,-37,-25,-12
.word 0,12,25,37,50,62,75,87,100,113,125,138,150,163,175,188,201,213,226,238,251,263,276,289,301,314,326,339,351,364,376,389,402,414,427,439,452,464,477,490,502,515,527,540,552,565,578,590,603,615,628,640,653,665,678,691,703,716,728,741,753,766,779,791,804,816,829,841,854,866,879,892,904,917,929,942,954,967,980,992,1005,1017,1030,1042,1055,1067,1080,1093,1105,1118,1130,1143,1155,1168,1180,1193,1206,1218,1231,1243,1256,1268,1281,1293,1306,1319,1331,1344,1356,1369,1381,1394,1406,1419,1432,1444,1457,1469,1482,1494,1507,1519,1532,1545,1557,1570,1582,1595
.word 1607,1620,1632,1645,1658,1670,1683,1695,1708,1720,1733,1745,1758,1770,1783,1796,1808,1821,1833,1846,1858,1871,1883,1896,1908,1921,1934,1946,1959,1971,1984,1996,2009,2021,2034,2046,2059,2072,2084,2097,2109,2122,2134,2147,2159,2172,2184,2197,2209,2222,2235,2247,2260,2272,2285,2297,2310,2322,2335,2347,2360,2372,2385,2397,2410,2423,2435,2448,2460,2473,2485,2498,2510,2523,2535,2548,2560,2573,2585,2598,2610,2623,2636,2648,2661,2673,2686,2698,2711,2723,2736,2748,2761,2773,2786,2798,2811,2823,2836,2848,2861,2873,2886,2898,2911,2923,2936,2949,2961,2974,2986,2999,3011,3024,3036,3049,3061,3074,3086,3099,3111,3124,3136,3149,3161,3174,3186,3199
.word 3211,3224,3236,3249,3261,3274,3286,3299,3311,3324,3336,3349,3361,3374,3386,3399,3411,3424,3436,3449,3461,3474,3486,3499,3511,3524,3536,3549,3561,3574,3586,3599,3611,3624,3636,3649,3661,3674,3686,3699,3711,3724,3736,3749,3761,3773,3786,3798,3811,3823,3836,3848,3861,3873,3886,3898,3911,3923,3936,3948,3961,3973,3986,3998,4011,4023,4035,4048,4060,4073,4085,4098,4110,4123,4135,4148,4160,4173,4185,4198,4210,4222,4235,4247,4260,4272,4285,4297,4310,4322,4335,4347,4359,4372,4384,4397,4409,4422,4434,4447,4459,4472,4484,4496,4509,4521,4534,4546,4559,4571,4584,4596,4608,4621,4633,4646,4658,4671,4683,4696,4708,4720,4733,4745,4758,4770,4783,4795
.word 4807,4820,4832,4845,4857,4870,4882,4894,4907,4919,4932,4944,4957,4969,4981,4994,5006,5019,5031,5043,5056,5068,5081,5093,5106,5118,5130,5143,5155,5168,5180,5192,5205,5217,5230,5242,5254,5267,5279,5292,5304,5316,5329,5341,5354,5366,5378,5391,5403,5416,5428,5440,5453,5465,5478,5490,5502,5515,5527,5539,5552,5564,5577,5589,5601,5614,5626,5639,5651,5663,5676,5688,5700,5713,5725,5738,5750,5762,5775,5787,5799,5812,5824,5837,5849,5861,5874,5886,5898,5911,5923,5935,5948,5960,5972,5985,5997,6010,6022,6034,6047,6059,6071,6084,6096,6108,6121,6133,6145,6158,6170,6182,6195,6207,6219,6232,6244,6256,6269,6281,6293,6306,6318,6330,6343,6355,6367,6380
.word 6392,6404,6417,6429,6441,6454,6466,6478,6491,6503,6515,6528,6540,6552,6564,6577,6589,6601,6614,6626,6638,6651,6663,6675,6688,6700,6712,6724,6737,6749,6761,6774,6786,6798,6811,6823,6835,6847,6860,6872,6884,6897,6909,6921,6933,6946,6958,6970,6982,6995,7007,7019,7032,7044,7056,7068,7081,7093,7105,7117,7130,7142,7154,7167,7179,7191,7203,7216,7228,7240,7252,7265,7277,7289,7301,7314,7326,7338,7350,7363,7375,7387,7399,7412,7424,7436,7448,7461,7473,7485,7497,7509,7522,7534,7546,7558,7571,7583,7595,7607,7619,7632,7644,7656,7668,7681,7693,7705,7717,7729,7742,7754,7766,7778,7790,7803,7815,7827,7839,7851,7864,7876,7888,7900,7912,7925,7937,7949
.word 7961,7973,7986,7998,8010,8022,8034,8047,8059,8071,8083,8095,8107,8120,8132,8144,8156,8168,8180,8193,8205,8217,8229,8241,8253,8266,8278,8290,8302,8314,8326,8339,8351,8363,8375,8387,8399,8411,8424,8436,8448,8460,8472,8484,8496,8509,8521,8533,8545,8557,8569,8581,8593,8606,8618,8630,8642,8654,8666,8678,8690,8703,8715,8727,8739,8751,8763,8775,8787,8799,8812,8824,8836,8848,8860,8872,8884,8896,8908,8920,8932,8945,8957,8969,8981,8993,9005,9017,9029,9041,9053,9065,9077,9090,9102,9114,9126,9138,9150,9162,9174,9186,9198,9210,9222,9234,9246,9258,9270,9283,9295,9307,9319,9331,9343,9355,9367,9379,9391,9403,9415,9427,9439,9451,9463,9475,9487,9499
.word 9511,9523,9535,9547,9559,9571,9583,9595,9607,9619,9631,9643,9655,9667,9679,9691,9703,9715,9727,9739,9751,9763,9775,9787,9799,9811,9823,9835,9847,9859,9871,9883,9895,9907,9919,9931,9943,9955,9967,9979,9991,10003,10015,10027,10039,10051,10063,10075,10087,10099,10111,10123,10135,10147,10159,10170,10182,10194,10206,10218,10230,10242,10254,10266,10278,10290,10302,10314,10326,10338,10349,10361,10373,10385,10397,10409,10421,10433,10445,10457,10469,10481,10492,10504,10516,10528,10540,10552,10564,10576,10588,10600,10611,10623,10635,10647,10659,10671,10683,10695,10706,10718,10730,10742,10754,10766,10778,10790,10801,10813,10825,10837,10849,10861,10873,10884,10896,10908,10920,10932,10944,10956,10967,10979,10991,11003,11015,11027
.word 11038,11050,11062,11074,11086,11098,11109,11121,11133,11145,11157,11168,11180,11192,11204,11216,11227,11239,11251,11263,11275,11286,11298,11310,11322,11334,11345,11357,11369,11381,11393,11404,11416,11428,11440,11451,11463,11475,11487,11499,11510,11522,11534,11546,11557,11569,11581,11593,11604,11616,11628,11640,11651,11663,11675,11687,11698,11710,11722,11734,11745,11757,11769,11780,11792,11804,11816,11827,11839,11851,11863,11874,11886,11898,11909,11921,11933,11944,11956,11968,11980,11991,12003,12015,12026,12038,12050,12061,12073,12085,12096,12108,12120,12131,12143,12155,12166,12178,12190,12201,12213,12225,12236,12248,12260,12271,12283,12295,12306,12318,12330,12341,12353,12365,12376,12388,12399,12411,12423,12434,12446,12458,12469,12481,12492,12504,12516,12527
.word 12539,12550,12562,12574,12585,12597,12609,12620,12632,12643,12655,12666,12678,12690,12701,12713,12724,12736,12748,12759,12771,12782,12794,12805,12817,12829,12840,12852,12863,12875,12886,12898,12909,12921,12933,12944,12956,12967,12979,12990,13002,13013,13025,13036,13048,13059,13071,13082,13094,13106,13117,13129,13140,13152,13163,13175,13186,13198,13209,13221,13232,13244,13255,13267,13278,13290,13301,13313,13324,13335,13347,13358,13370,13381,13393,13404,13416,13427,13439,13450,13462,13473,13485,13496,13507,13519,13530,13542,13553,13565,13576,13587,13599,13610,13622,13633,13645,13656,13667,13679,13690,13702,13713,13725,13736,13747,13759,13770,13782,13793,13804,13816,13827,13839,13850,13861,13873,13884,13896,13907,13918,13930,13941,13952,13964,13975,13986,13998
.word 14009,14021,14032,14043,14055,14066,14077,14089,14100,14111,14123,14134,14145,14157,14168,14179,14191,14202,14213,14225,14236,14247,14259,14270,14281,14293,14304,14315,14326,14338,14349,14360,14372,14383,14394,14406,14417,14428,14439,14451,14462,14473,14484,14496,14507,14518,14530,14541,14552,14563,14575,14586,14597,14608,14620,14631,14642,14653,14665,14676,14687,14698,14709,14721,14732,14743,14754,14766,14777,14788,14799,14810,14822,14833,14844,14855,14866,14878,14889,14900,14911,14922,14934,14945,14956,14967,14978,14989,15001,15012,15023,15034,15045,15057,15068,15079,15090,15101,15112,15123,15135,15146,15157,15168,15179,15190,15201,15213,15224,15235,15246,15257,15268,15279,15290,15301,15313,15324,15335,15346,15357,15368,15379,15390,15401,15413,15424,15435
.word 15446,15457,15468,15479,15490,15501,15512,15523,15534,15545,15556,15568,15579,15590,15601,15612,15623,15634,15645,15656,15667,15678,15689,15700,15711,15722,15733,15744,15755,15766,15777,15788,15799,15810,15821,15832,15843,15854,15865,15876,15887,15898,15909,15920,15931,15942,15953,15964,15975,15986,15997,16008,16019,16030,16041,16052,16063,16074,16085,16096,16107,16117,16128,16139,16150,16161,16172,16183,16194,16205,16216,16227,16238,16249,16260,16270,16281,16292,16303,16314,16325,16336,16347,16358,16368,16379,16390,16401,16412,16423,16434,16445,16455,16466,16477,16488,16499,16510,16521,16532,16542,16553,16564,16575,16586,16597,16607,16618,16629,16640,16651,16662,16672,16683,16694,16705,16716,16726,16737,16748,16759,16770,16780,16791,16802,16813,16824,16834
.word 16845,16856,16867,16877,16888,16899,16910,16920,16931,16942,16953,16964,16974,16985,16996,17007,17017,17028,17039,17049,17060,17071,17082,17092,17103,17114,17125,17135,17146,17157,17167,17178,17189,17199,17210,17221,17232,17242,17253,17264,17274,17285,17296,17306,17317,17328,17338,17349,17360,17370,17381,17392,17402,17413,17423,17434,17445,17455,17466,17477,17487,17498,17509,17519,17530,17540,17551,17562,17572,17583,17593,17604,17615,17625,17636,17646,17657,17668,17678,17689,17699,17710,17720,17731,17742,17752,17763,17773,17784,17794,17805,17815,17826,17837,17847,17858,17868,17879,17889,17900,17910,17921,17931,17942,17952,17963,17973,17984,17994,18005,18015,18026,18036,18047,18057,18068,18078,18089,18099,18110,18120,18131,18141,18152,18162,18173,18183,18193
.word 18204,18214,18225,18235,18246,18256,18267,18277,18287,18298,18308,18319,18329,18339,18350,18360,18371,18381,18392,18402,18412,18423,18433,18443,18454,18464,18475,18485,18495,18506,18516,18526,18537,18547,18558,18568,18578,18589,18599,18609,18620,18630,18640,18651,18661,18671,18682,18692,18702,18713,18723,18733,18744,18754,18764,18774,18785,18795,18805,18816,18826,18836,18846,18857,18867,18877,18888,18898,18908,18918,18929,18939,18949,18959,18970,18980,18990,19000,19011,19021,19031,19041,19051,19062,19072,19082,19092,19103,19113,19123,19133,19143,19154,19164,19174,19184,19194,19205,19215,19225,19235,19245,19255,19266,19276,19286,19296,19306,19316,19327,19337,19347,19357,19367,19377,19387,19397,19408,19418,19428,19438,19448,19458,19468,19478,19488,19499,19509
.word 19519,19529,19539,19549,19559,19569,19579,19589,19599,19610,19620,19630,19640,19650,19660,19670,19680,19690,19700,19710,19720,19730,19740,19750,19760,19770,19780,19790,19800,19810,19820,19830,19840,19850,19860,19870,19880,19890,19900,19910,19920,19930,19940,19950,19960,19970,19980,19990,20000,20010,20020,20030,20040,20050,20060,20070,20079,20089,20099,20109,20119,20129,20139,20149,20159,20169,20179,20189,20198,20208,20218,20228,20238,20248,20258,20268,20277,20287,20297,20307,20317,20327,20337,20346,20356,20366,20376,20386,20396,20406,20415,20425,20435,20445,20455,20464,20474,20484,20494,20504,20513,20523,20533,20543,20553,20562,20572,20582,20592,20602,20611,20621,20631,20641,20650,20660,20670,20680,20689,20699,20709,20719,20728,20738,20748,20758,20767,20777
.word 20787,20796,20806,20816,20825,20835,20845,20855,20864,20874,20884,20893,20903,20913,20922,20932,20942,20951,20961,20971,20980,20990,21000,21009,21019,21029,21038,21048,21057,21067,21077,21086,21096,21106,21115,21125,21134,21144,21154,21163,21173,21182,21192,21202,21211,21221,21230,21240,21249,21259,21269,21278,21288,21297,21307,21316,21326,21335,21345,21354,21364,21373,21383,21393,21402,21412,21421,21431,21440,21450,21459,21469,21478,21488,21497,21506,21516,21525,21535,21544,21554,21563,21573,21582,21592,21601,21611,21620,21629,21639,21648,21658,21667,21677,21686,21695,21705,21714,21724,21733,21743,21752,21761,21771,21780,21789,21799,21808,21818,21827,21836,21846,21855,21864,21874,21883,21893,21902,21911,21921,21930,21939,21949,21958,21967,21977,21986,21995
.word 22004,22014,22023,22032,22042,22051,22060,22070,22079,22088,22097,22107,22116,22125,22135,22144,22153,22162,22172,22181,22190,22199,22209,22218,22227,22236,22245,22255,22264,22273,22282,22292,22301,22310,22319,22328,22338,22347,22356,22365,22374,22383,22393,22402,22411,22420,22429,22438,22448,22457,22466,22475,22484,22493,22503,22512,22521,22530,22539,22548,22557,22566,22575,22585,22594,22603,22612,22621,22630,22639,22648,22657,22666,22675,22685,22694,22703,22712,22721,22730,22739,22748,22757,22766,22775,22784,22793,22802,22811,22820,22829,22838,22847,22856,22865,22874,22883,22892,22901,22910,22919,22928,22937,22946,22955,22964,22973,22982,22991,23000,23009,23018,23027,23036,23045,23053,23062,23071,23080,23089,23098,23107,23116,23125,23134,23143,23151,23160
.word 23169,23178,23187,23196,23205,23214,23223,23231,23240,23249,23258,23267,23276,23284,23293,23302,23311,23320,23329,23337,23346,23355,23364,23373,23382,23390,23399,23408,23417,23426,23434,23443,23452,23461,23469,23478,23487,23496,23504,23513,23522,23531,23539,23548,23557,23566,23574,23583,23592,23601,23609,23618,23627,23635,23644,23653,23661,23670,23679,23688,23696,23705,23714,23722,23731,23740,23748,23757,23766,23774,23783,23791,23800,23809,23817,23826,23835,23843,23852,23860,23869,23878,23886,23895,23903,23912,23921,23929,23938,23946,23955,23964,23972,23981,23989,23998,24006,24015,24023,24032,24041,24049,24058,24066,24075,24083,24092,24100,24109,24117,24126,24134,24143,24151,24160,24168,24177,24185,24194,24202,24211,24219,24228,24236,24244,24253,24261,24270
.word 24278,24287,24295,24304,24312,24320,24329,24337,24346,24354,24362,24371,24379,24388,24396,24404,24413,24421,24430,24438,24446,24455,24463,24471,24480,24488,24496,24505,24513,24521,24530,24538,24546,24555,24563,24571,24580,24588,24596,24605,24613,24621,24630,24638,24646,24654,24663,24671,24679,24687,24696,24704,24712,24720,24729,24737,24745,24753,24762,24770,24778,24786,24795,24803,24811,24819,24827,24836,24844,24852,24860,24868,24877,24885,24893,24901,24909,24917,24926,24934,24942,24950,24958,24966,24974,24983,24991,24999,25007,25015,25023,25031,25039,25047,25056,25064,25072,25080,25088,25096,25104,25112,25120,25128,25136,25144,25152,25161,25169,25177,25185,25193,25201,25209,25217,25225,25233,25241,25249,25257,25265,25273,25281,25289,25297,25305,25313,25321
.word 25329,25337,25345,25353,25361,25369,25377,25384,25392,25400,25408,25416,25424,25432,25440,25448,25456,25464,25472,25480,25487,25495,25503,25511,25519,25527,25535,25543,25550,25558,25566,25574,25582,25590,25598,25605,25613,25621,25629,25637,25645,25652,25660,25668,25676,25684,25691,25699,25707,25715,25723,25730,25738,25746,25754,25762,25769,25777,25785,25793,25800,25808,25816,25824,25831,25839,25847,25854,25862,25870,25878,25885,25893,25901,25908,25916,25924,25931,25939,25947,25954,25962,25970,25977,25985,25993,26000,26008,26016,26023,26031,26039,26046,26054,26061,26069,26077,26084,26092,26100,26107,26115,26122,26130,26137,26145,26153,26160,26168,26175,26183,26190,26198,26205,26213,26221,26228,26236,26243,26251,26258,26266,26273,26281,26288,26296,26303,26311
.word 26318,26326,26333,26341,26348,26356,26363,26371,26378,26385,26393,26400,26408,26415,26423,26430,26437,26445,26452,26460,26467,26475,26482,26489,26497,26504,26512,26519,26526,26534,26541,26548,26556,26563,26570,26578,26585,26593,26600,26607,26615,26622,26629,26636,26644,26651,26658,26666,26673,26680,26688,26695,26702,26709,26717,26724,26731,26739,26746,26753,26760,26768,26775,26782,26789,26797,26804,26811,26818,26825,26833,26840,26847,26854,26861,26869,26876,26883,26890,26897,26905,26912,26919,26926,26933,26940,26948,26955,26962,26969,26976,26983,26990,26997,27005,27012,27019,27026,27033,27040,27047,27054,27061,27068,27076,27083,27090,27097,27104,27111,27118,27125,27132,27139,27146,27153,27160,27167,27174,27181,27188,27195,27202,27209,27216,27223,27230,27237
.word 27244,27251,27258,27265,27272,27279,27286,27293,27300,27307,27314,27321,27328,27335,27342,27349,27355,27362,27369,27376,27383,27390,27397,27404,27411,27418,27424,27431,27438,27445,27452,27459,27466,27472,27479,27486,27493,27500,27507,27513,27520,27527,27534,27541,27548,27554,27561,27568,27575,27582,27588,27595,27602,27609,27615,27622,27629,27636,27642,27649,27656,27663,27669,27676,27683,27690,27696,27703,27710,27716,27723,27730,27736,27743,27750,27757,27763,27770,27777,27783,27790,27797,27803,27810,27816,27823,27830,27836,27843,27850,27856,27863,27869,27876,27883,27889,27896,27902,27909,27916,27922,27929,27935,27942,27948,27955,27962,27968,27975,27981,27988,27994,28001,28007,28014,28020,28027,28033,28040,28046,28053,28059,28066,28072,28079,28085,28092,28098
.word 28105,28111,28118,28124,28131,28137,28143,28150,28156,28163,28169,28176,28182,28188,28195,28201,28208,28214,28220,28227,28233,28239,28246,28252,28259,28265,28271,28278,28284,28290,28297,28303,28309,28316,28322,28328,28335,28341,28347,28353,28360,28366,28372,28379,28385,28391,28397,28404,28410,28416,28423,28429,28435,28441,28447,28454,28460,28466,28472,28479,28485,28491,28497,28503,28510,28516,28522,28528,28534,28541,28547,28553,28559,28565,28571,28578,28584,28590,28596,28602,28608,28614,28620,28627,28633,28639,28645,28651,28657,28663,28669,28675,28681,28687,28694,28700,28706,28712,28718,28724,28730,28736,28742,28748,28754,28760,28766,28772,28778,28784,28790,28796,28802,28808,28814,28820,28826,28832,28838,28844,28850,28856,28862,28868,28874,28880,28886,28891
.word 28897,28903,28909,28915,28921,28927,28933,28939,28945,28951,28956,28962,28968,28974,28980,28986,28992,28998,29003,29009,29015,29021,29027,29033,29038,29044,29050,29056,29062,29067,29073,29079,29085,29091,29096,29102,29108,29114,29119,29125,29131,29137,29142,29148,29154,29160,29165,29171,29177,29183,29188,29194,29200,29205,29211,29217,29222,29228,29234,29239,29245,29251,29256,29262,29268,29273,29279,29285,29290,29296,29302,29307,29313,29318,29324,29330,29335,29341,29346,29352,29358,29363,29369,29374,29380,29385,29391,29397,29402,29408,29413,29419,29424,29430,29435,29441,29446,29452,29457,29463,29468,29474,29479,29485,29490,29496,29501,29507,29512,29518,29523,29529,29534,29539,29545,29550,29556,29561,29567,29572,29577,29583,29588,29594,29599,29604,29610,29615
.word 29621,29626,29631,29637,29642,29647,29653,29658,29663,29669,29674,29679,29685,29690,29695,29701,29706,29711,29717,29722,29727,29732,29738,29743,29748,29753,29759,29764,29769,29774,29780,29785,29790,29795,29801,29806,29811,29816,29822,29827,29832,29837,29842,29848,29853,29858,29863,29868,29873,29879,29884,29889,29894,29899,29904,29909,29915,29920,29925,29930,29935,29940,29945,29950,29955,29961,29966,29971,29976,29981,29986,29991,29996,30001,30006,30011,30016,30021,30026,30031,30036,30041,30046,30051,30056,30061,30066,30071,30076,30081,30086,30091,30096,30101,30106,30111,30116,30121,30126,30131,30136,30141,30146,30151,30156,30160,30165,30170,30175,30180,30185,30190,30195,30200,30205,30209,30214,30219,30224,30229,30234,30238,30243,30248,30253,30258,30263,30267
.word 30272,30277,30282,30287,30291,30296,30301,30306,30311,30315,30320,30325,30330,30334,30339,30344,30349,30353,30358,30363,30368,30372,30377,30382,30386,30391,30396,30400,30405,30410,30415,30419,30424,30429,30433,30438,30442,30447,30452,30456,30461,30466,30470,30475,30480,30484,30489,30493,30498,30503,30507,30512,30516,30521,30525,30530,30535,30539,30544,30548,30553,30557,30562,30566,30571,30575,30580,30584,30589,30593,30598,30602,30607,30611,30616,30620,30625,30629,30634,30638,30643,30647,30652,30656,30660,30665,30669,30674,30678,30683,30687,30691,30696,30700,30705,30709,30713,30718,30722,30726,30731,30735,30739,30744,30748,30753,30757,30761,30766,30770,30774,30778,30783,30787,30791,30796,30800,30804,30809,30813,30817,30821,30826,30830,30834,30838,30843,30847
.word 30851,30855,30860,30864,30868,30872,30876,30881,30885,30889,30893,30897,30902,30906,30910,30914,30918,30922,30927,30931,30935,30939,30943,30947,30951,30955,30960,30964,30968,30972,30976,30980,30984,30988,30992,30996,31001,31005,31009,31013,31017,31021,31025,31029,31033,31037,31041,31045,31049,31053,31057,31061,31065,31069,31073,31077,31081,31085,31089,31093,31097,31101,31105,31109,31113,31117,31121,31124,31128,31132,31136,31140,31144,31148,31152,31156,31160,31164,31167,31171,31175,31179,31183,31187,31191,31194,31198,31202,31206,31210,31214,31217,31221,31225,31229,31233,31236,31240,31244,31248,31252,31255,31259,31263,31267,31270,31274,31278,31282,31285,31289,31293,31297,31300,31304,31308,31311,31315,31319,31323,31326,31330,31334,31337,31341,31345,31348,31352
.word 31356,31359,31363,31366,31370,31374,31377,31381,31385,31388,31392,31395,31399,31403,31406,31410,31413,31417,31420,31424,31428,31431,31435,31438,31442,31445,31449,31452,31456,31459,31463,31466,31470,31473,31477,31480,31484,31487,31491,31494,31498,31501,31505,31508,31512,31515,31518,31522,31525,31529,31532,31536,31539,31542,31546,31549,31553,31556,31559,31563,31566,31569,31573,31576,31580,31583,31586,31590,31593,31596,31600,31603,31606,31610,31613,31616,31619,31623,31626,31629,31633,31636,31639,31642,31646,31649,31652,31655,31659,31662,31665,31668,31672,31675,31678,31681,31684,31688,31691,31694,31697,31700,31704,31707,31710,31713,31716,31719,31723,31726,31729,31732,31735,31738,31741,31744,31748,31751,31754,31757,31760,31763,31766,31769,31772,31775,31778,31781
.word 31785,31788,31791,31794,31797,31800,31803,31806,31809,31812,31815,31818,31821,31824,31827,31830,31833,31836,31839,31842,31845,31848,31851,31854,31856,31859,31862,31865,31868,31871,31874,31877,31880,31883,31886,31889,31891,31894,31897,31900,31903,31906,31909,31911,31914,31917,31920,31923,31926,31929,31931,31934,31937,31940,31943,31945,31948,31951,31954,31957,31959,31962,31965,31968,31970,31973,31976,31979,31981,31984,31987,31989,31992,31995,31998,32000,32003,32006,32008,32011,32014,32016,32019,32022,32024,32027,32030,32032,32035,32038,32040,32043,32046,32048,32051,32053,32056,32059,32061,32064,32066,32069,32072,32074,32077,32079,32082,32084,32087,32089,32092,32095,32097,32100,32102,32105,32107,32110,32112,32115,32117,32120,32122,32125,32127,32130,32132,32134
.word 32137,32139,32142,32144,32147,32149,32152,32154,32156,32159,32161,32164,32166,32168,32171,32173,32176,32178,32180,32183,32185,32187,32190,32192,32194,32197,32199,32201,32204,32206,32208,32211,32213,32215,32218,32220,32222,32224,32227,32229,32231,32233,32236,32238,32240,32242,32245,32247,32249,32251,32254,32256,32258,32260,32262,32265,32267,32269,32271,32273,32275,32278,32280,32282,32284,32286,32288,32291,32293,32295,32297,32299,32301,32303,32305,32307,32310,32312,32314,32316,32318,32320,32322,32324,32326,32328,32330,32332,32334,32336,32338,32340,32342,32344,32346,32348,32350,32352,32354,32356,32358,32360,32362,32364,32366,32368,32370,32372,32374,32376,32378,32380,32382,32384,32386,32387,32389,32391,32393,32395,32397,32399,32401,32403,32404,32406,32408,32410
.word 32412,32414,32416,32417,32419,32421,32423,32425,32426,32428,32430,32432,32434,32435,32437,32439,32441,32443,32444,32446,32448,32450,32451,32453,32455,32456,32458,32460,32462,32463,32465,32467,32468,32470,32472,32473,32475,32477,32478,32480,32482,32483,32485,32487,32488,32490,32492,32493,32495,32496,32498,32500,32501,32503,32504,32506,32508,32509,32511,32512,32514,32515,32517,32519,32520,32522,32523,32525,32526,32528,32529,32531,32532,32534,32535,32537,32538,32540,32541,32543,32544,32546,32547,32548,32550,32551,32553,32554,32556,32557,32558,32560,32561,32563,32564,32565,32567,32568,32570,32571,32572,32574,32575,32576,32578,32579,32580,32582,32583,32584,32586,32587,32588,32590,32591,32592,32594,32595,32596,32597,32599,32600,32601,32602,32604,32605,32606,32607
.word 32609,32610,32611,32612,32614,32615,32616,32617,32618,32620,32621,32622,32623,32624,32625,32627,32628,32629,32630,32631,32632,32634,32635,32636,32637,32638,32639,32640,32641,32642,32644,32645,32646,32647,32648,32649,32650,32651,32652,32653,32654,32655,32656,32657,32658,32659,32660,32661,32662,32663,32664,32665,32666,32667,32668,32669,32670,32671,32672,32673,32674,32675,32676,32677,32678,32679,32680,32680,32681,32682,32683,32684,32685,32686,32687,32688,32688,32689,32690,32691,32692,32693,32694,32694,32695,32696,32697,32698,32699,32699,32700,32701,32702,32703,32703,32704,32705,32706,32706,32707,32708,32709,32709,32710,32711,32712,32712,32713,32714,32714,32715,32716,32717,32717,32718,32719,32719,32720,32721,32721,32722,32723,32723,32724,32725,32725,32726,32726
.word 32727,32728,32728,32729,32729,32730,32731,32731,32732,32732,32733,32734,32734,32735,32735,32736,32736,32737,32737,32738,32738,32739,32739,32740,32740,32741,32741,32742,32742,32743,32743,32744,32744,32745,32745,32746,32746,32747,32747,32747,32748,32748,32749,32749,32750,32750,32750,32751,32751,32751,32752,32752,32753,32753,32753,32754,32754,32754,32755,32755,32755,32756,32756,32756,32757,32757,32757,32758,32758,32758,32758,32759,32759,32759,32759,32760,32760,32760,32760,32761,32761,32761,32761,32762,32762,32762,32762,32762,32763,32763,32763,32763,32763,32764,32764,32764,32764,32764,32764,32764,32765,32765,32765,32765,32765,32765,32765,32765,32766,32766,32766,32766,32766,32766,32766,32766,32766,32766,32766,32766,32766,32766,32766,32766,32766,32766,32766,32766

.global costable


.end

