///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// 
// Copyright Nurve Networks LLC 2009
// 
// Filename: REM_AVR_ULTRA_DEMO_NTSC_01.c
//
// Original Author: Remi Veilleux
// 
// Last Modified: 01.19.09
//
// Overview: Technology demo to showcase Rem's Ultra graphic engine
//
// Controls: gamepad, use d-pad to move sprite or scrolling in some part of the demo
// 
// Demo must be linked with following source files:
// 
// XGS_AVR_SYSTEM_V010.c              - System variables.
// REM_AVR_NTSC_128_96_ULTRA_V010.s   - ASM NTSC bitmap driver.
// XGS_AVR_GAMEPAD_DRV_V010.c         - Gamepad driver.
//
// Note 1: header files for all sources must be in current working directory, so compiler can find them
//
// 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// INCLUDES ///////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// define chip type here
#define __AVR_ATmega644__

// define CPU frequency in Mhz here if not defined in Makefile, this is used for conditional compilation, so needs
// to be first, before other XGS includes, also note there is a copy of this constant in XGS_AVR_SYSTEM_V010, so if you 
// change it here, also change it in the header to make certain everthing is sync'ed
#define F_CPU 28636360UL

#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <math.h>
#include <avr/eeprom.h>
#include <avr/io.h>
#include <avr/sleep.h>
#include <avr/pgmspace.h>

#include <util/delay.h>
#include <avr/interrupt.h>
#include <avr/pgmspace.h>
#include <inttypes.h>
#include <compat/twi.h>

// include local XGS API header files
#include "XGS_AVR_SYSTEM_V010.h"
#include "XGS_AVR_GAMEPAD_DRV_V010.h"

// include header file for video driver
#include "REM_AVR_NTSC_128_96_ULTRA_V010.h"

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// TYPES  /////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
extern UCHAR overscan_color;
extern UCHAR hscroll;
extern UCHAR vscroll;
extern UINT framecount;
extern UCHAR* tilemap[];
extern UCHAR rem_avr_ultra_tiles;
extern UCHAR sintable[];

typedef struct
{
	UCHAR rowindex;
	UCHAR xoffset;
} SScanList;
extern SScanList scanlist[];

typedef struct
{
	UCHAR address;
	UCHAR x;
} SSprite;
extern SSprite spritelist[];


// NOTE: these externs need to be declared volatile because they are modified by the asm interrupt driver
extern volatile unsigned int  curr_line;
extern volatile unsigned char curr_raster_line;


///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// GLOBALS/////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// MAIN ///////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////


void GFX_Init(int video_interrupt_rate)
{
	// this function initializes the I/O ports for NTSC/PAL/VGA graphics as well as initilizes variables and turns on the 
	// driver interrupt which will immediately start feeding the data sources to the currently installed ASM driver, thus
	// make sure any pointers to data structures are initialized before calling this function
	// when done with graphics and you want to stop calling the graphics interrupt, call GFX_Shutdown(..)
	//
	// Inputs:
	//     video_interrupt_rate - the clock divider, so that the number of clocks per interrupt is equal to the HSYNC rate
	//                            since the interrupt handler runs every HSYNC in both NTSC/PAL and VGA modes

	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	// VIDEO INTERRUPT EXPERIMENT /////////////////////////////////////////////////////////////////////////////////////////
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

	// main graphics port that luma/chroma and VGA signals come from, port A
	#define GFX_MAIN_PORT       PORTA
	#define GFX_MAIN_DDR        DDRA

	// the "saturation" control is connected to port B
	#define GFX_SATURATION_PORT PORTB
	#define GFX_SATURATION_DDR  DDRB

	// set video ports to output
	GFX_MAIN_DDR  = 0xFF; // NTSC/PAL LUMA7:4 | CHROMA3:0, VGA7:0 [vsync, hsync, B1,B0, G1,G0, G1,G0] 
	              //                                        b7      b6    b5:4   b3:2   b1:0
	GFX_MAIN_PORT = 0x00;

	// set sat control bits PB2, PB3 as outputs
	GFX_SATURATION_DDR  =  SETPORTBITS(0,0,0,0,1,1,0,0);
	PORTB               =  SETPORTBITS(0,0,0,0,1,1,0,0);

	// set up timer                                     
	TCCR1A = (0 << COM1A1) | (0 << COM1A0) | (0 << COM1B1) | (0 << COM1B0) | (0 << WGM11) | (0 << WGM10);

	// set clock pre-scaler and counter mode
	TCCR1B = (0 << WGM13) | (1 << WGM12) | (0 << CS12) | (0 << CS11)  | (1 << CS10);    

	// 168. 644 use TIMSK1,TIFR1
	// 162 use TIMSK,TIFR

	// enable timer interrupts for timer 
	TIMSK1 = (1 << OCIE1A);                  //(1<<TOIE1);                 

	// clear and pendings timer x CTC interrupts (1 clears it)
	TIFR1  = (1 << OCF1A); // (1<<TOV1);                  

	// set output compare register value
	OCR1A  = video_interrupt_rate; // 1817+-1 for NTSC at 28.636 Mhz = 15.748Hkz hsync rate, 910 for VGA @ 28.636Mhz = 31.468Khz, hsync rate

	// enable interrupt
	sei();
} // end GFX_Init

#define GET_TILE(index) (&rem_avr_ultra_tiles + (((UINT)(index)&31)*8) + (((UINT)(index)>>5)*256*8))

void resettile()
{
	UCHAR i, j;

	// Prepare address for tiles
	for(j=0; j<13; j++)
	{
		for(i=0; i<TILEMAP_WIDTH; i++)
		{
			tilemap[(j*TILEMAP_WIDTH) + i] = GET_TILE(0);
		}
	}
	for(j=13; j<TILEMAP_HEIGHT; j++)
	{
		for(i=0; i<TILEMAP_WIDTH; i++)
		{
			tilemap[(j*TILEMAP_WIDTH) + i] = GET_TILE(639); // Tile 639 is last tile: fully black
		}
	}

	// Initialize default scanlist: this tells which tilemap scanline gets rendered by each scanline.
	for(i=0; i<192; i++)
	{
		scanlist[i].rowindex = i>>1;
		scanlist[i].xoffset = 0;
	}
	// Special case: last row should not be used because it also displays the first scanline
	// We'll make it point to line 7 of tilerow 14
	scanlist[191].rowindex = 14*8+7;

	vscroll = 0;
	hscroll = 0;
}

void drawcursor(UCHAR x, UCHAR y)
{
	tilemap[(y*TILEMAP_WIDTH) + x] = GET_TILE(64 + ((framecount>>2)&3));
}

void drawchar(UCHAR c, UCHAR x, UCHAR y)
{
	c -= 32;
	tilemap[(y*TILEMAP_WIDTH)+x] = GET_TILE(c);
}

void drawtext(PGM_P t, UCHAR x, UCHAR y)
{
	UCHAR c;

	do
	{
		c = pgm_read_byte(t);
		if(!c) break;
		drawchar(c, x, y);
		x++;
		t++;
	} while(1);
}

void debug_drawtext(char* t, UCHAR x, UCHAR y)
{
	UCHAR c;

	do
	{
		c = *t;
		if(!c) break;
		drawchar(c, x, y);
		x++;
		t++;
	} while(1);
}

void clear_displaylist()
{
	UINT i;
	for(i=0; i<96*8; i++)
	{
		spritelist[i].x = 0;
	}
}

char st0[] PROGMEM = "XGS AVR 8-BIT";
char st1[] PROGMEM = "ULTRA DEMO NTSC";
char st2[] PROGMEM = "RESOLUTION:";
char st3[] PROGMEM = "  128 X 96";
char st4[] PROGMEM = "TILE BASED";
char st5[] PROGMEM = "WITH SPRITES";

UCHAR cx, cy, command_index;

typedef struct
{
	UCHAR delay;
	PGM_P string;
} SCommand;

UCHAR do_commands(SCommand* commands)
{
	UCHAR c;
	UINT command;

	// If delay not elapsed: keep waiting
	if(commands[command_index].delay != 0)
	{
		drawcursor(cx, cy);
		commands[command_index].delay--;
		return 0;
	}

	drawchar(32, cx, cy);

	// If current command delay has elasped, it's time to do something
	command = (UINT) commands[command_index].string;

	switch(command)
	{
		case 0:  // If command is 0, this is the last command, we are done.
			return 1;
		case 1: // Command 1 means wipe screen
			if((framecount&1) == 0)
			{
				if(cx > 0)
				{
					cx--;
				}
				else
				{
					if(cy > 0)
					{
						cy--;
						cx = 15;
					}
					else
					{
						cx = 0;
						cy = 0;
						command_index++; // Wipe is complete: process with next command
						return 0;
					}
				}
			}
			drawcursor(cx, cy);
			break;

		default:
			// Fetch a single character for output
			c = pgm_read_byte(commands[command_index].string++);
			if(c) // If it's not 0, draw this character, make cursor move, and delay a little bit
			{
				drawchar(c, cx, cy);
				cx++;
				commands[command_index].delay = (rand()&7)+0;
			}
			else // Else we are done displaying this line: reset cursor to new line and proceed with next command
			{
				cx=0;
				cy++;
				command_index++;
			}
			break;
	}

	return 0;
}

void text_intro()
{
	int gamepad;           // used to read gamepad

	SCommand commands[7];

	commands[0].delay = 60; commands[0].string = st0;
	commands[1].delay = 30; commands[1].string = st1;
	commands[2].delay = 30; commands[2].string = st2;
	commands[3].delay = 10; commands[3].string = st3;
	commands[4].delay = 20; commands[4].string = st4;
	commands[5].delay = 20; commands[5].string = st5;
	commands[6].delay = 120; commands[6].string = 0;

	cx = 0;
	cy = 0;
	framecount = 0;
	command_index = 0;

	while(1)
	{
	    sleep_cpu();
	    if ( curr_line != END_ACTIVE_SCAN ) continue;

        gamepad = Gamepad_Read(GAMEPAD0);

		if(do_commands(commands))
		{
			return;
		}

		framecount++;
	}
}

char stintrowipe0[] PROGMEM = "4-WAY SMOOTH";
char stintrowipe1[] PROGMEM = "SCROLLING";

void text_intro_wipe()
{
	UCHAR y, j, i, state;
	y=190;
	for(i=0; i<TILEMAP_WIDTH; i++)
	{
		// Tile 638 is gray (because white seems to be problematic on some LCD monitor?
		tilemap[(13*TILEMAP_WIDTH) + i] = GET_TILE(638); 
	}

	cx = 15;
	cy = 1;
	state = 0;

	SCommand commands[4];
	commands[0].delay = 0; commands[0].string = (char*)1;
	commands[1].delay = 20; commands[1].string = stintrowipe0;
	commands[2].delay = 0; commands[2].string = stintrowipe1;
	commands[3].delay = 20; commands[3].string = 0;
	command_index = 0;

	while(1)
	{
	    sleep_cpu();
	    if ( curr_line != END_ACTIVE_SCAN ) continue;

		switch(state)
		{
			case 0:
				for(j=y+2; j<191; j++)
				{
					scanlist[j].rowindex = 13*8; // make these scanlines white
				}
				scanlist[y].rowindex = 14*8+7; // make this scanline black
				scanlist[y+1].rowindex = 14*8+7; // make this scanline black

				y-=2;
				if(y <= 28) state = 1;
				break;
			case 1:
				if(do_commands(commands))
				{
					return;
				}
				break;
		};

		framecount++;
	}
}

char stparallax0[] PROGMEM = "PARALLAX SCROLL";
char stparallax1[] PROGMEM = "D-PAD CONTROL";

void parallax()
{
	UCHAR gamepad;
	UCHAR i, j, k;
	UCHAR state;
	#define MAXLAYER 9
	struct
	{
		UINT x;
		UINT dx;
		UCHAR xoffset;
	} layers[MAXLAYER];

	framecount = 0;
	state = 0;

	resettile();

	for(j=0; j<MAXLAYER; j++)
	{
		layers[j].x = 0;
		layers[j].dx = 2 + j*2;
		layers[j].xoffset = 0;
	}
	vscroll = 128;
	hscroll = 32;

	SCommand commands[4];

	while(1)
	{
	    sleep_cpu();
	    if ( curr_line != END_ACTIVE_SCAN ) continue;

        gamepad = Gamepad_Read(GAMEPAD0);

		if ((gamepad & GAMEPAD_UP) && vscroll > 90) vscroll--;
		if ((gamepad & GAMEPAD_DOWN) && vscroll < 255) vscroll++;
		if ((gamepad & GAMEPAD_LEFT) && hscroll > 0) hscroll--;
		if ((gamepad & GAMEPAD_RIGHT) && hscroll < 255) hscroll++;

		// Clear display list
		clear_displaylist();

		switch(state)
		{
			case 0: // prepare text display
				commands[0].delay = 0; commands[0].string = (char*)1;
				commands[1].delay = 5; commands[1].string = stparallax0;
				commands[2].delay = 5; commands[2].string = stparallax1;
				commands[3].delay = 20; commands[3].string = 0;
				command_index = 0;
				state = 1;
				break;
			case 1: // wait for text commands
				if(do_commands(commands))
				{
					state = 2;
				}
				break;
			case 2:
				for(j=0; j<MAXLAYER; j++)
				{
					layers[j].x += layers[j].dx * hscroll;

					UCHAR c1 = (layers[j].x>>8)&15;
					UCHAR c2 = 24;

					if(c1 >= 8) c2 = 25;

					layers[j].xoffset = c1&7;
			
					for(i=0; i<TILEMAP_WIDTH; i++)
					{
						tilemap[((j+3)*TILEMAP_WIDTH) + i] = &rem_avr_ultra_tiles + (c2*8) + ((j+2)*256*8);
						c2 = 49-c2;
					}
				}
				if(framecount >= 900) return;

				break;
		}

		for(i=48; i<191; i++)
		{
			j = (((i-48) * vscroll)>>11);
			k = ((i-48) * vscroll)>>8;
			if(j >= MAXLAYER)
			{
				scanlist[i].xoffset = 0;
			}
			else
			{
				scanlist[i].xoffset = layers[j].xoffset;
			}
			if(k >= MAXLAYER*8)
			{
				scanlist[i].rowindex = 2*8;
			}
			else
			{
				scanlist[i].rowindex = (k+3*8);
			}
		}

		framecount++;
	}
}

char stball0[] PROGMEM = "WITH SPRITES";
char stball1[] PROGMEM = "EVEN BIG SPRITES";
char stball2[] PROGMEM = "WITH SPECIAL FX";

void tilemap_balls()
{
	UCHAR gamepad;
	int tx;
	UCHAR i, j, k;
	UCHAR c1, c2, c3, state;
	UCHAR nb_ball;
	UCHAR vbar[8];

	#define MAXBALLS 36
	struct
	{
		UINT x, y;
		int dx, dy;
	} balls[MAXBALLS]; // Struct takes 8 bytes * MAXBALLS = 288 of stack SRAM

	SCommand commands[4];

	for(i=0; i<MAXBALLS; i++)
	{
		balls[i].x = (rand()&127)<<8;
		balls[i].y = (rand()%78)<<8;
		balls[i].dx = (rand()&511) - 256;
		balls[i].dy = 0;
	}

	framecount = 0;
	nb_ball = 0;
	state = 0;

	// DEBUG: Skip some stuff
	//state = 8;
	//framecount = 2200;

	while(1)
	{
	    sleep_cpu();
	    if ( curr_line != END_ACTIVE_SCAN ) continue;

        gamepad = Gamepad_Read(GAMEPAD0);

		// Clear display list
		clear_displaylist();

		switch(state)
		{
			case 0: // wait 2 seconds, then prepare text display
				if(framecount >=120)
				{
					commands[0].delay = 0; commands[0].string = (char*)1;
					commands[1].delay = 5; commands[1].string = stball0;
					commands[2].delay = 20; commands[2].string = 0;
					command_index = 0;
					state = 1;
				}
				break;
			case 1: // wait for text commands
				if(do_commands(commands))
				{
					state = 2;
				}
				break;
			case 2: // Add sprites progressively (multiple small sprites bouncing)
				if((framecount&3)==0)
				{
					if(nb_ball == MAXBALLS-1)
					{
						state = 3;
					}
					else
					{
						nb_ball++;
					}
				}
				break;
			case 3: // Wait a bit, then display text
				if(framecount >= 560)
				{
					commands[0].delay = 0; commands[0].string = (char*)1;
					commands[1].delay = 5; commands[1].string = stball1;
					commands[2].delay = 0; commands[2].string = stball2;
					commands[3].delay = 20; commands[3].string = 0;
					command_index = 0;
					state = 4;
				}
				break;
			case 4: // Remove all sprites and wait for text commands, then create two big sprites
				if((framecount&1)==0 && nb_ball > 0) nb_ball--;

				if(do_commands(commands))
				{
					balls[0].x = 48<<8;
					balls[0].y = -32<<8;
					balls[0].dx = 127;
					balls[0].dy = 0;

					balls[0].x = 118<<8;
					balls[0].y = -32<<8;
					balls[0].dx = -127;
					balls[0].dy = 120;

					state = 5;
				}
				break;
			case 5: // Wait a bit, big sprites bouncing
				if(framecount >= 1200)
				{
					state = 6;
				}
				break;
			case 6: // Stop screen 4-way scrolling and make screen wave
				for(i=32; i<191; i++)
				{
					scanlist[i].rowindex = (((i)>>1));
					hscroll = (pgm_read_byte_near(sintable + (((i<<1)+(framecount<<1))&255))) >> 5;
					scanlist[i].xoffset = hscroll&7;
				}
				if(framecount >= 1400)
				{
					state = 7;
				}
				break;
			case 7: // screen wave + mirror effect 
				if(framecount >= 1600)
				{
					state = 8;
					for(i=0; i<8; i++)
					{
						vbar[i] = 32;
					}
				}
				break;
			case 8: // And add rotation color bars
				for(j=0; j<8; j++)
				{
					c1 = j&3;
					for(i=0; i<TILEMAP_WIDTH; i++)
					{
						tilemap[((c1+11)*TILEMAP_WIDTH) + i] = GET_TILE(90+c1); // Tile 90 is red color bar
					}
					vbar[j] = 48 + ((pgm_read_byte_near(sintable + (((framecount<<1) + 11*j)&255))) >> 2);
				}
				if(framecount >= 2300)
				{
					return;
				}
				break;
		};

		if(state >= 7)
		{
			for(i=32; i<138; i++)
			{
				scanlist[i].rowindex = (((i)>>1));
				hscroll = (pgm_read_byte_near(sintable + (((i<<1)+(framecount<<1))&255))) >> 5;
				scanlist[i].xoffset = hscroll&7;
			}
		}

		if(state >= 8)
		{
			for(i=0; i<8; i++)
			{
				for(j=0; j<16; j++)
				{
					scanlist[vbar[i]+j].rowindex = ((((11+(i&3))*8+(j>>1))));
					scanlist[vbar[i]+j].xoffset = 0;
				}
			}
		}

		if(state >= 7)
		{
			// Do mirror effect on the bottom part of the screen
			for(i=138; i<191; i++)
			{
				j = 413-(i<<1);
				scanlist[i].rowindex = scanlist[j].rowindex;
				scanlist[i].xoffset = scanlist[j].xoffset;
			}
		}

		if(state <= 5)
		{
			hscroll = pgm_read_byte(sintable + (framecount&255));
			vscroll = pgm_read_byte(sintable + ((framecount+64)&255))>>1;
			if(vscroll > (136-80)*2) vscroll = (136-80)*2;

			// Make screen scroll (4 directions)
			c1 = vscroll&15;
			for(i=32; i<191; i++)
			{
				scanlist[i].rowindex = (((i+c1)>>1));
				scanlist[i].xoffset = hscroll&7;
			}
			c1 = (vscroll>>4) + 3;
			for(j=2; j<13; j++)
			{
				if(c1 >= 20) c1 -= 17;
				c2 = hscroll>>3;
				for(i=0; i<TILEMAP_WIDTH; i++)
				{
					if(c2 >= 24) c2 -= 24;
					tilemap[(j*TILEMAP_WIDTH) + i] = &rem_avr_ultra_tiles + ((c2)*8) + ((c1)*256*8);

					c2++;
				}
				c1++;
			}
		}

		if(state >= 5)
		{
			// Make gamepad control balls[0]
			if ((gamepad & GAMEPAD_UP)) balls[0].y -= 256;
			if ((gamepad & GAMEPAD_DOWN)) balls[0].y += 256;
			if ((gamepad & GAMEPAD_LEFT)) balls[0].dx -= 10;
			if ((gamepad & GAMEPAD_RIGHT)) balls[0].dx += 10;
		}

		// Animate multiple small balls
		if(state <= 4)
		{
			{
				for(j=0; j<nb_ball; j++)
				{
					balls[j].x+=balls[j].dx;
					if(balls[j].x >= (136<<8))
					{
						balls[j].x = (136<<8);
						balls[j].dx = -(rand()&511)-50;
					}
					else if(balls[j].x < 256)
					{
						balls[j].x = 256;
						balls[j].dx = (rand()&511)+50;
					}

					balls[j].dy+=13;
					balls[j].y+=balls[j].dy;

					if(balls[j].y > (87<<8))
					{
						balls[j].y = (87<<8);
						balls[j].dy = -balls[j].dy;
					}
				}
			}
			{
				// For each ball, find an empty sprite in display list (if any!)
				for(j=0; j<nb_ball; j++)
				{
					// For each scanline of a ball
					for(k=0; k<8; k++)
					{
						c1 = (balls[j].y>>8) + k;

						for(i=0; i<8; i++)
						{
							if(spritelist[c1*8 + i].x != 0) continue;

							spritelist[c1*8 + i].x = balls[j].x>>8;
							spritelist[c1*8 + i].address = ((k&7)) + (((j&15)+16)<<3);
							break;
						}
					}
				}
			}
		}
		else // Else, draw two big sprites 32x32 (sprite 0,1,2,3 and 4,5,6,7)
		{
			for(k=0; k<=4; k+=4)
			{
				balls[k].x+=balls[k].dx;
				if(balls[k].x > (104<<8))
				{
					balls[k].x = (104<<8);
					balls[k].dx = -balls[k].dx;
				}
				else if(balls[k].x < (8<<8))
				{
					balls[k].x = (8<<8);
					balls[k].dx = -balls[k].dx;
				}

				balls[k].dy+=19;
				balls[k].y+=balls[k].dy;

				// Determinate 'floor' for sprite bouncing:
				c1 = 95-32; // normal floor: pixel 95
				if(state >= 7) c1 = 70-32; // when mirror is active, floor is now at 70

				if(balls[k].y < 32767 && balls[k].y > (c1<<8))
				{
					balls[k].y = (c1<<8);
					balls[k].dy = -400-((rand()&511));
				}

				tx = (balls[k].x>>8);
				c2=tx;

				for(j=0; j<32; j++)
				{
					c1 = j+(balls[k].y>>8);
					if(c1 > 94) continue;
					c3 = c2;

					for(i=0; i<4; i++)
					{
						spritelist[c1*8 + i+k].x = c3;
						spritelist[c1*8 + i+k].address = ((j&7)) + (((i + ((j>>3)<<2)))<<3);
						c3 += 8;
					}
				}
			}

			// one of the big-sprite appear 'behind' color bars
			if(state >= 8)
			{
				for(i=0; i<8; i++)
				{
					for(j=0; j<8; j++)
					{
						for(k=0; k<4; k++)
						{
							spritelist[((vbar[i]>>1)+j)*8 + k].x = 0;
						}
					}
				}
			}

			// Sprite mirror effect
			if(state >= 7)
			{
				for(j=69; j<95; j++)
				{
					k = 206-(j<<1);
					for(i=0; i<8; i++)
					{
						spritelist[j*8 + i].x = spritelist[k*8 + i].x;
						spritelist[j*8 + i].address = spritelist[k*8 + i].address;
					}
				}
			}
		}

		framecount++; 
	}
}

int main(void)
{
	resettile();

	// initialize the video driver and GFX engine
	GFX_Init( VIDEO_INTERRUPT_RATE );

	// initialize gamepad
	Gamepad_Init();

	// set processor sleep mode
	set_sleep_mode( SLEEP_MODE_IDLE );
	sleep_enable();
	//overscan_color = NTSC_ORANGE;

	while(1)
	{
		clear_displaylist();
		resettile();
		text_intro();
		text_intro_wipe();
		tilemap_balls();
		parallax();
	}

	return 0;
} // end main

