///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// 
// Copyright Nurve Networks LLC 2008
// 
// Filename: RPE_NTSC_BMP_96_72_4_V010.s
//
// Original Author: Andre' LaMothe
// 
// Last Modified: 12.21.08
// 
// Description: 96x72 resolution NTSC driver with 4-bits per pixel , thus
// every 4-bit pixel is used as an index into the color palette as shown 
// below:
//
//                                                    
// Pixel Value     Palette Index                Index      Color Encoding
//   0000       =       0    ---------------->   0   - [LUMA3..0 : CHROMA3..0 ] - 8-bit color (some values for sync etc.)
//   0001       =       1    ---------------->   1   - [LUMA3..0 : CHROMA3..0 ] - " "
//   0010       =       2    ---------------->   2   - [LUMA3..0 : CHROMA3..0 ] - " "
//    ..                .                        .        ..          ..          ..
//    ..                .                        .        ..          ..          ..
//   1110       =      14    ---------------->  14   - [LUMA3..0 : CHROMA3..0 ] - " "
//   1111       =      15    ---------------->  15   - [LUMA3..0 : CHROMA3..0 ] - " "
//
// Memory for bitmap modes is laid out from top left corner of the screen from left to right, top to bottom.
// Each byte represents 2 pixels where pixel 0,1 on screen are encoded frow low bit to high bit as shown below:
// 
// Pixel Encoding
//
//        P1     |      P0        <------ pixel #
// [ b7 b6 b5 b4 | b3 b2 b1 b0 ]  <------ bit encodings
// msb                         lsb        
// 
//                Video RAM Layout
// (0,0).....................................(96,0)
// .P0 P1 P2 P3...                           P96
// .
// .
// .
// .
// .
// .
// (0,96)...................................(96, 72)                          
// 
// For example, if you wanted to change the color of the pixel (0,0), then you would write the lower 4-bits
// of the very first byte of Video RAM.
//
// One palette of 16 colors
//
// The interface between the C caller and this driver is accomplished thru a pointer to VRAM from C,
// the palette base address exported back to C from this driver, along with a few status variables
// from the driver to interogate the current line, etc. See below:
//
// There is a single pointer to VRAM, the driver expects the C caller to allocate memory and then 
// initialize a pointer with the following name to point to the VRAM:
// 
// .extern vram_ptr      // 16-bit pointer passed in from caller that points to video RAM
//
// Next, the driver passses back the current absolute video line 0..524 via curr_line and the current
// virtual raster line via curr_raster_line:
//
// .global curr_line         // read only, current physical line
// .global curr_raster_line  // read only, current logical raster line
//
// Finally,the driver allocates its own memory for the palette which can be accessed here:
//
// .global palette_table // read/write, 16-bit base address to palette used for driver
//
// The caller is recommended to initialize the palette since it only has simple test colors in it.
//

//
// Modifications|Bugs|Additions:
//
// Author Name: Roy Eltham
//
//
//
//
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////



///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// SET PROCESSOR TYPE (must come first)
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#ifndef __AVR_ATmega644__
#define __AVR_ATmega644__
#endif

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// INCLUDES 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
#include <avr/interrupt.h> 
#include <avr/io.h>

// include header file for driver
#include "RPE_NTSC_BMP_96_72_4_V010.h"

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// DEFINES 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#define __SFR_OFFSET 0 // needed for macro, also fixes so you can use register names directly and NOT need macro _SFR_IO_ADDR( x )

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// MACROS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// this macro delays any number of clocks, uses chunks of 4
.macro  DELAYX reg = r16, clocks
    ldi     \reg, (\clocks)/4        // (1)
1:
    dec     \reg                     // (1)
    nop                              // (1)
    brne    1b                       // (1/2)

    // now delay fractional component
    .rept   (\clocks % 4)
    nop                              // (1)
    .endr

.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
   
// this macro delays any number of clocks that are a multiple of 4, anything else is truncated
.macro  DELAY4X reg = r16, clocks
    ldi     \reg, (\clocks)/4        // (1)
1:
    dec     \reg                     // (1)
    nop                              // (1)
    brne    1b                       // (1/2)
.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// this macro delays any number of clocks that are a multiple of 3, anything else is truncated
.macro  DELAY3X reg = r16, clocks
    ldi     \reg, (\clocks)/3        // (1)
1:
    dec     \reg                     // (1)
    brne    1b                       // (1/2)
.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.macro SPLIT_PIXEL2 rt = r0
    // pre-computational pixel block, simply splits each 2-pixels packed into a byte and spreads them across 2-bytes in the scanline buffer

    // assumes X is pointing to the next pixel in VRAM to split, 
    // Y is pointing to the back scanline buffer to store the split pixels
    // rt is the working register

    // 8 clocks per macro

    // split 0: retrieve next 2 pixels from VRAM, 1 byte
    // store lowest 4-bits, pixel 0
    ld      \rt, X+             // (2)
    st      Y+, \rt             // (2)

    // split 1: shift data 4x right to get next pixel value then store it
    swap    \rt                 // (1)
    st      Y+, \rt             // (2)

	nop							// (1)

.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.macro DRAW_PIXELS_NTSC_PT0B rp4 = r18, rp = r19
    // pixel type 0, starts off process, retrieves next 2-pack of pixels, total of 12 clocks
    
    // X -> scanline buffer
    // Z -> palette for set of 8-16 pixels
    // Y will be used as a temp register pair
    // r0 must be 0

    // retrieve next pixel and mask
    ld      \rp, X+           // (2), retrieve next pixel from unpacked scanline buffer
    andi    \rp, 0x0F         // (1), mask off lower bits representing pixel

    // at this point \rp has 4-bit pixel code, now lookup in palette
    movw    YL, ZL            // (1), copy Z -> Y, save for a moment
    add     ZL, \rp           // (1), Z = Z + \rp
    adc     ZH, r0            // (1), add carry in if needed from low byte
    
    // retrieve pixel
    ld      \rp, Z            // (2) rp = Z, retrieves pixel from lookup table  

    // restore palette pointer
    movw    ZL, YL            // (1), copy Y -> Z, restore


    // finally output pixel
    out     PORTA, \rp        // (1), write the pixel to video port

	nop						  // (1)
	nop						  // (1)

.endm


///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.macro  SAVE_SREG reg = r16

    in      \reg, SREG                       // save status register
    push    \reg

.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.macro  COLOR_BURST_CYCLE color_burst_lo, color_burst_hi

    out     PORTA, \color_burst_lo
    nop
    out     PORTA, \color_burst_hi
    nop
.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.macro  RESTORE_SREG reg = r16

    pop     \reg
    out     _SFR_IO_ADDR( SREG ), \reg      // restore status register

.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// LOCAL INITIALIZED VARIABLES (SRAM)
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.section .data

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// The palette is 16 colors of 8bits each. So 16 bytes. Also, there is no requirement that the palette data must be on a 
// page boundary, since there is time for full 16-bit addressing in the palette code. 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////


// these values arbitrary and just something to start with, the caller will want to initialize the palette himself
palette_table:  

.byte NTSC_GREEN, NTSC_YELLOW, NTSC_BROWN, NTSC_ORANGE
.byte NTSC_RED, NTSC_CRIMSON, NTSC_MAGENTA, NTSC_DARKPINK
.byte NTSC_PURPLE, NTSC_VIOLET, NTSC_SLATEBLUE, NTSC_ROYALBLUE
.byte NTSC_BLUE, NTSC_COBALT, NTSC_SKYBLUE, NTSC_BLACK

//.byte NTSC_BLACK, NTSC_GRAY0, NTSC_GRAY1, NTSC_GRAY2
//.byte NTSC_GRAY3, NTSC_GRAY4, NTSC_GRAY5, NTSC_GRAY6
//.byte NTSC_GRAY7, NTSC_GRAY8, NTSC_GRAY9, NTSC_WHITE
//.byte NTSC_RED, NTSC_GREEN, NTSC_BLUE, NTSC_VIOLET


///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// scanline buffer, used to decompose packed pixels (96 bytes)
sline_buffer:             .byte 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0 
                          .byte 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0 
                          .byte 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0

// pointer to vram's current position
vram_curr_ptr:            .byte 0,0

// current video line
curr_line:                .byte 0,0    

// current pixel
curr_pixel:               .byte 0     

// used to do line doubling
double_line_count:        .byte 0

// current raster line 0..95
curr_raster_line:         .byte 0

video_state:              .byte 0     // state of video kernal 0=init, 1=run normally

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// DATA STRUCTURES IN FLASH/ROM - NOTE: MUST ON WORD BOUNDARIES
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.section .text

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// EXTERNALS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.extern vram_ptr // 16-pit pointer passed in from caller that points to video RAM

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// GLOBALS EXPORTS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// export these to caller, so he can interogate and change
.global curr_line        // read only, current physical line
.global curr_raster_line // read only, current logical raster line
.global palette_table    // read/write, 16-bit base address to palette used for driver

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// ASM FUNCTIONS 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////


// VGA Interface Reference
//DDRA  = 0xFF; // NTSC/PAL LUMA7:4 | CHROMA3:0, VGA7:0 [vsync, hsync, B1,B0, G1,G0, G1,G0] 
//                                                        b7      b6    b5:4   b3:2   b1:0

.section .text

// asm entry point

.global	TIMER1_COMPA_vect  
TIMER1_COMPA_vect:

Save_Regs:

    // save working registers on stack
    push    r0              // (2)        
    push    r1              // (2)
    
    push    r16             // (2)
    push    r17             // (2)

    push    r18             // (2)
    push    r19             // (2)

    push    r20             // (2)
    push    r21             // (2)

    push    r24             // (2)
    push    r25             // (2)

    push    r26             // (2)   X
    push    r27             // (2)

    push    r28             // (2)   Y
    push    r29             // (2)

    push    r30             // (2)   Z
    push    r31             // (2)

    in      r0, SREG        // (2)
    push    r0              // (2) save the status register

                            // (32) clocks for stack push

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

NTSC_Start:

    // load r25:24 with curr_line
    lds     r24, curr_line                  // (2)
    lds     r25, curr_line+1                // (2)      

NTSC_Video_State_Test1:

    // if (curr_line < offset) then NTSC_Draw_Blank_Line
    ldi     r16, hi8(NTSC_VERTICAL_OFFSET)  // (1)
    cpi     r24, lo8(NTSC_VERTICAL_OFFSET)  // (1)
    cpc     r25, r16                        // (1)
    brlo    NTSC_Draw_Blank_Line_Top        // (1/2) NTSC_Start: (9) clocks -> jump, jump need due to code out of range for branch

// elseif
NTSC_Video_State_Test2:    

    // if (curr_line < ( screen height + offset) ) then NTSC_Draw_Active_Line
    ldi     r16, hi8(NTSC_SCREEN_HEIGHT*3 + NTSC_VERTICAL_OFFSET)  // (1) 
    cpi     r24, lo8(NTSC_SCREEN_HEIGHT*3 + NTSC_VERTICAL_OFFSET)  // (1)
    cpc     r25, r16                                             // (1)

    //brlo    NTSC_Draw_Active_Line  // (1/2) 

    brsh    NTSC_Video_State_Test3   // (1/2)
    jmp     NTSC_Draw_Active_Line    // (3)     NTSC_Start: (15) clocks -> jump, jump need due to code out of range for branch

// elseif
NTSC_Video_State_Test3:    

    // if (curr_line < 258) then NTSC_Draw_Blank_Line
    ldi     r16, hi8(258)            // (1) 
    cpi     r24, lo8(258)            // (1)
    cpc     r25, r16                 // (1)
    brlo    NTSC_Draw_Blank_Line_Bot // (1/2)   NTSC_Start: (18) clocks -> jump, jump need due to code out of range for branch

// elseif
NTSC_Video_State_Test4:    

    // if (curr_line < 262) then NTSC_Draw_Vsync_Line
    ldi     r16, hi8(262)            // (1) 
    cpi     r24, lo8(262)            // (1)
    cpc     r25, r16                 // (1)
    brlo    NTSC_Draw_Vsync_Line     // (1/2)   NTSC_Start: (22) clocks -> jump, jump need due to code out of range for branch
    // else should never get here...

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

NTSC_Draw_Blank_Line_Top: 

    // equalize delay from conditional line fork
    .rept (18 - 9)
    nop
    .endr

NTSC_Draw_Blank_Line_Bot: 

    // equalize delay from conditional line fork
    .rept (22 - 18)
    nop
    .endr

    // enable hsync, set video to black
    ldi     r16, NTSC_SYNC           // (1)
    out     PORTA, r16               // (1)

    // test if this is the top of frame here, we need to initialize the rendering kernel
    // if (curr_line == 0) then NTSC_Reset_Kernel
    ldi     r16, hi8(0)              // (1)
    cpi     r24, lo8(0)              // (1)
    cpc     r25, r16                 // (1)

    // now based on flags set above, jump to normal blank line or reset 
    breq    NTSC_Reset_Kernel        // (1/2)

    // else delay hsync time (this will be filled with processing in later versions)

    // 16 color clocks sync (128 clocks), this needs to be adjusted correctly to take above computation into consideration
    DELAYX r16, (16*CLOCKS_PER_PIXEL + 20)
    
    // disble hsync, maintain black
    ldi     r16, NTSC_BLACK          // (1)
    out     PORTA, r16               // (1)

#if 1
    // now color burst
    DELAY4X r16, (2*CLOCKS_PER_PIXEL)
    
    ldi     r16, NTSC_CBURST0               // (1)
    out     PORTA, r16                      // (1)

    // now color burst
    DELAYX r16, (10*CLOCKS_PER_PIXEL)

    // back to black HSYNC off
    ldi     r16, NTSC_BLACK                 // (1)
    out     PORTA, r16                      // (1)
#endif

    jmp     NTSC_Next_Line           // (3)    

NTSC_Reset_Kernel:
    // reset all data structures each frame at line 0

    // initialize any variables for algorithm    

    // assign VRAM pointer to begining of VRAM

    // vram_curr_ptr = vram_ptr
    lds     XL, vram_ptr                    // (2)
    lds     XH, vram_ptr+1                  // (2)
    sts     vram_curr_ptr, XL               // (2) 
    sts     vram_curr_ptr+1, XH             // (2)

    // initialize curr_raster_line for next frame, 
    ldi     r16, 0                           // (1)
    sts     curr_raster_line, r16                 // (2)

    // initialize double_line_count
    ldi     r16, 3                           // (1)
    sts     double_line_count, r16           // (2)

    // 16 color clocks sync (128 clocks), this needs to be adjusted correctly to take above computation into consideration
    DELAYX r16, (16*CLOCKS_PER_PIXEL + (20 - 12))

    // disble hsync, maintain black
    ldi     r16, NTSC_BLACK                 // (1)
    out     PORTA, r16                      // (1)

    jmp     NTSC_Next_Line                  // (3)

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  
NTSC_Draw_Vsync_Line:

    // invert hsync and maintain sync for 4-6 lines
    ldi     r16, NTSC_BLACK   // (1)
    out     PORTA, r16        // (1)

    // delay for hsync pulse length 

    // 16 color clocks sync (128 clocks)
    DELAYX r16, (16*CLOCKS_PER_PIXEL)
    
    // disble hsync, but maintain vsync and black
    ldi     r16, NTSC_SYNC   // (1)
    out     PORTA, r16       // (1)

    jmp     NTSC_Next_Line   // (3)

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

// enter
NTSC_Draw_Active_Line:

    // delay to equalize initial line fork
    .rept (22 - 12)
    nop
    .endr

    // enable hsync, set RGB to black (want approximately 16 color clocks for sync
    ldi     r16, NTSC_SYNC                  // (1)
    out     PORTA, r16                      // (1)

    // compute pallete base address based on current "raster line" 0..87
    lds     r20, curr_raster_line           // (1) r20 = curr_raster_line
    //mov     r16, r20                        // (1)
    //lsr     r16                             // (1), r16 = (curr_raster_line/8) * 4
    //lsr     r16                             // (1)
    //lsr     r16                             // (1)

    //ldi     r17, 4                          // (1)
    //mul     r16, r17                        // (2)  r1:r0 = (curr_raster_line/8) * 4 = [0..47]. i.e. 1 byte, result wholly in r0

    // now add base address of palette memory
    ldi     ZL, lo8( palette_table )        // (1)  
    ldi     ZH, hi8( palette_table )        // (1)

    //add     ZL, r0                          // (1), Z = palette + (curr_raster_line / 8) * 4
    //adc     ZH, r1                          // (1), dummy add for carry                                             
   
    // Z is now pointing to palette data for current curr_raster_line

    // restore X from VRAM saved current ptr   
    lds     XL, vram_curr_ptr               // (2)  
    lds     XH, vram_curr_ptr+1             // (2)

    // point Y to scanline buffer
    ldi     YL, lo8( sline_buffer )         // (1)  
    ldi     YH, hi8( sline_buffer )         // (1)  

    // split all the pixels apart, interleaving the color burst cycle
    .rept 16
    // each call splits 2 pixels apart, but no final AND mask for color index, must be done in active scan
    SPLIT_PIXEL2
    .endr

    // turn HSYNC off
    ldi     r16, NTSC_BLACK                 // (1)
    out     PORTA, r16                      // (1)

    .rept 2
    // each call splits 2 pixels apart, but no final AND mask for color index, must be done in active scan
    SPLIT_PIXEL2
    .endr

    ldi     r16, NTSC_CBURST0               // (1)
    out     PORTA, r16                      // (1)

    .rept 10
    // each call splits 2 pixels apart, but no final AND mask for color index, must be done in active scan
    SPLIT_PIXEL2
    .endr

    // back to black HSYNC off
    ldi     r16, NTSC_BLACK                 // (1)
    out     PORTA, r16                      // (1)

    .rept 20
    // each call splits 2 pixels apart, but no final AND mask for color index, must be done in active scan
    SPLIT_PIXEL2
    .endr

    // save VRAM ptr from X
    sts     vram_curr_ptr, XL               // (2)
    sts     vram_curr_ptr+1, XH             // (2)

    // now, point X to scanline buffer
    ldi     XL, lo8( sline_buffer )         // (1)  
    ldi     XH, hi8( sline_buffer )         // (1)  


    // Z is pointing to palette, Y will be used for temp

    // on entry X -> current video line
    //          Z -> first palette for tile on this raster line
    clr     r0                              // (1), r0 used as 0 in macros below

    // draw 96 pixels
    .rept NTSC_SCREEN_WIDTH 
        // draw the pixels now
        DRAW_PIXELS_NTSC_PT0B r18, r19  
    .endr

    // at this point, last pixel must display for n clocks = normal pixel time, do some work, delay the difference

    // delay remainder (pixel time - any work above - time to black below)
    .rept (12-2)
    nop
    .endr

    // set video back to black
    ldi     r16, NTSC_BLACK                 // (1)
    out     PORTA, r16                      // (1)

    // should we repeat this line?
    lds     r16, double_line_count         // (2)
    dec     r16                            // (1)
    brne    1f

    // reset line counter
    ldi     r16, 3                          // (1)
    sts     double_line_count, r16          // (2)

    // increment curr_raster_line
    inc     r20                             // (1)
    sts     curr_raster_line, r20           // (2)

    jmp     NTSC_Next_Line                  // (3)

1:
    // save line counter
    sts     double_line_count, r16          // (2)

    // load vram pointer back in
    lds     XL, vram_curr_ptr               // (2)
    lds     XH, vram_curr_ptr+1             // (2)

    //  back it up one line, i.e. draw the same line again
    sbiw    XL, (NTSC_SCREEN_WIDTH/NTSC_PIXELS_PER_BYTE) // (1)
    
    // save pointer back
    sts     vram_curr_ptr, XL               // (2)
    sts     vram_curr_ptr+1, XH             // (2)
   
    jmp     NTSC_Next_Line                  // (3)

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

NTSC_Next_Line:

    // curr_line++
    adiw    r24, 1                 // (2)

    // if (curr_line >= 262) curr_line = 0
    ldi     r16, hi8(262)          // (1) 
    cpi     r24, lo8(262)          // (1)
    cpc     r25, r16               // (1)
    brne    NTSC_End_Line          // (1/2)

    // curr_line = 0
    ldi     r24, 0                 // (1)
    ldi     r25, 0                 // (1)

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

NTSC_End_Line:

    // save registers back to curr_line in SRAM for exit back to C/C++ caller
    sts     curr_line,   r24       // (2)
    sts     curr_line+1, r25       // (2)

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

Restore_Regs:

    // restore the status register
    pop     r0          // (2)
    out     SREG, r0    // (1)        

    // restore working registers
    pop     r31         // (2), Z
    pop     r30         // (2)

    pop     r29         // (2), Y
    pop     r28         // (2)

    pop     r27         // (2), X
    pop     r26         // (2)

    pop     r25         // (2)
    pop     r24         // (2)

    pop     r21         // (2)
    pop     r20         // (2)

    pop     r19         // (2)
    pop     r18         // (2)

    pop     r17         // (2)
    pop     r16         // (2)

    pop     r1          // (2)
    pop     r0          // (2)

#if 0
    .rept 50
    nop
    .endr
#endif
  
    reti                // (5) return from interrupt and reset interupt flag, total time of restore 38 clocks for restore

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// END ASM FUNCTIONS 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.end

