///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// 
// Copyright Nurve Networks LLC 2008
// 
// Filename: XGS_AVR_SCREENSAVER_NTSC_01.c
//
// Original Author: Andre' LaMothe
// 
// Last Modified: 12.21.08
//
// Overview: Screen saver demo with bouncing lines
//
// Controls: gamepad, use <START> button to re-seed demo.
// 
// 
// Demo must be linked with following source files (in addition to primary file):
// 
// XGS_AVR_SYSTEM_V010.c         - System variables.
// RPE_NTSC_BMP_96_72_4_V010.s   - ASM NTSC bitmap driver.
// RPE_NTSC_BMP_80_60_4_V010.s   - ASM NTSC bitmap driver.
// RPE_GFX_LIB_4BIT_V010.c       - Graphics library which includes bitmapped graphics functions, etc.
// XGS_AVR_GAMEPAD_DRV_V010.c    - Gamepad driver.
//
// Note 1: header files for all sources must be in current working directory, so compiler can find them
//
// 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
// Modifications|Bugs|Additions:
//
// Author Name: Roy Eltham
//
//
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// INCLUDES ///////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// define chip type here
#define __AVR_ATmega644__

// define CPU frequency in Mhz here if not defined in Makefile, this is used for conditional compilation, so needs
// to be first, before other XGS includes, also note there is a copy of this constant in XGS_AVR_SYSTEM_V010, so if you 
// change it here, also change it in the header to make certain everthing is sync'ed
#define F_CPU 28636360UL

#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <math.h>
#include <avr/eeprom.h>
#include <avr/io.h>
#include <avr/sleep.h>

#include <util/delay.h>
#include <avr/interrupt.h>
#include <avr/pgmspace.h>
#include <inttypes.h>
#include <compat/twi.h>
#include <avr/pgmspace.h>

// include local XGS API header files
#include "XGS_AVR_SYSTEM_V010.h"
#include "XGS_AVR_GAMEPAD_DRV_V010.h"

// include header file for video driver
//#include "RPE_NTSC_BMP_96_72_4_V010.h"
#include "RPE_NTSC_BMP_80_60_4_V010.h"
#include "RPE_GFX_LIB_4BIT_V010.h"

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// TYPES  /////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// simple structure to hold a line with velocity
typedef struct MLINE_TYP
    {

    int x0, y0, x1, y1;         // endpoints of line
    int xv0, yv0, xv1, yv1;     // velocities of endpoints

    } MLINE, *MLINE_PTR;

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// GLOBALS/////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// bitmap for VGA/NTSC
volatile UCHAR vram[SCREEN_WIDTH * SCREEN_HEIGHT / PIXELS_PER_BYTE ];

MLINE lines[2]; // two lines for screen saver, one to draw, one to erase

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// MAIN ///////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

int main(void)
{
int eraser_count = 0;  // general counter
int draw_count = 0;
int gamepad;           // used to read gamepad
int color;

// initialize graphics variables
vram_ptr = vram;

// initialize rendering real-time variables
g_screen_width  = SCREEN_WIDTH;
g_screen_height = SCREEN_HEIGHT;

// set clipping region (eventhough we don't really need it)
g_clip_min_x = 0;
g_clip_max_x = SCREEN_WIDTH-1;
g_clip_min_y = 0;
g_clip_max_y = SCREEN_HEIGHT-1;

// seed random number generator
srandom(17);

// initialize lines
lines[0].x0 = RAND_RANGE(10, g_screen_width-10);
lines[0].y0 = RAND_RANGE(10, g_screen_height-10);

lines[0].x1 = RAND_RANGE(10, g_screen_width-10);
lines[0].y1 = RAND_RANGE(10, g_screen_height-10);

lines[0].xv0 = RAND_RANGE(-2,2);
lines[0].yv0 = RAND_RANGE(-2,2);

lines[0].xv1 = RAND_RANGE(-3,3);
lines[0].yv1 = RAND_RANGE(-3,3);

// copy line 1 -> 0
lines[1] = lines[0];

// initialize the video driver and GFX engine
GFX_Init( VIDEO_INTERRUPT_RATE );

// initialize gamepad
Gamepad_Init();

// set processor sleep mode
set_sleep_mode( SLEEP_MODE_IDLE );
sleep_enable();

// clear screen with black
GFX_Fill_Screen(15, vram);

// main event loop
while(1)
    {
    // main loop that executes and is interrupted by video interrupt

    // now goto sleep and wait for interrupt
    sleep_cpu();

    // only do video processing on a single line (at the top of the video scan)
    if ( curr_line == END_ACTIVE_SCAN+1 )
        {
        // erase screen?
        gamepad = Gamepad_Read(GAMEPAD0);

        // test for <START> button to re-seed and re-start
        if (gamepad & GAMEPAD_START)
            {
            // clear screen
            GFX_Fill_Screen(15, vram);

            // seed random number generator
            srandom(eraser_count);

            eraser_count = 0;

            // initialize lines
            lines[0].x0 = RAND_RANGE(10, g_screen_width-10);
            lines[0].y0 = RAND_RANGE(10, g_screen_height-10);

            lines[0].x1 = RAND_RANGE(10, g_screen_width-10);
            lines[0].y1 = RAND_RANGE(10, g_screen_height-10);

            lines[0].xv0 = RAND_RANGE(-2,2);
            lines[0].yv0 = RAND_RANGE(-2,2);

            lines[0].xv1 = RAND_RANGE(-3,3);
            lines[0].yv1 = RAND_RANGE(-3,3);

            // copy line 1 -> 0
            lines[1] = lines[0];


            } // end if
    
        // based on function of line state select a color
		color = (draw_count>>1)&0x0F;
		draw_count++;

		// don't use bg color for lines
		if (color == 15)
		{
			color = 0;
			draw_count++;
		}

        // draw the line
        GFX_Draw_Line( lines[0].x0, lines[0].y0, lines[0].x1, lines[0].y1, color, vram);

		//GFX_Draw_HLine( 0, g_screen_width-1, (draw_count % (g_screen_height >> 1)) << 1, color, vram);

		//GFX_Draw_VLine( 0, g_screen_height-1, (draw_count % (g_screen_width >> 1)) << 1, color, vram);

        // move the line
        lines[0].x0 += lines[0].xv0;
        lines[0].y0 += lines[0].yv0;
    
        lines[0].x1 += lines[0].xv1;
        lines[0].y1 += lines[0].yv1;

        // test for out of bounds
        if ( (lines[0].x0 >= g_screen_width) || (lines[0].x0 <= 0 ) )
            {
            lines[0].xv0 = -lines[0].xv0;
            lines[0].x0 += lines[0].xv0;
            } // end if

        if ( (lines[0].x1 >= g_screen_width) || (lines[0].x1 <= 0 ) )
            {
            lines[0].xv1 = -lines[0].xv1;
            lines[0].x1 += lines[0].xv1;
            } // end if

        if ( (lines[0].y0 >= g_screen_height ) || (lines[0].y0 <= 0 ) )
            {
            lines[0].yv0 = -lines[0].yv0;
            lines[0].y0 += lines[0].yv0;
            } // end if

        if ( (lines[0].y1 >= g_screen_height ) || (lines[0].y1 <= 0 ) )
            {
            lines[0].yv1 = -lines[0].yv1;
            lines[0].y1 += lines[0].yv1;
            } // end if

        // test if its time to turn on eraser to follow behind drawing code
        if (++eraser_count > 25)
            {
            // reset, so doesn't overflow
            eraser_count = 25;

            // draw the line
            GFX_Draw_Line( lines[1].x0, lines[1].y0, lines[1].x1, lines[1].y1, 15, vram);

            // move the line
            lines[1].x0 += lines[1].xv0;
            lines[1].y0 += lines[1].yv0;
    
            lines[1].x1 += lines[1].xv1;
            lines[1].y1 += lines[1].yv1;

            // test for out of bounds
            if ( (lines[1].x0 >= g_screen_width ) || (lines[1].x0 <= 0 ) )
                {
                lines[1].xv0 = -lines[1].xv0;
                lines[1].x0 += lines[1].xv0;
                } // end if

            if ( (lines[1].x1 >= g_screen_width ) || (lines[1].x1 <= 0 ) )
                {
                lines[1].xv1 = -lines[1].xv1;
                lines[1].x1 += lines[1].xv1;
                } // end if

            if ( (lines[1].y0 >= g_screen_height ) || (lines[1].y0 <= 0) )
                {
                lines[1].yv0 = -lines[1].yv0;
                lines[1].y0 += lines[1].yv0;
                } // end if

            if ( (lines[1].y1 >= g_screen_height ) || (lines[1].y1 <= 0 ) )
                {
                lines[1].yv1 = -lines[1].yv1;
                lines[1].y1 += lines[1].yv1;
                } // end if

            } // end if

        } // end if

    } // end while

} // end main

