///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// 
// Copyright Nurve Networks LLC 2009
// 
// Filename: RPE_XGS_BLASTER_NTSC_01.c
//
// Original Author: Roy Eltham 
// 
// Last Modified: 01.19.09
//
// Overview: Space SHoot 'em up vertical scroller game using Rem's Ultra graphic engine
//
// Controls: gamepads, dpad to move, yellow/action1 to shoot
// 
// Demo must be linked with following source files:
// 
// XGS_AVR_SYSTEM_V010.c              - System variables.
// REM_AVR_NTSC_128_96_ULTRA_V010.s   - ASM NTSC bitmap driver.
// XGS_AVR_GAMEPAD_DRV_V010.c         - Gamepad driver.
//
// Note 1: header files for all sources must be in current working directory, so compiler can find them
//
// 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// INCLUDES ///////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// define chip type here
#define __AVR_ATmega644__

// define CPU frequency in Mhz here if not defined in Makefile, this is used for conditional compilation, so needs
// to be first, before other XGS includes, also note there is a copy of this constant in XGS_AVR_SYSTEM_V010, so if you 
// change it here, also change it in the header to make certain everthing is sync'ed
#define F_CPU 28636360UL

#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <math.h>
#include <avr/eeprom.h>
#include <avr/io.h>
#include <avr/sleep.h>
#include <avr/pgmspace.h>

#include <util/delay.h>
#include <avr/interrupt.h>
#include <avr/pgmspace.h>
#include <inttypes.h>
#include <compat/twi.h>

// include local XGS API header files
#include "XGS_AVR_SYSTEM_V010.h"
#include "XGS_AVR_GAMEPAD_DRV_V010.h"

// include header file for video driver
#include "REM_AVR_NTSC_128_96_ULTRA_V010.h"

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// TYPES  /////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
extern UINT framecount;
extern UCHAR* tilemap[];
extern UCHAR rpe_bg_tiles;
extern UCHAR sintable[];
typedef struct
{
	UCHAR rowindex;
	UCHAR xoffset;
} SScanList;
extern SScanList scanlist[];

typedef struct
{
	UCHAR address;
	UCHAR x;
} SSprite;
extern SSprite spritelist[];

// NOTE: these externs need to be declared volatile because they are modified by the asm interrupt driver
extern volatile unsigned int  curr_line;
extern volatile unsigned char curr_raster_line;


///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// GLOBALS/////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

char game_name[] PROGMEM =   "XGS BLASTER";
char author_name[] PROGMEM = "BY ROY ELTHAM";
char press_start[] PROGMEM = "PRESS START";

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// MAIN ///////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////


void GFX_Init(int video_interrupt_rate)
{
	// this function initializes the I/O ports for NTSC/PAL/VGA graphics as well as initilizes variables and turns on the 
	// driver interrupt which will immediately start feeding the data sources to the currently installed ASM driver, thus
	// make sure any pointers to data structures are initialized before calling this function
	// when done with graphics and you want to stop calling the graphics interrupt, call GFX_Shutdown(..)
	//
	// Inputs:
	//     video_interrupt_rate - the clock divider, so that the number of clocks per interrupt is equal to the HSYNC rate
	//                            since the interrupt handler runs every HSYNC in both NTSC/PAL and VGA modes

	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	// VIDEO INTERRUPT EXPERIMENT /////////////////////////////////////////////////////////////////////////////////////////
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

	// main graphics port that luma/chroma and VGA signals come from, port A
	#define GFX_MAIN_PORT       PORTA
	#define GFX_MAIN_DDR        DDRA

	// the "saturation" control is connected to port B
	#define GFX_SATURATION_PORT PORTB
	#define GFX_SATURATION_DDR  DDRB

	// set video ports to output
	GFX_MAIN_DDR  = 0xFF; // NTSC/PAL LUMA7:4 | CHROMA3:0, VGA7:0 [vsync, hsync, B1,B0, G1,G0, G1,G0] 
	              //                                        b7      b6    b5:4   b3:2   b1:0
	GFX_MAIN_PORT = 0x00;

	// set sat control bits PB2, PB3 as outputs
	GFX_SATURATION_DDR  =  SETPORTBITS(0,0,0,0,1,1,0,0);
	PORTB               =  SETPORTBITS(0,0,0,0,1,1,0,0);

	// set up timer                                     
	TCCR1A = (0 << COM1A1) | (0 << COM1A0) | (0 << COM1B1) | (0 << COM1B0) | (0 << WGM11) | (0 << WGM10);

	// set clock pre-scaler and counter mode
	TCCR1B = (0 << WGM13) | (1 << WGM12) | (0 << CS12) | (0 << CS11)  | (1 << CS10);    

	// 168. 644 use TIMSK1,TIFR1
	// 162 use TIMSK,TIFR

	// enable timer interrupts for timer 
	TIMSK1 = (1 << OCIE1A);                  //(1<<TOIE1);                 

	// clear and pendings timer x CTC interrupts (1 clears it)
	TIFR1  = (1 << OCF1A); // (1<<TOV1);                  

	// set output compare register value
	OCR1A  = video_interrupt_rate; // 1817+-1 for NTSC at 28.636 Mhz = 15.748Hkz hsync rate, 910 for VGA @ 28.636Mhz = 31.468Khz, hsync rate

	// enable interrupt
	sei();
} // end GFX_Init

#define GET_TILE(index) (&rpe_bg_tiles + (((UINT)(index)&31)*8) + (((UINT)(index)>>5)*256*8))

void resettile()
{
	UCHAR i, j;

	// Prepare address for tiles
	for(j=0; j<13; j++)
	{
		for(i=0; i<TILEMAP_WIDTH; i++)
		{
			tilemap[(j*TILEMAP_WIDTH) + i] = GET_TILE(0);
		}
	}
	for(j=13; j<TILEMAP_HEIGHT; j++)
	{
		for(i=0; i<TILEMAP_WIDTH; i++)
		{
			tilemap[(j*TILEMAP_WIDTH) + i] = GET_TILE(0);
		}
	}

	// Initialize default scanlist: this tells which tilemap scanline gets rendered by each scanline.
	for(i=0; i<192; i++)
	{
		scanlist[i].rowindex = i>>1;
		scanlist[i].xoffset = 0;
	}
	// Special case: last row should not be used because it also displays the first scanline
	// We'll make it point to line 7 of tilerow 14
	scanlist[191].rowindex = 14*8+7;
}

void drawcursor(UCHAR x, UCHAR y)
{
	tilemap[(y*TILEMAP_WIDTH) + x] = GET_TILE(64 + ((framecount>>2)&3));
}

void drawchar(UCHAR c, UCHAR x, UCHAR y)
{
	c -= 32;
	tilemap[(y*TILEMAP_WIDTH)+x] = GET_TILE(c);
}

void drawtext(PGM_P t, UCHAR x, UCHAR y)
{
	UCHAR c;

	do
	{
		c = pgm_read_byte(t);
		if(!c) break;
		drawchar(c, x, y);
		x++;
		t++;
	} while(1);
}

void clear_displaylist()
{
	UINT i;
	for(i=0; i<96*8; i++)
	{
		spritelist[i].x = 0;
	}
}

int find_available_sprite_slot(int screen_y)
{
	int i;

	if (screen_y < 96 && screen_y >= 0)
	{
		for (i = 0; i < 8; i++)
		{
			if (spritelist[screen_y * 8 + i].x == 0)
			{
				return i;
			}
		}
	}

	return -1;
}

//
//  end graphics engine stuff
//


//
// game data and code starts here
//

#define MAX_ENEMIES 32
#define MAX_BULLETS 16

// tiles are set up so I can use lines of 16 at a time
// I have 40 lines (2 columns of 20 in the 256 wide bitmap)
// lines:
// 0-15 = big green galaxy
// 16-19 = stars
// 20-27 = small red galaxy
// 28-39 = stars

// these numbers are the tile index of the first tile in a line
// since the font is first, the code will add 64 to these numbers to get the actual index

unsigned short bg_map[] PROGMEM =
{
	// repeat just stars for a bit (48 tile lines)
	272, 304, 336, 368, 400, 432, 464, 496, 528, 560, 592, 624,
	272, 304, 336, 368, 400, 432, 464, 496, 528, 560, 592, 624, 
	272, 304, 336, 368, 400, 432, 464, 496, 528, 560, 592, 624, 
	272, 304, 336, 368, 400, 432, 464, 496, 528, 560, 592, 624,

	// stars and galaxies (28 tile lines)
	  0,  32,  64,  96, 128, 160, 192, 224, 256, 288, 320, 352, 384, 416, 
	448, 480, 512, 544, 576, 608,  16,  48,  80, 112, 144, 176, 208, 240,
	 
	// repeat just stars for a bit (24 tile lines)
	272, 304, 336, 368, 400, 432, 464, 496, 528, 560, 592, 624,
	272, 304, 336, 368, 400, 432, 464, 496, 528, 560, 592, 624, 

	// stars and galaxies (28 tile lines)
	  0,  32,  64,  96, 128, 160, 192, 224, 256, 288, 320, 352, 384, 416, 
	448, 480, 512, 544, 576, 608,  16,  48,  80, 112, 144, 176, 208, 240,

	// above is 128 lines, the code will index into this table modulo 127
	// we need the last 12 lines below to fill the screen properly when index 115-127 are used	

	// just stars (12 tile lines) 
	272, 304, 336, 368, 400, 432, 464, 496, 528, 560, 592, 624, 
};

typedef struct
{
	UCHAR enemyStartDelay1;
	UCHAR enemyCount1;
	UCHAR enemyType1;
	UCHAR enemySpacing1;
	UCHAR flightpath1;
	UCHAR speed1;
	UCHAR value1;

	UCHAR enemyStartDelay2;
	UCHAR enemyCount2;
	UCHAR enemyType2;
	UCHAR enemySpacing2;
	UCHAR flightpath2;
	UCHAR speed2;
	UCHAR value2;
	
} Wave;

Wave Waves[5] =
{
	{120, 10, 1, 10, 0, 1,  5,    0,  0, 0,  0, 0, 0,  0},
	{  0, 10, 2, 10, 1, 1,  5,    0,  0, 0,  0, 0, 0,  0},
	{  0, 10, 1, 25, 3, 1,  5,   10, 10, 2, 25, 2, 1,  5},
	{  0, 10, 1, 25, 4, 1,  5,   15, 10, 2, 25, 5, 1,  5},
	{  0, 10, 1,  5, 2, 2, 10,    0, 10, 2,  5, 3, 2, 10}
};

typedef struct
{
	UCHAR x;
	UCHAR y;
	UCHAR type; 		// which sprite to use, and behaviors (type 0 = none/unused)
	UCHAR flightpath;	// what flightpath type it's following
	UCHAR speed;
	UCHAR value;		// score given to player when destroyed
} Enemy;

Enemy Enemies[MAX_ENEMIES];

typedef struct 
{
	UCHAR x;
	UCHAR y;
	UCHAR size;  // for collision
	UCHAR type;  // 0 = none/unused, 1 = player1, 2 = player2, 3+ = enemies
} Bullet;

Bullet Bullets[MAX_BULLETS];

typedef struct
{
	UCHAR x;
	UCHAR lives;
	UCHAR bullets; // number of active bullets
	UCHAR bullet_delay;
	int score;
} Player;

Player Players[2];

void handle_player_input(int player, UCHAR gamepad)
{
	int i;

	if (Players[player].lives > 0)
	{
		if (gamepad & GAMEPAD_RIGHT)
		{
			if (Players[player].x < 127)
			{
				Players[player].x += 1;
			}
		}
		if (gamepad & GAMEPAD_LEFT)
		{
			if (Players[player].x > 8)
			{
				Players[player].x -= 1;
			}
		}
		if (gamepad & GAMEPAD_YELLOW && Players[player].bullets < 2 && Players[player].bullet_delay == 0)
		{
			for (i = 0; i < MAX_BULLETS; i++)
			{
				if (Bullets[i].type == 0)
				{
					Bullets[i].x = Players[player].x;
					Bullets[i].y = 84;
					Bullets[i].type = player + 1;
					Bullets[i].size = 5;
					break;
				}
			}
			Players[player].bullets++;
			Players[player].bullet_delay = 8;
		}

		if (Players[player].bullet_delay > 0)
		{
			Players[player].bullet_delay--;
		}
	}
	else if (gamepad & GAMEPAD_START)
	{
		Players[player].lives = 3;
		Players[player].score = 0;
		Players[player].x = 64 + (8 * player);
	}
}

void draw_background(unsigned int bgscroll)
{
	int i;

	// handle smooth vertical scroll
	int v_offset = bgscroll & 15;
	for(i = 0; i < 191; i++)
	{
		scanlist[i].rowindex = ((i + v_offset) >> 1);
	}

	// fill screen
	for(i = 0; i < 13; i++)
	{
		int bg_line = ((bgscroll >> 4) + i) & 127; // & 127 here is because bg_map 128 (+ 12) lines of data
		int line_tile_index = pgm_read_word(bg_map + (bg_line)) + 64; // + 64 here is to skip over font
		int j;

		// fill line
		for(j = 0; j < TILEMAP_WIDTH; j++)
		{
			tilemap[(i*TILEMAP_WIDTH) + j] = GET_TILE(line_tile_index + j);
		}
	}
}

void draw_scores(void)
{
	UCHAR digits[8];
	int i;

	int score = Players[0].score;
	for (i = 0; i < 4; i ++)
	{
		digits[i] = (score % 10) + 16;
		score /= 10;
	}
	score = Players[1].score;
	for (i = 4; i < 8; i ++)
	{
		digits[i] = (score % 10) + 16;
		score /= 10;
	}

	for (i = 0; i < 5; i++)
	{
		spritelist[(1 + i) * 8 + 0].x = 8;
		spritelist[(1 + i) * 8 + 0].address = i + (digits[3] * 8);
		spritelist[(1 + i) * 8 + 1].x = 13;
		spritelist[(1 + i) * 8 + 1].address = i + (digits[2] * 8);
		spritelist[(1 + i) * 8 + 2].x = 18;
		spritelist[(1 + i) * 8 + 2].address = i + (digits[1] * 8);
		spritelist[(1 + i) * 8 + 3].x = 23;
		spritelist[(1 + i) * 8 + 3].address = i + (digits[0] * 8);

		spritelist[(1 + i) * 8 + 4].x = 113;
		spritelist[(1 + i) * 8 + 4].address = i + (digits[7] * 8);
		spritelist[(1 + i) * 8 + 5].x = 118;
		spritelist[(1 + i) * 8 + 5].address = i + (digits[6] * 8);
		spritelist[(1 + i) * 8 + 6].x = 123;
		spritelist[(1 + i) * 8 + 6].address = i + (digits[5] * 8);
		spritelist[(1 + i) * 8 + 7].x = 128;
		spritelist[(1 + i) * 8 + 7].address = i + (digits[4] * 8);

	}
}

void draw_game_sprites(void)
{
	int i, j;
	int sprite_slot;

	for (i = 0; i < 8; i++)
	{
		if (Players[0].lives > 0)
		{
			spritelist[(87 + i) * 8].x = Players[0].x;
			spritelist[(87 + i) * 8].address = i;
		}
		if (Players[1].lives > 0)
		{
			spritelist[(87 + i) * 8 + 1].x = Players[1].x;
			spritelist[(87 + i) * 8 + 1].address = i + 8;
		}

		for (j = 0; j < MAX_ENEMIES; j++)
		{
			if (Enemies[j].type > 0 && (Enemies[j].y + i) > 5 && (Enemies[j].y + i) < 95)
			{
				sprite_slot = find_available_sprite_slot(Enemies[j].y + i);
				if (sprite_slot != -1)
				{
					spritelist[(Enemies[j].y + i) * 8 + sprite_slot].x = Enemies[j].x;
					spritelist[(Enemies[j].y + i) * 8 + sprite_slot].address = i + ((Enemies[j].type + 1) * 8);
				}
			}
		}

		for (j = 0; j < MAX_BULLETS; j++)
		{
			if (Bullets[j].type > 0 && (Bullets[j].y + i) > 5 && (Bullets[j].y + i) < 95)
			{
				sprite_slot = find_available_sprite_slot(Bullets[j].y + i);
				if (sprite_slot != -1)
				{
					spritelist[(Bullets[j].y + i) * 8 + sprite_slot].x = Bullets[j].x;
					int bullet_sprite = 0;
					if (Bullets[j].type > 2)
					{
						bullet_sprite = 1;
					}
					spritelist[(Bullets[j].y + i) * 8 + sprite_slot].address = i + ((14 + bullet_sprite) * 8);
				}
			}
		}
	}
}

void update_bullets(void)
{
	int i;

	for(i = 0; i < MAX_BULLETS; i++)
	{
		if (Bullets[i].type > 0 && Bullets[i].type < 3)
		{
			// players bullets
			if(Bullets[i].y > 1)
			{
				Bullets[i].y -= 3;
			}
			else
			{
				if (Players[Bullets[i].type - 1].bullets > 0)
				{
					Players[Bullets[i].type - 1].bullets--;
				}
				Bullets[i].type = 0;
			}
		}
		else if (Bullets[i].type > 2)
		{
			// enemy bullets
			if(Bullets[i].y < 96)
			{
				Bullets[i].y += 2;
			}
			else
			{
				Bullets[i].type = 0;
			}
		}
	}
}

void update_enemies(void)
{
	int i;
	UCHAR flightpath_x = -8;

	// update active enemies on their flightpaths
	for(i = 0; i < MAX_ENEMIES; i++)
	{
		if (Enemies[i].type > 0)
		{
			Enemies[i].y += Enemies[i].speed;

			switch(Enemies[i].flightpath)
			{
				case 0:
					flightpath_x = (pgm_read_byte(sintable + ((Enemies[i].y << 1) & 255)) >> 1);
					break;
				case 1:
					flightpath_x = ((255 - pgm_read_byte(sintable + ((Enemies[i].y << 1) & 255))) >> 1) + 8;
					break;
				case 2:
					flightpath_x = (pgm_read_byte(sintable + ((64 + Enemies[i].y) & 255)) >> 2) + 32;
					break;
				case 3:
					flightpath_x = ((255 - pgm_read_byte(sintable + ((64 + Enemies[i].y) & 255))) >> 2) + 32;
					break;
				case 4:
					flightpath_x = (pgm_read_byte(sintable + ((16 + Enemies[i].y) & 255)) >> 2);
					break;
				case 5:
					flightpath_x = ((255 - pgm_read_byte(sintable + ((16 + Enemies[i].y) & 255))) >> 2) + 64;
					break;
			}
			Enemies[i].x = 0 + flightpath_x;

			if (Enemies[i].y > 94)
			{
				// flew off bottom of screen
				Enemies[i].type = 0;
			}
		}
	}
}

void play_game(void)
{
	UCHAR gamepad;
	unsigned int bgscroll = 0;
	int i, j;

	// starting new game so reset waves, enemies and bullets
	int wave = 0;
	int waveCount[2] = {0, 0};
	int waveDelay[2] = {0, 0};

	waveDelay[0] = Waves[wave].enemyStartDelay1;
	waveDelay[1] = Waves[wave].enemyStartDelay2;

	for (i = 0; i < MAX_ENEMIES; i++)
	{
		Enemies[i].type = 0;
	}

	for (i = 0; i < MAX_BULLETS; i++)
	{
		Bullets[i].type = 0;
	}

	framecount = 0;

	while(1)
	{
	    sleep_cpu();
	    if ( curr_line != END_ACTIVE_SCAN )
		{
			continue;
		}

		clear_displaylist();

		if (Players[0].lives < 1 && Players[1].lives < 1)
		{ 
			// return to title mode
			break;
		}

		// get player input
        gamepad = Gamepad_Read(GAMEPAD0);
		if (gamepad != 0xFF)
		{
			handle_player_input(0, gamepad);
		}
        gamepad = Gamepad_Read(GAMEPAD1);
		if (gamepad != 0xFF)
		{
			handle_player_input(1, gamepad);
		}

		// draw/update scrolling background
		bgscroll--;
		draw_background(bgscroll);

		draw_scores();
		draw_game_sprites(); // players, enemies, and bullets
		update_bullets();
		update_enemies();

		// update wave (launch enemies and advance thru waves)
		if (Waves[wave].enemyCount1 > waveCount[0] && waveDelay[0] == 0)
		{
			for(i = 0; i < MAX_ENEMIES; i++)
			{
				if (Enemies[i].type == 0)
				{
					Enemies[i].x = 0;
					Enemies[i].y = 0;
					Enemies[i].type = Waves[wave].enemyType1;
					Enemies[i].flightpath = Waves[wave].flightpath1;
					Enemies[i].speed = Waves[wave].speed1;
					Enemies[i].value = Waves[wave].value1;
					waveDelay[0] = Waves[wave].enemySpacing1;
					waveCount[0]++;
					break;
				}
			}

			if (Waves[wave].enemyCount1 == waveCount[0])
			{
				waveDelay[0] = 200;
			}
		}
		if (Waves[wave].enemyCount2 > waveCount[1] && waveDelay[1] == 0)
		{
			for(i = 0; i < MAX_ENEMIES; i++)
			{
				if (Enemies[i].type == 0)
				{
					Enemies[i].x = 0;
					Enemies[i].y = 1;
					Enemies[i].type = Waves[wave].enemyType2;
					Enemies[i].flightpath = Waves[wave].flightpath2;
					Enemies[i].speed = Waves[wave].speed2;
					Enemies[i].value = Waves[wave].value2;
					waveDelay[1] = Waves[wave].enemySpacing2;
					waveCount[1]++;
					break;
				}
			}

			if (Waves[wave].enemyCount2 == waveCount[1])
			{
				waveDelay[1] = 200;
			}
		}

		for (i = 0; i < 2; i++)
		{
			if (waveDelay[i] > 0)
			{
				waveDelay[i]--;
			}
		}
		
		if (Waves[wave].enemyCount1 == waveCount[0] && waveDelay[0] == 0 &&
			Waves[wave].enemyCount2 == waveCount[1] && waveDelay[1] == 0)
		{
			wave++;
			if (wave > 4)
			{
				wave = 0;
			}
			waveCount[0] = 0;
			waveCount[1] = 0;
			waveDelay[0] = Waves[wave].enemyStartDelay1;
			waveDelay[1] = Waves[wave].enemyStartDelay2;
		}

		// check collision between bullets and enemies and players

		// see if any player bullets hit enemies or if any enemy bullets hit players
		for (i = 0; i < MAX_BULLETS; i++)
		{
			int bullet_left = Bullets[i].x;
			int bullet_right = Bullets[i].x + Bullets[i].size;
			int bullet_top = Bullets[i].y;
			int bullet_bottom = Bullets[i].y + Bullets[i].size;

			if (Bullets[i].type == 1 || Bullets[i].type == 2)
			{
				for (j = 0; j < MAX_ENEMIES; j++)
				{
					if (Enemies[j].type > 0)
					{
						if (!(Enemies[j].x >= bullet_right || 
							  (Enemies[j].x + 8) <= bullet_left || 
							  Enemies[j].y >= bullet_bottom ||
							  (Enemies[j].y + 7) <= bullet_top))
						{
							// we hit, so add to score and destroy enemy and bullet
							Players[Bullets[i].type - 1].score += Enemies[j].value;
							Players[Bullets[i].type - 1].bullets--;
							Players[Bullets[i].type - 1].bullet_delay = 0;
							Enemies[j].type = 0;
							Bullets[i].type = 0;
							
							// add explosion sprite here
							break;
						}
					}
				}
			}
			else if (Bullets[i].type > 0)
			{
				for (j = 0; j < 2; j++)
				{
					if (Players[j].lives > 0)
					{
						if (!(Players[j].x >= bullet_right || 
							  (Players[j].x + 8) <= bullet_left || 
							  88 >= bullet_bottom ||
							  95 <= bullet_top))
						{
							Players[j].lives--;
							Bullets[i].type = 0;

							// add explosion sprite here
							break;
						}
					}
				}
			}
		}

		// see it any enemies hit players
		for (i = 0; i < MAX_ENEMIES; i++)
		{
			if (Enemies[i].type > 0)
			{
				int enemy_left = Enemies[i].x;
				int enemy_right = Enemies[i].x + 8;
				int enemy_top = Enemies[i].y;
				int enemy_bottom = Enemies[i].y + 7;

				for (j = 0; j < 2; j++)
				{
					if (Players[j].lives > 0)
					{
						if (!(Players[j].x >= enemy_right || 
							  (Players[j].x + 8) <= enemy_left || 
							  88 >= enemy_bottom ||
							  95 <= enemy_top))
						{
							Players[j].lives--;
							Players[j].score += Enemies[i].value;
							Enemies[i].type = 0;

							// add explosion sprite here
							break;
						}
					}
				}
			}
		}

		framecount++;
	}
}

void title_mode(void)
{
	UCHAR gamepad;

	resettile();
	clear_displaylist();

	while(1)
	{
	    sleep_cpu();
	    if ( curr_line != END_ACTIVE_SCAN ) continue;

	    drawtext(game_name, 2,4);
	    drawtext(author_name, 1,5);
	    drawtext(press_start, 2,8);

		draw_scores();

        gamepad = Gamepad_Read(GAMEPAD0);
		if ((gamepad != 0xFF) && (gamepad & GAMEPAD_START))
		{
			Players[0].lives = 3;
			break;
		}
        gamepad = Gamepad_Read(GAMEPAD0);
		if ((gamepad != 0xFF) && (gamepad & GAMEPAD_START))
		{
			Players[1].lives = 3;
			break;
		}
	}
}

void reset_players()
{
	Players[0].x = 64;
	Players[0].bullets = 0;
	Players[0].bullet_delay = 0;
	Players[0].score = 0;

	Players[1].x = 72;
	Players[1].bullets = 0;
	Players[1].bullet_delay = 0;
	Players[1].score = 0;
}

int main(void)
{
	resettile();

	// initialize the video driver and GFX engine
	GFX_Init( VIDEO_INTERRUPT_RATE );

	// initialize gamepad
	Gamepad_Init();

	// set processor sleep mode
	set_sleep_mode( SLEEP_MODE_IDLE );
	sleep_enable();

	reset_players();
	Players[0].lives = 0;
	Players[1].lives = 0;

	while(1)
	{
		title_mode();
		reset_players();
		play_game();
	}

	return 0;
} // end main

