//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// 
// Copyright Nurve Networks LLC 2008
// 
// Filename: XGS_NTSC_TILE_MODE6_V010.S
// 
// Description: 144x104, 18x13, 8x8 tiles resolution NTSC driver tile engine with 5 8x8 sprites
//  
// Original Author: Andre' LaMothe
// 
// Last Modified: 9.1.08
//
// Overview:
//   
// This is a 18x13 NTSC tile engine. Each tile is 8x8 pixels, where each pixel is encoded as a full byte LUMA4:CHROMA4.
//
//
// 18 tiles per row / 13 rows
//
//  colum 0      1       2              15       16       17
// |........|........|........| ... |........|........|........|  Row 0
// |........|........|........| ... |........|........|........|  Row 1
// |........|........|........| ... |........|........|........|  Row 2
// |........|........|........| ... |........|........|........|
// .
// .  13 rows
// .
// |........|........|........| ... |........|........|........|  Row 12
//
// The engine supports fine scrolling in the vertical direction as well as course scrolling scrolling in the
// horizontal direction via a controllable tile map logical width or "pitch" parameter, so eventhough the physical
// screen is always 18x13 tiles the logical width can be anything up to 256 tiles wide.
//
// Additionally, the engine supports 5 8x8 pixel sprites with full 8-bit color. The sprites have some limitations;
// Sprites 0,1,2 can not be on the same raster lines at the same time.
// Sprites 3,4 can not be on the same raster lines at the same time.
//
// Sprites 0 and 3 are called "masters" and the remaining sprites are "slaves" or children of the masters. All sprites
// support scrolling off the right, left, and bottom of the screen. The sprite coordinates are slightly translated 
// relative to the tile coordinates, so sprite X=0, places the sprite just beyond the left edge of the screen,
// similary sprite X=152 places the sprite beyond the right edge of the screen. In other words, the sprite coordinates
// look like this:
//
//         <------- visible on screen --------->|, x's represent tile imagery
// 
//         0                                    143        <--- tile pixels (18*8 = 0...143)
//         |                                     | 
// --------xxxxxxxxxxxxxxxxxxxxxxx....xxxxxxxxxxxx--------
// |      |                                       | 
// 0      7                                       152      <--- sprite X coordinates (0..152)
//
//
// The interface to the tile engine from the C/C++ caller consists of a set of pointers to data structures as well as 
// some read/write variables exported from the tile engine that the caller needs to control the engines operation. Here 
// are the important variables that the tile engine must have initialized:
//
// .extern tile_map_ptr      // 16-bit pointer to tile map, allows indirection
// .extern tile_bitmaps_ptr  // 16-bit pointer to 8x8 tile bitmaps, allows indirection
// .extern sprite_table      // sprite table base address containing sprite records, must be static data structure
//
// 
// First, are the tile map, bitmap, and sprite data structures. The tile map is a simple byte array MxN, where each
// byte represents the tile "index" to be rendered at that position. Each index refers to the tile bitmap that should
// be drawn. The tiles themselves are a continguous array of 8x8 pixel (byte) tiles, thus 64-bytes per tile. Both of
// these data structures are referred to by pointers to allow movement of the data structure in real-time. So the 
// caller would typically dynamically or statically allocate the tile map and tile bitmaps then point the below pointers
// at them, so the tile engine could locate them
//
// Finally, there is the sprite table base address, this is a static name, thus the caller will typically define the 
// sprite_table as a static array of sprite records, where each record is a of the type:
//
//  // SPRITE type, 8 bytes each
//  typedef struct SPRITE_TYP
//      {
//      // SPRITE members, note depending on driver some are used, some are not
//      UCHAR state;    // state of sprite    
//      UCHAR attr;     // bit encoded attributes
//      UCHAR color;    // general color information
//      UCHAR height;   // height of sprite
//      UCHAR x;        // x position of sprite
//      UCHAR y;        // y position of sprite
//      UCHAR *bitmap;  // pointer to bitmap (2 bytes)
//
//      } SPRITE, *SPRITE_PTR;

// In most incarnations of the tile engines only attr, height, x, y, and *bitmap are used. The remaining fields are for the 
// caller's own use. Moreover, the attr field "attribute" is rarely used, and simply holds bit encoded attributes of
// the sprite. Currently, the only attribute that is defined is:
//
// #define SPRITE_ATTR_2X       1  // enable 2X scaling mode
//
// Which as it states controls sprite scaling on sprite engines that support it (this one doesn't). Other than that
// the only oher interesting field is the bitmap pointer *bitmap. This is a pointer that points to the 8x8 matrix
// of pixels that will be used for the sprite image. The data is in the SAME format as tiles, this you can point it
// to a tile, or another set of data as you wish. The important thing is that each sprite is 8x8 pixels where each
// pixel is an NTSC byte. Additionally, value 0 is used for transparent which equates to NTSC_SYNC, however, the
// video will not sync when this value is encoded, it directs the renderer not to draw anything, and thus make
// the pixel transparent to the tile data under it.
//
// Moving on, there are a few values that are EXPORTED out from the tile engine to give the user control of the 
// engine as well as indicate the state of the engine (what line its on, etc.), so the user can initiate render
// changes properly as not to disturb the video scan. These values are:
//
// 
// .global curr_line                   // int, read only, current physical line
// .global curr_raster_line            // byte, read only, current logical raster line
// .global tile_map_logical_width      // byte, read/write, logical width of tile map
// .global tile_map_vscroll            // byte, read/write, current vertical scroll value 0..7
//
// They are self explanatory. The caller can read curr_line to determine the video line 0..261 of the NTSC scan,
// similarly curr_raster_line indicates the logical raster line for the resolution. Finally, tile_map_logical_width
// allows logical tile maps larger than the 18 wide to support scrolling, and tile_map_vscroll controls smooth 
// scrolling vertically.
//
// 
//
// Modifications|Bugs|Additions:
//
// Author Name: 
//
//
//
//
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// SET PROCESSOR TYPE (must come first)
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#ifndef __AVR_ATmega644__
#define __AVR_ATmega644__
#endif

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// INCLUDES 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
#include <avr/interrupt.h> 
#include <avr/io.h>

// include header for driver
#include "XGS_AVR_NTSC_TILE_MODE6_V010.h"

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// DEFINES 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// needed for macro, also fixes so you can use register names directly and NOT need macro _SFR_IO_ADDR( x )
#define __SFR_OFFSET 0 


///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// MACROS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// this macro delays any number of clocks that are a multiple of 4, anything else is truncated
.macro  DELAY4X reg = r16, clocks
    ldi     \reg, (\clocks)/4        // (1)
1:
    dec     \reg                     // (1)
    nop                              // (1)
    brne    1b                       // (1/2)
.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// this macro delays any number of clocks, uses chunks of 4
.macro  DELAYX reg = r16, clocks
    ldi     \reg, (\clocks)/4        // (1)
1:
    dec     \reg                     // (1)
    nop                              // (1)
    brne    1b                       // (1/2)

    // now delay fractional component
    .rept   (\clocks % 4)
    nop                              // (1)
    .endr

.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// this macro delays any number of clocks that are a multiple of 3, anything else is truncated
.macro  DELAY3X reg = r16, clocks
    ldi     \reg, (\clocks)/3        // (1)
1:
    dec     \reg                     // (1)
    brne    1b                       // (1/2)
.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.macro DRAW_SPRITE3 spriteM, spriteN, SpriteO

Sprite3\spriteM:

    lds     r17, sprite_table+SPRITE_SIZE*\spriteM+SPRITE_INDEX_Y      // (2), r17 = sprite_y, (6)
    mov     r18, r17                                                   // (1), 
    lds     r19, sprite_table+SPRITE_SIZE*\spriteM+SPRITE_INDEX_HEIGHT // (2), r17 = sprite_y
    add     r18, r19                                                   // (1), r18 = sprite_y + sprite_height

Sprite3_Test_Top\spriteM:

    // compare top of sprite with current_raster_line    
    cp      r16, r17                          // (1)      compare sprite_y and curr_raster_line
    brsh    Sprite3_Test_Bottom\spriteM        // (1/2)    if (curr_raster_line >= sprite_y) then...
    jmp     Sprite3_End_Loop1\spriteM          // (3)      (8+3) -> jump

Sprite3_Test_Bottom\spriteM:

    // compare bottom of sprite with current_raster_line
    cp      r16, r18                          // (1), compare sprite_y and cur
    brlo    Sprite3_Draw\spriteM               // (1/2)
    jmp     Sprite3_End_Loop2\spriteM          // (3),     (11+3)-> jump, raster is beyond bottom of sprite, don't draw into scanline

Sprite3_Draw\spriteM:
    // (12) clocks to entry
    // at this point, we know the sprite is visible, draw the currently intersected bitmap scanline 
    // into the scanline buffer at the sprite_x position    

    // point X to scanline back buffer
    ldi     XL, lo8 ( slinebuff0 )                           // (1),  (21) clocks for entire setup
    ldi     XH, hi8 ( slinebuff0 )                           // (1)

    // offset X by -8 to place sprites to left of screen at x = 0
    sbiw    XL, SPRITE_SCROLL_X                              // (2)

    // add in position of sprite_x
    lds     r19, sprite_table+SPRITE_SIZE*\spriteM+SPRITE_INDEX_X   // (2)
    add     XL, r19                                          // (1)
    clr     r19                                              // (1)
    adc     XH, r19                                          // (1)

    // point Y to sprite bitmap
    lds     YL,  sprite_table+SPRITE_SIZE*\spriteM+SPRITE_INDEX_BITMAP      // (2), used for pointer addressing of bitmaps
    lds     YH,  sprite_table+SPRITE_SIZE*\spriteM+SPRITE_INDEX_BITMAP+1    // (2)

    // compute sprite row intersected by current raster line and multiple by 8 to find sprite bitmap row to render
    // sprite_bitmap_row*8 = (curr_raster_line - sprite_y)*8
    
    mov     r19, r16                     // (1)   copy curr_raster_line into r19
    sub     r19, r17                     // (1)   r19 = current_raster_line:r19 - sprite_y:r17

    lsl     r19                          // (1)   r19 = r19*8
    lsl     r19                          // (1)
    lsl     r19                          // (1)

    clr     r0                           // (1)   Y = sprite_bitmap + sprite_bitmap_row*8
    add     YL, r19                      // (1)   r19 = sprite_bitmap_row*8 (0..56)
    adc     YH, r0                       // (1)   dummy add to take into consideration carry bit C overflow from lower byte

    // copy the sprite bytes into scanline buffer

    // transparent version of sprite, (64) clocks per copy
    .rept 8
    // copy pixel ///////////////////
    ld      r19, Y+                          // (2)
    cpi     r19, 0                           // (1)
    breq    1f                               // (1/2)
    st      X+, r19                          // (2)
    rjmp    2f                               // (2)           
1:
    adiw    XL, 1                            // (2)
    nop                                      // (1)
2:
    .endr

    // this added time needed for embedded sprite
    .rept (14 + 14)
    nop
    .endr

    // draw pixels on line now
    rjmp    Sprite3_End_Loop3\spriteM        // (2)     


Sprite3_End_Loop1\spriteM:

    .rept ( 14 - 11 ) // delay differential between paths
    nop
    .endr

Sprite3_End_Loop2\spriteM:

// this delay time is now used for sprite render    
//    .rept ( (64 + 21 + 12 + 2 + 14 + 14) - 14 )
//    nop
//    .endr

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// render linked slave sprite (both sprites can't be on the same scanlines)

        Sprite3\spriteN:

            lds     r17, sprite_table+SPRITE_SIZE*\spriteN+SPRITE_INDEX_Y      // (2), r17 = sprite_y, (6)
            mov     r18, r17                                                   // (1), 
            lds     r19, sprite_table+SPRITE_SIZE*\spriteN+SPRITE_INDEX_HEIGHT // (2), r17 = sprite_y
            add     r18, r19                                                   // (1), r18 = sprite_y + sprite_height
   
        Sprite3_Test_Top\spriteN:

            // compare top of sprite with current_raster_line    
            cp      r16, r17                          // (1)      compare sprite_y and curr_raster_line
            brsh    Sprite3_Test_Bottom\spriteN        // (1/2)    if (curr_raster_line >= sprite_y) then...
            jmp     Sprite3_End_Loop1\spriteN          // (3)      (8+3) -> jump

        Sprite3_Test_Bottom\spriteN:

            // compare bottom of sprite with current_raster_line
            cp      r16, r18                          // (1), compare sprite_y and cur
            brlo    Sprite3_Draw\spriteN               // (1/2)
            jmp     Sprite3_End_Loop2\spriteN          // (3),     (11+3)-> jump, raster is beyond bottom of sprite, don't draw into scanline
 
        Sprite3_Draw\spriteN:
            // (12) clocks to entry
            // at this point, we know the sprite is visible, draw the currently intersected bitmap scanline 
            // into the scanline buffer at the sprite_x position    

            // point X to scanline back buffer
            ldi     XL, lo8 ( slinebuff0 )                           // (1),  (21) clocks for entire setup
            ldi     XH, hi8 ( slinebuff0 )                           // (1)

            // offset X by -8 to place sprites to left of screen at x = 0
            sbiw    XL, SPRITE_SCROLL_X                              // (2)

            // add in position of sprite_x
            lds     r19, sprite_table+SPRITE_SIZE*\spriteN+SPRITE_INDEX_X   // (2)
            add     XL, r19                                          // (1)
            clr     r19                                              // (1)
            adc     XH, r19                                          // (1)

            // point Y to sprite bitmap
            lds     YL,  sprite_table+SPRITE_SIZE*\spriteN+SPRITE_INDEX_BITMAP      // (2), used for pointer addressing of bitmaps
            lds     YH,  sprite_table+SPRITE_SIZE*\spriteN+SPRITE_INDEX_BITMAP+1    // (2)

            // compute sprite row intersected by current raster line and multiple by 8 to find sprite bitmap row to render
            // sprite_bitmap_row*8 = (curr_raster_line - sprite_y)*8
    
            mov     r19, r16                     // (1)   copy curr_raster_line into r19
            sub     r19, r17                     // (1)   r19 = current_raster_line:r19 - sprite_y:r17

            lsl     r19                          // (1)   r19 = r19*8
            lsl     r19                          // (1)
            lsl     r19                          // (1)

            clr     r0                           // (1)   Y = sprite_bitmap + sprite_bitmap_row*8
            add     YL, r19                      // (1)   r19 = sprite_bitmap_row*8 (0..56)
            adc     YH, r0                       // (1)   dummy add to take into consideration carry bit C overflow from lower byte

            // copy the sprite bytes into scanline buffer

            // transparent version of sprite, (64) clocks per copy
            .rept 8
            // copy pixel ///////////////////
            ld      r19, Y+                          // (2)
            cpi     r19, 0                           // (1)
            breq    1f                               // (1/2)
            st      X+, r19                          // (2)
            rjmp    2f                               // (2)           
        1:
            adiw    XL, 1                            // (2)
            nop                                      // (1)
        2:
            .endr

            // this added time needed for embedded sprite in master sprite, but not in slave sprite
            .rept 14
            nop
            .endr

            // draw pixels on line now
            rjmp    Sprite3_End_Loop3\spriteM        // (2)     ,not always jumps out to master spirte index

        Sprite3_End_Loop1\spriteN:

            .rept ( 14 - 11 ) // delay differential between paths
            nop
            .endr

        Sprite3_End_Loop2\spriteN:

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

            //.rept ( (64 + 21 + 12 + 2 + 14 )  - 14 )
            //nop
            //.endr

            //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
            // render linked slave sprite (both sprites can't be on the same scanlines)

                Sprite3\SpriteO:

                    lds     r17, sprite_table+SPRITE_SIZE*\SpriteO+SPRITE_INDEX_Y      // (2), r17 = sprite_y, (6)
                    mov     r18, r17                                                   // (1), 
                    lds     r19, sprite_table+SPRITE_SIZE*\SpriteO+SPRITE_INDEX_HEIGHT // (2), r17 = sprite_y
                    add     r18, r19                                                   // (1), r18 = sprite_y + sprite_height
   
                Sprite3_Test_Top\SpriteO:

                    // compare top of sprite with current_raster_line    
                    cp      r16, r17                          // (1)      compare sprite_y and curr_raster_line
                    brsh    Sprite3_Test_Bottom\SpriteO        // (1/2)    if (curr_raster_line >= sprite_y) then...
                    jmp     Sprite3_End_Loop1\SpriteO          // (3)      (8+3) -> jump

                Sprite3_Test_Bottom\SpriteO:

                    // compare bottom of sprite with current_raster_line
                    cp      r16, r18                          // (1), compare sprite_y and cur
                    brlo    Sprite3_Draw\SpriteO               // (1/2)
                    jmp     Sprite3_End_Loop2\SpriteO          // (3),     (11+3)-> jump, raster is beyond bottom of sprite, don't draw into scanline
 
                Sprite3_Draw\SpriteO:
                    // (12) clocks to entry
                    // at this point, we know the sprite is visible, draw the currently intersected bitmap scanline 
                    // into the scanline buffer at the sprite_x position    

                    // point X to scanline back buffer
                    ldi     XL, lo8 ( slinebuff0 )                           // (1),  (21) clocks for entire setup
                    ldi     XH, hi8 ( slinebuff0 )                           // (1)

                    // offset X by -8 to place sprites to left of screen at x = 0
                    sbiw    XL, SPRITE_SCROLL_X                              // (2)

                    // add in position of sprite_x
                    lds     r19, sprite_table+SPRITE_SIZE*\SpriteO+SPRITE_INDEX_X   // (2)
                    add     XL, r19                                          // (1)
                    clr     r19                                              // (1)
                    adc     XH, r19                                          // (1)

                    // point Y to sprite bitmap
                    lds     YL,  sprite_table+SPRITE_SIZE*\SpriteO+SPRITE_INDEX_BITMAP      // (2), used for pointer addressing of bitmaps
                    lds     YH,  sprite_table+SPRITE_SIZE*\SpriteO+SPRITE_INDEX_BITMAP+1    // (2)

                    // compute sprite row intersected by current raster line and multiple by 8 to find sprite bitmap row to render
                    // sprite_bitmap_row*8 = (curr_raster_line - sprite_y)*8
    
                    mov     r19, r16                     // (1)   copy curr_raster_line into r19
                    sub     r19, r17                     // (1)   r19 = current_raster_line:r19 - sprite_y:r17

                    lsl     r19                          // (1)   r19 = r19*8
                    lsl     r19                          // (1)
                    lsl     r19                          // (1)

                    clr     r0                           // (1)   Y = sprite_bitmap + sprite_bitmap_row*8
                    add     YL, r19                      // (1)   r19 = sprite_bitmap_row*8 (0..56)
                    adc     YH, r0                       // (1)   dummy add to take into consideration carry bit C overflow from lower byte

                    // copy the sprite bytes into scanline buffer

                    // transparent version of sprite, (64) clocks per copy
                    .rept 8
                    // copy pixel ///////////////////
                    ld      r19, Y+                          // (2)
                    cpi     r19, 0                           // (1)
                    breq    1f                               // (1/2)
                    st      X+, r19                          // (2)
                    rjmp    2f                               // (2)           
                1:
                    adiw    XL, 1                            // (2)
                    nop                                      // (1)
                2:
                    .endr

                    // this added time needed for embedded sprite in master sprite, but not in slave sprite
                    //.rept 14
                    //nop
                    //.endr

                    // draw pixels on line now
                    rjmp    Sprite3_End_Loop3\spriteM        // (2)     ,not always jumps out to master spirte index

                Sprite3_End_Loop1\SpriteO:

                    .rept ( 14 - 11 ) // delay differential between paths
                    nop
                    .endr

                Sprite3_End_Loop2\SpriteO:

                    .rept ( (64 + 21 + 12 + 2 )  - 14 )
                    nop
                    .endr

                //////////////////////////////////////////////////////////////////////////////////////////////////////


//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

Sprite3_End_Loop3\spriteM:

.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.macro DRAW_SPRITE2 spriteM, spriteN

Sprite2\spriteM:

    lds     r17, sprite_table+SPRITE_SIZE*\spriteM+SPRITE_INDEX_Y      // (2), r17 = sprite_y, (6)
    mov     r18, r17                                                   // (1), 
    lds     r19, sprite_table+SPRITE_SIZE*\spriteM+SPRITE_INDEX_HEIGHT // (2), r17 = sprite_y
    add     r18, r19                                                   // (1), r18 = sprite_y + sprite_height

Sprite2_Test_Top\spriteM:

    // compare top of sprite with current_raster_line    
    cp      r16, r17                          // (1)      compare sprite_y and curr_raster_line
    brsh    Sprite2_Test_Bottom\spriteM        // (1/2)    if (curr_raster_line >= sprite_y) then...
    jmp     Sprite2_End_Loop1\spriteM          // (3)      (8+3) -> jump

Sprite2_Test_Bottom\spriteM:

    // compare bottom of sprite with current_raster_line
    cp      r16, r18                          // (1), compare sprite_y and cur
    brlo    Sprite2_Draw\spriteM               // (1/2)
    jmp     Sprite2_End_Loop2\spriteM          // (3),     (11+3)-> jump, raster is beyond bottom of sprite, don't draw into scanline

Sprite2_Draw\spriteM:
    // (12) clocks to entry
    // at this point, we know the sprite is visible, draw the currently intersected bitmap scanline 
    // into the scanline buffer at the sprite_x position    

    // point X to scanline back buffer
    ldi     XL, lo8 ( slinebuff0 )                           // (1),  (21) clocks for entire setup
    ldi     XH, hi8 ( slinebuff0 )                           // (1)

    // offset X by -8 to place sprites to left of screen at x = 0
    sbiw    XL, SPRITE_SCROLL_X                              // (2)

    // add in position of sprite_x
    lds     r19, sprite_table+SPRITE_SIZE*\spriteM+SPRITE_INDEX_X   // (2)
    add     XL, r19                                          // (1)
    clr     r19                                              // (1)
    adc     XH, r19                                          // (1)

    // point Y to sprite bitmap
    lds     YL,  sprite_table+SPRITE_SIZE*\spriteM+SPRITE_INDEX_BITMAP      // (2), used for pointer addressing of bitmaps
    lds     YH,  sprite_table+SPRITE_SIZE*\spriteM+SPRITE_INDEX_BITMAP+1    // (2)

    // compute sprite row intersected by current raster line and multiple by 8 to find sprite bitmap row to render
    // sprite_bitmap_row*8 = (curr_raster_line - sprite_y)*8
    
    mov     r19, r16                     // (1)   copy curr_raster_line into r19
    sub     r19, r17                     // (1)   r19 = current_raster_line:r19 - sprite_y:r17

    lsl     r19                          // (1)   r19 = r19*8
    lsl     r19                          // (1)
    lsl     r19                          // (1)

    clr     r0                           // (1)   Y = sprite_bitmap + sprite_bitmap_row*8
    add     YL, r19                      // (1)   r19 = sprite_bitmap_row*8 (0..56)
    adc     YH, r0                       // (1)   dummy add to take into consideration carry bit C overflow from lower byte

    // copy the sprite bytes into scanline buffer

    // transparent version of sprite, (64) clocks per copy
    .rept 8
    // copy pixel ///////////////////
    ld      r19, Y+                          // (2)
    cpi     r19, 0                           // (1)
    breq    1f                               // (1/2)
    st      X+, r19                          // (2)
    rjmp    2f                               // (2)           
1:
    adiw    XL, 1                            // (2)
    nop                                      // (1)
2:
    .endr

    // this added time needed for embedded sprite
    .rept 14
    nop
    .endr

    // draw pixels on line now
    rjmp    Sprite2_End_Loop3\spriteM        // (2)     


Sprite2_End_Loop1\spriteM:

    .rept ( 14 - 11 ) // delay differential between paths
    nop
    .endr

Sprite2_End_Loop2\spriteM:

// this delay time is now used for sprite render    
//    .rept ( (64 + 21 + 12 + 2 + 14) - 14 )
//    nop
//    .endr

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// render linked slave sprite (both sprites can't be on the same scanlines)

        Sprite2\spriteN:

            lds     r17, sprite_table+SPRITE_SIZE*\spriteN+SPRITE_INDEX_Y      // (2), r17 = sprite_y, (6)
            mov     r18, r17                                                   // (1), 
            lds     r19, sprite_table+SPRITE_SIZE*\spriteN+SPRITE_INDEX_HEIGHT // (2), r17 = sprite_y
            add     r18, r19                                                   // (1), r18 = sprite_y + sprite_height
   
        Sprite2_Test_Top\spriteN:

            // compare top of sprite with current_raster_line    
            cp      r16, r17                          // (1)      compare sprite_y and curr_raster_line
            brsh    Sprite2_Test_Bottom\spriteN        // (1/2)    if (curr_raster_line >= sprite_y) then...
            jmp     Sprite2_End_Loop1\spriteN          // (3)      (8+3) -> jump

        Sprite2_Test_Bottom\spriteN:

            // compare bottom of sprite with current_raster_line
            cp      r16, r18                          // (1), compare sprite_y and cur
            brlo    Sprite2_Draw\spriteN               // (1/2)
            jmp     Sprite2_End_Loop2\spriteN          // (3),     (11+3)-> jump, raster is beyond bottom of sprite, don't draw into scanline
 
        Sprite2_Draw\spriteN:
            // (12) clocks to entry
            // at this point, we know the sprite is visible, draw the currently intersected bitmap scanline 
            // into the scanline buffer at the sprite_x position    

            // point X to scanline back buffer
            ldi     XL, lo8 ( slinebuff0 )                           // (1),  (21) clocks for entire setup
            ldi     XH, hi8 ( slinebuff0 )                           // (1)

            // offset X by -8 to place sprites to left of screen at x = 0
            sbiw    XL, SPRITE_SCROLL_X                              // (2)

            // add in position of sprite_x
            lds     r19, sprite_table+SPRITE_SIZE*\spriteN+SPRITE_INDEX_X   // (2)
            add     XL, r19                                          // (1)
            clr     r19                                              // (1)
            adc     XH, r19                                          // (1)

            // point Y to sprite bitmap
            lds     YL,  sprite_table+SPRITE_SIZE*\spriteN+SPRITE_INDEX_BITMAP      // (2), used for pointer addressing of bitmaps
            lds     YH,  sprite_table+SPRITE_SIZE*\spriteN+SPRITE_INDEX_BITMAP+1    // (2)

            // compute sprite row intersected by current raster line and multiple by 8 to find sprite bitmap row to render
            // sprite_bitmap_row*8 = (curr_raster_line - sprite_y)*8
    
            mov     r19, r16                     // (1)   copy curr_raster_line into r19
            sub     r19, r17                     // (1)   r19 = current_raster_line:r19 - sprite_y:r17

            lsl     r19                          // (1)   r19 = r19*8
            lsl     r19                          // (1)
            lsl     r19                          // (1)

            clr     r0                           // (1)   Y = sprite_bitmap + sprite_bitmap_row*8
            add     YL, r19                      // (1)   r19 = sprite_bitmap_row*8 (0..56)
            adc     YH, r0                       // (1)   dummy add to take into consideration carry bit C overflow from lower byte

            // copy the sprite bytes into scanline buffer

            // transparent version of sprite, (64) clocks per copy
            .rept 8
            // copy pixel ///////////////////
            ld      r19, Y+                          // (2)
            cpi     r19, 0                           // (1)
            breq    1f                               // (1/2)
            st      X+, r19                          // (2)
            rjmp    2f                               // (2)           
        1:
            adiw    XL, 1                            // (2)
            nop                                      // (1)
        2:
            .endr

            // this added time needed for embedded sprite in master sprite, but not in slave sprite
            //.rept 14
            //nop
           // .endr

            // draw pixels on line now
            rjmp    Sprite2_End_Loop3\spriteM        // (2)     ,not always jumps out to master spirte index

        Sprite2_End_Loop1\spriteN:

            .rept ( 14 - 11 ) // delay differential between paths
            nop
            .endr

        Sprite2_End_Loop2\spriteN:

            .rept ( (64 + 21 + 12 + 2 )  - 14 )
            nop
            .endr

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

Sprite2_End_Loop3\spriteM:

.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.macro COMPUTE_TILE_PTR
        // point Y at bitmap data based on tile index etc.
        // tile_index = tile_map [ tile_index_x... + tile_index_y * 20 ]
        ld      r18, Z+                      // (2), get next tile from tile map

        // tile_bitmap_ptr      = tile_bitmaps_base_ptr + tile_index*64  
        //ldi     r19, 64                      // (1)
        mul     r19, r18                     // (2)  r1:r0 = tile_index*64  

        // note r17:r16 holds tile_bitmaps_base_ptr from above since reading out of vars is too slow
        // thus corruption of Y is ok, since restored below
        add     YL, r0                       // (1)
        adc     YH, r1                       // (1) Y -> tile_bitmaps + tile_bitmap_row*8 + tile_index*64  
                                         
        // now simply insert Y pointer into storage array which will be used during rendering
        st     X+, YL                        // (2), store low byte first
        st     X+, YH                        // (2), now high byte, [low0, high0], [low1, high1]...[lowN, highN]

        // reset Y for next pass
        mov     YL, r16                      // (1)  restore Y, tile_bitmap_base_ptr from r17:r16    
        mov     YH, r17                      // (1)
.endm
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////


.macro DRAW_TILE_PIXELS_NTSC_PT0 rt = r0
    // draws a single row of tile bitmap pixels by retrieving the next pointer in the tile bitmap row pointer array
    // then streams out 8 pixels, this macro initiates the process
    // on entry assumes:
    // Y -> pointer array containing pointers to bitmap rows to render for each tile
    // X will be used to retrieve pixels from bitmaps, therefore, save before call    

    // pixel 0, retrieve pointer, draw pixel
    ld      XL, Y+              // (2)
    ld      XH, Y+              // (2) X <- [ Y ], X -> tile bitmap data
    nop                         // (2), do nothing 
    nop                         

    ld      \rt, X+             // (2), retrieve next pixel from tile bitmap row
    out     PORTA, \rt          // (1), render to screen
.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.macro DRAW_TILE_PIXELS_NTSC_PT1 rt = r0
    // draws a single row of tile bitmap pixels by retrieving the next pointer in the tile bitmap row pointer array
    // then streams out 8 pixels, this macro continues the process
    // on entry assumes:
    // X -> pointer array containing pointers to bitmap rows to render for each tile
    // Y will be used to retrieve pixels from bitmaps, therefore, save before call    

    // pixel n, draw pixel
    nop                         // (6)
    nop
    nop
    nop
    nop
    nop

    ld      \rt, X+             // (2), retrieve next pixel from tile bitmap row
    out     PORTA, \rt          // (1), render to screen
.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// this macro set PT0..PT3, splits the computational load such that each pixel can be rendered in the shortest
// time possible relative to  NTSC_CLOCKS_PER_PIXEL, the idea is that each tile pointer takes more time to retrive
// that the nomal render process, so try and stagger computation in free areas while keeping the time per pixel constant
// proper sequencing is [PT0, [PT1, PT2, PT2, PT2, PT2, PT2, PT2, PT3]* ]
// PT0 initializes the process, called once per scanline, the PT1 starts the set of 8 pixels, PT2 continues, PT3
// finishes, then the process begins again with PT1
// additionally, since computation is split every 2 lines, these macros are used for even lines, the next 
// macro for the odd lines, so every 2 lines a new render line is computed, thus cutting the vertical resolution
// down by 2, however, it does allow sprites, so a necessary sacrifice...


// X temp pointer, used to traverse bytes of tile bitmap row
// Y -> tile bitmap pointer array
// Z -> scanline buffer

.macro DRAW_TILE_PIXELS_NTSC_SCAN0_PT0
// call single time before rendering process

    ld      XL, Y+              // (2), XL <- [ Y ], X -> tile bitmap data
.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.macro DRAW_TILE_PIXELS_NTSC_SCAN0_PT1 rt = r0, rp = r20
// call at start of pixel run 0...7 

    ld      XH, Y+              // (2), XH <- [ Y ], X -> tile bitmap data
    ld      \rp, Z              // (2), get next pixel from scanline buffer
    ld      \rt, X+             // (2), retrieve next pixel from tile bitmap row
    st      Z+, \rt             // (2), store new pixel back into scanline buffer, overwrite current

    out     PORTA, \rp          // (1), render scanline buffered pixel to screen
.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.macro DRAW_TILE_PIXELS_NTSC_SCAN0_PT2 rt = r0, rp = r20
// call each time during pixel up to last pixel - 1

    ld      \rp, Z              // (2), get next pixel from scanline buffer
    ld      \rt, X+             // (2), retrieve next pixel from tile bitmap row
    st      Z+, \rt             // (2), store new pixel back into scanline buffer, overwrite current
    nop                         // (1)
    nop                         // (1)

    out     PORTA, \rp          // (1), render scanline buffered pixel to screen
.endm
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.macro DRAW_TILE_PIXELS_NTSC_SCAN0_PT3 rt = r0, rp = r20
// call last in pixel run before looping back to PT1
    ld      \rp, Z              // (2), get next pixel from scanline buffer
    ld      \rt, X+             // (2), retrieve next pixel from tile bitmap row
    st      Z+, \rt             // (2), store new pixel back into scanline buffer, overwrite current
    ld      XL, Y+              // (2), XL <- [ Y ], X -> tile bitmap data

    out     PORTA, \rp          // (1), render scanline buffered pixel to screen
.endm
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.macro DRAW_TILE_PIXELS_NTSC_SCAN1_PT0 rt = r0, rp = r20
// this macro is used on off scanline of the render pair, it simple renders the scanline buffer, and does no other
// computation, thus, its available for work, 6 clocks
    nop                         // (6)
    nop
    nop
    nop
    nop
    nop

    ld      \rp, Z+             // (2), get next pixel from scanline buffer
    out     PORTA, \rp          // (1), render scanline buffered pixel to screen
.endm
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.macro  RESTORE_SREG reg = r16

    pop     \reg
    out     _SFR_IO_ADDR( SREG ), \reg      // restore status register
.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// LOCAL INITIALIZED VARIABLES (SRAM)
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.section .data

// tile map variables
tile_index_x:             .byte 0
tile_index_y:             .byte 0
tile_bitmap_row:          .byte 0

tile_map_save_ptr:        .byte 0,0
tile_bitmap_base_ptr:     .byte 0,0

// current video line
curr_line:                .byte 0,0    

// current raster line 0..virtual rez-1
curr_raster_line:         .byte 0
raster_line:              .byte 0

// amount of vertical scroll 0..7 (caller controlled)
tile_map_vscroll:         .byte 0

// the logical tile map width, used to access rows, this support horizontal course scrolling, (caller controlled)
tile_map_logical_width:   .byte  TILE_MAP_WIDTH

// tile bitmaps pointer array buffer, 18 tiles, 16-bit pointer for each that points to a bitmap row to render. 2x18 = 36 bytes
tile_bitmaps_ptr_array:   .byte 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0
                          .byte 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0

// scanline buffers, 144 + (sprite scroll buffer for left/right overscan bytes + 2 for insurance)
// the buffers are used interchangeably and swapped each set of active scanlines
slinebuff0:  .byte 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 
             .byte 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 
             .byte 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 
             .byte 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0
                       
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// DATA STRUCTURES IN FLASH/ROM - NOTE: MUST ON WORD BOUNDARIES
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.section .text

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// EXTERNALS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.extern tile_map_ptr      // 16-bit pointer to tile map
.extern tile_bitmaps_ptr  // 16-bit pointer to 8x8 tile bitmaps 
.extern sprite_table      // pointer to strite table containing sprite records

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// GLOBALS EXPORTS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// export these to caller, so he can interogate and change
.global curr_line                   // read only, current physical line
.global curr_raster_line            // read only, current logical raster line
.global tile_map_logical_width      // read/write, logical width of tile map
.global tile_map_vscroll            // read/write, current vertical scroll value 0..7

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// ASM FUNCTIONS 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// VGA/NTSC Interface Reference
//DDRA  = 0xFF; // NTSC/PAL LUMA7:4 | CHROMA3:0, VGA7:0 [vsync, hsync, B1,B0, G1,G0, G1,G0] 
//                                                        b7      b6    b5:4   b3:2   b1:0

.section .text

// asm entry point

.global	TIMER1_COMPA_vect  
TIMER1_COMPA_vect:

Save_Regs:

    // save working registers on stack
    push    r0              // (2)        
    
    push    r16             // (2)
    push    r17             // (2)

    push    r18             // (2)
    push    r19             // (2)

    push    r20             // (2)

    push    r24             // (2)
    push    r25             // (2)

    push    r26             // (2)   X
    push    r27             // (2)

    push    r28             // (2)   Y
    push    r29             // (2)

    push    r30             // (2)   Z
    push    r31             // (2)

    in      r0, SREG        // (2)
    push    r0              // (2) save the status register
                            // (32) clocks for stack push
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  
/*
Brief overview of design. The engine has to draw both tiles and sprites. To accomplish this 2 scanlines are used to 
spread the computation out and make it happen. On the first scanline of each pair, the process begins in the HSYNC
and horizontal blanking period. The tile map is interogated and the current scanline is tested for intersections thru
the tile map tiles, then for each tile intersected, the pointer to the actual bitmap data is computed and stored in 
an array, then during the active scan the render engine renders the previously computed line, and as each pixel is 
sent out to video, the new pixel from the new scanline is written into the buffer. However, this still doens't account
for sprites. Now, with the new tile scanline buffered up, in the next scanline of the pair, sprites are overlaid into
the scanline buffer. However, they take so much time that only 5 sprites can be drawn into the buffer. However, the
sprites are not completely independent. Sprite 0 has a slave sprite 1, slave sprite 1 has a slave sprite 2. Thus,
if sprite 0 is not rendered on the current line then slave sprite is tested, and rendered, if its not rendered then
slave sprite 2 is tested and rendered. the idea then is that as long as the sprites are on different vertical 
positions they can be on the same screen at the same time. 

This goes for another master sprite 3, it has a single slave 4.

So the idea is you can have 5 sprites on the screen but sprites 0,1,2 can't occupy the same vertical positions, 
similarly sprite 3,4 can't occupy the same positions. However, sprites 0,1,2 and 3,4 can overlap in any pair.

*/
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

NTSC_Start:

    // load r25:24 with curr_line
    lds     r24, curr_line                  // (2)
    lds     r25, curr_line+1                // (2)      

NTSC_Video_State_Test1:

    // if (curr_line < offset) then NTSC_Draw_Blank_Line
    ldi     r16, hi8(NTSC_VERTICAL_OFFSET)  // (1)
    cpi     r24, lo8(NTSC_VERTICAL_OFFSET)  // (1)
    cpc     r25, r16                        // (1)
    brlo    NTSC_Draw_Blank_Line_Top        // (1/2) NTSC_Start: (9) clocks -> jump, jump need due to code out of range for branch

// elseif
NTSC_Video_State_Test2:    

    // if (curr_line < ( screen height + offset) ) then NTSC_Draw_Active_Line
    ldi     r16, hi8(NTSC_SCREEN_HEIGHT + NTSC_VERTICAL_OFFSET)  // (1) 
    cpi     r24, lo8(NTSC_SCREEN_HEIGHT + NTSC_VERTICAL_OFFSET)  // (1)
    cpc     r25, r16                                             // (1)

    //brlo    NTSC_Draw_Active_Line  // (1/2) 

    brsh    NTSC_Video_State_Test3   // (1/2)
    jmp     NTSC_Draw_Active_Line    // (3)         NTSC_Start: (15) clocks -> jump, jump need due to code out of range for branch

// elseif
NTSC_Video_State_Test3:    

    // if (curr_line < 258) then NTSC_Draw_Blank_Line
    ldi     r16, hi8(256)            // (1) 
    cpi     r24, lo8(256)            // (1)
    cpc     r25, r16                 // (1)
    brlo    NTSC_Draw_Blank_Line_Bot // (1/2)       NTSC_Start: (18) clocks -> jump, jump need due to code out of range for branch

// elseif
NTSC_Video_State_Test4:    

    // if (curr_line < 262) then NTSC_Draw_Vsync_Line
    ldi     r16, hi8(262)            // (1) 
    cpi     r24, lo8(262)            // (1)
    cpc     r25, r16                 // (1)
    brlo    NTSC_Draw_Vsync_Line     // (1/2)       NTSC_Start: (22) clocks -> jump, jump need due to code out of range for branch
    // else should never get here...

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

NTSC_Draw_Vsync_Line:

    // invert hsync and maintain sync for 4-6 lines
    ldi     r16, NTSC_BLACK   // (1)
    out     PORTA, r16        // (1)

    // delay for hsync pulse length 

    // 16 color clocks sync (128 clocks)
    DELAY4X r16, (18*CLOCKS_PER_PIXEL)
    
    // disble hsync, but maintain vsync and black
    ldi     r16, NTSC_SYNC   // (1)
    out     PORTA, r16       // (1)

    jmp     NTSC_Next_Line   // (3)

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

NTSC_Draw_Blank_Line_Top: 
   
    // equalize delay from conditional line fork 
    .rept (18 - 9    )
    nop
    .endr

NTSC_Draw_Blank_Line_Bot: 

    // equalize delay from conditional line fork
    .rept (22 - 18    )
    nop
    .endr

    // enable hsync, set video to black
    ldi     r16, NTSC_SYNC           // (1)
    out     PORTA, r16               // (1)

    // test if this is the top of frame here, we need to initialize the rendering kernel
    // if (curr_line == 0) then NTSC_Reset_Kernel
    ldi     r16, hi8(0)              // (1)
    cpi     r24, lo8(0)              // (1)
    cpc     r25, r16                 // (1)

    // now based on flags set above, jump to normal blank line or reset 
    breq    NTSC_Reset_Kernel        // (1/2)

    // else delay hsync time (this will be filled with processing in later versions)

    // 16 color clocks sync (128 clocks), this needs to be adjusted correctly to take above computation into consideration
    DELAYX r16, (18*CLOCKS_PER_PIXEL - 8)
    
    // disble hsync, maintain black
    ldi     r16, NTSC_BLACK          // (1)
    out     PORTA, r16               // (1)

    // now color burst
    DELAYX r16, (2*CLOCKS_PER_PIXEL)
    
    ldi     r16, NTSC_CBURST0               // (1)
    out     PORTA, r16                      // (1)

    // now color burst
    DELAYX r16, (10*CLOCKS_PER_PIXEL)

    // back to black HSYNC off
    ldi     r16, NTSC_BLACK                 // (1)
    out     PORTA, r16                      // (1)

    jmp     NTSC_Next_Line           // (3)    

NTSC_Reset_Kernel:

    // reset all data structures each frame at line 0

    // initialize any variables for algorithm    

    // initialize raster_line for next frame, take into consideration vertical scroll value
    lds     r16, tile_map_vscroll            // (2)
    lsl     r16                              // (1), *2 since scanline are doubled
    sts     curr_raster_line, r16            // (2)

    // 16 color clocks sync (128 clocks), this needs to be adjusted correctly to take above computation into consideration..
    DELAYX r16, (18*CLOCKS_PER_PIXEL - 12)

    // disble hsync, maintain black
    ldi     r16, NTSC_BLACK                 // (1)
    out     PORTA, r16                      // (1)

    // now color burst
    DELAYX r16, (2*CLOCKS_PER_PIXEL)
    
    ldi     r16, NTSC_CBURST0               // (1)
    out     PORTA, r16                      // (1)

    // now color burst
    DELAYX r16, (10*CLOCKS_PER_PIXEL)

    // back to black HSYNC off
    ldi     r16, NTSC_BLACK                 // (1)
    out     PORTA, r16                      // (1)

    // clear scanline buffer, note offset since buffer extends beyond right and left to support sprites
    ldi     XL, lo8( slinebuff0+TILE_BITMAP_WIDTH ) // (2)
    ldi     XH, hi8( slinebuff0+TILE_BITMAP_WIDTH ) // (2)

    // clear buffer with NTSC_BLACK
    ldi     r16, NTSC_BLACK                 // (1)

    // fill the scanline buffer
    .rept 144
    st      X+, r16                         // (2)
    .endr

    jmp     NTSC_Next_Line                  // (3)

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

NTSC_Draw_Active_Line:

    // delay to equalize initial line fork
    .rept ( 22 - 15 - 1 )
    nop
    .endr

    // (37) for entire setup process..
    // enable hsync, set RGB to black (want approximately 16 color clocks for sync
    ldi     r16, NTSC_SYNC               // (1)
    out     PORTA, r16                   // (1)

    // determine if this is an even/odd line, then fork to proper computation logic, even lines set up 
    // tile pointer array, and extract scanline tile bitmap data during rendering and overwrite 
    // scanline buffer in FIFO fashion, then odd lines overlay sprite data into scanline, then in 
    // render section simply render the scanline buffer

    lds     r20, curr_raster_line        // (2)
    mov     r18, r20                     // (1), copy copy raster line to r18
    lsr     r18                          // (1) divide raster line by 2

    // test for even/odd line
    andi    r20, 0x01                    // (1) 
    breq    NTSC_Scanline_Type0          // (1/2)
    jmp     NTSC_Scanline_Type1          // (3)

NTSC_Scanline_Type0: // even scanlines

    // equalize delay from conditional fork on even/odd
    .rept (4 - 2)
    nop
    .endr

    // this section of code processes even scanlines type 0, they are responsible for pre-processing the tile bitmap 
    // pointers as well as rendering the pixels while computing the next line's bitmap data

    // on entry tile_index_x = 0 for start of scan left to right, line 0,1,2

    // tile_index_y = curr_raster_line / 8, later cache curr_raster_line as well
    mov     r16, r18                     // (1) r16 = curr_raster_line:r18,    (6) clocks
    lsr     r16                          // (1)
    lsr     r16                          // (1)
    lsr     r16                          // (1)
    sts     tile_index_y, r16            // (2)    r16 = tile_index_y

    // tile_bitmap_row = curr_raster_line mod 8, then multiply by 8, so directly indexes into tile bitmap data, 8 bytes per row
    mov     r17, r18                     // (1) r17 = curr_raster_line:418,   (7) clocks
    andi    r17, 0x07                    // (1)    
    lsl     r17                          // (1)    multiply by 8 
    lsl     r17                          // (1)
    lsl     r17                          // (1)
    sts     tile_bitmap_row, r17         // (2)    r17 = tile_bitmap_row*8

    // Z  -> tile_map [ tile_index_x=0 + tile_index_y * TILE_MAP_WIDTH ]
   
    lds     ZL, tile_map_ptr             // (2), (9) this code for pointer location storage
    lds     ZH, tile_map_ptr+1           // (2)
 
    lds     r18, tile_map_logical_width  // (2)    r18 = * TILE_MAP_WIDTH constant, * TILE_MAP_WIDTH tiles per row
    mul     r18, r16                     // (2)    r1:r0 = tile_index_y:r16 * * TILE_MAP_WIDTH:r18

    add     ZL, r0                       // (1)    Z -> tile_map[ tile_index_x=0 + tile_index_y * * TILE_MAP_WIDTH ]
    adc     ZH, r1                       // (1)    first tile, in current row intersected by current raster line

    // now pre-compute tile_bitmap_base_ptr (might need be needed due to register caching, review later)
    // tile_bitmap_base_ptr = tile_bitmaps + tile_bitmap_row*8
    lds     YL, tile_bitmaps_ptr         // (2), (9) this code for pointer location storage
    lds     YH, tile_bitmaps_ptr+1       // (2)

    clr     r0                           // (1)   Y = tile_bitmaps + tile_bitmap_row*8
    add     YL, r17                      // (1)   r17 = tile_bitmap_row*8 (0..56)
    adc     YH, r0                       // (1)   dummy add to take into consideration carry bit C overflow from lower byte
    
    mov     r16, YL                      // (1)   save tile_bitmap_base_ptr in r17:r16 for transient usage
    mov     r17, YH                      // (1)

    // X -> tile bitmaps base address pointer array
    ldi     XL, lo8( tile_bitmaps_ptr_array ) // (1), (2) this code for pointer location storage
    ldi     XH, hi8( tile_bitmaps_ptr_array ) // (1)

    // initialize constant in r19 = tile bitmap size in bytes
    ldi     r19, 64                           // (1)    

    // setup on entry to tile bitmap pointer conputation and storage, computes pointer to every tile bitmap
    // to be rendered on this row, stores in array
    // X -> tile bitmaps base address pointer array
    // Z -> tile map next tile index entry
    // Y =  tile_bitmap_base_ptr
    // r19 = 64, number of bytes per tile bitmap
    // (34) clocks to here


    // each pass takes (12) clocks * 18 = 216 clocks, break up into pieces to interleave hsync and color burst
    .rept 9
        COMPUTE_TILE_PTR
    .endr

    // turn HSYNC off, make sure to align with blank and vsync lines total time of hsync pulse, make as short as possible, 
    // so other lines can exit out ASAP and return to C
    ldi     r18, NTSC_BLACK                 // (1)
    out     PORTA, r18                      // (1)

    // now begin color burst
    //    DELAY4X r16, (2*CLOCKS_PER_PIXEL), above

    // each pass takes (12) clocks * 18 = 216 clocks, break up into pieces to interleave hsync and color burst
    .rept 2 
    COMPUTE_TILE_PTR    
    .endr

    // now turn on color burst  
    ldi     r18, NTSC_CBURST0               // (1)
    out     PORTA, r18                      // (1)

    // now color burst
    // DELAY4X r16, (10*CLOCKS_PER_PIXEL)

    // each pass takes (12) clocks * 18 = 216 clocks, break up into pieces to interleave hsync and color burst
    .rept 6 
    COMPUTE_TILE_PTR        
    .endr

    // a little more delay for color burst to complete
    // DELAY4X r18, 8

    // back to black HSYNC off
    ldi     r18, NTSC_BLACK                 // (1)
    out     PORTA, r18                      // (1)

    // each pass takes (12) clocks * 18 = 216 clocks, break up into pieces to interleave hsync and color burst
    .rept 1
    COMPUTE_TILE_PTR
    .endr

    // total of 18 tiles now complete

    // increment raster line
    lds     r0, curr_raster_line       // (2)
    inc     r0                         // (1)
    sts     curr_raster_line, r0       // (2)

///////////////////////////////////////////////////////////////////////////////////////////////////////

NTSC_Draw_Tile_Pixels_Type0:
// this draws the actual pixels in the front scanline buffer to the screen

    // Y -> tile bitmaps base address pointer array
    ldi     YL, lo8( tile_bitmaps_ptr_array ) // (1), this code for pointer location storage
    ldi     YH, hi8( tile_bitmaps_ptr_array ) // (1)

    // Z -> scanline buffer
    ldi     ZL, lo8( slinebuff0 + TILE_BITMAP_WIDTH ) // (1), point Z to scanline buffer
    ldi     ZH, hi8( slinebuff0 + TILE_BITMAP_WIDTH ) // (1)
    
    // move display out a bit
    DELAYX r16, (NTSC_HORIZONTAL_OFFSET)

    // initializes rendering process, partial pointer fetch
    DRAW_TILE_PIXELS_NTSC_SCAN0_PT0 

    // render the tiles in sets of 8 pixels, retrieve pointer to bitmap data for current tile row
    // and render it..., repeat
    .rept TILE_MAP_WIDTH // each pixel takes (9) clocks, 18*9*8 = 1296 clocks, 144 pixels
        DRAW_TILE_PIXELS_NTSC_SCAN0_PT1 // pixel 0

        DRAW_TILE_PIXELS_NTSC_SCAN0_PT2 // pixel 1
        DRAW_TILE_PIXELS_NTSC_SCAN0_PT2 // pixel 2
        DRAW_TILE_PIXELS_NTSC_SCAN0_PT2 // pixel 3
        DRAW_TILE_PIXELS_NTSC_SCAN0_PT2 // pixel 4
        DRAW_TILE_PIXELS_NTSC_SCAN0_PT2 // pixel 5
        DRAW_TILE_PIXELS_NTSC_SCAN0_PT2 // pixel 6

        DRAW_TILE_PIXELS_NTSC_SCAN0_PT3 // pixel 7
    .endr

    // hold last pixel for a moment
    .rept 7
    nop                                     // (1)
    .endr

    // and back to black
    ldi     r16, NTSC_BLACK                 // (1)
    out     PORTA, r16                      // (1)

    jmp     NTSC_Next_Line                  // (3)

///////////////////////////////////////////////////////////////////////////////////////////////////////

NTSC_Scanline_Type1: // odd scanlines

    DELAYX r16, (33 + 9*12 + 2 - (99 + 14 + 14 + 6) ) // last term contributed by sprite init and sprite 0
    
    // SPRITE ENGINE INITIALIZATION
    // sub tile_map_vscroll to take into account vertical scroll offset (3) clocks
    lds     r16, curr_raster_line           // (2) (6)
    lsr     r16                             // (1)
    lds     r17, tile_map_vscroll           // (2)
    sub     r16, r17                        // (1)  r16 = r16 - tile_map_vscroll

    // draw sprite # 0 (master), 1 (slave), 2 (slave)
    // sprite render uses r0, r16, r17, r18. r19, X, Y
    DRAW_SPRITE3 0, 1, 2

    // turn HSYNC off, make sure to align with blank and vsync lines total time of hsync pulse, 
    // make as short as possible, so other lines can exit out ASAP and return to C
    ldi     r18, NTSC_BLACK                 // (1)
    out     PORTA, r18                      // (1)

    // now begin color burst
    //    DELAY4X r16, (2*CLOCKS_PER_PIXEL), above

    DELAYX r18, (2*12)

    // now turn on color burst  
    ldi     r18, NTSC_CBURST0               // (1)
    out     PORTA, r18                      // (1)

    // now color burst
    // DELAY4X r16, (10*CLOCKS_PER_PIXEL)

    DELAYX r18, (6*12)
   
    // a little more delay for color burst to complete
    // DELAY4X r18, 8

    // back to black HSYNC off
    ldi     r18, NTSC_BLACK                 // (1)
    out     PORTA, r18                      // (1)

    //DELAYX r18, (1*12) // push delay downstream

NTSC_Draw_Tile_Pixels_Type1:
// this draws the actual pixels in the front scanline buffer to the screen

    // draw sprite # 3 (master), 4 (slave)
    // sprite render uses r0, r16, r17, r18. r19, X, Y
    DRAW_SPRITE2 3, 4

    // increment raster line
    lds     r0, curr_raster_line       // (2)
    inc     r0                         // (1)
    sts     curr_raster_line, r0       // (2)

    // Z -> scanline buffer
    ldi     ZL, lo8( slinebuff0 + TILE_BITMAP_WIDTH ) // (1), point Z to scanline buffer
    ldi     ZH, hi8( slinebuff0 + TILE_BITMAP_WIDTH ) // (1)
    
    // move display out a bit, extra 4 for the differential code between scanline types
    DELAYX r16, ( ((NTSC_HORIZONTAL_OFFSET + 4 + 1*12) - (99 + 14 + 0))) 

    // render the tiles in sets of 8 pixels directly from scanline buffer
    .rept TILE_MAP_WIDTH // each pixel takes (9) clocks, 18*9*8 = 1296 clocks, 144 pixels
        DRAW_TILE_PIXELS_NTSC_SCAN1_PT0 // pixel 0
        DRAW_TILE_PIXELS_NTSC_SCAN1_PT0 // pixel 1
        DRAW_TILE_PIXELS_NTSC_SCAN1_PT0 // pixel 2
        DRAW_TILE_PIXELS_NTSC_SCAN1_PT0 // pixel 3
        DRAW_TILE_PIXELS_NTSC_SCAN1_PT0 // pixel 4
        DRAW_TILE_PIXELS_NTSC_SCAN1_PT0 // pixel 5
        DRAW_TILE_PIXELS_NTSC_SCAN1_PT0 // pixel 6
        DRAW_TILE_PIXELS_NTSC_SCAN1_PT0 // pixel 7
    .endr

    // hold last pixel for a moment
    .rept 7
    nop                                     // (1)
    .endr

    // and back to black
    ldi     r16, NTSC_BLACK                 // (1)
    out     PORTA, r16                      // (1)

    jmp     NTSC_Next_Line                  // (3)

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

NTSC_Next_Line:

    // curr_line++
    adiw    r24, 1                 // (2)

    // if (curr_line >= 262) curr_line = 0
    ldi     r16, hi8(262)          // (1) 
    cpi     r24, lo8(262)          // (1)
    cpc     r25, r16               // (1)
    brne    NTSC_End_Line          // (1/2)

    // curr_line = 0
    ldi     r24, 0                 // (1)
    ldi     r25, 0                 // (1)

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

NTSC_End_Line:

    // save registers back to curr_line in SRAM for exit back to C/C++ caller
    sts     curr_line,   r24       // (2)
    sts     curr_line+1, r25       // (2)
    
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

Restore_Regs:

    // restore the status register
    pop     r0          // (2)
    out     SREG, r0    // (1)        

    // restore working registers
    pop     r31         // (2), Z
    pop     r30         // (2)

    pop     r29         // (2), Y
    pop     r28         // (2)

    pop     r27         // (2), X
    pop     r26         // (2)

    pop     r25         // (2)
    pop     r24         // (2)


    pop     r20         // (2)

    pop     r19         // (2)
    pop     r18         // (2)

    pop     r17         // (2)
    pop     r16         // (2)

    pop     r0          // (2)

#if 0
    .rept 50
    nop
    .endr
#endif

    
    reti                // (5) return from interrupt and reset interupt flag, total time of restore 36 clocks for restore

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// END ASM FUNCTIONS 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.end


