/* db_type.c - type table routines
 *
 * Copyright (c) 2009 by David Michael Betz.  All rights reserved.
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "db_compiler.h"

/* InitTypeTable - initialize a type table */
void InitTypeTable(TypeTable *table)
{
    table->head = NULL;
    table->pTail = &table->head;
}

/* FreeTypes - free the named types */
void FreeTypes(ParseContext *c, TypeTable *table)
{
    NamedType *type, *next;
    for (type = table->head; type != NULL; type = next) {
        next = type->next;
        FreeType(c, type->type);
        Free(type);
    }
}

/* NewType - allocate a new type */
Type *NewType(int id)
{
    Type *type;
    type = (Type *)Alloc("TYP", sizeof(Type));
    type->id = id;
    return type;
}

/* FreeType - free a type */
void FreeType(ParseContext *c, Type *type)
{
    if (type
    &&  type != &c->integerType
    &&  type != &c->integerArrayType
    &&  type != &c->byteType
    &&  type != &c->byteArrayType
    &&  type != &c->stringType) {
        switch (type->id) {
        case TYPE_ARRAY:
            FreeType(c, type->ArrayInfo.elementType);
            break;
        case TYPE_FUNCTION:
            FreeType(c, type->FunctionInfo.returnType);
            FreeSymbols(c, &type->FunctionInfo.arguments);
            break;
        }
        Free(type);
    }
}

/* DefaultType - get the default type based on the variable name */
Type *DefaultType(ParseContext *c, char *name)
{
    Type *type;
    switch (name[strlen(name) - 1]) {
    case '$':
        type = &c->stringType;
        break;
    case '%':
        type = &c->integerType;
        break;
    default:
        type = &c->integerType;
        break;
    }
    return type;
}

/* AddType - add a type to the type table */
Type *AddType(TypeTable *table, char *name, Type *type)
{
    size_t size = sizeof(NamedType) + strlen(name);
    NamedType *namedType;
    
    /* allocate the symbol structure */
    namedType = (NamedType *)Alloc("NTY", size);
    strcpy(namedType->name, name);
    namedType->type = type;
    namedType->next = NULL;

    /* add it to the symbol table */
    *table->pTail = namedType;
    table->pTail = &namedType->next;
    
    /* return the type */
    return type;
}

/* FindType - find a type in a type table */
Type *FindType(TypeTable *table, char *name)
{
    NamedType *namedType = table->head;
    while (namedType) {
        if (strcasecmp(name, namedType->name) == 0)
            return namedType->type;
        namedType = namedType->next;
    }
    return NULL;
}

/* CompareTypes - compare two types to see if they are equivilent */
int CompareTypes(Type *type1, Type *type2)
{
    int match;

    /* make sure the type ids match */
    if (type1->id == type2->id) {
        switch (type1->id) {
        case TYPE_ARRAY:
            match = CompareTypes(type1->ArrayInfo.elementType, type2->ArrayInfo.elementType);
            break;
        default:
            match = VMTRUE;
            break;
        }
    }

    /* no type id match */
    else
        match = VMFALSE;

    return match;
}

/* ValueSize - determine the size and prefix of a variable */
int ValueSize(Type *type, int *pPrefix)
{
    int size, elements, elementBytes;

    switch (type->id) {
    case TYPE_INTEGER:
        *pPrefix = 0;
        size = 1;
        break;
    case TYPE_BYTE:
        *pPrefix = 0;
        size = 1;
        break;
    case TYPE_STRING:
        *pPrefix = 0;
        size = 1;
        break;
    case TYPE_ARRAY:
        *pPrefix = 2;
        elements = type->ArrayInfo.dim1 * type->ArrayInfo.dim2;
        elementBytes = elements * ValueByteSize(type->ArrayInfo.elementType);
        size = 2 + (elementBytes + 1) / 2;
        break;
    default:
        break;
    }

    return size;
}

/* ValueByteSize - determine the byte size of a type */
int ValueByteSize(Type *type)
{
    int size;

    switch (type->id) {
    case TYPE_INTEGER:
        size = 2;
        break;
    case TYPE_BYTE:
        size = 1;
        break;
    case TYPE_STRING:
        size = 2;
        break;
    default:
        break;
    }

    return size;
}


