/* db_vmint.c - bytecode interpreter for a simple virtual machine
 *
 * Copyright (c) 2009 by David Michael Betz.  All rights reserved.
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <stdarg.h>
#include <string.h>
#include <ctype.h>
#include "db_vm.h"
#include "../common/db_packet.h"

#define INDEX1                                                                  \
            do {                                                                \
                ind1 = Pop(i);                                                  \
                tmp = i->sp[0];                                                 \
                if (ind1 < 1 || ind1 > i->variables[tmp - 1])                   \
                    Abort(i, "array subscript out of bounds: %d", ind1);        \
            } while (0)

#define INDEX2                                                                  \
            do {                                                                \
                ind2 = Pop(i);                                                  \
                ind1 = Pop(i);                                                  \
                tmp = i->sp[0];                                                 \
                if (ind1 < 1 || ind1 > i->variables[tmp - 2])                   \
                    Abort(i, "first array subscript out of bounds: %d", ind1);  \
                ind1 += (ind2 - 1) * i->variables[tmp - 2];                     \
                if (ind1 < 1 || ind1 > i->variables[tmp - 1])                   \
                    Abort(i, "second array subscript out of bounds: %d", ind2); \
            } while (0)

/* prototypes for local functions */
static void StringCat(Interpreter *i);
static int StringCmp(Interpreter *i);
static void PrintInteger(Interpreter *i, int dev, int16_t value);
static void PrintString(Interpreter *i, int dev, int16_t value);
static void PrintTab(Interpreter *i, int dev);
static void PrintNewline(Interpreter *i, int dev);
static void InputGetLine(Interpreter *i, int dev);
static void InputInteger(Interpreter *i, int dev);
static void InputString(Interpreter *i, int dev);
static void InputLine(Interpreter *i, int dev);
static void OpenFile(Interpreter *i);
static void CloseFile(Interpreter *i);
static void WriteString(Interpreter *i);

/* InitInterpreter - initialize the interpreter */
void InitInterpreter(Interpreter *i, int target)
{
    i->state = STATE_IDLE;
    i->target = target;
    i->cycleCount = 0;
    i->linePos = 0;
}

/* VerifyAndSetupImageHeader - verify and setup an image header */
static int VerifyAndSetupImageHeader(Interpreter *i, FileHdr *hdr)
{
    uint16_t dataSize, heapSize;

    /* verify the image header */
    if (strncmp(hdr->tag, FILE_TAG, strlen(FILE_TAG)) != 0 || hdr->version != FILE_VERSION) {
        VM_printf("header verify failed\n");
        return VMFALSE;
    }

    /* verify the target */
    //if (hdr->target != i->target) {
    //    VM_printf("not built for this target: expected %d, got %d\n", i->target, hdr->target);
    //    return VMFALSE;
    //}

    /* allocate the code and data space */
    dataSize = (hdr->variableCount + hdr->stackSize) * sizeof(int16_t);
    heapSize = hdr->heapSize ? sizeof(StringHeap) + hdr->heapSize + hdr->heapHandles * sizeof(void *) : 0;
    if (!VM_AllocateImage(i, hdr->codeSize, hdr->initSize, dataSize, heapSize)) {
        VM_printf("image space allocation failed: code %u, data %u, heap %u\n",
                  hdr->codeSize, dataSize, heapSize);
        return VMFALSE;
    }

    /* clear the variable space */
    memset(i->variables, 0, hdr->variableCount * sizeof(int16_t));
    i->init_state = INIT_HDR1;

    /* setup the stack */
    i->stack = (int16_t *)(i->variables + hdr->variableCount);
    i->stackTop = i->stack + hdr->stackSize;

    /* setup the heap if one was configured */
    if (i->heap)
        InitHeap(i, hdr->heapSize, hdr->heapHandles);

    /* return successfully */
    return VMTRUE;
}

/* InitMemoryImage - initialize an image already in memory */
int InitMemoryImage(Interpreter *i)
{    
    uint16_t off, cnt;
    uint8_t buf[128];
    
    /* get the memory image header */
    if (!VM_LoadMemoryImageHeader(i))
        return VMFALSE;

    /* verify and setup the header */
    if (!VerifyAndSetupImageHeader(i, &i->hdr))
        return VMFALSE;

    /* process the initialization data */
    for (off = 0; off < i->hdr.initSize; off += cnt) {

        /* determine how much initializer data to read */
        if ((cnt = i->hdr.initSize - off) > sizeof(buf))
			cnt = sizeof(buf);

        /* read the next block of initializer data */
        VM_ReadInit(off, buf, cnt);

        /* process the initializer data */
        ProcessInitData(i, buf, cnt);
    }

    /* finish loading */
    FinishImageLoad(i);

    /* return successfully */
    return VMTRUE;
}

/* StartImageLoad - start loading an image */
int StartImageLoad(Interpreter *i, FileHdr *hdr)
{
    /* verify and setup the image header */
    if (!VerifyAndSetupImageHeader(i, hdr))
        return VMFALSE;

    /* store the image header */
    i->hdr = *hdr;

    /* loading image */
    i->state = STATE_LOADING;

    /* stop the runtime functions */
    VM_fcnstop();

    /* return successfully */
    return VMTRUE;
}

/* ProcessInitData - process a block of variable initializers */
void ProcessInitData(Interpreter *i, uint8_t *buf, int len)
{
    uint8_t *end = buf + len;
    while (buf < end) {
        switch (i->init_state) {
        case INIT_HDR1:
            i->init_off = *(uint16_t *)buf;
            i->init_state = INIT_HDR2;
            buf += sizeof(uint16_t);
            break;
        case INIT_HDR2:
            i->init_cnt = *(uint16_t *)buf;
            i->init_state = INIT_DATA;
            buf += sizeof(uint16_t);
            break;
        case INIT_DATA:
            i->variables[i->init_off++] = *(int16_t *)buf;
            buf += sizeof(int16_t);
            if (--i->init_cnt == 0)
                i->init_state = INIT_HDR1;
            break;
        }
    }
}

/* FinishImageLoad - finish loading an image */
void FinishImageLoad(Interpreter *i)
{
    i->state = STATE_STARTING;
}

/* Execute - execute the main code */
int Execute(Interpreter *i, int cycleCount)
{
    int16_t tmp, tmp2, ind1, ind2;
    int8_t tmpb;

    i->cycleCount = cycleCount;
    
    if (i->state == STATE_STARTING) {
        i->pc = i->code + i->hdr.mainCodeOffset;
        i->sp = i->fp = i->stack - 1;
        VM_fcninit();
    }
    i->state = STATE_RUNNING;

    if (setjmp(i->errorTarget)) {
        VM_fcnstop();
        i->state = STATE_IDLE;
        return i->state;
    }

    for (;;) {
#if 0
        ShowStack(i);
        DecodeInstruction(0, i->code, i->pc);
#endif
        switch (VMCODEBYTE(i->pc++)) {
        case OP_HALT:
            VM_fcnstop();
            i->state = STATE_IDLE;
            return i->state;
        case OP_BRT:
            tmp = VMCODEBYTE(i->pc++);
            tmp |= (int16_t)(VMCODEBYTE(i->pc++) << 8);
            if (Pop(i))
                i->pc += tmp;
            break;
        case OP_BRTSC:
            tmp = VMCODEBYTE(i->pc++);
            tmp |= (int16_t)(VMCODEBYTE(i->pc++) << 8);
            if (*i->sp)
                i->pc += tmp;
            else
                Drop(i, 1);
            break;
        case OP_BRF:
            tmp = VMCODEBYTE(i->pc++);
            tmp |= (int16_t)(VMCODEBYTE(i->pc++) << 8);
            if (!Pop(i))
                i->pc += tmp;
            break;
        case OP_BRFSC:
            tmp = VMCODEBYTE(i->pc++);
            tmp |= (int16_t)(VMCODEBYTE(i->pc++) << 8);
            if (!*i->sp)
                i->pc += tmp;
            else
                Drop(i, 1);
            break;
        case OP_BR:
            tmp = VMCODEBYTE(i->pc++);
            tmp |= (int16_t)(VMCODEBYTE(i->pc++) << 8);
            i->pc += tmp;
            break;
        case OP_NOT:
            *i->sp = (*i->sp ? VMFALSE : VMTRUE);
            break;
        case OP_NEG:
            *i->sp = -*i->sp;
            break;
        case OP_ADD:
            tmp = Pop(i);
            *i->sp += tmp;
            break;
        case OP_SUB:
            tmp = Pop(i);
            *i->sp -= tmp;
            break;
        case OP_MUL:
            tmp = Pop(i);
            *i->sp *= tmp;
            break;
        case OP_DIV:
            tmp = Pop(i);
            *i->sp = (tmp == 0 ? 0 : *i->sp / tmp);
            break;
        case OP_REM:
            tmp = Pop(i);
            *i->sp = (tmp == 0 ? 0 : *i->sp % tmp);
            break;
        case OP_BNOT:
            *i->sp = ~*i->sp;
            break;
        case OP_BAND:
            tmp = Pop(i);
            *i->sp &= tmp;
            break;
        case OP_BOR:
            tmp = Pop(i);
            *i->sp |= tmp;
            break;
        case OP_BXOR:
            tmp = Pop(i);
            *i->sp ^= tmp;
            break;
        case OP_SHL:
            tmp = Pop(i);
            *i->sp <<= tmp;
            break;
        case OP_SHR:
            tmp = Pop(i);
            *i->sp >>= tmp;
            break;
        case OP_LT:
            tmp = Pop(i);
            *i->sp = (*i->sp < tmp ? VMTRUE : VMFALSE);
            break;
        case OP_LE:
            tmp = Pop(i);
            *i->sp = (*i->sp <= tmp ? VMTRUE : VMFALSE);
            break;
        case OP_EQ:
            tmp = Pop(i);
            *i->sp = (*i->sp == tmp ? VMTRUE : VMFALSE);
            break;
        case OP_NE:
            tmp = Pop(i);
            *i->sp = (*i->sp != tmp ? VMTRUE : VMFALSE);
            break;
        case OP_GE:
            tmp = Pop(i);
            *i->sp = (*i->sp >= tmp ? VMTRUE : VMFALSE);
            break;
        case OP_GT:
            tmp = Pop(i);
            *i->sp = (*i->sp > tmp ? VMTRUE : VMFALSE);
            break;
        case OP_CAT:
            StringCat(i);
            break;
        case OP_LTS:
            tmp = (StringCmp(i) < 0 ? VMTRUE : VMFALSE);
            *i->sp = tmp;
            break;
        case OP_LES:
            tmp = (StringCmp(i) <= 0 ? VMTRUE : VMFALSE);
            *i->sp = tmp;
            break;
        case OP_EQS:
            tmp = (StringCmp(i) == 0 ? VMTRUE : VMFALSE);
            *i->sp = tmp;
            break;
        case OP_NES:
            tmp = (StringCmp(i) != 0 ? VMTRUE : VMFALSE);
            *i->sp = tmp;
            break;
        case OP_GES:
            tmp = (StringCmp(i) >= 0 ? VMTRUE : VMFALSE);
            *i->sp = tmp;
            break;
        case OP_GTS:
            tmp = (StringCmp(i) > 0 ? VMTRUE : VMFALSE);
            *i->sp = tmp;
            break;
        case OP_LIT:
            tmp = VMCODEBYTE(i->pc++);
            CPush(i, (int16_t)(VMCODEBYTE(i->pc++) << 8) | tmp);
            break;
        case OP_GREF:
            tmp = VMCODEBYTE(i->pc++);
            tmp |= (int16_t)VMCODEBYTE(i->pc++) << 8;
            CPush(i, i->variables[tmp]);
            break;
        case OP_GSET:
            tmp = VMCODEBYTE(i->pc++);
            tmp |= (int16_t)VMCODEBYTE(i->pc++) << 8;
            i->variables[tmp] = Pop(i);
            break;
        case OP_GREFB:
            tmp = VMCODEBYTE(i->pc++);
            tmp |= (int16_t)VMCODEBYTE(i->pc++) << 8;
            CPush(i, *(uint8_t *)&i->variables[tmp]);
            break;
        case OP_GSETB:
            tmp = VMCODEBYTE(i->pc++);
            tmp |= (int16_t)VMCODEBYTE(i->pc++) << 8;
            *(uint8_t *)&i->variables[tmp] = (uint8_t)Pop(i);
            break;
        case OP_GREFS:
            tmp = VMCODEBYTE(i->pc++);
            tmp |= (int16_t)VMCODEBYTE(i->pc++) << 8;
            StringAddRef(i, i->variables[tmp]);
            CPush(i, i->variables[tmp]);
            break;
        case OP_GSETS:
            tmp = VMCODEBYTE(i->pc++);
            tmp |= (int16_t)VMCODEBYTE(i->pc++) << 8;
            StringRelease(i, i->variables[tmp]);
            i->variables[tmp] = Pop(i);
            break;
        case OP_LOFF:
            tmp = VMCODEBYTE(i->pc++);
            CPush(i, (int16_t)(i->fp - i->variables) + tmp);
            break;
        case OP_LREF:
            tmpb = (int8_t)VMCODEBYTE(i->pc++);
            CPush(i, i->fp[(int)tmpb]);
            break;
        case OP_LSET:
            tmpb = (int8_t)VMCODEBYTE(i->pc++);
            i->fp[(int)tmpb] = Pop(i);
            break;
        case OP_LREFB:
            tmpb = (int8_t)VMCODEBYTE(i->pc++);
            CPush(i, *(uint8_t *)&i->fp[(int)tmpb]);
            break;
        case OP_LSETB:
            tmpb = (int8_t)VMCODEBYTE(i->pc++);
            *(uint8_t *)&i->fp[(int)tmpb] = (uint8_t)Pop(i);
            break;
        case OP_LREFS:
            tmpb = (int8_t)VMCODEBYTE(i->pc++);
            StringAddRef(i, i->fp[(int)tmpb]);
            CPush(i, i->fp[(int)tmpb]);
            break;
        case OP_LSETS:
            tmpb = (int8_t)VMCODEBYTE(i->pc++);
            StringRelease(i, i->fp[(int)tmpb]);
            i->fp[(int)tmpb] = Pop(i);
            break;
        case OP_LDECREF:
            tmpb = (int8_t)VMCODEBYTE(i->pc++);
            StringRelease(i, i->fp[(int)tmpb]);
            break;
        case OP_AREF1:
            INDEX1;
            i->sp[0] = i->variables[tmp + ind1 - 1];
            break;
        case OP_ASET1:
            tmp2 = Pop(i);
            INDEX1;
            i->variables[tmp + ind1 - 1] = tmp2;
            Drop(i, 1);
            break;
        case OP_AREF2:
            INDEX2;
            i->sp[0] = i->variables[tmp + ind1 - 1];
            break;
        case OP_ASET2:
            tmp2 = Pop(i);
            INDEX2;
            i->variables[tmp + ind1 - 1] = tmp2;
            Drop(i, 1);
            break;
        case OP_AREF1B:
            INDEX1;
            i->sp[0] = ((uint8_t *)&i->variables[tmp])[ind1 - 1];
            break;
        case OP_ASET1B:
            tmp2 = Pop(i);
            INDEX1;
            ((uint8_t *)&i->variables[tmp])[ind1 - 1] = (uint8_t)tmp2;
            Drop(i, 1);
            break;
        case OP_AREF2B:
            INDEX2;
            i->sp[0] = ((uint8_t *)&i->variables[tmp])[ind1 - 1];
            break;
        case OP_ASET2B:
            tmp2 = Pop(i);
            INDEX2;
            ((uint8_t *)&i->variables[tmp])[ind1 - 1] = (uint8_t)tmp2;
            Drop(i, 1);
            break;
        case OP_AREF1S:
            INDEX1;
            tmp = i->variables[tmp + ind1 - 1];
            i->sp[0] = tmp;
            StringAddRef(i, tmp);
            break;
        case OP_ASET1S:
            tmp2 = Pop(i);
            INDEX1;
            tmp += ind1 - 1;
            StringRelease(i, tmp);
            i->variables[tmp] = tmp2;
            Drop(i, 1);
            break;
        case OP_AREF2S:
            INDEX2;
            tmp = i->variables[tmp + ind1 - 1];
            i->sp[0] = tmp;
            StringAddRef(i, tmp);
            break;
        case OP_ASET2S:
            tmp2 = Pop(i);
            INDEX2;
            tmp += ind1 - 1;
            StringRelease(i, tmp);
            i->variables[tmp] = tmp2;
            Drop(i, 1);
            break;
        case OP_RESERVE:
            tmp = VMCODEBYTE(i->pc++);
            Reserve(i, tmp);
            break;
        case OP_CALL:
            tmp = i->sp[-(int16_t)VMCODEBYTE(i->pc++)];
            if (tmp & 1)
                (*Intrinsics[tmp >> 1])(i);
            else {
                tmp2 = (int16_t)(i->fp - i->stack);
                i->fp = i->sp;
                Reserve(i, F_SIZE);
                i->fp[F_FP] = tmp2;
                i->fp[F_PC] = (int16_t)(i->pc - i->code);
                i->pc = i->code + tmp;
            }
            break;
        case OP_FRET:
            i->pc = i->code + i->fp[F_PC];
            i->sp = i->fp;
            Drop(i, VMCODEBYTE(i->pc - 1));
            i->fp = i->stack + i->fp[F_FP];
            break;
        case OP_SRET:
            i->pc = i->code + i->fp[F_PC];
            i->sp = i->fp;
            Drop(i, VMCODEBYTE(i->pc - 1) + 1);
            i->fp = i->stack + i->fp[F_FP];
            break;
        case OP_DUP:
            tmp = *(i)->sp;
            CPush(i, tmp);
            break;
        case OP_DROP:
            Drop(i, 1);
            break;
        case OP_PRINTI:
            tmp = VMCODEBYTE(i->pc++);
            PrintInteger(i, tmp, Pop(i));
            break;
        case OP_PRINTS:
            tmp = VMCODEBYTE(i->pc++);
            PrintString(i, tmp, i->sp[0]);
            StringRelease(i, Pop(i));
            break;
        case OP_PRINTT:
            tmp = VMCODEBYTE(i->pc++);
            PrintTab(i, tmp);
            break;
        case OP_PRINTN:
            tmp = VMCODEBYTE(i->pc++);
            PrintNewline(i, tmp);
            break;
        case OP_GETLINE:
            tmp = VMCODEBYTE(i->pc++);
            InputGetLine(i, tmp);
            if (i->state != STATE_RUNNING)
                return i->state;
            break;
        case OP_INPUTI:
            tmp = VMCODEBYTE(i->pc++);
            InputInteger(i, tmp);
            if (i->state != STATE_RUNNING)
                return i->state;
            break;
        case OP_INPUTS:
            tmp = VMCODEBYTE(i->pc++);
            InputString(i, tmp);
            if (i->state != STATE_RUNNING)
                return i->state;
            break;
        case OP_INPUTL:
            tmp = VMCODEBYTE(i->pc++);
            InputLine(i, tmp);
            if (i->state != STATE_RUNNING)
                return i->state;
            break;
        case OP_OPEN:
            OpenFile(i);
            break;
        case OP_CLOSE:
            CloseFile(i);
            break;
        case OP_WRITES:
            WriteString(i);
            break;
        default:
            Abort(i, "undefined opcode 0x%02x", VMCODEBYTE(i->pc - 1));
            break;
        }
        if (i->cycleCount > 0 && --i->cycleCount == 0)
            return i->state;
    }
}

static void StringCat(Interpreter *i)
{
    int16_t hStr2 = Pop(i);
    int16_t hStr1 = i->sp[0];
    int len1, inHeap1, len2, inHeap2;
    char *str1, *str2, *str;

    /* get the first string pointer and length */
    str1 = GetStringPtr(i, hStr1, &inHeap1);
    len1 = GetStringLen(i, hStr1);

    /* get the second string pointer and length */
    str2 = GetStringPtr(i, hStr2, &inHeap2);
    len2 = GetStringLen(i, hStr2);

    /* allocate the result string */
    i->sp[0] = StringAlloc(i, (uint16_t)(len1 + len2));
    str = (char *)GetHeapStringPtr(i, i->sp[0]);

    /* copy the source strings into the result string */
    VMCOPY(str, str1, len1, inHeap1);
    VMCOPY(str + len1, str2, len2, inHeap2);

    /* adjust the reference counts */
    StringRelease(i, hStr1);
    StringRelease(i, hStr2);
}

static int StringCmp(Interpreter *i)
{
    int16_t hStr2 = Pop(i);
    int16_t hStr1 = i->sp[0];
    int len1, inHeap1, len2, inHeap2, cnt, cmp;
    char *str1, *str2;

    /* get the first string pointer and length */
    str1 = GetStringPtr(i, hStr1, &inHeap1);
    len1 = GetStringLen(i, hStr1);

    /* get the second string pointer and length */
    str2 = GetStringPtr(i, hStr2, &inHeap2);
    len2 = GetStringLen(i, hStr2);

    /* handle the case where the first string is shorter than the second */
    if (len1 < len2) {
        for (cnt = len1; cnt > 0; --cnt) {
            if ((cmp = VMGETBYTE(str1++, inHeap1) - VMGETBYTE(str2++, inHeap2)) != 0)
                break;
        }
        if (cnt <= 0)
            cmp = -1;
    }
    
    /* handle the case where the first string is longer or the same length as the first */
    else {
        for (cnt = len2; cnt > 0; --cnt) {
            if ((cmp = VMGETBYTE(str1++, inHeap1) - VMGETBYTE(str2++, inHeap2)) != 0)
                break;
        }
        if (cnt <= 0)
            cmp = (len1 == len2 ? 0 : 1);
    }

    /* adjust the reference counts */
    StringRelease(i, hStr1);
    StringRelease(i, hStr2);

    /* return the comparision result */
    return cmp;
}

static void PrintC(Interpreter *i, int ch)
{
    VM_putchar(ch);
    if (ch == '\n')
        i->linePos = 0;
    else
        ++i->linePos;
}

static void PrintS(Interpreter *i, char *str)
{
    while (*str != '\0')
        PrintC(i, *str++);
}

static void PrintT(Interpreter *i)
{
    do {
        VM_putchar(' ');
        ++i->linePos;
    } while ((i->linePos % 8) != 0);
}

static void PrintInteger(Interpreter *i, int dev, int16_t value)
{
    char buf[20];
    sprintf(buf, "%d", value);
    if (dev == 0)
        PrintS(i, buf);
    else
        VM_displaystr(buf);
}

static void PrintString(Interpreter *i, int dev, int16_t value)
{
    int inHeap;
    char *str = GetStringPtr(i, value, &inHeap);
    int len = GetStringLen(i, value);
    if (dev == 0) {
        while (--len >= 0)
            PrintC(i, VMGETBYTE(str++, inHeap));
    }
    else {
        while (--len >= 0)
            VM_displaychar(VMGETBYTE(str++, inHeap));
    }
}

static void PrintTab(Interpreter *i, int dev)
{
    if (dev == 0)
        PrintT(i);
    else
        VM_displaytab();
}

static void PrintNewline(Interpreter *i, int dev)
{
    if (dev == 0)
        PrintC(i, '\n');
    else
        VM_displaychar('\n');
}

static char inputBuf[PKTMAXLEN + 1];
static char *inputPtr = NULL;

static char *GetInputToken(void)
{
    char *token, *p;
    
    /* make sure there is a current line */
    if (!inputPtr)
        return VMFALSE;
    
    /* skip leading spaces */
    for (token = inputPtr; *token != '\0' && isspace(*token); ++token)
        ;

    /* check for the end of line */
    if (*token == '\0' || *token == '\n') {
        inputPtr = NULL;
        return VMFALSE;
    }

    /* handle quoted strings */
    if (*token == '"') {
        p = ++token;
        while (*p != '\0' && *p != '\n' && *p != '"')
            ++p;
    }

    /* handle tokens without quotes */
    else {
        p = token;
        while (*p != '\0' && *p != '\n' && *p != ',')
            ++p;
    }

    /* skip past the terminator */
    if (*p == '\0' || *p == '\n')
        inputPtr = NULL;
    else {
        inputPtr = p;
        if (*inputPtr == '"') {
            while (*inputPtr != '\0' && *inputPtr != '\n' && *inputPtr != ',')
                ++inputPtr;
        }
        if (*inputPtr == ',')
            ++inputPtr;
        else
            inputPtr = NULL;
    }

    /* strip trailing blanks */
    while (p > token) {
        if (isspace(p[-1]))
            --p;
        else
            break;
    }
    
    /* terminate the token string */
    *p = '\0';

    /* return the token */
    return token;
}

void SetInputLine(uint8_t *buf, int cnt)
{
    memcpy(inputBuf, buf, cnt);
    inputBuf[cnt] = '\0';
    inputPtr = inputBuf;
    interp.state = STATE_RUNNING;
}

static void InputGetLine(Interpreter *i, int dev)
{
    inputPtr = NULL;
    i->state = STATE_PAUSED;
    VM_getline();
}

static void InputInteger(Interpreter *i, int dev)
{
    char *token;
    if (!(token = GetInputToken())) {
        InputGetLine(i, dev);
        i->pc -= 2;
    }
    else
        CPush(i, atoi(token));
}

static void InputString(Interpreter *i, int dev)
{
    char *token;
    if (!(token = GetInputToken())) {
        InputGetLine(i, dev);
        i->pc -= 2;
    }
    else {
        uint16_t len = (uint16_t)strlen(token);
        int16_t hStr = StringAlloc(i, len);
        char *str = (char *)GetHeapStringPtr(i, hStr);
        memcpy(str, token, len);
        CPush(i, hStr);
    }
}

static void InputLine(Interpreter *i, int dev)
{
}

static void OpenFile(Interpreter *i)
{
}

static void CloseFile(Interpreter *i)
{
}

static void WriteString(Interpreter *i)
{
}

void StackOverflow(Interpreter *i)
{
    Abort(i, "stack overflow");
}

void Abort(Interpreter *i, char *fmt, ...)
{
    va_list ap;
    va_start(ap, fmt);
    VM_printf("error: ");
    VM_vprintf(fmt, ap);
    VM_putchar('\n');
    va_end(ap);
    VM_flush();
    if (i)
        longjmp(i->errorTarget, 1);
    else
        exit(1);
}
