/* main.cpp - the main window for xgsbasic
 *
 * Copyright (c) 2009 by David Michael Betz.  All rights reserved.
 *
 */

#include "xgsbasicw.h"
#include "main.h"

extern "C" {
    #include "../common/db_packet.h"
}

extern char *load_xpm[];
extern char *reload_xpm[];

BEGIN_EVENT_TABLE(MainFrame, wxFrame)
    EVT_MENU(wxID_ABOUT,                                MainFrame::OnAbout)
    EVT_MENU(wxID_EXIT,                                 MainFrame::OnQuit)
    EVT_MENU_RANGE(ID_DOWNLOAD_CARD, ID_DOWNLOAD_SRAM,  MainFrame::OnDownloadSelect)
    EVT_MENU_RANGE(ID_PORT_COM1, ID_PORT_COM6,          MainFrame::OnPortSelect)
    EVT_TOOL(ID_LOAD,                                   MainFrame::OnLoad)
    EVT_TOOL(ID_RELOAD,                                 MainFrame::OnReload)
    EVT_CLOSE(                                          MainFrame::OnClose)
    EVT_IDLE(                                           MainFrame::OnIdle)
END_EVENT_TABLE()

MainFrame::MainFrame(const wxString &title)
    : wxFrame(NULL, wxID_ANY, title)
{
    /////////////
    // TOOLBAR //
    /////////////

    m_toolBar = CreateToolBar();
    m_toolBar->SetToolBitmapSize(wxSize(26, 25));

    wxBitmap load_image(load_xpm);
    m_toolBar->AddTool(ID_LOAD, wxT("Load"), load_image, wxT("Load a program"));

    wxBitmap reload_image(reload_xpm);
    m_toolBar->AddTool(ID_RELOAD, wxT("Reload"), reload_image, wxT("Reload the last program loaded"));
    
    m_toolBar->Realize();

    ///////////
    // MENUS //
    ///////////

    wxMenu *fileMenu = new wxMenu;
    fileMenu->Append(wxID_EXIT,wxT("E&xit\tAlt-X"),wxT("Quit this program"));

    m_downloadMenu = new wxMenu;
    m_downloadMenu->AppendRadioItem(ID_DOWNLOAD_CARD,wxT("MicroSD Card"),wxT("Download to the microSD card"));
    m_downloadMenu->AppendRadioItem(ID_DOWNLOAD_FLASH,wxT("Internal Flash Memory"),wxT("Download to MCU internal flash memory"));
    m_downloadMenu->AppendRadioItem(ID_DOWNLOAD_SRAM,wxT("SRAM"),wxT("Download to MCU SRAM"));
    m_downloadMenu->Enable(ID_DOWNLOAD_SRAM, false);
    SelectDownloadMode(wxGetApp().DownloadMode());

    m_portMenu = new wxMenu;
    m_portMenu->AppendRadioItem(ID_PORT_COM1,wxT("COM1"),wxT("Use serial port COM1"));
    m_portMenu->AppendRadioItem(ID_PORT_COM2,wxT("COM2"),wxT("Use serial port COM2"));
    m_portMenu->AppendRadioItem(ID_PORT_COM3,wxT("COM3"),wxT("Use serial port COM3"));
    m_portMenu->AppendRadioItem(ID_PORT_COM4,wxT("COM4"),wxT("Use serial port COM4"));
    m_portMenu->AppendRadioItem(ID_PORT_COM5,wxT("COM5"),wxT("Use serial port COM5"));
    m_portMenu->AppendRadioItem(ID_PORT_COM6,wxT("COM6"),wxT("Use serial port COM6"));

    wxMenu *helpMenu = new wxMenu;
    helpMenu->Append(wxID_ABOUT,wxT("&About..."),wxT("About XGS Basic..."));

    wxMenuBar *menuBar = new wxMenuBar();
    menuBar->Append(fileMenu,wxT("&File"));
    menuBar->Append(m_downloadMenu,wxT("Download"));
    menuBar->Append(m_portMenu,wxT("Port"));
    menuBar->Append(helpMenu,wxT("Help"));

    SetMenuBar(menuBar);

    //////////////
    // LISTENER //
    //////////////

    m_listener = new Listener(this,wxID_ANY,wxEmptyString);
    m_listener->Show();

    ////////////////
    // STATUS BAR //
    ////////////////

    CreateStatusBar(2);
    SetStatusText(wxT("Welcome to XGS Basic!"));
}

#define AboutStringFmt "\
XGS Basic %d.%d\n\
Copyright (c) 2009, David Betz\n\
All Rights Reserved"

void MainFrame::OnAbout(wxCommandEvent &event)
{
    char about[200];
    sprintf(about, AboutStringFmt, FILE_VERSION >> 8, FILE_VERSION & 0xff);
    wxMessageBox(wxT(about),wxT("About XGS Basic"),wxOK | wxICON_INFORMATION,this);
}

void MainFrame::OnQuit(wxCommandEvent &event)
{
    Close();
}

void MainFrame::OnClose(wxCloseEvent &event)
{
    SetStatusText(wxT("Thank you for using XGS Basic!"));
    wxGetApp().SaveSettingsAndExit();
}

void MainFrame::OnIdle(wxIdleEvent &event)
{
    PktPoll(0);
}

void MainFrame::OnDownloadSelect(wxCommandEvent &event)
{
    switch (event.GetId()) {
    case ID_DOWNLOAD_CARD:
        SelectDownloadMode(kDownloadCard);
        break;
    case ID_DOWNLOAD_FLASH:
        SelectDownloadMode(kDownloadFlash);
        break;
    case ID_DOWNLOAD_SRAM:
        SelectDownloadMode(kDownloadSRAM);
        break;
    }
}

void MainFrame::SelectDownloadMode(int mode)
{
    switch (mode) {
    case kDownloadCard:
        m_downloadMenu->Check(ID_DOWNLOAD_CARD, true);
        break;
    case kDownloadFlash:
        m_downloadMenu->Check(ID_DOWNLOAD_FLASH, true);
        break;
    case kDownloadSRAM:
        m_downloadMenu->Check(ID_DOWNLOAD_SRAM, true);
        break;
    }
    wxGetApp().SetDownloadMode(mode);
}

void MainFrame::OnPortSelect(wxCommandEvent &event)
{
    wxGetApp().OpenPort((const char *)m_portMenu->GetLabelText(event.GetId()), false);
}

void MainFrame::SelectPort(wxString &port)
{
    int id;
    if ((id = m_portMenu->FindItem(port)) != wxNOT_FOUND)
        m_portMenu->Check(id, true);
}

void MainFrame::OnLoad(wxCommandEvent &event)
{
    wxGetApp().CompileAndLoad();
}

void MainFrame::OnReload(wxCommandEvent &event)
{
    wxGetApp().ReloadLastFile();
}

/* UpdateSerialMenu - update the state of serial port selection menu */
void MainFrame::ConsoleSetInputHandler(void (*handler)(void *data, const char *buf), void *data)
{
    m_listener->SetInputHandler(handler, data);
}

void MainFrame::ConsolePutC(int ch)
{
    m_listener->PutC(ch);
}

void MainFrame::ConsoleFlushOutput(void)
{
    m_listener->FlushOutput();
}
