/* xgsbasicw.cpp - an xgsbasic gui using wxWidgets 2.8.10
 *
 * Copyright (c) 2009 by David Michael Betz.  All rights reserved.
 *
 */

#include "xgsbasicw.h"

extern "C" {
    #include "../compiler/db_compiler.h"
    #include "../common/db_packet.h"
    #include "../runtime/db_vm.h"
}

IMPLEMENT_APP(Basic)

bool Basic::OnInit()
{
    m_config = new wxConfig("XGS-Basic");
    m_screenRect = wxGetClientDisplayRect();
    
    m_main = new MainFrame(wxT("XGS Basic"));

    m_downloadMode = kDownloadFlash;

    m_portOpen = false;
    m_port = wxT("COM1");

    m_lastFileLoaded.Empty();

    RestoreSettings();

    return true;
}

void Basic::SaveSettingsAndExit()
{
    m_config->Write(wxT("downloadMode"), m_downloadMode);
    m_config->Write(wxT("port"), m_port);
    SaveWindowPositions();
    ExitMainLoop();
}

void Basic::SaveWindowPositions()
{
    SaveWindowPosition(wxT("/windows/main"),m_main);
}

void Basic::SaveWindowPosition(wxString key, wxTopLevelWindow *win)
{
    wxString itemKey;

    int x, y;
    win->GetPosition(&x, &y);

    itemKey.Printf(wxT("%s/x"), (const wxChar *)key);
    m_config->Write(itemKey,(const long)x);

    itemKey.Printf(wxT("%s/y"), (const wxChar *)key);
    m_config->Write(itemKey, (long)y);
    
    int width, height;
    win->GetSize(&width, &height);

    itemKey.Printf(wxT("%s/width"), (const wxChar *)key);
    m_config->Write(itemKey, (long)width);

    itemKey.Printf(wxT("%s/height"), (const wxChar *)key);
    m_config->Write(itemKey, (long)height);
}

void Basic::RestoreSettings()
{
    m_config->Read(wxT("downloadMode"), &m_downloadMode, kDownloadFlash);
    m_main->SelectDownloadMode(m_downloadMode);
    m_config->Read(wxT("port"), &m_port, wxString(wxT("COM1")));
    OpenPort((const char *)m_port, true);
    RestoreWindowPositions();
}

void Basic::RestoreWindowPositions()
{
    RestoreWindowPosition(wxT("/windows/main"), m_main);
}

void Basic::RestoreWindowPosition(wxString key, wxTopLevelWindow *win)
{
    wxString itemKey;

    int x, y;
    win->GetPosition(&x, &y);

    long targetX;
    itemKey.Printf(wxT("%s/x"), (const wxChar *)key);
    m_config->Read(itemKey, &targetX, (long)x);
    if (targetX < m_screenRect.GetLeft())
        targetX = m_screenRect.GetLeft();
    else if (targetX > m_screenRect.GetRight() - 20)
        targetX = m_screenRect.GetRight() - 20;

    long targetY;
    itemKey.Printf(wxT("%s/y"), (const wxChar *)key);
    m_config->Read(itemKey, &targetY, (long)y);
    if (targetY < m_screenRect.GetTop())
        targetY = m_screenRect.GetTop();
    else if (targetY > m_screenRect.GetBottom() - 20)
        targetY = m_screenRect.GetBottom() - 20;

    int width, height;
    win->GetSize(&width, &height);

    long targetWidth;
    itemKey.Printf(wxT("%s/width"), (const wxChar *)key);
    m_config->Read(itemKey, &targetWidth, (long)width);

    long targetHeight;
    itemKey.Printf(wxT("%s/height"), (const wxChar *)key);
    m_config->Read(itemKey, &targetHeight, (long)height);

    win->SetSize((int)targetX,(int)targetY, (int)targetWidth, (int)targetHeight);
    win->Show();
}

void Basic::OpenPort(const char *port, bool init)
{
    if (m_portOpen)
        ClosePort();

    m_port = port;
    m_main->SelectPort(m_port);

    if (PktOpen((char *)port))
        m_portOpen = true;
    else if (!init) {
        char error[200];
        sprintf(error, wxT("Can't open %s"), port);
        wxMessageBox(wxT(error), wxT("Open failed"), wxOK | wxICON_ERROR, m_main);
    }
}

void Basic::ClosePort()
{
    m_portOpen = false;
    PktClose();
}

#define LOAD_FILTER wxT("Basic source files (*.bas)|*.bas|Basic compiled image files (*.bai)|*.bai")

void Basic::CompileAndLoad()
{
    if (m_portOpen) {
        wxFileDialog dialog(m_main, wxT("Select a file to load"), wxEmptyString, wxEmptyString, LOAD_FILTER, wxOPEN);
        if (dialog.ShowModal() == wxID_OK)
            Load(dialog.GetPath());
    }
    else
        Warning("Serial port not open");
}

void Basic::ReloadLastFile()
{
    if (m_lastFileLoaded.IsNull())
        Warning("No last file to reload");
    else
        Load(m_lastFileLoaded);
}

void Basic::Load(wxString file)
{
    if (m_portOpen) {
        if (IsSourceFile((char *)(const char *)file)) {
            char outfile[_MAX_PATH];
            ConstructOutputName((char *)(const char *)file, outfile);
            m_lastFileLoaded = file;
            if (CompileFile((char *)(const char *)file, outfile, false))
                Download(wxString(outfile));
        }
        else if (IsImageFile((char *)(const char *)file))
            Download(file);
        else
            Warning("Unknown file type: %s", (char *)(const char *)file);
    }
    else
        Warning("Serial port not open");
}

void Basic::Download(wxString file)
{
    switch (m_downloadMode) {
    case kDownloadCard:
        DownloadImage((char *)(const char *)file, "autorun.bai");
        break;
    case kDownloadFlash:
        DownloadImage((char *)(const char *)file, NULL);
        break;
    case kDownloadSRAM:
        /* not implemented yet */
        break;
    }
}

void Basic::ConsolePutC(int ch)
{
    m_main->ConsolePutC(ch);
}

void Basic::ConsoleFlushOutput(void)
{
    m_main->ConsoleFlushOutput();
}

void Basic::ConsoleGetLine()
{
    m_main->ConsoleSetInputHandler(HandleInput, this);
}

void Basic::HandleInput(void *data, const char *buf)
{
    Basic *app = (Basic *)data;
    app->m_main->ConsoleSetInputHandler(NULL, NULL);
    PktSendFrame(PKT_LINE, (uint8_t *)buf, strlen(buf));
}

void Basic::Warning(char *fmt, ...)
{
	char buf[2048];
    va_list ap;
	va_start(ap,fmt);
	vsprintf(buf,fmt,ap);
    wxMessageBox(wxT(buf), wxT("Warning"), wxOK | wxICON_EXCLAMATION, m_main);
	va_end(ap);
}

extern "C" void VM_writedebug(char *buf, int cnt)
{   
    while (--cnt >= 0)
        wxGetApp().ConsolePutC(*buf++);
}

extern "C" void VM_printf(char *fmt, ...)
{
    char buf[200];
    va_list ap;
    va_start(ap, fmt);
    vsprintf(buf, fmt, ap);
    VM_writedebug(buf, strlen(buf));
    va_end(ap);
}

extern "C" void VM_vprintf(char *fmt, va_list ap)
{
	vprintf(fmt, ap);
}

extern "C" void VM_putchar(int ch)
{
    wxGetApp().ConsolePutC(ch);
}

extern "C" void VM_getline(void)
{
    wxGetApp().ConsoleFlushOutput();
    wxGetApp().ConsoleGetLine();
}

