///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// 
// Copyright Nurve Networks LLC 2008
// 
// Filename: XGS_NTSC_TILE_MODE2_V010.S
// 
// Description: 180x192, 22x24, 8x8 tiles resolution NTSC driver tile engine
//  
// Original Author: Andre' LaMothe
// 
// Last Modified: 9.1.08
//
// This is a 22x24 NTSC tile engine. Each tile is 8x8 pixels, where each pixel is encoded as a full byte LUMA4:CHROMA4.
//
//
// 22 tiles per row / 24 rows
//
//  colum 0      1       2              19       20       21
// |........|........|........| ... |........|........|........|  Row 0
// |........|........|........| ... |........|........|........|  Row 1
// |........|........|........| ... |........|........|........|  Row 2
// |........|........|........| ... |........|........|........|
// .
// .  24 rows
// .
// |........|........|........| ... |........|........|........|  Row 23
//
// The engine supports fine scrolling in the vertical direction as well as course scrolling scrolling in the
// horizontal direction via a controllable tile map logical width or "pitch" parameter, so eventhough the physical
// screen is always 22x24 tiles the logical width can be anything up to 256 tiles wide.
//
//
// The interface to the tile engine from the C/C++ caller consists of a set of pointers to data structures as well as 
// some read/write variables exported from the tile engine that the caller needs to control the engines operation. Here 
// are the important variables that the tile engine must have initialized:
//
// .extern tile_map_ptr      // 16-bit pointer to tile map, allows indirection
// .extern tile_bitmaps_ptr  // 16-bit pointer to 8x8 tile bitmaps, allows indirection
//
// 
// First, are the tile map, tile bitmap data structures. The tile map is a simple byte array MxN, where each
// byte represents the tile "index" to be rendered at that position. Each index refers to the tile bitmap that should
// be drawn. The tiles themselves are a continguous array of 8x8 pixel (byte) tiles, thus 64-bytes per tile. Both of
// these data structures are referred to by pointers to allow movement of the data structure in real-time. So the 
// caller would typically dynamically or statically allocate the tile map and tile bitmaps then point the below pointers
// at them, so the tile engine could locate them
//
//
// Moving on, there are a few values that are EXPORTED out from the tile engine to give the user control of the 
// engine as well as indicate the state of the engine (what line its on, etc.), so the user can initiate render
// changes properly as not to disturb the video scan. These values are:
//
// 
// .global curr_line                   // int, read only, current physical line
// .global curr_raster_line            // byte, read only, current logical raster line
// .global tile_map_logical_width      // byte, read/write, logical width of tile map
// .global tile_map_vscroll            // byte, read/write, current vertical scroll value 0..7
//
// They are self explanatory. The caller can read curr_line to determine the video line 0..261 of the NTSC scan,
// similarly curr_raster_line indicates the logical raster line for the resolution. Finally, tile_map_logical_width
// allows logical tile maps larger than the 18 wide to support scrolling, and tile_map_vscroll controls smooth 
// scrolling vertically.
//
// Modifications|Bugs|Additions:
//
// Author Name: 
//
//
//
//
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////



///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// SET PROCESSOR TYPE (must come first)
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#ifndef __AVR_ATmega644__
#define __AVR_ATmega644__
#endif

// needed for macro, also fixes so you can use register names directly and NOT need macro _SFR_IO_ADDR( x )
#define __SFR_OFFSET 0 

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// INCLUDES 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
#include <avr/interrupt.h> 
#include <avr/io.h>

// include header file for driver
#include "XGS_AVR_NTSC_TILE_MODE2_V010.h"

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// DEFINES 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// MACROS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// this macro delays any number of clocks, uses chunks of 4
.macro  DELAYX reg = r16, clocks
    ldi     \reg, (\clocks)/4        // (1)
1:
    dec     \reg                     // (1)
    nop                              // (1)
    brne    1b                       // (1/2)

    // now delay fractional component
    .rept   (\clocks % 4)
    nop                              // (1)
    .endr

.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// this macro delays any number of clocks that are a multiple of 4, anything else is truncated
.macro  DELAY4X reg = r16, clocks
    ldi     \reg, (\clocks)/4        // (1)
1:
    dec     \reg                     // (1)
    nop                              // (1)
    brne    1b                       // (1/2)
.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// this macro delays any number of clocks that are a multiple of 3, anything else is truncated
.macro  DELAY3X reg = r16, clocks
    ldi     \reg, (\clocks)/3        // (1)
1:
    dec     \reg                     // (1)
    brne    1b                       // (1/2)
.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.macro COMPUTE_TILE_PTR
        // point Y at bitmap data based on tile index etc.
        // tile_index = tile_map [ tile_index_x... + tile_index_y * 20 ]
        ld      r18, Z+                      // (2), get next tile from tile map

        // tile_bitmap_ptr      = tile_bitmaps_base_ptr + tile_index*64  
        //ldi     r19, 64                      // (1)
        mul     r19, r18                     // (2)  r1:r0 = tile_index*64  

        // note r17:r16 holds tile_bitmaps_base_ptr from above since reading out of vars is too slow
        // thus corruption of Y is ok, since restored below
        add     YL, r0                       // (1)
        adc     YH, r1                       // (1) Y -> tile_bitmaps + tile_bitmap_row*8 + tile_index*64  
                                         
        // now simply insert Y pointer into storage array which will be used during rendering
        st     X+, YL                        // (2), store low byte first
        st     X+, YH                        // (2), now high byte, [low0, high0], [low1, high1]...[lowN, highN]

        // reset Y for next pass
        mov     YL, r16                      // (1)  restore Y, tile_bitmap_base_ptr from r17:r16    
        mov     YH, r17                      // (1)
.endm
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////


.macro DRAW_TILE_PIXELS_NTSC_PT0 rt = r0
    // draws a single row of tile bitmap pixels by retrieving the next pointer in the tile bitmap row pointer array
    // then streams out 8 pixels, this macro initiates the process
    // on entry assumes:
    // Y -> pointer array containing pointers to bitmap rows to render for each tile
    // X will be used to retrieve pixels from bitmaps, therefore, save before call    

    // pixel 0, retrieve pointer, draw pixel
    ld      XL, Y+              // (2)
    ld      XH, Y+              // (2) X <- [ Y ], X -> tile bitmap data
//    nop                         // (1), do nothing 
    ld      \rt, X+             // (2), retrieve next pixel from tile bitmap row
    out     PORTA, \rt          // (1), render to screen
.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.macro DRAW_TILE_PIXELS_NTSC_PT1 rt = r0
    // draws a single row of tile bitmap pixels by retrieving the next pointer in the tile bitmap row pointer array
    // then streams out 8 pixels, this macro continues the process
    // on entry assumes:
    // X -> pointer array containing pointers to bitmap rows to render for each tile
    // Y will be used to retrieve pixels from bitmaps, therefore, save before call    

    // pixel n, draw pixel
    nop                         // (4)
    nop
    nop
    nop
//    nop

    ld      \rt, X+             // (2), retrieve next pixel from tile bitmap row
    out     PORTA, \rt          // (1), render to screen
.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.macro  RESTORE_SREG reg = r16

    pop     \reg
    out     _SFR_IO_ADDR( SREG ), \reg      // restore status register

.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// LOCAL INITIALIZED VARIABLES (SRAM)
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.section .data

tile_init_start:

// tile map variables
tile_index_x:             .byte 0
tile_index_y:             .byte 0
tile_bitmap_row:          .byte 0

tile_map_save_ptr:        .byte 0,0
tile_bitmap_base_ptr:     .byte 0,0

// current video line
curr_line:                .byte 0,0    

// current raster line 0..virtual rez-1
curr_raster_line:         .byte 0
raster_line:              .byte 0

// amount of vertical scroll 0..7 (caller controlled)
tile_map_vscroll:         .byte 0

// the logical tile map width, used to access rows, this support horizontal course scrolling, (caller controlled)
tile_map_logical_width:   .byte  TILE_MAP_WIDTH

// tile bitmaps pointer array buffer, 22 tiles, 16-bit pointer for each that points to a bitmap row to render. 2x22 = 44 bytes
tile_bitmaps_ptr_array:   .byte 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0
                          .byte 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0,0, 0,0,0,0,0,0,0, 0,0,0,0

tile_init_end:
                          
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// DATA STRUCTURES IN FLASH/ROM - NOTE: MUST ON WORD BOUNDARIES
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.section .text

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// EXTERNALS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.extern tile_map_ptr      // 16-bit pointer to tile map
.extern tile_bitmaps_ptr  // 16-bit pointer to 8x8 tile bitmaps 
.extern tile_map_vscroll  // int value of amount of fine vertical scroll 0..7  

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// GLOBALS EXPORTS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// export these to caller, so he can interogate and change
.global curr_line                   // read only, current physical line
.global curr_raster_line            // read only, current logical raster line
.global tile_map_logical_width      // read/write, logical width of tile map
.global tile_map_vscroll            // read/write, current vertical scroll value 0..7
.global tile_init_start             // start of initialized SRAM area (clear before starting graphics)
.global tile_init_end               // end of initialized SRAM area

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// ASM FUNCTIONS 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// VGA Interface Reference
//DDRA  = 0xFF; // NTSC/PAL LUMA7:4 | CHROMA3:0, VGA7:0 [vsync, hsync, B1,B0, G1,G0, G1,G0] 
//                                                        b7      b6    b5:4   b3:2   b1:0

.section .text

// asm entry point

.global NTSC_Init
NTSC_Init:
    ldi     r18, TILE_MAP_WIDTH
    sts     tile_map_logical_width, r18
    ret

.global	TIMER1_COMPA_vect  
TIMER1_COMPA_vect:

Save_Regs:

    // save working registers on stack
    push    r0              // (2)        
    
    push    r16             // (2)
    push    r17             // (2)

    push    r18             // (2)
    push    r19             // (2)

    push    r20             // (2)

    push    r24             // (2)
    push    r25             // (2)

    push    r26             // (2)   X
    push    r27             // (2)

    push    r28             // (2)   Y
    push    r29             // (2)

    push    r30             // (2)   Z
    push    r31             // (2)

    in      r0, SREG        // (2)
    push    r0              // (2) save the status register

                            // (32) clocks for stack push

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/*
Brief overview of design. This tile engine is ideal for most games and mixed text displays. The mode supports 30x26 tiles 
at 8x8, so. The engine works on a single scanline basis, thus everything has to be done very quickly. The division 
of work is between HSYNC/Blank and the active scan regions. In the HSYNC/Blank regions the tile map is interrogated 
and the current row of tiles is intersected with the current raster line, the resulting intersections are computed
and the bitmap data from the tile bitmaps is retrieved and stored in an array, thus, the array holds pointers to 
all the 8 pixel sets of tile bitmap rows that make up the current scanline. Then during the active scan the data
structure is acceessed, the data retrieved and rendered all in 8 clocks per pixel, exactly matching the color burst
frequency.
*/
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

NTSC_Start:

    // load r25:24 with curr_line
    lds     r24, curr_line                  // (2)
    lds     r25, curr_line+1                // (2)      

NTSC_Video_State_Test1:

    // if (curr_line < offset) then NTSC_Draw_Blank_Line
    ldi     r16, hi8(NTSC_VERTICAL_OFFSET)  // (1)
    cpi     r24, lo8(NTSC_VERTICAL_OFFSET)  // (1)
    cpc     r25, r16                        // (1)
    brlo    NTSC_Draw_Blank_Line_Top        // (1/2) NTSC_Start: (9) clocks -> jump, jump need due to code out of range for branch

// elseif
NTSC_Video_State_Test2:    

    // if (curr_line < ( screen height + offset) ) then NTSC_Draw_Active_Line
    ldi     r16, hi8(NTSC_SCREEN_HEIGHT + NTSC_VERTICAL_OFFSET)  // (1) 
    cpi     r24, lo8(NTSC_SCREEN_HEIGHT + NTSC_VERTICAL_OFFSET)  // (1)
    cpc     r25, r16                                             // (1)

    //brlo    NTSC_Draw_Active_Line  // (1/2) 

    brsh    NTSC_Video_State_Test3   // (1/2)
    jmp     NTSC_Draw_Active_Line    // (3)          NTSC_Start: (15) clocks -> jump, jump need due to code out of range for branch

// elseif
NTSC_Video_State_Test3:    

    // if (curr_line < 258) then NTSC_Draw_Blank_Line
    ldi     r16, hi8(256)            // (1) 
    cpi     r24, lo8(256)            // (1)
    cpc     r25, r16                 // (1)
    brlo    NTSC_Draw_Blank_Line_Bot // (1/2)        NTSC_Start: (18) clocks -> jump, jump need due to code out of range for branch

// elseif
NTSC_Video_State_Test4:    

    // if (curr_line < 262) then NTSC_Draw_Vsync_Line
    ldi     r16, hi8(262)            // (1) 
    cpi     r24, lo8(262)            // (1)
    cpc     r25, r16                 // (1)
    brlo    NTSC_Draw_Vsync_Line     // (1/2)        NTSC_Start: (22) clocks -> jump, jump need due to code out of range for branch
    // else should never get here...

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

NTSC_Draw_Blank_Line_Top: 
   
    // equalize delay from conditional line fork 
    .rept ( 18 - 9 )
    nop
    .endr

NTSC_Draw_Blank_Line_Bot: 

    // equalize delay from conditional line fork
    .rept ( 22 - 18 )
    nop
    .endr

    // enable hsync, set video to black
    ldi     r16, NTSC_SYNC           // (1)
    out     PORTA, r16               // (1)

    // test if this is the top of frame here, we need to initialize the rendering kernel
    // if (curr_line == 0) then NTSC_Reset_Kernel
    ldi     r16, hi8(0)              // (1)
    cpi     r24, lo8(0)              // (1)
    cpc     r25, r16                 // (1)

    // now based on flags set above, jump to normal blank line or reset 
    breq    NTSC_Reset_Kernel        // (1/2)

    // else delay hsync time (this will be filled with processing in later versions)

    // 16 color clocks sync (128 clocks), this needs to be adjusted correctly to take above computation into consideration
    DELAYX r16, (18*CLOCKS_PER_PIXEL - 8)
    
    // disble hsync, maintain black
    ldi     r16, NTSC_BLACK          // (1)
    out     PORTA, r16               // (1)

    // now color burst
    DELAYX r16, (2*CLOCKS_PER_PIXEL)
    
    ldi     r16, NTSC_CBURST0               // (1)
    out     PORTA, r16                      // (1)

    // now color burst
    DELAYX r16, (10*CLOCKS_PER_PIXEL)

    // back to black HSYNC off
    ldi     r16, NTSC_BLACK                 // (1)
    out     PORTA, r16                      // (1)

    jmp     NTSC_Next_Line           // (3)    

NTSC_Reset_Kernel:

    // reset all data structures each frame at line 0

    // initialize any variables for algorithm    

    // initialize raster_line for next frame, take into consideration vertical scroll value
    lds     r16, tile_map_vscroll            // (2)
    sts     curr_raster_line, r16            // (2)

    // 16 color clocks sync (128 clocks), this needs to be adjusted correctly to take above computation into consideration..
    DELAYX r16, (18*CLOCKS_PER_PIXEL - 12)

    // disble hsync, maintain black
    ldi     r16, NTSC_BLACK                 // (1)
    out     PORTA, r16                      // (1)

    // now color burst
    DELAYX r16, (2*CLOCKS_PER_PIXEL)
    
    ldi     r16, NTSC_CBURST0               // (1)
    out     PORTA, r16                      // (1)

    // now color burst
    DELAYX r16, (10*CLOCKS_PER_PIXEL)

    // back to black HSYNC off
    ldi     r16, NTSC_BLACK                 // (1)
    out     PORTA, r16                      // (1)

    jmp     NTSC_Next_Line                  // (3)

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

NTSC_Draw_Vsync_Line:

    // invert hsync and maintain sync for 4-6 lines
    ldi     r16, NTSC_BLACK   // (1)
    out     PORTA, r16        // (1)

    // delay for hsync pulse length 

    // 16 color clocks sync (128 clocks)
    DELAYX r16, (16*CLOCKS_PER_PIXEL)
    
    // disble hsync, but maintain vsync and black
    ldi     r16, NTSC_SYNC   // (1)
    out     PORTA, r16       // (1)

    jmp     NTSC_Next_Line   // (3)

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

NTSC_Draw_Active_Line:

    // delay to equalize initial line fork
    .rept ( 22 - 15 - 1 )
    nop
    .endr

    // (37) for entire setup process..
    // enable hsync, set RGB to black (want approximately 16 color clocks for sync
    ldi     r16, NTSC_SYNC               // (1)
    out     PORTA, r16                   // (1)

    // on entry tile_index_x = 0 for start of scan left to right, line 0,1,2

    // tile_index_y = curr_raster_line / 8, later cache curr_raster_line as well
    lds     r16, curr_raster_line        // (2)    (7) clocks
    lsr     r16                          // (1)
    lsr     r16                          // (1)
    lsr     r16                          // (1)
    sts     tile_index_y, r16            // (2)    r16 = tile_index_y

    // tile_bitmap_row = curr_raster_line mod 8, then multiply by 8, so directly indexes into tile bitmap data, 8 bytes per row
    lds     r17, curr_raster_line        // (2)    (8) clocks
    andi    r17, 0x07                    // (1)    
    lsl     r17                          // (1)    multiply by 8 
    lsl     r17                          // (1)
    lsl     r17                          // (1)
    sts     tile_bitmap_row, r17         // (2)    r17 = tile_bitmap_row*8

    // Z  -> tile_map [ tile_index_x=0 + tile_index_y * 22 ]
   
    lds     ZL, tile_map_ptr             // (2), (9) this code for pointer location storage
    lds     ZH, tile_map_ptr+1           // (2)
 
    lds     r18, tile_map_logical_width  // (2)    r18 = 22 constant, 22 tiles per row
    mul     r18, r16                     // (2)    r1:r0 = tile_index_y:r16 * 20:r18

    add     ZL, r0                       // (1)    Z -> tile_map[ tile_index_x=0 + tile_index_y * 22 ]
    adc     ZH, r1                       // (1)    first tile, in current row intersected by current raster line

    // now pre-compute tile_bitmap_base_ptr (might need be needed due to register caching, review later)
    // tile_bitmap_base_ptr = tile_bitmaps + tile_bitmap_row*8
    lds     YL, tile_bitmaps_ptr         // (2), (9) this code for pointer location storage
    lds     YH, tile_bitmaps_ptr+1       // (2)

    clr     r0                           // (1)   Y = tile_bitmaps + tile_bitmap_row*8
    add     YL, r17                      // (1)   r17 = tile_bitmap_row*8 (0..56)
    adc     YH, r0                       // (1)   dummy add to take into consideration carry bit C overflow from lower byte
    
    //sts     tile_bitmap_base_ptr,   YL   // (2)   tile_bitmap_base_ptr = Y
    //sts     tile_bitmap_base_ptr+1, YH   // (2)   global storage variable might not be necessary, since its cached in r17:r16
    
    mov     r16, YL                      // (1)   save tile_bitmap_base_ptr in r17:r16 for transient usage
    mov     r17, YH                      // (1)

    // X -> tile bitmaps base address pointer array
    ldi     XL, lo8( tile_bitmaps_ptr_array ) // (1), (2) this code for pointer location storage
    ldi     XH, hi8( tile_bitmaps_ptr_array ) // (1)

    // initialize constant in r19 = tile bitmap size in bytes
    ldi     r19, 64                           // (1)    

    // setup on entry to tile bitmap pointer conputation and storage, computes pointer to every tile bitmap
    // to be rendered on this row, stores in array
    // X -> tile bitmaps base address pointer array
    // Z -> tile map next tile index entry
    // Y =  tile_bitmap_base_ptr
    // r19 = 64, number of bytes per tile bitmap


    // each pass takes (12) clocks * 20 = 240 clocks, break up into pieces to interleave hsync and color burst
    .rept 9 
        COMPUTE_TILE_PTR
    .endr

    // turn HSYNC off, make sure to align with blank and vsync lines total time of hsync pulse, make as short as possible, 
    // so other lines can exit out ASAP and return to C
    ldi     r18, NTSC_BLACK                 // (1)
    out     PORTA, r18                      // (1)

    // now begin color burst
    //    DELAY4X r16, (2*CLOCKS_PER_PIXEL), above

    // each pass takes (12) clocks * 20 = 240 clocks, break up into pieces to interleave hsync and color burst
    .rept 2 
    COMPUTE_TILE_PTR    
    .endr

    // delay, tunes the color burst start
    .rept 0
    nop
    .endr

    // now turn on color burst  
    ldi     r18, NTSC_CBURST0               // (1)
    out     PORTA, r18                      // (1)

    // now color burst
    // DELAY4X r16, (10*CLOCKS_PER_PIXEL)

    // each pass takes (12) clocks * 20 = 240 clocks, break up into pieces to interleave hsync and color burst
    .rept 6 
    COMPUTE_TILE_PTR        
    .endr

    // a little more delay for color burst to complete
    // DELAY4X r18, 8

    // back to black HSYNC off
    ldi     r18, NTSC_BLACK                 // (1)
    out     PORTA, r18                      // (1)

    // each pass takes (12) clocks * 20 = 240 clocks, break up into pieces to interleave hsync and color burst
    .rept (3 + 2)
    COMPUTE_TILE_PTR
    .endr

    // total of 20 tiles now complete

    // increment raster line
    lds     r0, curr_raster_line       // (2)
    inc     r0                         // (1)
    sts     curr_raster_line, r0       // (2)

// fall thru to render the pixels...

///////////////////////////////////////////////////////////////////////////////////////////////////////

NTSC_Draw_Tile_Pixels:
// this draws the actual pixels in the front scanline buffer to the screen

    // Y -> tile bitmaps base address pointer array
    ldi     YL, lo8( tile_bitmaps_ptr_array ) // (1), this code for pointer location storage
    ldi     YH, hi8( tile_bitmaps_ptr_array ) // (1)

    // move display out a bit, always a multiple of 4
    DELAYX r16, (NTSC_HORIZONTAL_OFFSET)

    // delay, tunes the color burst start
    .rept 0
    nop
    .endr

    // render the tiles in sets of 8 pixels, retrieve pointer to bitmap data for current tile row
    // and render it..., repeat
    .rept TILE_MAP_WIDTH // each pixel takes (8) clocks, 20*8*8 = 1280 clocks, 160 pixels, 160 color clocks
        DRAW_TILE_PIXELS_NTSC_PT0 // pixel 0
        DRAW_TILE_PIXELS_NTSC_PT1 // pixel 1
        DRAW_TILE_PIXELS_NTSC_PT1 // pixel 2
        DRAW_TILE_PIXELS_NTSC_PT1 // pixel 3
        DRAW_TILE_PIXELS_NTSC_PT1 // pixel 4
        DRAW_TILE_PIXELS_NTSC_PT1 // pixel 5
        DRAW_TILE_PIXELS_NTSC_PT1 // pixel 6
        DRAW_TILE_PIXELS_NTSC_PT1 // pixel 7
    .endr

    // hold last pixel for a moment
    .rept 6
    nop                                     // (1)
    .endr

    // and back to black
    ldi     r16, NTSC_BLACK                 // (1)
    out     PORTA, r16                      // (1)


    jmp     NTSC_Next_Line                  // (3)

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

NTSC_Next_Line:

    // curr_line++
    adiw    r24, 1                 // (2)

    // if (curr_line >= 262) curr_line = 0
    ldi     r16, hi8(262)          // (1) 
    cpi     r24, lo8(262)          // (1)
    cpc     r25, r16               // (1)
    brne    NTSC_End_Line          // (1/2)

    // curr_line = 0
    ldi     r24, 0                 // (1)
    ldi     r25, 0                 // (1)

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

NTSC_End_Line:

    // save registers back to curr_line in SRAM for exit back to C/C++ caller
    sts     curr_line,   r24       // (2)
    sts     curr_line+1, r25       // (2)
    
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

Restore_Regs:

    // restore the status register
    pop     r0          // (2)
    out     SREG, r0    // (1)        

    // restore working registers
    pop     r31         // (2), Z
    pop     r30         // (2)

    pop     r29         // (2), Y
    pop     r28         // (2)

    pop     r27         // (2), X
    pop     r26         // (2)

    pop     r25         // (2)
    pop     r24         // (2)


    pop     r20         // (2)

    pop     r19         // (2)
    pop     r18         // (2)

    pop     r17         // (2)
    pop     r16         // (2)

    pop     r0          // (2)

#if 0
    .rept 50
    nop
    .endr
#endif
    
    reti                // (5) return from interrupt and reset interupt flag, total time of restore 36 clocks for restore

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// END ASM FUNCTIONS 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.end
















