///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// 
// Copyright Nurve Networks LLC 2008
// 
// Filename: XGS_AVR_INDY500_NTSC_01.c
//
// Original Author: Andre' LaMothe
// 
// Modified by : Lee McColl Sylvester (somewhat heavily... I had to start somewhere ;-))
//
// Last Modified: 1.23.09
//
// Uses the Indy500 source as a base, but is heavily modified to provide a simple arena, with an
// animated sprite character. The idea will be that the character will be able to pick up bombs and
// throw them, but need more time.
//
//
// Controls: Gamepad
//
//    Dpad Right/Left/Up/Down  - right/left/up/down
//
// Demo must be linked with following source files (in addition to primary file):
// 
// XGS_AVR_SYSTEM_V010.c              - System variables.
// XGS_AVR_NTSC_TILE_MODE6_V010.s     - ASM tile mapped driver with sprites.
// XGS_AVR_GFX_LIB_V010.c             - Graphics library which includes bitmapped graphics functions, etc.
// XGS_AVR_GAMEPAD_DRV_V010.c         - Gamepad driver.
//
// Note: header files for all sources must be in current working directory, so compiler can find them
// 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// INCLUDES ///////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// define chip type here
#define __AVR_ATmega644__

// define CPU frequency in Mhz here if not defined in Makefile, this is used for conditional compilation, so needs
// to be first, before other XGS includes, also note there is a copy of this constant in XGS_AVR_SYSTEM_V010, so if you 
// change it here, also change it in the header to make certain everthing is sync'ed
#define F_CPU 28636360UL

#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <math.h>
#include <avr/eeprom.h>
#include <avr/io.h>
#include <avr/sleep.h>

#include <util/delay.h>
#include <avr/interrupt.h>
#include <avr/pgmspace.h>
#include <inttypes.h>
#include <compat/twi.h>
#include <avr/pgmspace.h>

// include local XGS API header files
#include "XGS_AVR_SYSTEM_V010.h"
#include "XGS_AVR_GAMEPAD_DRV_V010.h"

// include header file for video driver
#include "XGS_AVR_NTSC_TILE_MODE6_V010.h"
#include "XGS_AVR_GFX_LIB_V010.h"

// sprites and tiles contained in here!
#include "lms_pigsuxb_demo_sprites.h"


///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// MAIN ///////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

int main(void)
{
int gamepad;          // used to hold gamepad call results
int x,y,indx,color;   // general working vars
int temp_x, temp_y;   // temps
int walk_cntr = 0;	  // used to cycle through animation frames
int direction = 0;	  // used to remember player direction so when pad not pressed, user can show correct idle pose

// initialize the tile map related pointers
// assign the driver's working pointers to our local data structures
tile_map_ptr       = tile_map;
tile_bitmaps_ptr   = tile_bitmaps;

// set up clipping region eventhough, "clipping" is more of a bitmapped rendering concern, the clipping extents
// can be used in various tile and sprite operations in the future, so can't hurt to set up the variables
g_clip_min_x = 0;
g_clip_max_x = SCREEN_WIDTH-1;
g_clip_min_y = 0;
g_clip_max_y = SCREEN_HEIGHT-1;

// initialize rendering real-time variables
g_screen_width  = SCREEN_WIDTH;
g_screen_height = SCREEN_HEIGHT;

// this is new, we need to set up the global tile map width and height, so they are in variable form
g_tile_map_width  = TILE_MAP_WIDTH;
g_tile_map_height = TILE_MAP_HEIGHT;

// set the logical width to the tile map size (no horizontal scrolling this time)
tile_map_logical_width = TILE_MAP_WIDTH;

// initialize the video driver and GFX engine
GFX_Init( VIDEO_INTERRUPT_RATE );

// set the sleeping mode up and enable it
set_sleep_mode( SLEEP_MODE_IDLE );
sleep_enable();

// initialize the gamepad driver, this is not necessary of course, but we are going to use the gamepad to move 
// a sprite around
Gamepad_Init();

// tile engine test
while(1)
    {
    // now goto sleep and wait for interrupt (the cycles are too fast (yes, really), so slowing it down some
	// prob a better way of doing it, but it works for now!
    sleep_cpu();
    sleep_cpu();
    sleep_cpu();

    // update everything only during the following time/event...
    if (curr_line >= END_ACTIVE_SCAN && curr_line < (END_ACTIVE_SCAN+2) )
        {
        // read gamepads
        gamepad = Gamepad_Read(GAMEPAD0);

		if ( gamepad & GAMEPAD_RIGHT || gamepad & GAMEPAD_LEFT || gamepad & GAMEPAD_UP || gamepad & GAMEPAD_DOWN )
			walk_cntr = 1 - walk_cntr;
			
		
        // move pig with gamepade up/down
        if ( gamepad & GAMEPAD_UP ) 
           {
		   direction = 0;
		   sprite_table[0].bitmap = player1_bitmap_up_anim + ( ( walk_cntr + 1 ) * 64 );
           sprite_table[0].y -= 1;
        
           // collision with top wall
           if (sprite_table[0].y <= 2)
              {
              temp_y = RAND_RANGE(1,3);
              sprite_table[0].y += temp_y;
              } // end if

           } // end if

        else if ( gamepad & GAMEPAD_DOWN ) 
           {
		   direction = 1;
		   sprite_table[0].bitmap = player1_bitmap_down_anim + ( ( walk_cntr + 1 ) * 64 );
           sprite_table[0].y += 1;

           // collision with bottom wall
           if (sprite_table[0].y >= 96)
              {
              temp_y = RAND_RANGE(1,3);
              sprite_table[0].y -= temp_y;
              } // end if

           } // end if

        // move pig with gamepade right/left
        else if ( gamepad & GAMEPAD_RIGHT ) 
           {
		   direction = 2;
		   sprite_table[0].bitmap = player1_bitmap_right_anim + ( ( walk_cntr + 1 ) * 64 );
           sprite_table[0].x += 1;
        
           // collision with right wall
           if (sprite_table[0].x >= 136)
              {
              temp_x = RAND_RANGE(1,3);
              sprite_table[0].x -= temp_x;
              } // end if

           } // end if

        else if ( gamepad & GAMEPAD_LEFT ) 
           {
		   direction = 3;
		   sprite_table[0].bitmap = player1_bitmap_left_anim + ( ( walk_cntr + 1 ) * 64 );
           sprite_table[0].x -= 1;

           // collision with right wall
           if (sprite_table[0].x <= 2)
              {
              temp_x = RAND_RANGE(1,3);
              sprite_table[0].x += temp_x;
              } // end if

           } // end if

		else
			{
				// assume the correct idle pose
				if ( direction == 0 )
					sprite_table[0].bitmap = player1_bitmap_up_anim;
					
				if ( direction == 1 )
					sprite_table[0].bitmap = player1_bitmap_down_anim;

				if ( direction == 2 )
					sprite_table[0].bitmap = player1_bitmap_right_anim;
					
				if ( direction == 3 )
					sprite_table[0].bitmap = player1_bitmap_left_anim;
			}
		}

     } // end while

} // end main

