///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// 
// Copyright Nurve Networks LLC 2008
// 
// Filename: REM_AVR_NTSC_128_96_ULTRA_V010.S
//
// Original Author: Remi Veilleux
// 
// Last Modified: 01.09.08
// 
// Description: 128x96 resolution NTSC driver with 8-bit per pixel "true color" mode
// using 8x8 tiles + sprites overlayed 
//
// .global curr_line         // read only, current physical line
// .global curr_raster_line  // read only, current logical raster line
//
//
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////



///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// SET PROCESSOR TYPE (must come first)
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#ifndef __AVR_ATmega644__
#define __AVR_ATmega644__
#endif

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// INCLUDES 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
#include <avr/interrupt.h> 
#include <avr/io.h>

#include "REM_AVR_NTSC_128_96_ULTRA_V010.h"
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// DEFINES 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#undef __SFR_OFFSET
#define __SFR_OFFSET 0 // needed for macro, also fixes so you can use register names directly and NOT need macro _SFR_IO_ADDR( x )

// with the current D/A converter range 0 .. 15, 1 = 62mV
#define NTSC_SYNC     (0x0F)     // 0V  
#define NTSC_CBURST0  (0x40)


///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// MACROS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// this macro delays any number of clocks, even 0, up to a maximum of 775
.macro  DELAYX clocks
// Shorter optimized code for short delay:
.if (\clocks) == 0
.elseif (\clocks) == 1
	nop
.elseif  (\clocks) == 2
	ld		r16, X
.elseif  (\clocks) == 3
	ld		r16, X
	nop
.elseif  (\clocks) == 4
	ld		r16, X
	ld		r16, X
.elseif  (\clocks) == 5
	ld		r16, X
	ld		r16, X
	nop
.elseif  (\clocks) == 6
	ld		r16, X
	ld		r16, X
	ld		r16, X
.elseif  (\clocks) == 7
	ld		r16, X
	ld		r16, X
	ld		r16, X
	nop
.elseif  (\clocks) == 8
	call	DELAY_0CLOCK	// 4+4
.elseif  (\clocks) == 9
	call	DELAY_1CLOCK	// 4+4 + 1
.elseif  (\clocks) == 10
	call	DELAY_2CLOCK	// 4+4 + 2
.elseif  (\clocks) >= 11
	// This flexbile delay proc waits a multiple of 3 clocks
    ldi     r16, (\clocks-8)/3        // (0: accounted in brne)
	call	DELAY_VARIABLE3CLOCK	// 4+4
	// Compensate remaining (1 or 2 clocks)
	.if (\clocks-8) % 3 == 1
		nop
	.elseif  (\clocks-8) % 3 == 2
		ld		r16, X
	.endif
.endif
.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// LOCAL INITIALIZED VARIABLES (SRAM)
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.section .data

overscan_color:			.byte NTSC_BLACK
.global overscan_color   // read/write: 8-bit NTSC color used for overscan 

hscroll:				.byte 0
.global hscroll

vscroll:				.byte 0
.global vscroll

framecount:				.byte 0,0 // 16-bit UINT frame counter
.global framecount

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// current video line
curr_line:                .byte 0,0    
.global curr_line        // read only, current physical line

// current raster line 0..NTSC_SCREEN_HEIGHT-1
curr_raster_line:         .byte 0
.global curr_raster_line // read only, current logical raster line

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// LOCAL UNITIALIZED VARIABLES (SRAM) (this doesn't waste any FLASH to initialize)
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
.section .bss
// Tilemap is 16 (TILEMAP_WIDTH) x 12 (TILEMAP_HEIGHT) tiles, 2 byte each = 384 bytes of SRAM
tilemap:					.rept TILEMAP_WIDTH*TILEMAP_HEIGHT
							.byte 0,0
							.endr
.global tilemap

// scanline buffer in SRAM of 128+8+8 bytes (8 on left and right side to allow sprite clipping/hiding)
scanline1:					.rept 144
							.byte 0
							.endr

// Sprite Display List
spritelist:					.rept 96*MAXSPRITES
							.byte 0
							.byte 0
							.endr
.global spritelist

// Scanline List: Y row index (0..113), X scroll offset (0..15)
scanlist:					.rept NTSC_SCREEN_HEIGHT
							.byte 0
							.byte 0
							.endr
.global scanlist

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// DATA STRUCTURES IN FLASH/ROM - NOTE: MUST ON WORD BOUNDARIES
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.section .text

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// EXTERNALS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// GLOBALS EXPORTS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// export these to caller, so he can interogate and change


///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// ASM FUNCTIONS 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////



.section .text

// asm entry point

.global	TIMER1_COMPA_vect  
TIMER1_COMPA_vect:

Save_Regs:

    // save working registers on stack
    push    r0              // (2)        
    push    r1              // (2)        
    
    push    r16             // (2)
    push    r17             // (2)

    push    r18             // (2)
    push    r19             // (2)

    push    r20             // (2)
    push    r21             // (2)

    //push    r22             // (2)
    //push    r23             // (2)

    push    r24             // (2)
    push    r25             // (2)

    push    r26             // (2)   X
    push    r27             // (2)

    push    r28             // (2)   Y
    push    r29             // (2)

    push    r30             // (2)   Z
    push    r31             // (2)

    in      r0, SREG        // (2)
    push    r0              // (2) save the status register

                            // (32) clocks for stack push
	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

NTSC_Start:
   // load r25:24 with curr_line
    lds     r24, curr_line                  // (2)
    lds     r25, curr_line+1                // (2)      

NTSC_Video_State_Test1:

    // if (curr_line < offset) then NTSC_Draw_Blank_Line
    ldi     r16, hi8(NTSC_VERTICAL_OFFSET)  // (1)
    cpi     r24, lo8(NTSC_VERTICAL_OFFSET)  // (1)
    cpc     r25, r16                        // (1)
    brlo    NTSC_Draw_Blank_Line_Top        // (1/2) NTSC_Start: (9) clocks -> jump, jump need due to code out of range for branch

// elseif
NTSC_Video_State_Test2:    

    // if (curr_line >= ( screen height + offset) ) then NTSC_Video_State_Test3 else NTSC_Draw_Active_Line
    ldi     r16, hi8(NTSC_SCREEN_HEIGHT + NTSC_VERTICAL_OFFSET)  // (1) 
    cpi     r24, lo8(NTSC_SCREEN_HEIGHT + NTSC_VERTICAL_OFFSET)  // (1)
    cpc     r25, r16                                             // (1)

    brsh    NTSC_Video_State_Test3   // (1/2)
    jmp     NTSC_Draw_Active_Line    // (3)     NTSC_Start: (15) clocks -> jump, jump need due to code out of range for branch

// elseif
NTSC_Video_State_Test3:    

    // if (curr_line < 258) then NTSC_Draw_Blank_Line
    ldi     r16, hi8(258)            // (1) 
    cpi     r24, lo8(258)            // (1)
    cpc     r25, r16                 // (1)
    brlo    NTSC_Draw_Blank_Line_Bot // (1/2)   NTSC_Start: (18) clocks -> jump, jump need due to code out of range for branch

// elseif
NTSC_Video_State_Test4:    

    // if (curr_line < 262) then NTSC_Draw_Vsync_Line
    ldi     r16, hi8(262)            // (1) 
    cpi     r24, lo8(262)            // (1)
    cpc     r25, r16                 // (1)
    brlo    NTSC_Draw_Vsync_Line     // (1/2)   NTSC_Start: (22) clocks -> jump, jump need due to code out of range for branch
    // else should never get here...

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

NTSC_Draw_Blank_Line_Top: 

    // equalize delay from conditional line fork
    DELAYX (9-0)

 NTSC_Draw_Blank_Line_Bot: 

    // equalize delay from conditional line fork
    DELAYX (4-0)

    // enable hsync, set video to black
    ldi     r16, NTSC_SYNC           // (1)
    out     PORTA, r16               // (1)

    // 16 color clocks sync (128 clocks), this needs to be adjusted correctly to take above computation into consideration
    DELAYX (16*CLOCKS_PER_PIXEL + 20)
    
    // disble hsync, maintain black
    ldi     r16, NTSC_BLACK          // (1)
    out     PORTA, r16               // (1)

    // now color burst
    DELAYX (2*CLOCKS_PER_PIXEL)
    
    ldi     r16, NTSC_CBURST0               // (1)
    out     PORTA, r16                      // (1)

    // now color burst
    DELAYX (10*CLOCKS_PER_PIXEL)

    // back to black HSYNC off
    lds     r16, overscan_color             // (2) // RV: added 1 clock here
	//ldi		r16, NTSC_BLUE
	//nop
    out     PORTA, r16                      // (1)

	DELAYX(164+24)

	//ldi		r16, NTSC_GRAY6
    //out     PORTA, r16                      // (1)

	// test if this is the top of frame here, we need to initialize the rendering kernel
    // if (curr_line == 0) then NTSC_Reset_Kernel
    ldi     r16, hi8(0)              // (1)
    cpi     r24, lo8(0)              // (1)
    cpc     r25, r16                 // (1)
    breq    NTSC_Reset_Kernel        // (1/2)

    jmp     NTSC_Next_Line           // (3)    

NTSC_Reset_Kernel:
    // reset all data structures each frame at line 0

    // initialize any variables for algorithm    

    // initialize curr_raster_line for next frame, 
    ldi     r16, -1                           // (1)
    sts     curr_raster_line, r16                 // (2)

    jmp     NTSC_Next_Line                  // (3)

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  
NTSC_Draw_Vsync_Line:

    // invert hsync and maintain sync for 4-6 lines
    ldi     r16, NTSC_BLACK   // (1)
    out     PORTA, r16        // (1)

    // delay for hsync pulse length 

    // 16 color clocks sync (128 clocks)
    DELAYX (16*CLOCKS_PER_PIXEL)
    
    // disble hsync, but maintain vsync and black
    ldi     r16, NTSC_SYNC   // (1)
    out     PORTA, r16       // (1)

    jmp     NTSC_Next_Line   // (3)

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  
NTSC_Video_First_Overscan_Bot:
	DELAYX (26)
    // enable hsync, set video to black
    ldi     r16, NTSC_SYNC           // (1)
    out     PORTA, r16               // (1)

    // 16 color clocks sync (128 clocks), this needs to be adjusted correctly to take above computation into consideration
    DELAYX (16*CLOCKS_PER_PIXEL + 20)
    
    // disble hsync, maintain black
    ldi     r16, NTSC_BLACK          // (1)
    out     PORTA, r16               // (1)

    // now color burst
    DELAYX (2*CLOCKS_PER_PIXEL)
    
    ldi     r16, NTSC_CBURST0               // (1)
    out     PORTA, r16                      // (1)

    // now color burst
    DELAYX (10*CLOCKS_PER_PIXEL)

    // back to black HSYNC off
    //lds     r16, overscan_color             // (2) // RV: added 1 clock here
	ldi		r16, NTSC_BLACK
	nop

    out     PORTA, r16                      // (1)

	DELAYX(164+24)

	ldi		r16, NTSC_BLACK
	//ldi		r16, NTSC_VIOLET
    out     PORTA, r16                      // (1)

	// Delay approx. 1200 clocks
	DELAYX(775)
	DELAYX(463)
/*
	// delay: 1 + hscroll*3
	lds		r17, hscroll // 1
wastetime:
	dec r17 // 1 
	brne wastetime // 2
*/

	//ldi		r16, NTSC_GREEN
	ldi		r16, NTSC_BLACK
    out     PORTA, r16                      // (1)

    jmp     NTSC_Next_Line           // (3)    

// enter
NTSC_Draw_Active_Line:

    // delay to equalize initial line fork
    DELAYX (10-2)
	push r22 // 2

    // enable hsync, set RGB to black (want approximately 16 color clocks for sync
    ldi     r16, NTSC_SYNC                  // (1)
    out     PORTA, r16                      // (1)

#define SYNC_DELAY (146-126)
	// total: 22 + 52*2 = 126
	ldi		r21, 2 // 0 (accounted inside rendersprites)
	ldi		r22, (2*2) // 0 (accounted inside rendersprites)
	call rendersprites
	DELAYX (SYNC_DELAY)


    // turn HSYNC off
    ldi     r16, NTSC_BLACK                 // (1)
    out     PORTA, r16                      // (1)

	DELAYX (16-5) // waste some time
	lds     r19, curr_raster_line	// 2
    inc     r19                     // 1
    sts     curr_raster_line, r19   // 2

    ldi     r16, NTSC_CBURST0               // (1)
    out     PORTA, r16                      // (1)

	//DELAYX (80) // waste some time
#define BURST_DELAY (80-60-14)
	// total: 8 + 52*1 = 60
	ldi		r21, 1 // 0 (accounted inside rendersprites)
	call rendersprites_X
	DELAYX (BURST_DELAY)

	// Moved a bit of code here, before the last batch of sprites, in hope to save a few clock
	// total : 14

	ldi		r18, 0 // 1
	ldi		ZL, lo8(scanlist) // 1
	ldi		ZH, hi8(scanlist) // 1
	clc				// 1
	rol		r19 	// 1
	adc		ZH, r18	// 1
	add		ZL, r19 // 1
	adc		ZH, r18 // 1
	ld		r19, Z+ // 2 // load scanline index into r19, which remains untouched by rendersprites_X
	ld		r18, Z+ // 2 // load scroll x offset and push it for later retrieval
	push	r18     // 2

    // back to black HSYNC off
	// RV: Here we can set 'left horizontal overscan' color
    //lds     r16, overscan_color                 // (2) // NOT GOOD: it absolutely needs to be black
	// because some sync issue occurs.
	//ldi		r16, NTSC_GREEN
	ldi		r16, NTSC_BLACK
	nop
    out     PORTA, r16                      // (1)

	//DELAYX (164) // waste some time
	#define LEFT_OVERSCAN_DELAY (164-164)
	// total: 8 + 52*3 = 164
	ldi		r21, 3 // 0 (accounted inside rendersprites)
	call rendersprites_X
	DELAYX (LEFT_OVERSCAN_DELAY)

	// Total: 24 clocks: preparation before scanline image
	// Y contains tilemap pointer (in SRAM)
	ldi     YL, lo8( tilemap )	// 1
	ldi     YH, hi8( tilemap )	// 1

	// X contains scanline pointer
	ldi		XL, lo8(scanline1+8) // 1
	ldi		XH, hi8(scanline1+8) // 1
	// Here: add xoffset to scanline buffer
	pop		r20 // 2
	//add		XL, r18 // 1
	//adc		XH, r21 // 1 (Note: r21 is assumed always=0 after a call to rendersprites)

	mov		r16, r19 // 1
	andi	r19, 7 // 1 // get tile line (from 0..7) to get base offset
	// No need to multiply by 256 (width of tiles_256x8): just add r19 to ZH!

	// Now add to tilemap pointer (Y) the current tile row (which is scanline / 8)
	// ..and multiply by tilemap width
	lsr		r16 // 1
	lsr		r16 // 1
	lsr		r16 // 1
	ldi		r17, TILEMAP_WIDTH*2 // 1  (tilemap width * 2 because each tile takes 2 bytes)
	mul		r16, r17 // 2
	add		YL, r0 // 1
	adc		YH, r1 // 1

	// First tile: special case:
	// This tile have exactly 8 possible way to be drawn, depending on xoffset (0..7)
	ldi		ZL,lo8(pm(jmpfirsttile)) // 1
	ldi 	ZH,hi8(pm(jmpfirsttile)) // 1
	add		ZL, r20 // 1
	adc		ZH, r21 // 1
	ijmp // 2+2

jmpfirsttile:
	rjmp offset0
	rjmp offset1
	rjmp offset2
	rjmp offset3
	rjmp offset4
	rjmp offset5
	rjmp offset6
	rjmp offset7

.macro FIRSTPIXEL index
	// fetch first tile: first pixel takes 13 or 14 clocks:
	// if 'index==0' -> 13 clocks
	// else -> 14 clocks
	ld		ZL, Y+			// 2
	ld		ZH, Y+			// 2
	.if(\index <> 0)
		subi	ZL, -(\index)	// addi inversed
	.endif
	add		ZH, r19			// 1

	lpm		r18, Z+ // 3
	ld		r17, X	// 2 load from scanlinebuffer
	out     PORTA, r17 // 1
	st		X+, r18 // 2 store into scanline buffer
.endm

.macro MIDPIXELS count
	.rept (\count)	// middle pixel takes 9 clocks
		lpm		r18, Z+ // 3
		ld		r17, X	// 2 load from scanlinebuffer
		st		X+, r18 // 2 store into scanline buffer
		out     PORTA, r17 // 1
		nop // 1
	.endr
.endm

.macro LASTPIXEL
	// pixel 7: takes 8 clocks
	lpm		r18, Z+ // 3
	ld		r17, X	// 2 load from scanlinebuffer
	st		X+, r18 // 2 store into scanline buffer
	out     PORTA, r17 // 1
.endm

offset0:
	FIRSTPIXEL 0	// 13
	MIDPIXELS 6		// 54
	LASTPIXEL		// 8

	rcall	draw15tiles // 3+4 = 7

	// Total: 80
	DELAYX (80-75)
	jmp finished_tiles // 3

offset1:
	FIRSTPIXEL 1	// 14
	MIDPIXELS 5		// 45
	LASTPIXEL		// 8

	rcall	draw15tiles // 3+4 = 7

	FIRSTPIXEL 0	// 13

	// Total: 80
	DELAYX (80-80)
	jmp finished_tiles // 3

offset2:
	FIRSTPIXEL 2	// 14
	MIDPIXELS 4		// 36
	LASTPIXEL		// 8

	rcall	draw15tiles // 3+4 = 7

	FIRSTPIXEL 0	// 13
	LASTPIXEL		// 8

	// Total: 79
	DELAYX (80-79)
	jmp finished_tiles // 3

offset3:
	FIRSTPIXEL 3	// 14
	MIDPIXELS 3		// 27
	LASTPIXEL		// 8

	rcall	draw15tiles // 3+4 = 7

	FIRSTPIXEL 0	// 13
	MIDPIXELS 1		// 9
	LASTPIXEL		// 8

	// Total: 79
	DELAYX (80-79)
	jmp finished_tiles // 3

offset4:
	FIRSTPIXEL 4	// 14
	MIDPIXELS 2		// 18
	LASTPIXEL		// 8

	rcall	draw15tiles // 3+4 = 7

	FIRSTPIXEL 0	// 13
	MIDPIXELS 2		// 18
	LASTPIXEL		// 8

	// Total: 79
	DELAYX (80-79)
	jmp finished_tiles // 3

offset5:
	FIRSTPIXEL 5	// 14
	MIDPIXELS 1		// 9
	LASTPIXEL		// 8

	rcall	draw15tiles // 3+4 = 7

	FIRSTPIXEL 0	// 13
	MIDPIXELS 3		// 27
	LASTPIXEL		// 8

	// Total: 79
	DELAYX (80-79)
	jmp finished_tiles // 3

offset6:
	FIRSTPIXEL 6	// 14
	LASTPIXEL		// 8

	rcall	draw15tiles // 3+4 = 7

	FIRSTPIXEL 0	// 13
	MIDPIXELS 4		// 36
	LASTPIXEL		// 8

	// Total: 79
	DELAYX (80-79)
	jmp finished_tiles // 3

offset7:
	FIRSTPIXEL 7	// 14

	rcall	draw15tiles // 3+4 = 7

	FIRSTPIXEL 0	// 13
	MIDPIXELS 5		// 45
	LASTPIXEL		// 8

	// Total: 80
	DELAYX (80-80)
	jmp finished_tiles // 3

draw15tiles:
	// 16 tiles * 8 pixels = 128 pixels * 9 clocks = 1152 clocks per line
	// Each 8 pixel tile should take 8 * 9 = 72 clocks
	// 13 + 6*9 + 8 = 75 clocks: additionnal 3 clocks: the pixels won't be exactly the same width
	// but it doesn't show on a real TV. Real total = 16*75 = 1200 clocks per line. For each tile:
	// pixel 0 duration = 11 clocks
	// pixel 1 duration = 10 clocks
	// pixel 2..7 duration = 9 clocks
	.rept 15
		FIRSTPIXEL 0	// 13
		MIDPIXELS 6		// 9
		LASTPIXEL		// 8
	.endr
	ret
	
    // at this point, last pixel must display for n clocks = normal pixel time, do some work, delay the difference
finished_tiles:
    // delay remainder (pixel time - any work above - time to black below)
	//DELAYX (9-3-3)

    // set video back to black
    ldi     r16, NTSC_BLACK             	// (1)
	//ldi		r16, NTSC_YELLOW
    out     PORTA, r16                      // (1)

	// Test: Early out: exit now, so next scanline will be driven by interrupt
	// Result: 'perfect' timing, but we lose 2 sprites :(
	//pop		r22					   // 2
	//jmp NTSC_Next_Line

	// RV experimentation: don't return from interrupt between active scanline:
	// It is 'useless' because the next interrupt would occur so quickly there is nothing to do
	// and we would need to push and pop all registers..

	// Sprite draw time:
	// We are now in 'right overscan' portion of the current scanline
	// How much clock time do we have here?
	// Let's test with some trial and error:
	// We have exactly 141 clocks!
	// One less or one more and the display gets wavy.
	// Delay for horizontal scroll first tile jumptable: 8
#define RIGHTOVERSCAN_DELAY (141-126-4-7)
	// total: 22 + 52*2 = 126
	ldi		r21, 2 // 0 (accounted inside rendersprites)
	ldi		r22, (0*2) // 0 (accounted inside rendersprites)
	call rendersprites // 4 + 4 = 8

	DELAYX (RIGHTOVERSCAN_DELAY)

	// Total: 4 clocks
	adiw    r24, 1                 // (2)
	pop		r22					   // 2

	//DELAYX(130)
	// 130 = almost vertical
	// This loop takes: 1+hscroll*3 clocks
	/*
	lds		r17, hscroll // 1
wastetime2:
	dec r17  // 1
	brne wastetime2	// 2
*/

	// Total: 7 clocks
    // if (curr_line == ( screen height + offset) ) then NTSC_Video_First_Overscan_Bot
    ldi     r16, hi8(NTSC_SCREEN_HEIGHT + NTSC_VERTICAL_OFFSET)  // (1) 
    cpi     r24, lo8(NTSC_SCREEN_HEIGHT + NTSC_VERTICAL_OFFSET)  // (1)
    cpc     r25, r16                                             // (0)
    breq    NTSC_Video_First_Overscan_Bot1   // (2)

	jmp NTSC_Video_State_Test1     // 3

NTSC_Video_First_Overscan_Bot1:
	jmp NTSC_Video_First_Overscan_Bot

testdelay:
	ret

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

NTSC_Next_Line:


    // curr_line++
    adiw    r24, 1                 // (2)

    // if (curr_line >= 262) curr_line = 0
    ldi     r16, hi8(262)          // (1) 
    cpi     r24, lo8(262)          // (1)
    cpc     r25, r16               // (1)
    brne    NTSC_End_Line          // (1/2)

    // curr_line = 0
    ldi     r24, 0                 // (1)
    ldi     r25, 0                 // (1)

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

NTSC_End_Line:

    // save registers back to curr_line in SRAM for exit back to C/C++ caller
    sts     curr_line,   r24       // (2)
    sts     curr_line+1, r25       // (2)

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

Restore_Regs:

    // restore the status register
    pop     r0          // (2)
    out     SREG, r0    // (1)        

    // restore working registers
    pop     r31         // (2), Z
    pop     r30         // (2)

    pop     r29         // (2), Y
    pop     r28         // (2)

    pop     r27         // (2), X
    pop     r26         // (2)

    pop     r25         // (2)
    pop     r24         // (2)

    //pop     r23         // (2)
    //pop     r22         // (2)

    pop     r21         // (2)
    pop     r20         // (2)

    pop     r19         // (2)
    pop     r18         // (2)

    pop     r17         // (2)
    pop     r16         // (2)

    pop     r1          // (2)
    pop     r0          // (2)
  
    reti                // (5) return from interrupt and reset interupt flag, total time of restore 38 clocks for restore

////////////////////////////////////
// rendersprites
// Takes two parameters:
//  r21: number of sprites to render (1 or more)
//  r22: offset in bytes of starting sprite to render (3*spriteindex)
// on return,
//  r21 will always be set to 0

	// total clocks: 
	// rendersprites base setup: 14+8 = 22
	// rendersprites_X: 8
	//   per sprites setup: 3+11+4+10=28 clocks
	//           rendering: 24 clocks
	//               total: 52 clocks

rendersprites: // call+ret 4+4 = 8
	// Base part: prepare X pointer into spritelist.
	// This part can be skipped if X was not modified: X will point to start of next sprite automatically.
	// Total: 14 clocks
	lds     r16, curr_raster_line // 2
	lsr		r16 // 1
	ldi		r17, MAXSPRITES*2 // 1
	mul		r16, r17 // 2
	ldi		XL, lo8(spritelist) // 1
	ldi		XH, hi8(spritelist) // 1
	add		XL, r0 // 1
	adc		XH, r1 // 1

	// NOTE: ldi r22, VALUE is done before CALL rendersprites
	// ldi r22, VALUE // 1
	add		XL, r22 // 1
	ldi		r22, 0 // 1
	adc		XH, r22 // 1

rendersprites_X:
	// Loops take 3 clocks
	// we might want to draw 2 or more sprites here.
	// NOTE: this 'ldi' is done before CALL rendersprites
	// NOTE: 'X' register must still be valid
	// and r22 MUST be 0
	//ldi		r21, 2 // 0 (accounted in brne below)
reloop_sprite:

	// Total: 11 clocks
	ldi		ZH, 0 // 1
	ld 		ZL,X+ // 2
	lsl		ZL // 1
	adc		ZH, r22 // 1
	// Use these lines to compute 'hard coded' jmptable address..
	// I can't get it from C
	ldi		r16,lo8(pm(jmptable)) // 1
	ldi 	r17,hi8(pm(jmptable)) // 1
	add		ZL, r16 // 1
	adc		ZH, r17 // 1
	ld		r16, X+			// 2

	// Total: 4 clocks
	ldi		YL, lo8(scanline1) // 1
	ldi		YH, hi8(scanline1) // 1
	add		YL, r16 // 1
	adc		YH, r22 // 1
	// Y is fully prepared: points into scanline buffer, where sprite should be drawn

	icall // 3+3+4=10 jmp/ret for each sprite row

	// end sprite draw
	dec		r21 // 1
	brne reloop_sprite // 2	
	ret // 4

DELAY_2CLOCK:
	nop		// 1
DELAY_1CLOCK:
	nop		// 1
DELAY_0CLOCK:
	ret

DELAY_VARIABLE3CLOCK:
	dec r16 	// 1
	brne DELAY_VARIABLE3CLOCK	// 2
	ret

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// END ASM FUNCTIONS 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
.global sintable
sintable:
.byte 128,131,134,137,140,143,146,149,152,155,158,161,164,167,170,173,176,179,182,185,187,190,193,195,198,201,203,206,208,210,213,215,217,219,222,224,226,228,230,231,233,235,236,238,240,241,242,244,245,246,247,248,249,250,251,251,252,253,253,254,254,254,254,254,255,254,254,254,254,254,253,253,252,251,251,250,249,248,247,246,245,244,242,241,240,238,236,235,233,231,230,228,226,224,222,219,217,215,213,210,208,206,203,201,198,195,193,190,187,185,182,179,176,173,170,167,164,161,158,155,152,149,146,143,140,137,134,131,128,125,122,119,116,113,110,107,104,101,98,95,92,89,86,83,80,77,74,71,69,66,63,61,58,55,53,50,48,46,43,41,39,37,34,32,30,28,26,25,23,21,20,18,16,15,14,12,11,10,9,8,7,6,5,5,4,3,3,2,2,2,2,2,1,2,2,2,2,2,3,3,4,5,5,6,7,8,9,10,11,12,14,15,16,18,20,21,23,25,26,28,30,32,34,37,39,41,43,46,48,50,53,55,58,61,63,66,69,71,74,77,80,83,86,89,92,95,98,101,104,107,110,113,116,119,122,125

#include "rem_avr_ultra_sprites.h"

.align 8 // Important: this will ensure that tiles base adress will never cross a 256 boundary
#include "rem_avr_ultra_tiles.h"

.end

