///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// 
// Copyright Nurve Networks LLC 2008
// 
// Filename: REM_AVR_NTSC_224_168_8_V010.S
//
// Original Author: Remi Veilleux
// 
// Last Modified: 12.22.08
// 
// Description: 224x168 resolution NTSC driver with 8-bit per pixel "true color" mode.

// The driver fetch an image (located at the end of this file) named 'image_224x168'
// and draws one line per scanline, using 5 clock per pixel.
//
// Next, the driver passses back the current absolute video line 0..524 via curr_line and the current
// virtual raster line via curr_raster_line:
//
// .global curr_line         // read only, current physical line
// .global curr_raster_line  // read only, current logical raster line
//
//
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////



///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// SET PROCESSOR TYPE (must come first)
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#ifndef __AVR_ATmega644__
#define __AVR_ATmega644__
#endif

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// INCLUDES 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
#include <avr/interrupt.h> 
#include <avr/io.h>

#include "REM_AVR_NTSC_BMP_224_168_8_v010.h"
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// DEFINES 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#undef __SFR_OFFSET
#define __SFR_OFFSET 0 // needed for macro, also fixes so you can use register names directly and NOT need macro _SFR_IO_ADDR( x )

// with the current D/A converter range 0 .. 15, 1 = 62mV
#define NTSC_SYNC     (0x0F)     // 0V  
#define NTSC_CBURST0  (0x40)


///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// MACROS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// this macro delays any number of clocks, uses chunks of 4
.macro  DELAYX reg = r16, clocks
    ldi     \reg, (\clocks)/4        // (1)
1:
    dec     \reg                     // (1)
    nop                              // (1)
    brne    1b                       // (1/2)

    // now delay fractional component
    .rept   (\clocks % 4)
    nop                              // (1)
    .endr

.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
   
// this macro delays any number of clocks that are a multiple of 4, anything else is truncated
.macro  DELAY4X reg = r16, clocks
    ldi     \reg, (\clocks)/4        // (1)
1:
    dec     \reg                     // (1)
    nop                              // (1)
    brne    1b                       // (1/2)
.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// this macro delays any number of clocks that are a multiple of 3, anything else is truncated
.macro  DELAY3X reg = r16, clocks
    ldi     \reg, (\clocks)/3        // (1)
1:
    dec     \reg                     // (1)
    brne    1b                       // (1/2)
.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.macro  SAVE_SREG reg = r16

    in      \reg, SREG                       // save status register
    push    \reg

.endm



///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.macro  RESTORE_SREG reg = r16

    pop     \reg
    out     _SFR_IO_ADDR( SREG ), \reg      // restore status register

.endm

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// LOCAL INITIALIZED VARIABLES (SRAM)
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.section .data

overscan_color:			.byte NTSC_BLACK

hscroll:				.byte 0
.global hscroll

vscroll:				.byte 0
.global vscroll

framecount:				.byte 0,0 // 16-bit UINT frame counter
.global framecount

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// current video line
curr_line:                .byte 0,0    

// current raster line 0..167
curr_raster_line:         .byte 0

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// DATA STRUCTURES IN FLASH/ROM - NOTE: MUST ON WORD BOUNDARIES
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.section .text

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// EXTERNALS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// GLOBALS EXPORTS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// export these to caller, so he can interogate and change
.global curr_line        // read only, current physical line
.global curr_raster_line // read only, current logical raster line
.global overscan_color   // read/write: 8-bit NTSC color used for overscan 

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// ASM FUNCTIONS 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////



.section .text

// asm entry point

.global	TIMER1_COMPA_vect  
TIMER1_COMPA_vect:

Save_Regs:

    // save working registers on stack
    push    r0              // (2)        
    push    r1              // (2)        
    
    push    r16             // (2)
    push    r17             // (2)

    push    r18             // (2)
    push    r19             // (2)

    push    r20             // (2)
    push    r21             // (2)

    push    r24             // (2)
    push    r25             // (2)

    push    r26             // (2)   X
    push    r27             // (2)

    push    r28             // (2)   Y
    push    r29             // (2)

    push    r30             // (2)   Z
    push    r31             // (2)

    in      r0, SREG        // (2)
    push    r0              // (2) save the status register

                            // (32) clocks for stack push

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

NTSC_Start:

    // load r25:24 with curr_line
    lds     r24, curr_line                  // (2)
    lds     r25, curr_line+1                // (2)      

NTSC_Video_State_Test1:

    // if (curr_line < offset) then NTSC_Draw_Blank_Line
    ldi     r16, hi8(NTSC_VERTICAL_OFFSET)  // (1)
    cpi     r24, lo8(NTSC_VERTICAL_OFFSET)  // (1)
    cpc     r25, r16                        // (1)
    brlo    NTSC_Draw_Blank_Line_Top        // (1/2) NTSC_Start: (9) clocks -> jump, jump need due to code out of range for branch

// elseif
NTSC_Video_State_Test2:    

    // if (curr_line < ( screen height + offset) ) then NTSC_Draw_Active_Line
    ldi     r16, hi8(NTSC_SCREEN_HEIGHT + NTSC_VERTICAL_OFFSET)  // (1) 
    cpi     r24, lo8(NTSC_SCREEN_HEIGHT + NTSC_VERTICAL_OFFSET)  // (1)
    cpc     r25, r16                                             // (1)

    //brlo    NTSC_Draw_Active_Line  // (1/2) 

    brsh    NTSC_Video_State_Test3   // (1/2)
    jmp     NTSC_Draw_Active_Line    // (3)     NTSC_Start: (15) clocks -> jump, jump need due to code out of range for branch

// elseif
NTSC_Video_State_Test3:    

    // if (curr_line < 258) then NTSC_Draw_Blank_Line
    ldi     r16, hi8(258)            // (1) 
    cpi     r24, lo8(258)            // (1)
    cpc     r25, r16                 // (1)
    brlo    NTSC_Draw_Blank_Line_Bot // (1/2)   NTSC_Start: (18) clocks -> jump, jump need due to code out of range for branch

// elseif
NTSC_Video_State_Test4:    

    // if (curr_line < 262) then NTSC_Draw_Vsync_Line
    ldi     r16, hi8(262)            // (1) 
    cpi     r24, lo8(262)            // (1)
    cpc     r25, r16                 // (1)
    brlo    NTSC_Draw_Vsync_Line     // (1/2)   NTSC_Start: (22) clocks -> jump, jump need due to code out of range for branch
    // else should never get here...

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

NTSC_Draw_Blank_Line_Top: 

    // equalize delay from conditional line fork
    .rept (18 - 9)
    nop
    .endr

NTSC_Draw_Blank_Line_Bot: 

    // equalize delay from conditional line fork
    .rept (22 - 18)
    nop
    .endr

    // enable hsync, set video to black
    ldi     r16, NTSC_SYNC           // (1)
    out     PORTA, r16               // (1)

    // test if this is the top of frame here, we need to initialize the rendering kernel
    // if (curr_line == 0) then NTSC_Reset_Kernel
    ldi     r16, hi8(0)              // (1)
    cpi     r24, lo8(0)              // (1)
    cpc     r25, r16                 // (1)

    // now based on flags set above, jump to normal blank line or reset 
    breq    NTSC_Reset_Kernel        // (1/2)

    // else delay hsync time (this will be filled with processing in later versions)

    // 16 color clocks sync (128 clocks), this needs to be adjusted correctly to take above computation into consideration
    DELAYX r16, (16*CLOCKS_PER_PIXEL + 20)
    
    // disble hsync, maintain black
    ldi     r16, NTSC_BLACK          // (1)
    out     PORTA, r16               // (1)

    // now color burst
    DELAY4X r16, (2*CLOCKS_PER_PIXEL)
    
    ldi     r16, NTSC_CBURST0               // (1)
    out     PORTA, r16                      // (1)

    // now color burst
    DELAYX r16, (10*CLOCKS_PER_PIXEL)

    // back to black HSYNC off
    lds     r16, overscan_color             // (2) // RV: added 1 clock here
    out     PORTA, r16                      // (1)

    jmp     NTSC_Next_Line           // (3)    

NTSC_Reset_Kernel:
    // reset all data structures each frame at line 0

    // initialize any variables for algorithm    

    // initialize curr_raster_line for next frame, 
    ldi     r16, 0                           // (1)
    sts     curr_raster_line, r16                 // (2)

    // 16 color clocks sync (128 clocks), this needs to be adjusted correctly to take above computation into consideration
    DELAYX r16, (16*CLOCKS_PER_PIXEL + (20 - 12))

    // disble hsync, maintain black
    ldi     r16, NTSC_BLACK                 // (1)
    out     PORTA, r16                      // (1)

    jmp     NTSC_Next_Line                  // (3)

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  
NTSC_Draw_Vsync_Line:

    // invert hsync and maintain sync for 4-6 lines
    ldi     r16, NTSC_BLACK   // (1)
    out     PORTA, r16        // (1)

    // delay for hsync pulse length 

    // 16 color clocks sync (128 clocks)
    DELAYX r16, (16*CLOCKS_PER_PIXEL)
    
    // disble hsync, but maintain vsync and black
    ldi     r16, NTSC_SYNC   // (1)
    out     PORTA, r16       // (1)

    jmp     NTSC_Next_Line   // (3)

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

// enter
NTSC_Draw_Active_Line:

    // delay to equalize initial line fork
    .rept (22 - 12)
    nop
    .endr

    // enable hsync, set RGB to black (want approximately 16 color clocks for sync
    ldi     r16, NTSC_SYNC                  // (1)
    out     PORTA, r16                      // (1)

	DELAY4X r16, (8*16 + 18) // waste some time

    // turn HSYNC off
    ldi     r16, NTSC_BLACK                 // (1)
    out     PORTA, r16                      // (1)

	DELAY4X r16, (1*16) // waste some time


    ldi     r16, NTSC_CBURST0               // (1)
    out     PORTA, r16                      // (1)

	DELAY4X r16, (5*16) // waste some time


    // back to black HSYNC off
	// RV: Here we can set 'left horizontal overscan' color
    lds     r16, overscan_color                 // (2) RV: added 1 clock here!
    out     PORTA, r16                      // (1)

	DELAY4X r16, (12*16) // waste some time

	// 240 pixels : 1120 / 240 = 4.6 clocks per pixel.. not good

	// new attempt with 224 x 168 (1120 / 224 = 5 clocks per pixel)
	// Get image base address (16-bit) in Z
    ldi     ZL, lo8( image_224x168 )
    ldi     ZH, hi8( image_224x168 )

	// now take curr_raster_line (0..167) and multiply by NTSC_SCREEN_WIDTH
    lds     r16, curr_raster_line                // (1)

	// Add vscroll (8-bit)
    //lds     r17, vscroll
	//add		r16, r17

	// now wrap value in r16: it should be 0..167
	cpi		r16, 167
	brlo	r16_ok
	subi	r16, 167

r16_ok:
	ldi		r17, NTSC_SCREEN_WIDTH
	mul		r16, r17
	// result is always in r0:r1. Perform 16-bit add:
	add		ZL, r0
	adc		ZH, r1

	// keep a backup of 'Z' into 'Y' (because lpm always uses Z)
	movw	YL, ZL

	// fetch curr raster line from sintable
	/*
    lds     r17, curr_raster_line
    ldi     ZL, lo8( sintable )
    ldi     ZH, hi8( sintable )
	add		ZL, r16
	ldi		r16, 0
	adc		ZH, r16
	lpm		r17, Z
	subi	r17, -127

	// Multiply (amplitude) by vscroll (result 16-bit in r1:r0)
	lds     r16, vscroll
	mul		r16, r17
	*/

	// Add with framecount, from sintable
	lds		r16, framecount
    lds     r1, curr_raster_line
	lds     r17, vscroll
	mul		r1, r17
	add		r16,r1
    ldi     ZL, lo8( sintable )
    ldi     ZH, hi8( sintable )
	add		ZL, r16
	ldi		r16, 0
	adc		ZH, r16
	// Fetch sin value from table
	lpm		r16, Z
	subi	r16, -127

	// Multiply (amplitude) by hscroll (result 16-bit in r1:r0)
	lds     r17, hscroll
	mul		r16, r17

	movw	ZL, YL
	// add it to horizontal
	add		ZL, r1
	ldi		r16, 0
	adc		ZH, r16


    .rept NTSC_SCREEN_WIDTH 
		lpm		r16, Z+ // 3
		out     PORTA, r16 // 1
		nop // 1
    .endr

    // at this point, last pixel must display for n clocks = normal pixel time, do some work, delay the difference

    // delay remainder (pixel time - any work above - time to black below)
    .rept (4)
    nop
    .endr

    // set video back to black
    lds     r16, overscan_color             // (2)
    out     PORTA, r16                      // (1)

    // increment curr_raster_line
	lds     r20, curr_raster_line
    inc     r20                             // (1)
    sts     curr_raster_line, r20                // (2)

    jmp     NTSC_Next_Line                  // (3)

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

NTSC_Next_Line:

    // curr_line++
    adiw    r24, 1                 // (2)

    // if (curr_line >= 262) curr_line = 0
    ldi     r16, hi8(262)          // (1) 
    cpi     r24, lo8(262)          // (1)
    cpc     r25, r16               // (1)
    brne    NTSC_End_Line          // (1/2)

    // curr_line = 0
    ldi     r24, 0                 // (1)
    ldi     r25, 0                 // (1)

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

NTSC_End_Line:

    // save registers back to curr_line in SRAM for exit back to C/C++ caller
    sts     curr_line,   r24       // (2)
    sts     curr_line+1, r25       // (2)

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  

Restore_Regs:

    // restore the status register
    pop     r0          // (2)
    out     SREG, r0    // (1)        

    // restore working registers
    pop     r31         // (2), Z
    pop     r30         // (2)

    pop     r29         // (2), Y
    pop     r28         // (2)

    pop     r27         // (2), X
    pop     r26         // (2)

    pop     r25         // (2)
    pop     r24         // (2)

    pop     r21         // (2)
    pop     r20         // (2)

    pop     r19         // (2)
    pop     r18         // (2)

    pop     r17         // (2)
    pop     r16         // (2)

    pop     r1          // (2)
    pop     r0          // (2)

#if 0
    .rept 50
    nop
    .endr
#endif
  
    reti                // (5) return from interrupt and reset interupt flag, total time of restore 38 clocks for restore

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// END ASM FUNCTIONS 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
sintable:
.byte 0,3,6,9,12,15,18,21,24,27,30,33,36,39,42,45,48,51,54,57,59,62,65,67,70,73,75,78,80,82,85,87,89,91,94,96,98,100,102,103,105,107,108,110,112,113,114,116,117,118,119,120,121,122,123,123,124,125,125,126,126,126,126,126,127,126,126,126,126,126,125,125,124,123,123,122,121,120,119,118,117,116,114,113,112,110,108,107,105,103,102,100,98,96,94,91,89,87,85,82,80,78,75,73,70,67,65,62,59,57,54,51,48,45,42,39,36,33,30,27,24,21,18,15,12,9,6,3,0,-3,-6,-9,-12,-15,-18,-21,-24,-27,-30,-33,-36,-39,-42,-45,-48,-51,-54,-57,-59,-62,-65,-67,-70,-73,-75,-78,-80,-82,-85,-87,-89,-91,-94,-96,-98,-100,-102,-103,-105,-107,-108,-110,-112,-113,-114,-116,-117,-118,-119,-120,-121,-122,-123,-123,-124,-125,-125,-126,-126,-126,-126,-126,-127,-126,-126,-126,-126,-126,-125,-125,-124,-123,-123,-122,-121,-120,-119,-118,-117,-116,-114,-113,-112,-110,-108,-107,-105,-103,-102,-100,-98,-96,-94,-91,-89,-87,-85,-82,-80,-78,-75,-73,-70,-67,-65,-62,-59,-57,-54,-51,-48,-45,-42,-39,-36,-33,-30,-27,-24,-21,-18,-15,-12,-9,-6,-3

image_224x168:
.byte 0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0xAF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xCF,0xDF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0x9F,0x9F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F
.byte 0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x41,0x8F,0x8F,0x8F,0x41,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x8F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x41,0x9F,0x8F,0x41,0x8F,0x8F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0xAF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xDF,0xDF,0xDF,0xDF,0xFD,0xDF,0xFD,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0x9F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F
.byte 0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x41,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x9F,0x41,0x9F,0x8F,0x9F,0x41,0x9F,0x8F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x9F,0x41,0x8F,0x9F,0x8F,0x41,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0xAF,0xBF,0xBF,0xBF,0xCF,0xCF,0xDF,0xDF,0xDF,0xDF,0xFD,0xDF,0xEF,0xDF,0xEF,0xFD,0xEF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xAF,0xAF,0x9F,0x9F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F
.byte 0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x41,0x9F,0x8F,0x9F,0x41,0x9F,0x8F,0x9F,0x41,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x8F,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x41,0x8F,0x8F,0x41,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0x9F,0xAF,0x9F,0xAF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xDF,0xDF,0xDF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xDF,0xEF,0xFD,0xDF,0xDF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xAF,0xAF,0x9F,0x9F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x8F
.byte 0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x41,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x9F,0x41,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x8F,0x41,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x8F,0x8F,0x41,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0x9F,0xAF,0x9F,0xAF,0xAF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xDF,0xDF,0xFD,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xFD,0xEF,0xEF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xAF,0xAF,0x9F,0x9F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F
.byte 0x8F,0x8F,0x9F,0x8F,0x41,0x9F,0x8F,0x41,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x41,0x8F,0x8F,0x8F,0x8F,0x8F,0x41,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F,0x7F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x41,0x9F,0x8F,0x9F,0x41,0x8F,0x8F,0x41,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x8F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x41,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0x9F,0x9F,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xCF,0xDF,0xDF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xFD,0xDF,0xDF,0xDF,0xDF,0xDF,0xFC,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xAF,0xAF,0x9F,0x9F,0x8F,0x8F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F
.byte 0x8F,0x8F,0x41,0x9F,0x8F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x41,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0x9F,0xAF,0x9F,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x8F,0x9F,0x8F,0x41,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0x9F,0x9F,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xDF,0xDF,0xFD,0xEF,0xEF,0xFF,0xFF,0xFF,0xEF,0xFF,0xEF,0xEF,0xEF,0xEF,0xDF,0xFD,0xDF,0xDF,0xDF,0xCF,0xDF,0xCF,0xCF,0xCF,0xBF,0xBF,0xAF,0xAF,0xAF,0x9F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F
.byte 0x9F,0x8F,0x9F,0x8F,0x9F,0x41,0x8F,0x41,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x41,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x41,0x8F,0x8F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x41,0x8F,0x8F,0x8F,0x9F,0x9F,0x9F,0x9F,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x41,0x8F,0x41,0x8F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x41,0x8F,0x9F,0x9F,0x9F,0xAF,0xAF,0xAF,0xBF,0xAF,0xBF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xDF,0xDF,0xEF,0xEF,0xEF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xEF,0xEF,0xEF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xAF,0xAF,0x9F,0x8F,0x8F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F,0x7F
.byte 0x8F,0x9F,0x41,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x41,0x8F,0x8F,0x8F,0x41,0x8F,0x8F,0x8F,0x8F,0x8F,0x41,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x41,0x8F,0x8F,0x41,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0x9F,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0x9F,0xAF,0xAF,0xAF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xDF,0xDF,0xFD,0xEF,0xEF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xEF,0xEF,0xDF,0xDF,0xDF,0xDF,0xDF,0xCF,0xDF,0xCF,0xCF,0xBF,0xBF,0xAF,0xAF,0x9F,0x9F,0x8F,0x7F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F
.byte 0x9F,0x41,0x9F,0x9F,0x41,0x8F,0x9F,0x41,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x41,0x8F,0x41,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x41,0x8F,0x41,0x8F,0x41,0x8F,0x41,0x8F,0x41,0x8F,0x9F,0x41,0x8F,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x8F,0x9F,0x8F,0x8F,0x41,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0xAF,0xAF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xDF,0xDF,0xEF,0xEF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xEF,0xFD,0xDF,0xDF,0xDF,0xFC,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xAF,0xAF,0x9F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F,0x7F,0x7F
.byte 0x9F,0x9F,0x40,0x9F,0x9F,0x40,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x41,0x9F,0x8F,0x8F,0x8F,0x8F,0x40,0x8F,0x8F,0x8F,0x7F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x41,0x9F,0x9F,0xAF,0xAF,0xAF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0x9F,0xAF,0xAF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xDF,0xDF,0xEF,0xEF,0xEF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xEF,0xDF,0xDF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xBF,0xBF,0xAF,0xAF,0x9F,0x9F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F
.byte 0x9F,0x40,0x9F,0x41,0x9F,0x9F,0x40,0x9F,0x41,0x8F,0x8F,0x8F,0x8F,0x8F,0x41,0x8F,0x40,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x41,0x8F,0x8F,0x9F,0x9F,0xAF,0xAF,0xAF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x41,0x8F,0x41,0x8F,0x41,0x8F,0x41,0x8F,0x41,0x8F,0x41,0x8F,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x41,0x8F,0x8F,0x8F,0x9F,0xAF,0xAF,0xAF,0xBF,0xBF,0xCF,0xCF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xDF,0xDF,0xFD,0xEF,0xEF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xEF,0xFD,0xDF,0xDF,0xFC,0xCF,0xDF,0xCF,0xCF,0xBF,0xBF,0xAF,0x9F,0x9F,0x9F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F
.byte 0x9F,0x9F,0x9F,0x40,0x9F,0x40,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x41,0x9F,0x8F,0x8F,0x40,0x8F,0x8F,0x8F,0x7F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F,0x8F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0xAF,0xAF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0xAF,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x41,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0xAF,0xAF,0xBF,0xBF,0xBF,0xCF,0xBF,0xCF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xDF,0xDF,0xEF,0xEF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xEF,0xDF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xBF,0xBF,0xAF,0xAF,0x9F,0x8F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F
.byte 0x40,0x50,0x9F,0x9F,0x40,0x9F,0x40,0x9F,0x8F,0x8F,0x8F,0x41,0x8F,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x41,0x9F,0xAF,0xAF,0xAF,0xBF,0xBF,0xBF,0xBF,0xBF,0xCF,0xBF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xBF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0x9F,0x9F,0x41,0x8F,0x41,0x8F,0x41,0x8F,0x41,0x8F,0x41,0x8F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0xAF,0xAF,0xBF,0xBF,0xBF,0xCF,0xCF,0xBF,0xBF,0xBF,0xCF,0xBF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xDF,0xFD,0xEF,0xEF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xFD,0xDF,0xDF,0xFC,0xCF,0xCF,0xCF,0xBF,0xBF,0xAF,0x9F,0x9F,0x8F,0x8F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F
.byte 0x9F,0x9F,0x40,0x9F,0x40,0x9F,0x40,0x8F,0x8F,0x8F,0x8F,0x9F,0x40,0x9F,0x8F,0x40,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x8F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F,0x8F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0xAF,0xAF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0xAF,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0xAF,0xAF,0xBF,0xBF,0xBF,0xCF,0xCF,0xBF,0xCF,0xBF,0xBF,0xCF,0xCF,0xCF,0xBF,0xCF,0xCF,0xCF,0xDF,0xDF,0xEF,0xEF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xEF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xBF,0xBF,0xAF,0x9F,0x9F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F
.byte 0x50,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x41,0x8F,0x8F,0x8F,0x9F,0x8F,0x40,0x9F,0x40,0x8F,0x40,0x8F,0x8F,0x8F,0x8F,0x8F,0x40,0x8F,0x8F,0x40,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0xAF,0xAF,0xBF,0xBF,0xBF,0xCF,0xBF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0x9F,0x9F,0x41,0x8F,0x41,0x8F,0x41,0x8F,0x41,0x8F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x8F,0x8F,0x41,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0xAF,0xBF,0xBF,0xBF,0xCF,0xBF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xCF,0xCF,0xBF,0xCF,0xCF,0xCF,0xDF,0xDF,0xFD,0xEF,0xEF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xEF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xBF,0xBF,0xAF,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F
.byte 0x50,0x9F,0x50,0x9F,0x40,0x9F,0x40,0x9F,0x8F,0x8F,0x41,0x9F,0x40,0x9F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x8F,0x40,0x8F,0x8F,0x40,0x8F,0x8F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x41,0x9F,0xAF,0xBF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x8F,0x9F,0x8F,0x9F,0x41,0x9F,0x8F,0x9F,0x41,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0xAF,0xAF,0xBF,0xBF,0xBF,0xCF,0xCF,0xBF,0xCF,0xBF,0xCF,0xBF,0xCF,0xCF,0xCF,0xBF,0xCF,0xCF,0xCF,0xDF,0xDF,0xEF,0xEF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xEF,0xFD,0xDF,0xDF,0xCF,0xCF,0xCF,0xBF,0xAF,0xAF,0x9F,0x9F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F
.byte 0x9F,0x50,0x9F,0x50,0x9F,0x40,0x9F,0x8F,0x8F,0x8F,0x9F,0x40,0x9F,0x40,0x9F,0x40,0x8F,0x40,0x8F,0x8F,0x40,0x8F,0x40,0x8F,0x8F,0x40,0x8F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x9F,0xAF,0xAF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xFC,0xCF,0xFC,0xCF,0xFB,0xDF,0xCF,0xFB,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0x9F,0x41,0x8F,0x41,0x8F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x41,0x9F,0x8F,0x9F,0x9F,0x41,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x8F,0x9F,0x8F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x9F,0xAF,0xBF,0xBF,0xBF,0xBF,0xCF,0xBF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xDF,0xFD,0xEF,0xEF,0xEF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xDF,0xDF,0xDF,0xCF,0xCF,0xBF,0xBF,0xAF,0xAF,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F
.byte 0x50,0x9F,0x50,0x9F,0x50,0x9F,0x40,0x8F,0x9F,0x8F,0x9F,0x40,0x9F,0x40,0x40,0x9F,0x40,0x8F,0x40,0x8F,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x7F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x41,0x9F,0xAF,0xAF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xCF,0xFB,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xCF,0xDF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0x9F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x8F,0x9F,0x41,0x9F,0x8F,0x9F,0x8F,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x41,0x9F,0x8F,0x8F,0x8F,0x9F,0x9F,0xAF,0xAF,0xBF,0xBF,0xBF,0xCF,0xCF,0xBF,0xCF,0xBF,0xBF,0xBF,0xCF,0xBF,0xCF,0xBF,0xBF,0xCF,0xCF,0xCF,0xDF,0xDF,0xEF,0xEF,0xEF,0xFF,0xEF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xEF,0xDF,0xDF,0xDF,0xCF,0xCF,0xBF,0xBF,0xAF,0xAF,0x9F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F
.byte 0x50,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x8F,0x41,0x8F,0x9F,0x40,0x9F,0x40,0x9F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0xAF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xCF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xFC,0xDF,0xDF,0xDF,0xFB,0xDF,0xCF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0x9F,0x41,0x8F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x41,0x9F,0x8F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x41,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0xAF,0xAF,0xBF,0xBF,0xBF,0xBF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xDF,0xFD,0xEF,0xEF,0xEF,0xEF,0xEF,0xFF,0xEF,0xFF,0xEF,0xEF,0xEF,0xDF,0xDF,0xCF,0xCF,0xBF,0xBF,0xBF,0xAF,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F
.byte 0x50,0x9F,0x50,0x50,0x9F,0x40,0x9F,0x8F,0x9F,0x40,0x9F,0x40,0x9F,0x40,0x40,0x9F,0x40,0x9F,0x40,0x8F,0x40,0x8F,0x40,0x40,0x8F,0x40,0x8F,0x7F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x41,0x9F,0xAF,0xAF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xCF,0xDF,0xDF,0xDF,0xDF,0xFC,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x8F,0x9F,0x41,0x9F,0x9F,0x8F,0x41,0x9F,0x8F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x9F,0xAF,0xAF,0xBF,0xBF,0xBF,0xCF,0xBF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xDF,0xDF,0xFD,0xEF,0xEF,0xEF,0xEF,0xEF,0xFF,0xEF,0xEF,0xEF,0xFD,0xDF,0xDF,0xCF,0xCF,0xBF,0xBF,0xAF,0xAF,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F
.byte 0x50,0x9F,0x50,0x9F,0x50,0x9F,0x40,0x8F,0x9F,0x9F,0x40,0x9F,0x50,0x9F,0x40,0x40,0x40,0x8F,0x40,0x9F,0x40,0x40,0x9F,0x40,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F,0x8F,0x40,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0xAF,0xAF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xCF,0xFB,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xCF,0xBF,0xCF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0x41,0x9F,0x41,0x9F,0x41,0x8F,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x41,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0xAF,0xAF,0xBF,0xBF,0xBF,0xCF,0xBF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xCF,0xCF,0xDF,0xDF,0xFD,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xFD,0xDF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xAF,0xAF,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F
.byte 0x50,0x50,0x9F,0x50,0x50,0x9F,0x9F,0x8F,0x41,0x9F,0x9F,0x50,0x9F,0x50,0x9F,0x40,0x9F,0x40,0x40,0x40,0x9F,0x40,0x40,0x40,0x40,0x8F,0x8F,0x7F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x8F,0x40,0x8F,0x8F,0x8F,0x8F,0x40,0x7F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0xAF,0xAF,0xBF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xFD,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xFB,0xDF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0x9F,0x8F,0x8F,0x8F,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x8F,0x9F,0x41,0x9F,0x41,0x8F,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x8F,0x9F,0x41,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x9F,0x9F,0x9F,0xAF,0xAF,0xBF,0xBF,0xBF,0xBF,0xCF,0xBF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xBF,0xBF,0xCF,0xCF,0xCF,0xDF,0xDF,0xFD,0xEF,0xFD,0xEF,0xFD,0xEF,0xFD,0xEF,0xDF,0xDF,0xCF,0xCF,0xBF,0xBF,0xBF,0xAF,0xAF,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F
.byte 0x50,0x9F,0x50,0x9F,0x50,0x9F,0x40,0x9F,0x9F,0x40,0x9F,0x50,0x50,0x50,0x40,0x40,0x40,0x9F,0x50,0x9F,0x40,0x50,0x9F,0x40,0x8F,0x40,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x40,0x7F,0x8F,0x40,0x7F,0x40,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x41,0x9F,0xAF,0xAF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xFC,0xCF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0x9F,0x41,0x9F,0x41,0x9F,0x8F,0x41,0x9F,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x9F,0x9F,0xAF,0xAF,0xBF,0xBF,0xBF,0xBF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xDF,0xDF,0xDF,0xFD,0xDF,0xEF,0xFD,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xBF,0xBF,0xAF,0xAF,0xAF,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F
.byte 0x50,0x50,0x50,0x50,0x9F,0x40,0x9F,0x8F,0x9F,0x40,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x40,0x40,0x50,0x9F,0x40,0x40,0x40,0x8F,0x8F,0x8F,0x7F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0xAF,0xAF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xCF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xFD,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xAF,0xAF,0x9F,0x41,0x9F,0x8F,0x9F,0x41,0x9F,0x8F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x41,0x9F,0x41,0x8F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x9F,0x41,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0xAF,0xAF,0xAF,0xBF,0xBF,0xBF,0xBF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0xBF,0xBF,0xBF,0xCF,0xCF,0xFC,0xDF,0xDF,0xDF,0xFD,0xDF,0xDF,0xFD,0xDF,0xDF,0xCF,0xCF,0xBF,0xBF,0xAF,0xAF,0xAF,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F
.byte 0x50,0x9F,0x50,0x9F,0x50,0x9F,0x40,0x9F,0x9F,0x50,0x9F,0x50,0x50,0x50,0x50,0x50,0x40,0x9F,0x50,0x50,0x50,0x50,0x50,0x40,0x40,0x8F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F,0x8F,0x40,0x8F,0x40,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x8F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x41,0x8F,0x41,0x9F,0x9F,0xAF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xCF,0xDF,0xDF,0xDF,0xDF,0xEF,0xDF,0xEF,0xDF,0xEF,0xDF,0xEF,0xDF,0xEF,0xDF,0xDF,0xFD,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xBF,0xBF,0xAF,0xAF,0xAF,0x9F,0x9F,0x41,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x41,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0xAF,0xAF,0xAF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xBF,0xAF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xFC,0xCF,0xCF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F,0x7F,0x7F
.byte 0x50,0x50,0x50,0x50,0x9F,0x40,0x9F,0x40,0x9F,0x50,0x50,0x9F,0x50,0x50,0x9F,0x50,0x50,0x50,0x9F,0x50,0x50,0x50,0x9F,0x40,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x8F,0x40,0x8F,0x40,0x40,0x40,0x40,0x40,0x8F,0x40,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0xAF,0xAF,0xAF,0xBF,0xCF,0xCF,0xCF,0xCF,0xCF,0xDF,0xCF,0xDF,0xDF,0xDF,0xDF,0xEF,0xEF,0xDF,0xEF,0xEF,0xDF,0xEF,0xDF,0xEF,0xDF,0xEF,0xDF,0xEF,0xDF,0xDF,0xEF,0xDF,0xDF,0xDF,0xFB,0xDF,0xCF,0xCF,0xBF,0xBF,0xBF,0xAF,0xAF,0x9F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x8F,0x9F,0x41,0x9F,0x8F,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x8F,0x9F,0x41,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0xAF,0xAF,0xBF,0xBF,0xBF,0xBF,0xBF,0xCF,0xBF,0xBF,0xBF,0xBF,0xAF,0xBF,0xAF,0xBF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xDF,0xFC,0xDF,0xDF,0xFC,0xDF,0xDF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xAF,0xAF,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F
.byte 0x50,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x9F,0x40,0x9F,0x50,0x50,0x50,0x50,0x50,0x50,0x9F,0x50,0x50,0x50,0x50,0x50,0x50,0x40,0x8F,0x40,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x8F,0x8F,0x40,0x40,0x40,0x8F,0x40,0x40,0x40,0x40,0x8F,0x40,0x8F,0x8F,0x8F,0x8F,0x41,0x8F,0x41,0x8F,0x41,0x9F,0x9F,0x9F,0xAF,0xBF,0xBF,0xCF,0xCF,0xDF,0xCF,0xDF,0xCF,0xDF,0xDF,0xDF,0xEF,0xEF,0xDF,0xEF,0xEF,0xEF,0xDF,0xEF,0xEF,0xDF,0xEF,0xDF,0xEF,0xDF,0xEF,0xFD,0xEF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xCF,0xCF,0xBF,0xBF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x8F,0x9F,0x8F,0x8F,0x9F,0x41,0x9F,0x8F,0x9F,0x41,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x8F,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0xAF,0xAF,0xAF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xBF,0xAF,0xBF,0xAF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xDF,0xCF,0xFC,0xDF,0xCF,0xDF,0xFC,0xCF,0xCF,0xCF,0xBF,0xBF,0xAF,0xAF,0xAF,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F
.byte 0x50,0x50,0x50,0x50,0x9F,0x50,0x9F,0x40,0x9F,0x50,0x9F,0x50,0x50,0x50,0x9F,0x50,0x50,0x50,0x9F,0x50,0x50,0x50,0x40,0x40,0x8F,0x8F,0x8F,0x7F,0x7F,0x8F,0x7F,0x8F,0x8F,0x40,0x8F,0x40,0x40,0x40,0x40,0x40,0x8F,0x40,0x8F,0x8F,0x8F,0x8F,0x41,0x8F,0x8F,0x8F,0x9F,0x8F,0x9F,0x41,0x9F,0x51,0xAF,0xBF,0xCF,0xCF,0xCF,0xCF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xDF,0xEF,0xDF,0xEF,0xDF,0xEF,0xEF,0xDF,0xDF,0xDF,0xDF,0xCF,0xCF,0xBF,0xBF,0xBF,0xAF,0xAF,0x51,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x41,0x8F,0x9F,0x8F,0x9F,0x41,0x9F,0x8F,0x9F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0xAF,0xAF,0xAF,0xBF,0xAF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xBF,0xAF,0xAF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xDF,0xCF,0xDF,0xCF,0xCF,0xDF,0xCF,0xCF,0xBF,0xBF,0xBF,0xAF,0xAF,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F
.byte 0x50,0x9F,0x50,0x9F,0x50,0x9F,0x40,0x9F,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x9F,0x50,0x50,0x50,0x50,0x50,0x9F,0x40,0x8F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x8F,0x40,0x8F,0x40,0x40,0x50,0x40,0x50,0x40,0x40,0x40,0x8F,0x8F,0x41,0x8F,0x8F,0x8F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x50,0xAF,0xBF,0xBF,0xCF,0xCF,0xCF,0xDF,0xCF,0xDF,0xDF,0xDF,0xEF,0xEF,0xEF,0xDF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xDF,0xEF,0xEF,0xEF,0xEF,0xEF,0xDF,0xDF,0xDF,0xDF,0xDF,0xCF,0xBF,0xBF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x41,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x41,0x8F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0xAF,0xAF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0xAF,0xAF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xFC,0xCF,0xFC,0xDF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xAF,0xAF,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F
.byte 0x50,0x60,0x50,0x50,0x9F,0x50,0x9F,0x9F,0x50,0x9F,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x40,0x8F,0x8F,0x7F,0x7F,0x7F,0x8F,0x8F,0x8F,0x40,0x40,0x40,0x50,0x50,0x50,0x50,0x50,0x9F,0x40,0x8F,0x8F,0x8F,0x8F,0x41,0x9F,0x8F,0x9F,0x41,0x9F,0x9F,0x40,0xAF,0xAF,0xBF,0xCF,0xCF,0xCF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xFD,0xEF,0xEF,0xEF,0xEF,0xDF,0xEF,0xDF,0xCF,0xCF,0xBF,0xBF,0xAF,0xAF,0xAF,0x9F,0x51,0x9F,0x41,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0xAF,0xAF,0xAF,0xAF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xBF,0xAF,0xAF,0xAF,0xAF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xAF,0xAF,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F
.byte 0x50,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x60,0x50,0x50,0x50,0x40,0x8F,0x40,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x8F,0x40,0x40,0x50,0x50,0x50,0x50,0x50,0x40,0x40,0x8F,0x41,0x8F,0x41,0x8F,0x9F,0x8F,0x9F,0x41,0x9F,0x40,0x9F,0x50,0xAF,0xBF,0xCF,0xCF,0xCF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xDF,0xDF,0xDF,0xCF,0xBF,0xBF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x41,0x9F,0x8F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0xAF,0xAF,0xAF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xAF,0xAF,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F
.byte 0x50,0x50,0x50,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x60,0x9F,0x50,0x50,0x50,0x9F,0x60,0x50,0x50,0x60,0x50,0x50,0x50,0x40,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x40,0x8F,0x40,0x9F,0x50,0x50,0x50,0x50,0x50,0x9F,0x40,0x9F,0x8F,0x8F,0x8F,0x9F,0x41,0x9F,0x9F,0x9F,0x51,0x9F,0x50,0xAF,0xBF,0xBF,0xCF,0xCF,0xCF,0xDF,0xDF,0xDF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xFD,0xEF,0xDF,0xCF,0xCF,0xBF,0xAF,0xAF,0xAF,0x9F,0x51,0x9F,0x9F,0x41,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x8F,0x9F,0x41,0x9F,0x9F,0x8F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0xAF,0xAF,0xAF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0xAF,0x9F,0xAF,0xAF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xAF,0xAF,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F
.byte 0x50,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x50,0x9F,0x60,0x50,0x50,0x50,0x50,0x60,0x50,0x60,0x50,0x50,0x50,0x50,0x9F,0x40,0x8F,0x8F,0x8F,0x7F,0x8F,0x8F,0x8F,0x40,0x40,0x50,0x50,0x50,0x50,0x50,0x50,0x40,0x9F,0x40,0x8F,0x41,0x9F,0x8F,0x9F,0x41,0x9F,0x40,0x9F,0x50,0x50,0xAF,0x70,0xBF,0xCF,0xCF,0xDF,0xDF,0xDF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xFF,0xEF,0xFF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xDF,0xDF,0xCF,0xCF,0xBF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0xAF,0xAF,0xBF,0xAF,0xBF,0xAF,0xBF,0xAF,0xAF,0xAF,0xAF,0x9F,0xAF,0xAF,0xAF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F
.byte 0x50,0x50,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x60,0x50,0x60,0x50,0x50,0x60,0x50,0x50,0x60,0x9F,0x60,0x50,0x50,0x50,0x40,0x8F,0x40,0x8F,0x8F,0x7F,0x8F,0x8F,0x40,0x40,0x9F,0x50,0x50,0x50,0x50,0x50,0x9F,0x40,0x9F,0x8F,0x8F,0x9F,0x8F,0x41,0x9F,0x9F,0x51,0x9F,0x50,0x50,0xAF,0x70,0xBF,0xCF,0xCF,0xCF,0xDF,0xDF,0xDF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xFF,0xEF,0xEF,0xFF,0xEF,0xFF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xDF,0xDF,0xCF,0xCF,0xBF,0xAF,0xAF,0xAF,0x9F,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x8F,0x9F,0x8F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0xAF,0xAF,0xBF,0xAF,0xBF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0xAF,0xAF,0xAF,0xBF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xBF,0xCF,0xBF,0xBF,0xAF,0xAF,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F
.byte 0x50,0x50,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x50,0x50,0x60,0x50,0x50,0x9F,0x60,0x60,0x50,0x60,0x50,0x50,0x50,0x9F,0x40,0x8F,0x8F,0x7F,0x8F,0x8F,0x8F,0x40,0x40,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x9F,0x40,0x8F,0x41,0x9F,0x9F,0x9F,0x41,0x9F,0x50,0x9F,0x50,0x60,0xAF,0xAF,0xBF,0xCF,0xCF,0xDF,0xDF,0xDF,0xDF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xFF,0xFF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xDF,0xDF,0xDF,0xCF,0xBF,0xBF,0xAF,0xAF,0x9F,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x51,0x9F,0x62,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x51,0x9F,0x41,0x8F,0x8F,0x41,0x8F,0x8F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0xAF,0xAF,0xAF,0xBF,0xAF,0xBF,0xAF,0xAF,0xAF,0x9F,0xAF,0x9F,0xAF,0xAF,0xAF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F
.byte 0x50,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x60,0x50,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x50,0x50,0x40,0x8F,0x40,0x8F,0x8F,0x8F,0x8F,0x40,0x8F,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x9F,0x40,0x9F,0x8F,0x8F,0x41,0x9F,0x41,0x9F,0x50,0x9F,0x50,0x50,0xAF,0x60,0xBF,0xBF,0xCF,0xCF,0xDF,0xDF,0xDF,0xDF,0xF5,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xFF,0xEF,0xFF,0xEF,0xFF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xDF,0xDF,0xDF,0xCF,0xCF,0xBF,0xBF,0xAF,0xAF,0xAF,0x51,0x9F,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x62,0x62,0xD6,0xC4,0x73,0xC5,0xC4,0xC4,0xC4,0x73,0xC4,0xC4,0xC4,0x73,0xC5,0x62,0x73,0x62,0x52,0x73,0x62,0x52,0x52,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0xAF,0xAF,0xAF,0xAF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x8F,0x7F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x8F
.byte 0x50,0x50,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x60,0x50,0x60,0x50,0x60,0x50,0x9F,0x60,0x50,0x60,0x60,0x50,0x50,0x9F,0x50,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x40,0x40,0x9F,0x50,0x50,0x60,0x50,0x50,0x50,0x50,0x9F,0x41,0x8F,0x9F,0x9F,0x9F,0x9F,0x50,0x9F,0x50,0x50,0x60,0xAF,0x70,0xBF,0x71,0xCF,0xCF,0xDF,0xDF,0xDF,0xDF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xFF,0xEF,0xFF,0xEF,0xFF,0xFF,0xFF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xDF,0xDF,0xDF,0xDF,0xCF,0xCF,0xBF,0xBF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0xAF,0x9F,0x9F,0xAF,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x41,0x9F,0x62,0xD5,0xD5,0xC5,0xB4,0xC5,0xC5,0xB4,0xC5,0xC4,0xC5,0xC4,0xC5,0xC4,0xD5,0xC5,0xB4,0xC5,0xD5,0xC4,0xD6,0xC5,0xC5,0xC5,0xC5,0xB4,0xB4,0x73,0x73,0x73,0x62,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0xAF,0xAF,0xAF,0xBF,0xAF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F
.byte 0x50,0x9F,0x50,0x50,0x9F,0x50,0x9F,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x60,0x50,0x60,0x50,0x50,0x50,0x40,0x9F,0x40,0x8F,0x8F,0x8F,0x40,0x8F,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x9F,0x50,0x9F,0x8F,0x41,0x8F,0x41,0x9F,0x41,0x9F,0x50,0x50,0x9F,0x60,0xAF,0x70,0xBF,0xCF,0xCF,0xCF,0xDF,0xDF,0xDF,0xF4,0xDF,0xDF,0xEF,0xDF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xFF,0xEF,0xFF,0xEF,0xFF,0xEF,0xFF,0xEF,0xEF,0xEF,0xDF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xBF,0xBF,0xAF,0xAF,0xAF,0x9F,0xAF,0x9F,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x62,0xD5,0xC4,0xC5,0xB4,0xC5,0xB4,0xC5,0xB4,0xC5,0xC5,0xB4,0xC5,0xB4,0xC5,0xB4,0xC5,0xB4,0xC5,0xB4,0xC5,0xB4,0xC5,0x94,0xC5,0x84,0x84,0xC5,0xC5,0xC5,0xC5,0xC5,0xC4,0xC4,0xC4,0x73,0x73,0xAF,0x9F,0x9F,0x9F,0xAF,0x9F,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0xAF,0xAF,0xAF,0xAF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x8F,0x8F,0x7F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F
.byte 0x50,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0xAF,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x9F,0x60,0x60,0x50,0x50,0x9F,0x50,0x8F,0x8F,0x8F,0x8F,0x8F,0x40,0x9F,0x50,0x50,0x50,0x60,0x50,0x60,0x50,0x50,0x9F,0x40,0x9F,0x8F,0x9F,0x9F,0x9F,0x50,0x9F,0x50,0x50,0x60,0xAF,0x70,0xBF,0xBF,0xBF,0xCF,0xCF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xFF,0xFF,0xEF,0xFF,0xEF,0xFF,0xEF,0xEF,0xEF,0xDF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0xAF,0x9F,0x9F,0xAF,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x62,0xD5,0xC4,0xC5,0xC4,0xC5,0xC5,0xC5,0xB4,0xC5,0xC5,0xB4,0xC5,0xB4,0xC5,0x84,0xC5,0x84,0xC5,0xC5,0x84,0xC5,0x84,0xC5,0x84,0xC5,0x84,0xC5,0x74,0x74,0x84,0x84,0x84,0xC5,0xB4,0xC4,0xC5,0xC5,0xC5,0xB4,0x73,0x62,0xAF,0x9F,0x9F,0x9F,0x9F,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F,0x8F
.byte 0x50,0x50,0x50,0x9F,0x50,0x9F,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x9F,0x60,0x60,0x60,0x60,0x50,0x60,0x50,0x50,0x9F,0x40,0x8F,0x8F,0x8F,0x8F,0x40,0x40,0x50,0x50,0x60,0x50,0x60,0x50,0x9F,0x50,0x9F,0x41,0x8F,0x41,0x8F,0x41,0x9F,0x50,0x50,0x50,0xAF,0x60,0xAF,0xBF,0x70,0xBF,0x71,0xCF,0xCF,0xCF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xEF,0xEF,0xEF,0xEF,0xEF,0xFF,0xEF,0xFF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0xAF,0x73,0xD5,0xC5,0xC5,0xC5,0xC5,0xC5,0xB4,0xC5,0xC5,0xC5,0x84,0xC5,0x84,0xC5,0xC5,0x84,0xC5,0x84,0xC5,0x94,0xC5,0x84,0xC5,0x84,0xC5,0xC5,0x84,0xC5,0x84,0xC5,0xC5,0x84,0xC5,0xC5,0x74,0xC5,0x84,0xC5,0x84,0xC5,0x84,0xC5,0xC5,0x84,0xC5,0x73,0xAF,0xAF,0x9F,0x9F,0x9F,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0x9F,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x41,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F
.byte 0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x60,0x50,0x50,0x9F,0x50,0x40,0x8F,0x8F,0x8F,0x8F,0x40,0x9F,0x50,0x9F,0x50,0x60,0x50,0x50,0x50,0x50,0x40,0x9F,0x40,0x9F,0x8F,0x9F,0x9F,0x50,0x9F,0x50,0x50,0x60,0xAF,0x70,0xBF,0xBF,0xBF,0xBF,0xCF,0xCF,0xDF,0xCF,0xDF,0xCF,0xDF,0xCF,0xDF,0xCF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xDF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0xAF,0x9F,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0xC4,0xC5,0xC5,0xC5,0xB4,0x84,0xC5,0x84,0xC5,0xC5,0x84,0xC5,0xC5,0x84,0x74,0xC5,0x84,0xC5,0x84,0xC5,0x74,0xC5,0x74,0x74,0xC5,0x84,0xC5,0x84,0xC5,0x84,0xC5,0x84,0xC5,0x84,0x74,0x74,0xC5,0x74,0x74,0xC5,0xB4,0x84,0xC5,0x94,0xC5,0xB4,0xC5,0x74,0xC5,0x74,0x84,0x73,0x52,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F
.byte 0x50,0x50,0x9F,0x50,0x9F,0x60,0x9F,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x9F,0x60,0x60,0x50,0x60,0x50,0x50,0x9F,0x40,0x9F,0x8F,0x8F,0x8F,0x40,0x9F,0x50,0x50,0x60,0x50,0x60,0x50,0x50,0x9F,0x50,0x9F,0x8F,0x41,0x9F,0x41,0x9F,0x50,0x50,0x50,0x60,0xAF,0x70,0xBF,0x70,0xBF,0x71,0xBF,0xCF,0xCF,0xF4,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xDF,0xCF,0xDF,0xDF,0xDF,0xDF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xDF,0xEF,0xDF,0xDF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0xAF,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x52,0xD5,0xC5,0xB4,0xC5,0x84,0xC5,0xC5,0x74,0xC5,0x84,0xC5,0x84,0xC5,0xB4,0xC5,0xC5,0xC5,0xC5,0x84,0xC5,0x74,0xC5,0x74,0xC5,0x74,0x74,0xC5,0x84,0xC5,0x84,0x74,0xC5,0x84,0xC5,0x74,0xC5,0x74,0x74,0xC5,0x74,0xC5,0xC5,0xC4,0xC4,0xC4,0xB4,0xC5,0x94,0xC5,0x84,0xC5,0x74,0xC5,0x74,0xC5,0x73,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x41,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x8F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F,0x7F,0x7F
.byte 0x50,0x50,0x50,0x9F,0x50,0x9F,0x60,0x9F,0x60,0x50,0x60,0x50,0x60,0x60,0x60,0x60,0x60,0x60,0x50,0x60,0x50,0x50,0x9F,0x40,0x8F,0x8F,0x40,0x9F,0x40,0x50,0x50,0x50,0x60,0x50,0x60,0x50,0x50,0x40,0x9F,0x41,0x9F,0x8F,0x40,0x9F,0x50,0x9F,0x50,0x60,0xAF,0x70,0xBF,0xBF,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xDF,0xDF,0xF3,0xF3,0xEF,0xF3,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xEF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xBF,0xCF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x62,0xD5,0xC4,0xC5,0xC5,0xC5,0xC5,0x84,0xC5,0x74,0xC5,0xC5,0x63,0xC5,0x84,0xC5,0xC5,0xB4,0xC5,0xC5,0xC5,0x84,0xC5,0x84,0xC5,0x84,0xC5,0xC5,0x84,0xC5,0x84,0xC5,0x74,0x74,0xC5,0x63,0xC5,0x74,0x74,0x74,0x74,0x74,0x74,0x74,0xC5,0x84,0xC5,0x84,0xC5,0x84,0xC5,0x84,0x84,0x74,0xC5,0xC5,0xC5,0x84,0x84,0xC5,0x52,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x41,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F
.byte 0x50,0x9F,0x50,0x9F,0x50,0x50,0x9F,0x60,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x9F,0x50,0x8F,0x8F,0x8F,0x8F,0x40,0x9F,0x50,0x9F,0x60,0x60,0x50,0x60,0x50,0x50,0x9F,0x40,0x8F,0x8F,0x41,0x9F,0x50,0x9F,0x50,0x50,0x60,0x60,0xAF,0x70,0xBF,0x70,0xBF,0x71,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xCF,0xCF,0xE3,0xF3,0xEF,0xF2,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x62,0xD5,0xC5,0xC4,0xC5,0x63,0xC5,0x63,0xC5,0x74,0x74,0xC5,0x63,0xC5,0xC5,0x63,0xC5,0x63,0xC5,0x74,0xC5,0x84,0x84,0xC5,0x74,0xC5,0x74,0xC5,0x84,0xC5,0x84,0xC5,0x74,0x74,0xC5,0x63,0x74,0x74,0xC5,0x74,0xC5,0x74,0xC5,0x74,0xC5,0x84,0xC5,0xC5,0xB4,0xC5,0xC5,0x84,0xC5,0x84,0xC5,0x74,0x74,0x84,0xC5,0x74,0x74,0x74,0xC5,0x73,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F,0x7F
.byte 0x50,0x50,0x50,0x9F,0x50,0x9F,0x60,0x50,0x60,0x50,0x60,0x60,0x9F,0x60,0x50,0x60,0x60,0x60,0x50,0x50,0x50,0x9F,0x40,0x9F,0x40,0x8F,0x9F,0x40,0x50,0x50,0x50,0x60,0x50,0x60,0x50,0x50,0x40,0x9F,0x40,0x8F,0x9F,0x40,0x9F,0x50,0x50,0x50,0x60,0xAF,0x70,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xCF,0xBF,0xBF,0xBF,0x71,0xCF,0xCF,0xE3,0xDF,0xF2,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF3,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xBF,0xAF,0xAF,0xAF,0x51,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x62,0xD5,0xC5,0xC4,0xC5,0x63,0xC5,0x63,0x74,0x74,0xC5,0x63,0xC5,0x74,0x63,0xC5,0x74,0x63,0xC5,0x63,0x74,0xC5,0xC5,0x63,0x74,0xC5,0x63,0x74,0xC5,0x63,0xC5,0x74,0xC5,0x63,0x74,0x74,0xC5,0x63,0xC5,0x63,0x74,0x74,0x74,0x74,0x74,0x74,0xC5,0xC4,0xD5,0xC4,0xD5,0xD5,0xD5,0xC4,0xC5,0x74,0xC5,0x74,0xC5,0x74,0x74,0xC5,0x63,0x74,0xC5,0x62,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F
.byte 0x50,0x9F,0x50,0x9F,0x60,0x50,0x9F,0x60,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x60,0x60,0x50,0x60,0x50,0x9F,0x50,0x9F,0x8F,0x8F,0x40,0x9F,0x50,0x9F,0x60,0x60,0x50,0x60,0x50,0x50,0x9F,0x40,0x8F,0x8F,0x41,0x9F,0x40,0x9F,0x50,0x50,0x50,0x60,0xAF,0x70,0xBF,0x70,0xBF,0xBF,0xBF,0xBF,0x71,0xBF,0xBF,0xBF,0x71,0xBF,0xCF,0xCF,0xE3,0xEF,0xF2,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xDF,0xDF,0xCF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xBF,0xBF,0xAF,0xAF,0xAF,0x9F,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x62,0xD5,0xC5,0x63,0xC5,0x63,0xC5,0x63,0x74,0x64,0xC5,0x63,0xC5,0x63,0xC5,0x63,0x74,0xC5,0x63,0x64,0x74,0x63,0x63,0xC5,0x63,0x63,0x63,0xC5,0x43,0x64,0x63,0x74,0x63,0xC5,0x63,0xC5,0x43,0x74,0x74,0x63,0x74,0xC5,0x63,0xC5,0x63,0xC5,0x74,0xC5,0xC4,0xD5,0xD5,0xE5,0xE5,0xD5,0xC4,0xC5,0x74,0x74,0x74,0x74,0xC5,0x63,0x74,0xC5,0x63,0xC5,0x73,0x63,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F
.byte 0x50,0x50,0x50,0x9F,0x50,0x9F,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x60,0x50,0x50,0x50,0x9F,0x40,0x8F,0x9F,0x8F,0x50,0x9F,0x50,0x50,0x60,0x60,0x50,0x60,0x50,0x50,0x9F,0x40,0x8F,0x40,0x9F,0x40,0x50,0x50,0x50,0x60,0x60,0xAF,0x70,0xBF,0xBF,0x71,0xBF,0xBF,0xBF,0xAF,0xBF,0x61,0xBF,0xBF,0x71,0xCF,0xDF,0xF3,0xEF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF3,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xBF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x62,0xD5,0xC5,0x63,0xC5,0x63,0xC5,0x43,0x63,0x63,0xC5,0x43,0x64,0x63,0xC5,0x63,0x74,0x43,0x63,0xC5,0x43,0x63,0xC5,0x43,0x63,0x63,0x63,0x55,0x63,0x63,0x64,0x63,0xC5,0x63,0x43,0x63,0x63,0x64,0xC5,0x63,0x64,0x63,0x63,0x74,0x63,0x74,0x64,0xC5,0xC4,0xD5,0xC5,0xD4,0xF5,0xF5,0xD5,0xC5,0x84,0xC5,0xC5,0xC5,0x74,0x74,0xC5,0x63,0x74,0x63,0x74,0xC5,0x73,0xC5,0x63,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F,0x8F
.byte 0x50,0x9F,0x50,0x50,0x9F,0x60,0x9F,0x60,0x60,0x50,0x60,0x60,0x50,0x60,0x60,0x60,0x50,0x60,0x50,0x50,0x9F,0x40,0x9F,0x40,0x8F,0x9F,0x50,0x50,0x9F,0x60,0x50,0x60,0x50,0x50,0x9F,0x40,0x40,0x8F,0x40,0x9F,0x40,0x9F,0x50,0x50,0x50,0x60,0x60,0xAF,0x70,0xBF,0xBF,0xBF,0xBF,0x61,0xBF,0x61,0xBF,0xAF,0x61,0xBF,0xCF,0xDF,0xF3,0xF2,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF2,0xEF,0xDF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xBF,0xAF,0xBF,0xBF,0xAF,0xAF,0x51,0xAF,0x51,0x9F,0x51,0x9F,0x51,0x9F,0x51,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0xD5,0xC4,0xC5,0x63,0x43,0x63,0x43,0x43,0x55,0x63,0x63,0x64,0x63,0x64,0x63,0x64,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x63,0xC5,0x43,0x63,0xC5,0x63,0xC5,0x63,0xC5,0x63,0xC5,0x43,0x63,0x43,0x63,0xC5,0x64,0x74,0x63,0x64,0xC5,0x43,0x64,0x63,0xC5,0xC4,0xD5,0xE6,0xE5,0xD5,0x94,0xC5,0xC5,0x84,0xC5,0x84,0xC5,0x63,0x74,0xC5,0x63,0xC5,0x43,0x63,0x63,0x63,0xC5,0x73,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x41,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F
.byte 0x50,0x50,0x9F,0x60,0x9F,0x60,0x50,0x60,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x60,0x60,0x50,0x60,0x50,0x50,0x9F,0x40,0x9F,0x40,0x9F,0x9F,0x50,0x50,0x60,0x60,0x60,0x60,0x50,0x50,0x9F,0x40,0x8F,0x8F,0x40,0x9F,0x50,0x50,0x50,0x60,0x60,0xAF,0x60,0xAF,0x70,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0x61,0xAF,0xBF,0xCF,0xE3,0xDF,0xF3,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xDF,0xCF,0xCF,0xCF,0xCF,0xDF,0xDF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xBF,0xAF,0xAF,0xAF,0x9F,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x73,0xC5,0x63,0x63,0x43,0x43,0x43,0x43,0x43,0x43,0x55,0x43,0x55,0x43,0x43,0x55,0x43,0x43,0x43,0x63,0x43,0x42,0x43,0x43,0x43,0x43,0x43,0x43,0x63,0x63,0x43,0x63,0x63,0x63,0x43,0x63,0x43,0x43,0x43,0x43,0x43,0x43,0x63,0xC5,0x43,0x63,0x63,0x43,0x43,0x63,0xC5,0xC4,0xD5,0xC4,0xC5,0x84,0xC5,0x84,0xC5,0x74,0xC5,0x63,0x74,0x63,0x63,0x74,0x63,0x74,0x63,0xC5,0x73,0x63,0x73,0x9F,0x9F,0x9F,0x9F,0xAF,0x9F,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x41,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F
.byte 0x50,0x9F,0x50,0x50,0x9F,0x60,0x9F,0x60,0x50,0x60,0x60,0x50,0x60,0x50,0x60,0x9F,0x60,0x60,0x9F,0x50,0x9F,0x40,0x9F,0x8F,0x9F,0x40,0x50,0x9F,0x60,0x50,0x60,0x50,0x50,0x50,0x50,0x40,0x9F,0x40,0x9F,0x40,0x9F,0x50,0x50,0x50,0x50,0x60,0x60,0xAF,0x70,0xBF,0xBF,0x61,0xBF,0x61,0xAF,0x61,0xAF,0x70,0xCF,0xCF,0xDF,0xF3,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF3,0xDF,0xDF,0xCF,0xCF,0xCF,0xDF,0xDF,0xDF,0xDF,0xDF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0xAF,0x51,0xAF,0x51,0x9F,0x51,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0x73,0xC5,0x63,0x63,0x43,0x43,0x42,0x45,0x45,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x42,0x42,0x43,0x42,0x43,0x42,0x43,0x43,0x43,0x43,0x43,0x43,0x45,0x43,0x43,0x43,0x63,0x63,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x63,0x63,0x43,0xC5,0xC5,0x73,0xC5,0x84,0x74,0x74,0x63,0x74,0x64,0x74,0xC5,0x63,0x74,0x63,0x74,0x63,0xC5,0x63,0xC5,0xC5,0x63,0x73,0x52,0xAF,0x9F,0xAF,0x9F,0xAF,0x9F,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F
.byte 0x50,0x50,0x9F,0x60,0x50,0x9F,0x60,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x50,0x50,0x9F,0x40,0x9F,0x40,0x9F,0x50,0x50,0x60,0x60,0x60,0x60,0x50,0x9F,0x50,0x9F,0x40,0x8F,0x40,0x9F,0x50,0x50,0x50,0x60,0x50,0x60,0x60,0xAF,0xAF,0x61,0xBF,0xBF,0xAF,0xAF,0xAF,0x60,0xAF,0xBF,0xCF,0xE3,0xF3,0xEF,0xF1,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF1,0xEF,0xDF,0xDF,0xCF,0xCF,0xCF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x62,0xC5,0x63,0x43,0x43,0x45,0x43,0x45,0x43,0x45,0x43,0x45,0x45,0x43,0x43,0x43,0x43,0x43,0x43,0x42,0x42,0x42,0x42,0x43,0x43,0xC5,0x9F,0x63,0x9F,0x43,0x42,0x43,0x42,0x43,0xBB,0xD5,0xAF,0x43,0x43,0x43,0x43,0x45,0x42,0x42,0x42,0x45,0x43,0x43,0x43,0x43,0x43,0x43,0x63,0x63,0x63,0xC5,0x43,0x63,0x63,0x64,0x64,0x63,0x74,0x63,0xC5,0x63,0xC5,0xC5,0x63,0xC5,0x63,0xC5,0x73,0x73,0xC5,0x63,0x73,0xAF,0x9F,0xAF,0x9F,0xAF,0xAF,0x9F,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F
.byte 0x50,0x9F,0x60,0x9F,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x60,0x50,0x60,0x60,0x50,0x50,0x9F,0x50,0x9F,0x40,0x9F,0x9F,0x50,0x9F,0x50,0x60,0x9F,0x60,0x50,0x60,0x50,0x9F,0x40,0x8F,0x40,0x9F,0x40,0x50,0x50,0x50,0x50,0x60,0x50,0xAF,0x60,0xAF,0xAF,0x61,0xAF,0x61,0xAF,0x60,0xAF,0x71,0xCF,0xDF,0xDF,0xF2,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF2,0xDF,0xDF,0xCF,0xCF,0xCF,0xCF,0xDF,0xDF,0xF3,0xDF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0x61,0x9F,0x51,0xAF,0x51,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0x9F,0x73,0x43,0x45,0x43,0x42,0x45,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x43,0x42,0x45,0x42,0x42,0x42,0x42,0x42,0xEA,0x52,0xD5,0xAF,0xD5,0xD5,0xD5,0x42,0x52,0xE6,0xF5,0xF5,0xCF,0xE5,0xBF,0xD5,0x52,0x42,0x42,0x47,0x42,0x45,0x42,0x42,0x42,0x45,0x42,0x43,0x43,0x43,0x43,0x43,0x43,0x64,0xC5,0x63,0xC5,0xC5,0x63,0xC5,0x63,0xC5,0x63,0x63,0xC5,0xC5,0x63,0xC5,0x43,0x63,0x74,0x63,0xC5,0x63,0x73,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F
.byte 0x50,0x50,0x50,0x50,0x9F,0x60,0x9F,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x60,0x60,0x50,0x60,0x50,0x50,0x9F,0x40,0x9F,0x40,0x9F,0x50,0x9F,0x60,0x60,0x60,0x60,0x50,0x50,0x50,0x40,0x9F,0x40,0x9F,0x40,0x9F,0x50,0x50,0x50,0x60,0x50,0x60,0x60,0xAF,0x60,0xAF,0xAF,0x60,0xAF,0xAF,0x60,0xAF,0xCF,0xCF,0xE3,0xEF,0xF2,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF1,0xF2,0xDF,0xDF,0xCF,0xCF,0xCF,0xDF,0xDF,0xDF,0xF3,0xDF,0xF3,0xDF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x63,0x43,0x43,0x45,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x48,0x42,0xD5,0xD5,0xE5,0xD5,0xE5,0x62,0xE5,0xCF,0x73,0x42,0xE6,0xF5,0xCF,0xCF,0xF5,0xCF,0xBF,0xBF,0xEB,0xE5,0xCF,0xD5,0x42,0x42,0x42,0x47,0x42,0x43,0x43,0x43,0x43,0x43,0x43,0x63,0xC5,0x63,0xC5,0x63,0xC5,0x63,0xC5,0x73,0xC5,0x73,0xC5,0xC4,0x73,0xC5,0x73,0x63,0x64,0x55,0x43,0x43,0x63,0x63,0x63,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x8F,0x41,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x8F,0x7F
.byte 0x50,0x9F,0x50,0xAF,0x50,0x60,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x9F,0x50,0x9F,0x40,0x9F,0x9F,0x50,0x9F,0x50,0x60,0x50,0x60,0x50,0x60,0x9F,0x50,0x9F,0x40,0x9F,0x40,0x40,0x50,0x50,0x50,0x60,0x50,0x50,0x60,0x9F,0x60,0xAF,0x60,0xAF,0xAF,0x60,0xAF,0x60,0xBF,0xCF,0xDF,0xF3,0xEF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF1,0xFF,0xEF,0xF3,0xDF,0xCF,0xCF,0xCF,0xCF,0xDF,0xDF,0xF3,0xEF,0xEF,0xEF,0xF3,0xDF,0xDF,0xDF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0x61,0x9F,0x51,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x51,0x9F,0x51,0x9F,0x51,0x9F,0x9F,0x52,0x63,0x43,0x43,0x42,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x47,0x52,0x42,0xAF,0xD5,0xBF,0xE5,0xAF,0xD5,0xAF,0xE5,0xD5,0xAF,0xD5,0xBF,0xE5,0xCF,0xBF,0xAF,0x9F,0xAF,0xAF,0xCF,0xE5,0xF5,0xF5,0xF5,0xE5,0x52,0x52,0x52,0x45,0x42,0x43,0x43,0xC5,0x63,0xC5,0x73,0xC5,0x63,0xC5,0x73,0xC5,0x73,0xC5,0x73,0xC5,0x63,0xC5,0x63,0xC5,0x63,0xC5,0xC5,0x63,0x63,0x55,0xC5,0xC5,0x63,0x63,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x7F,0x8F
.byte 0x50,0x50,0x50,0x60,0x9F,0x60,0x9F,0x60,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x60,0x50,0x60,0x50,0x50,0x9F,0x40,0x9F,0x40,0x9F,0x50,0x9F,0x60,0x60,0x60,0x50,0x60,0x50,0x50,0x40,0x9F,0x40,0x9F,0x50,0x9F,0x50,0x60,0x50,0x60,0x50,0x50,0x60,0xAF,0x60,0x9F,0x60,0x9F,0x60,0x60,0xBF,0x71,0xCF,0xDF,0xF2,0xF2,0xFF,0xF1,0xFF,0xFF,0xFF,0xFF,0xF1,0xFF,0xF2,0xF3,0xDF,0xDF,0xCF,0xCF,0xCF,0xCF,0xDF,0xDF,0xF3,0xEF,0xF3,0xEF,0xF3,0xDF,0xF3,0xDF,0xDF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0x9F,0x9F,0x9F,0x9F,0xAF,0x62,0x43,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x42,0x42,0x4A,0x42,0x42,0x42,0x42,0xAF,0xD5,0xE5,0xAF,0xD5,0xD5,0xE5,0xBF,0xD5,0xAF,0x73,0xD5,0x52,0xAF,0xF5,0xCF,0xAF,0x8F,0x7F,0x8F,0xBF,0xBF,0xCF,0xDF,0xEF,0xF5,0xD5,0xD5,0xD5,0x52,0x63,0x63,0xC5,0x63,0x63,0xC5,0x63,0xC5,0x73,0xC5,0x63,0xC5,0x73,0xC5,0x73,0xC5,0x73,0xC5,0x63,0xC5,0x73,0xC5,0x73,0x73,0xC5,0x43,0xC5,0x43,0x63,0xC5,0x63,0x63,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F
.byte 0x50,0x9F,0x50,0x9F,0x60,0x50,0x60,0x50,0x60,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x50,0x9F,0x60,0x50,0x60,0x60,0x50,0x50,0x9F,0x50,0x9F,0x40,0x9F,0x40,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x60,0x9F,0x50,0xAF,0xBF,0xCF,0xDF,0xF3,0xEF,0xFF,0xFF,0xFF,0xFF,0xF1,0xFF,0xF2,0xFF,0xF2,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xCF,0xE3,0xDF,0xF3,0xEF,0xEF,0xEF,0xF3,0xEF,0xEF,0xDF,0xDF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0xAF,0x51,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0x51,0x9F,0x51,0x9F,0x51,0x9F,0x51,0x9F,0x51,0x9F,0x9F,0x9F,0x52,0x42,0x42,0x42,0x4A,0x42,0x42,0x6F,0x42,0x7F,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x52,0xBF,0xE5,0xBF,0xBF,0xE5,0xE5,0x42,0xD5,0xBF,0xD5,0xBF,0xE5,0xDF,0xCF,0xAF,0x8F,0x6F,0x9F,0xBF,0xBF,0xE5,0xF5,0xF5,0xAF,0x73,0x52,0x63,0xD6,0xC5,0x63,0xD6,0x63,0xC5,0x63,0xC5,0x63,0xC5,0x73,0xC5,0x63,0xC5,0x73,0xC5,0x73,0xC5,0x73,0xC5,0x63,0xC5,0xC4,0xD5,0x73,0x63,0x63,0x63,0xC5,0x43,0x43,0xC5,0x63,0x63,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x41,0x8F,0x8F,0x7F,0x8F,0x8F,0x7F,0x8F,0x7F
.byte 0x50,0x50,0x60,0x50,0x9F,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x60,0x50,0x50,0x9F,0x50,0x9F,0x40,0x9F,0x50,0x50,0x9F,0x60,0x60,0x50,0x60,0x50,0x50,0x40,0x9F,0x50,0x50,0xAF,0x60,0xAF,0x70,0xBF,0x70,0xAF,0x70,0x60,0xAF,0x60,0x9F,0x50,0x9F,0x50,0x60,0xAF,0xCF,0xCF,0xF3,0xEF,0xF2,0xFF,0xF1,0xFF,0xF2,0xFF,0xF2,0xEF,0xF3,0xEF,0xDF,0xCF,0xCF,0xCF,0xCF,0xCF,0xDF,0xDF,0xDF,0xEF,0xF3,0xEF,0xF2,0xEF,0xF3,0xDF,0xDF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xBF,0x61,0xAF,0xAF,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0xAF,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0xAF,0xD5,0x42,0x7F,0x42,0x9F,0x42,0x42,0x42,0x42,0x52,0xAF,0xD5,0xE5,0xF5,0xAF,0xD5,0xAF,0xD5,0xF5,0xBF,0xD5,0xE5,0xDF,0xBF,0xBF,0xAF,0x9F,0xAF,0xBF,0xCF,0xDF,0xF5,0xAF,0x63,0xD5,0x63,0xE6,0xE5,0x73,0x63,0xC5,0x73,0xC5,0x63,0xC5,0x73,0xC5,0x73,0xC5,0x73,0xC5,0x73,0xC5,0x73,0xC5,0x73,0xC5,0x73,0xC5,0x73,0xC5,0xC5,0xD5,0xC5,0x63,0x63,0xC5,0x43,0x63,0x63,0xC5,0x62,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F
.byte 0x50,0x9F,0x50,0x60,0x50,0xAF,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x9F,0x50,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x60,0x60,0x50,0x60,0x50,0x50,0x9F,0x9F,0x60,0xAF,0xBF,0x61,0xBF,0x80,0xCF,0x71,0x71,0xBF,0x80,0xCF,0x80,0xCF,0xCF,0x80,0xBF,0x60,0x50,0xAF,0x70,0xCF,0xDF,0xF3,0xEF,0xF2,0xFF,0xFF,0xF2,0xFF,0xF3,0xEF,0xF3,0xDF,0xDF,0xCF,0xCF,0x71,0xCF,0xCF,0xDF,0xDF,0xF3,0xEF,0xF2,0xEF,0xF2,0xEF,0xEF,0xF3,0xDF,0xCF,0xBF,0xBF,0x71,0xBF,0xBF,0xBF,0xBF,0xBF,0x61,0xAF,0xAF,0xAF,0xAF,0x60,0xAF,0x51,0x9F,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0x51,0x9F,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x52,0xBF,0xAF,0xD5,0xAF,0xD5,0xBF,0xBF,0xE5,0xBF,0x52,0x42,0x42,0x42,0x42,0x42,0xBB,0x62,0x52,0x9F,0xF6,0xE5,0x52,0xE5,0xE5,0xE5,0xBF,0xE5,0xCF,0xE5,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xE5,0xDF,0xD5,0x52,0xE6,0xD5,0xD5,0xE5,0xD5,0x73,0xD5,0x63,0x63,0xC5,0x63,0xC5,0x63,0xC5,0x63,0xC5,0x63,0xC5,0x63,0xC5,0x73,0xC5,0x73,0xC5,0x63,0xC5,0x63,0xC5,0x73,0xC5,0xC4,0xC5,0xC5,0x63,0x63,0x63,0x63,0x63,0x63,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F
.byte 0x50,0x50,0x9F,0x60,0x50,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x50,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x60,0x9F,0x60,0x9F,0x50,0xAF,0xAF,0x9F,0x9F,0x40,0x9F,0x61,0xAF,0x70,0xAF,0x70,0x71,0x70,0x71,0x70,0x70,0x70,0xCF,0xD0,0xCF,0x80,0xBF,0xCF,0xDF,0xF3,0xEF,0xF2,0xFF,0xF2,0xEF,0xF3,0xEF,0xF3,0xDF,0xDF,0xCF,0xCF,0x71,0xBF,0xCF,0xCF,0xDF,0xE3,0xDF,0xF3,0xEF,0xFF,0xFF,0xF2,0xEF,0xF3,0xDF,0xCF,0xBF,0x71,0xBF,0xBF,0xBF,0x61,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0x61,0xAF,0xAF,0xAF,0xAF,0x50,0x9F,0x51,0x9F,0x51,0x9F,0x51,0xAF,0x9F,0x51,0x9F,0x9F,0x9F,0x51,0x9F,0x51,0x9F,0x9F,0x9F,0xAF,0xF3,0xF3,0xF5,0xF5,0xF5,0xE5,0xBF,0xE5,0xE5,0xBF,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x52,0xD6,0xBF,0xE5,0xE5,0xBF,0xE6,0xBF,0xD5,0xBF,0xE5,0xCF,0xF5,0xDF,0xCF,0xCF,0xCF,0xE5,0xDF,0xE5,0xBF,0xE5,0x73,0xAF,0xD5,0xAF,0xD5,0xE6,0x73,0x63,0xC5,0x63,0x63,0xC5,0x63,0xC5,0x73,0xC5,0x73,0xC5,0x73,0x63,0xC5,0x73,0xC5,0x63,0xC5,0x73,0xC5,0x63,0xC5,0x84,0xC5,0x63,0xC5,0x63,0xC5,0x43,0xC5,0x63,0x63,0x52,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F
.byte 0x50,0x50,0x60,0x9F,0x60,0x9F,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x60,0x50,0x50,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x60,0x60,0x9F,0xBF,0xCF,0xCF,0xAF,0xAF,0x9F,0x9F,0x9F,0x60,0x60,0xAF,0x61,0xAF,0x70,0xBF,0x70,0xBF,0x70,0x71,0xBF,0xBF,0xBF,0x80,0xBF,0x80,0xDF,0xDF,0xF2,0xFF,0xEF,0xF3,0xEF,0xF3,0xDF,0xDF,0xDF,0xCF,0xCF,0xBF,0xBF,0xCF,0xCF,0xDF,0xDF,0xDF,0xEF,0xF2,0xFF,0xF2,0xFF,0xF3,0xDF,0xDF,0xCF,0xBF,0xBF,0xBF,0xBF,0x61,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0x61,0xAF,0xAF,0xAF,0xAF,0x61,0xAF,0x51,0xAF,0x50,0x9F,0x51,0x9F,0x9F,0x51,0x9F,0xAF,0x51,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0xBF,0xFF,0xFF,0xF3,0xEF,0xEF,0xF5,0xF5,0xAF,0xBF,0xE5,0xAF,0x42,0x42,0x4A,0x42,0x42,0x42,0xEA,0xCF,0xE5,0xE5,0xAF,0xE6,0xF5,0xBF,0xE5,0xE5,0xE5,0xE5,0xCF,0xF5,0xF5,0xFA,0xF5,0xDF,0xBF,0xD5,0xE5,0xBF,0xD5,0xE6,0xE5,0xD4,0xE5,0x63,0x63,0xC5,0x63,0xC5,0x63,0xC5,0x63,0xC5,0x73,0xC5,0x63,0x63,0xC5,0x63,0x63,0x63,0x63,0xC5,0x63,0x63,0x63,0xC5,0x63,0xC5,0x63,0x74,0x63,0x63,0x63,0x63,0x63,0x63,0x63,0x73,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F
.byte 0x50,0x9F,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x50,0x60,0x50,0x60,0x50,0x50,0x60,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x60,0x50,0xAF,0xBF,0xEF,0xFF,0xFF,0xFF,0xFF,0xDF,0xAF,0x9F,0x8F,0x40,0x50,0x60,0xAF,0x61,0x60,0x61,0x61,0xAF,0x70,0xBF,0x70,0xAF,0x70,0xBF,0x80,0xBF,0x80,0xDF,0xF3,0xEF,0xF3,0xDF,0xDF,0xDF,0xCF,0xCF,0x71,0xBF,0x71,0xBF,0xCF,0xCF,0xE3,0xDF,0xF3,0xEF,0xFF,0xFF,0xF2,0xEF,0xF3,0xDF,0xCF,0x71,0xBF,0xBF,0x61,0xBF,0xAF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xBF,0xAF,0xAF,0xAF,0x60,0x9F,0x51,0xAF,0x9F,0x60,0x9F,0x51,0x9F,0x51,0x9F,0x51,0x9F,0x51,0x9F,0x51,0x9F,0x9F,0x41,0xCF,0xFF,0xFF,0xFF,0xF3,0xEF,0xEF,0xF5,0xAF,0xAF,0xAF,0xBF,0xAF,0x52,0x42,0x42,0x42,0x42,0xD5,0xBF,0xD5,0xBF,0xD5,0xCF,0xD4,0xE5,0xCF,0xBF,0xD5,0xBF,0xE5,0xBF,0xE5,0xCF,0xE5,0xBF,0xD5,0xBF,0xE5,0xE5,0xE5,0xAF,0xD5,0xD5,0xD5,0xD5,0x63,0x63,0x63,0xC5,0x63,0x63,0x63,0x63,0x63,0xC5,0x73,0x63,0x63,0xC5,0x63,0xC5,0x73,0xC5,0xC5,0xC5,0x63,0x63,0x63,0x63,0xC5,0x63,0xC5,0x43,0x64,0x63,0xC5,0x63,0xC5,0x73,0x62,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F
.byte 0x50,0x50,0x9F,0x60,0x9F,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x50,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x60,0xAF,0xDF,0xCF,0xAF,0xCF,0xFF,0xFF,0xFF,0xFF,0xF4,0xCF,0xAF,0x9F,0x50,0x60,0xAF,0x60,0xAF,0x60,0x61,0x70,0x61,0x70,0xAF,0x60,0xAF,0x70,0x70,0xBF,0x80,0xCF,0xDF,0xDF,0xDF,0xDF,0xCF,0x71,0xBF,0xBF,0xBF,0xBF,0xCF,0xDF,0xDF,0xDF,0xF2,0xEF,0xF1,0xFF,0xF2,0xEF,0xF3,0xDF,0xCF,0xBF,0xBF,0x70,0xBF,0xAF,0xBF,0xBF,0xBF,0xBF,0xCF,0xBF,0xBF,0xBF,0xBF,0xAF,0xBF,0x61,0xAF,0x61,0xAF,0xAF,0x61,0xAF,0x51,0x9F,0x51,0x9F,0x60,0xAF,0x9F,0x60,0x9F,0xAF,0x51,0x9F,0xAF,0x51,0x9F,0x9F,0xDF,0xFF,0xF2,0xFF,0xFF,0xF3,0xEF,0xF5,0xBF,0xAF,0xAF,0xAF,0xAF,0x9F,0xAF,0xAF,0x52,0x42,0x42,0xAF,0x73,0xAF,0xD4,0xBF,0xBF,0xE5,0xE5,0xE5,0xE5,0xBF,0xE5,0xE5,0xE5,0xE5,0xAF,0xD5,0xBF,0xD5,0xBF,0xE5,0xBF,0xE5,0xE5,0xE5,0xE5,0xD5,0x63,0xC5,0x63,0x63,0xC5,0x63,0xC5,0x63,0xC5,0x63,0xC5,0xC5,0x73,0xC5,0x73,0xC5,0x63,0x73,0x63,0xC5,0x63,0xC5,0x43,0x43,0x43,0x43,0x63,0x63,0x43,0x63,0x63,0x63,0x63,0x63,0xC5,0x62,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x41,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F
.byte 0x50,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x50,0x60,0x50,0x60,0x50,0x50,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x60,0xAF,0xAF,0xAF,0xBF,0xBF,0xBF,0xAF,0xDF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xAF,0x9F,0x51,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xAF,0x70,0x70,0xBF,0x70,0xCF,0xDF,0xDF,0xCF,0xBF,0xBF,0xBF,0x70,0xBF,0xCF,0xCF,0xDF,0xF3,0xEF,0xEF,0xFF,0xFF,0xF2,0xEF,0xF3,0xDF,0xCF,0xBF,0x71,0xBF,0xAF,0xBF,0xAF,0xBF,0xBF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0x61,0xBF,0xAF,0xBF,0xAF,0x61,0xAF,0xAF,0x60,0xAF,0x60,0x9F,0x60,0x9F,0x51,0xAF,0x51,0xAF,0x51,0xAF,0x50,0x9F,0x9F,0x51,0xAF,0xF2,0xFF,0xFF,0xF3,0xFF,0xF3,0xEF,0xF5,0xBF,0xAF,0x9F,0xAF,0xAF,0x8F,0x8F,0x9F,0xAF,0x52,0x42,0x43,0x42,0xD5,0xBF,0xE5,0xE5,0xCF,0xE5,0xF5,0xE5,0xE5,0xE5,0xCF,0xF5,0xE5,0xD5,0xAF,0xD5,0xE5,0xBF,0xE5,0xF5,0xD5,0x52,0x63,0xD5,0xBF,0xD5,0x63,0xC5,0x63,0x63,0xC5,0x73,0xC5,0x73,0xC5,0x73,0x63,0xC5,0x63,0x63,0x63,0xC5,0xC5,0x63,0xC5,0x63,0x63,0x63,0x43,0x43,0x43,0x43,0x63,0x63,0x63,0x63,0x43,0x63,0x63,0x63,0x63,0x63,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0xAF,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F
.byte 0x50,0x9F,0x60,0x9F,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x50,0x60,0x50,0x60,0x50,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x9F,0xAF,0xAF,0xBF,0xAF,0xAF,0xAF,0x9F,0xBF,0xFF,0xFF,0xF5,0xCF,0xF5,0xFF,0xEF,0x9F,0x9F,0x60,0x9F,0x60,0x60,0xAF,0x60,0x60,0x60,0x61,0x60,0x60,0x61,0x70,0xBF,0x70,0xBF,0x70,0xCF,0xCF,0xCF,0x71,0xBF,0xBF,0xBF,0xCF,0xCF,0xDF,0xDF,0xF3,0xEF,0xF2,0xFF,0xF2,0xEF,0xF3,0xDF,0xCF,0xCF,0xBF,0xAF,0xBF,0x61,0xBF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xAF,0x61,0xAF,0xAF,0xAF,0x60,0xAF,0x51,0xAF,0x51,0xAF,0x51,0xAF,0x60,0x9F,0x60,0x9F,0x60,0x9F,0x60,0x9F,0x60,0x9F,0xBF,0xF2,0xFF,0xF3,0xFF,0xF3,0xFF,0xF3,0xF5,0xBF,0x9F,0xAF,0xBF,0xAF,0x9F,0x7F,0x7F,0x7F,0x8F,0x9F,0x52,0xAF,0x63,0xE6,0xCF,0xE5,0xE5,0xCF,0xE5,0xCF,0xE5,0xF5,0xE5,0xCF,0xE5,0xD5,0x73,0xE5,0xE5,0x62,0xD5,0xAF,0x63,0x63,0xD5,0xE5,0xD4,0x73,0x63,0x63,0x63,0x63,0x63,0x63,0x63,0x63,0x63,0xC5,0x63,0x63,0xC5,0x63,0xC5,0x63,0x73,0xC5,0x63,0xC5,0xC5,0x63,0x43,0x43,0x43,0x43,0x63,0x43,0x63,0xC5,0x63,0x63,0x63,0x63,0x63,0x63,0x73,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x7F,0x7F,0x7F
.byte 0x50,0x50,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x50,0x50,0x60,0x50,0x50,0x60,0x50,0x9F,0x50,0x50,0x9F,0x50,0x9F,0x9F,0x9F,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x8F,0x8F,0xAF,0xFF,0xFF,0xF5,0x9F,0x9F,0xF5,0xFF,0xCF,0x8F,0x50,0x50,0x9F,0x60,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0x60,0x60,0x70,0x70,0xBF,0x70,0xCF,0x80,0xCF,0x70,0xBF,0xBF,0xCF,0xCF,0xE3,0xDF,0xF2,0xFF,0xFF,0xF1,0xFF,0xF3,0xDF,0xCF,0xCF,0x61,0xBF,0x70,0xAF,0xBF,0xBF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0x61,0xBF,0xAF,0x70,0xAF,0x61,0xAF,0x60,0xAF,0x60,0x9F,0x60,0x9F,0x60,0x9F,0x60,0xAF,0x60,0x9F,0x60,0xAF,0x60,0x9F,0x50,0xBF,0xF2,0xFF,0xF3,0xFF,0xF3,0xFF,0xF3,0xF5,0xCF,0xAF,0xBF,0xF5,0xCF,0xBF,0x9F,0x8F,0x8F,0x7F,0x7F,0x9F,0xF5,0xF5,0x52,0xD5,0xF5,0xF5,0xE5,0xCF,0xE5,0xBF,0xE5,0xE5,0xF5,0xEF,0xE5,0xCF,0xE5,0xE5,0xD5,0x52,0x63,0xEA,0xF5,0xE5,0xAF,0xC5,0x73,0xC5,0x43,0x43,0x43,0x63,0xC5,0x43,0x63,0x43,0x63,0x63,0x63,0x63,0x63,0x63,0x63,0x63,0x63,0x63,0x63,0x63,0xC5,0x63,0x63,0x43,0xC5,0xC5,0x63,0x63,0x43,0x63,0x43,0x43,0x43,0x63,0xC5,0x63,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x41,0x8F,0x8F,0x8F,0x7F,0x8F,0x8F,0x7F
.byte 0x50,0x60,0x9F,0x60,0x9F,0x60,0x50,0x60,0x50,0x60,0x50,0x50,0x60,0x50,0x50,0x50,0x50,0x9F,0x50,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x9F,0xAF,0xEF,0xFF,0xF5,0x9F,0x8F,0xCF,0xEF,0xF3,0xCF,0xBF,0xAF,0x50,0x9F,0x50,0x41,0x50,0x40,0x50,0x50,0xAF,0x60,0xAF,0x60,0xAF,0x70,0x70,0xBF,0x70,0xBF,0xCF,0xBF,0xBF,0xCF,0xCF,0xDF,0xDF,0xF2,0xEF,0xF2,0xFF,0xF2,0xEF,0xDF,0xCF,0xCF,0x70,0xBF,0xAF,0xAF,0xBF,0xBF,0xCF,0xCF,0xCF,0xDF,0xCF,0xCF,0xCF,0xCF,0x71,0xBF,0xBF,0xBF,0x61,0xAF,0xAF,0x61,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x9F,0x60,0x60,0xAF,0x60,0x50,0xAF,0x60,0xAF,0x60,0x9F,0x60,0x9F,0xCF,0xF2,0xF3,0xF3,0xFF,0xF3,0xF3,0xEF,0xF5,0xBF,0xBF,0xF5,0xF5,0xF5,0xF5,0xAF,0x8F,0x8F,0x7F,0x7F,0x7F,0xAF,0xFF,0xF5,0xAF,0x52,0xCF,0xF5,0xF5,0xE5,0xCF,0xBF,0xE5,0xCF,0xD5,0xF5,0xF5,0xF5,0xEF,0xF5,0xF5,0xF6,0xE5,0xD5,0xAF,0x63,0x63,0xD6,0x52,0x43,0x63,0x63,0x43,0x43,0x63,0xC5,0x43,0x63,0xC5,0x63,0xC5,0x63,0xC5,0x63,0x63,0x43,0x63,0xC5,0x63,0xC5,0x63,0xC5,0x63,0x52,0xC5,0x73,0xC5,0x63,0x63,0xC5,0x43,0x43,0x42,0x43,0x63,0xD5,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x7F,0x7F,0x8F
.byte 0x50,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x50,0x50,0x50,0x50,0x50,0x60,0x50,0x50,0x50,0x50,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0xAF,0xCF,0xEF,0xEF,0xAF,0x7F,0xCF,0xEF,0xF5,0xEF,0xFF,0xFF,0xAF,0x9F,0xAF,0xBF,0x9F,0xAF,0xAF,0x40,0x40,0x50,0x60,0x60,0x60,0xAF,0x70,0x70,0xBF,0x80,0xBF,0xCF,0xDF,0xCF,0xDF,0xE3,0xEF,0xEF,0xF2,0xFF,0xF2,0xEF,0xF3,0xCF,0xCF,0xBF,0xAF,0x60,0xAF,0xBF,0xBF,0xCF,0xCF,0xCF,0xDF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0x70,0xAF,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0x9F,0x60,0xAF,0x60,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0xAF,0x50,0x50,0xCF,0xF2,0xFF,0xF3,0xF3,0xFF,0xF3,0xFF,0xF5,0xE5,0xBF,0xF4,0xEF,0xF5,0xDF,0xCF,0x9F,0x8F,0x7F,0x8F,0x7F,0x7F,0x9F,0xCF,0xE6,0x52,0xAF,0xD5,0xBF,0xE5,0xF5,0xE5,0xBF,0xE5,0xDF,0xE5,0xE5,0xBF,0xD5,0xAF,0xD5,0xBF,0xD4,0xD5,0xE5,0x73,0x63,0x43,0x43,0x63,0x63,0x63,0x43,0x63,0x43,0x63,0xC5,0x63,0x63,0xC5,0x63,0x63,0x63,0xC5,0x63,0xC5,0x63,0x63,0xC5,0x63,0x63,0x63,0xC5,0x63,0xC5,0x63,0x63,0xC5,0x43,0x63,0x63,0x43,0x43,0x42,0x42,0x42,0x73,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0xAF,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x7F
.byte 0x50,0x9F,0x50,0x50,0x50,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x50,0x60,0x9F,0x50,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x8F,0x8F,0x9F,0x8F,0x9F,0x9F,0x8F,0x8F,0x8F,0xBF,0xDF,0xF5,0xBF,0x9F,0xF5,0xEF,0xCF,0xF5,0xFF,0xCF,0xBF,0xBF,0xBF,0xAF,0xAF,0xCF,0xAF,0xBF,0xAF,0x9F,0x40,0xAF,0x60,0x60,0xAF,0x70,0x70,0xBF,0x70,0xCF,0xCF,0xDF,0xDF,0xEF,0xF3,0xEF,0xF2,0xEF,0xEF,0xDF,0xDF,0xCF,0x70,0xAF,0xAF,0xAF,0xBF,0xBF,0xCF,0xCF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xCF,0x71,0xBF,0x61,0xBF,0x70,0xAF,0xAF,0x61,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0x60,0x60,0xAF,0x60,0x60,0xAF,0x60,0x9F,0x60,0x60,0x60,0x9F,0x60,0xCF,0xF2,0xFF,0xF3,0xFF,0xF3,0xEF,0xF5,0xF3,0xCF,0xF4,0xF5,0xF5,0xF4,0xF5,0xCF,0x9F,0x7F,0x7F,0x7F,0x8F,0x8F,0x7F,0x8F,0x9F,0xAF,0xD5,0xE5,0x43,0xD5,0xCF,0xF5,0xF5,0xE5,0xCF,0xE5,0xF5,0xE5,0xE5,0xE5,0xE5,0xE5,0xCF,0xE5,0xE5,0xEB,0xD5,0xAF,0xC5,0x43,0x43,0x43,0xC5,0x43,0x63,0x43,0x63,0xC5,0x63,0x63,0x63,0x63,0x43,0x63,0x43,0x43,0x63,0x43,0x63,0x63,0x63,0x43,0x63,0x63,0x63,0xC5,0x63,0x63,0x63,0x63,0x43,0x43,0x43,0x43,0x42,0x42,0x42,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x41,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F
.byte 0x50,0x50,0x60,0x9F,0x60,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x60,0x50,0x50,0x50,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x8F,0x8F,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0xDF,0xDF,0xDF,0xF5,0xEF,0xF5,0xDF,0xFF,0xEF,0xAF,0xF5,0xBF,0xCF,0xAF,0xAF,0xAF,0xAF,0xBF,0xCF,0x9F,0x8F,0x40,0x50,0x60,0x60,0x60,0x60,0x70,0xBF,0x70,0xBF,0xCF,0xEF,0xEF,0xF2,0xEF,0xF2,0xEF,0xF3,0xDF,0xCF,0xBF,0xAF,0x70,0xAF,0xBF,0xBF,0xCF,0xCF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0x70,0xAF,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0x60,0x60,0x60,0xAF,0x60,0x60,0x60,0x9F,0xCF,0xF2,0xFF,0xF3,0xF3,0xF3,0xF3,0xF5,0xF3,0xF5,0xF5,0xEF,0xF4,0xDF,0xF5,0xF4,0x9F,0x8F,0x7F,0x7F,0x7F,0x7F,0x8F,0x8F,0x7F,0xAF,0xBF,0xBF,0xD5,0xCF,0xF5,0xE6,0xCF,0xF5,0xF5,0xBF,0xE6,0xBF,0xD5,0xE5,0xE5,0xE5,0xE5,0xE5,0xD4,0xE5,0xD5,0xD5,0xD5,0x63,0xC5,0x43,0x43,0x43,0xC5,0x63,0xC5,0x63,0xC5,0x63,0xC5,0x63,0xC5,0x63,0xC5,0x43,0x63,0x43,0x43,0x43,0xC5,0x43,0x43,0x64,0x63,0x63,0xC5,0x63,0x63,0xC5,0x43,0x43,0x43,0x63,0x43,0x52,0x9F,0x52,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x7F,0x7F,0x7F,0x8F
.byte 0x50,0x50,0x50,0x60,0x50,0x60,0x50,0x60,0x50,0x50,0x50,0x60,0x50,0x50,0x50,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0xBF,0xEF,0xF5,0xDF,0xCF,0xCF,0xEF,0xFF,0xAF,0xBF,0xBF,0xCF,0xF5,0xAF,0xDF,0xBF,0xAF,0xAF,0x8F,0xBF,0xBF,0x9F,0x8F,0x50,0x50,0xAF,0x60,0x60,0xBF,0xAF,0xAF,0xBF,0xDE,0xF0,0xEF,0xEF,0xEF,0xEF,0xDF,0xCF,0xBF,0x70,0xAF,0xAF,0xBF,0xCF,0xCF,0xDF,0xDF,0xDF,0xDF,0xDF,0xDF,0xCF,0xCF,0x71,0xBF,0x70,0xAF,0xBF,0x70,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0xAF,0x60,0x60,0x60,0x9F,0x60,0x50,0xBF,0xF3,0xF3,0xFF,0xF3,0xF5,0xF3,0xEF,0xF5,0xF4,0xF5,0xF3,0xF5,0xF5,0xDF,0xF5,0xAF,0x8F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F,0x7F,0x8F,0xAF,0xBF,0xBF,0xD5,0xDF,0xD4,0xAF,0xE6,0xBF,0xF5,0xE5,0xE5,0xF5,0xE5,0xEF,0xF5,0xCF,0xD5,0xAF,0x73,0x52,0x52,0x63,0x63,0x63,0xC5,0x63,0x63,0x63,0xC5,0x63,0xC5,0x63,0xC5,0x73,0xC5,0x63,0xC5,0x63,0xC5,0x63,0xC5,0x63,0x43,0x63,0x63,0xC5,0x43,0xC5,0x63,0x63,0x63,0x63,0x43,0x63,0x43,0x43,0x43,0x52,0x43,0x52,0xAF,0x52,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F
.byte 0x50,0x50,0x60,0x9F,0x50,0x50,0x60,0x50,0x50,0x50,0x50,0x50,0x50,0x60,0x50,0x9F,0x9F,0x8F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x9F,0xDF,0xDF,0xCF,0xCF,0xF5,0xDF,0xCF,0xBF,0xCF,0xAF,0xDF,0xAF,0xCF,0xCF,0x9F,0xCF,0x9F,0xBF,0x9F,0xBF,0xEF,0xEF,0xBF,0x50,0x50,0x50,0x60,0x60,0xAF,0xBF,0xBE,0xBF,0xCF,0xEF,0xF2,0xEF,0xDF,0xCF,0xBF,0x70,0xAF,0xBF,0xBF,0xCF,0xCF,0xDF,0xDF,0xDF,0xF3,0xDF,0xDF,0xCF,0xCF,0xBF,0xBF,0x70,0xBF,0x70,0xAF,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x50,0xCF,0xF3,0xF3,0xFF,0xF5,0xF3,0xF5,0xF3,0xF5,0xF3,0xF5,0xF5,0xF4,0xF5,0xF4,0xDF,0xAF,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x8F,0xBF,0xF5,0xDF,0xBF,0xE5,0xE5,0xF5,0xF5,0xF5,0xBF,0x62,0xAF,0xD5,0xCF,0xE5,0xF5,0xE5,0xE5,0xE5,0xD5,0xD5,0xD5,0x63,0xC5,0x43,0x43,0x55,0x63,0xC5,0x63,0x63,0x63,0x63,0x43,0x64,0x63,0xC5,0x63,0x64,0x63,0x63,0xC5,0x63,0xC5,0x43,0x63,0x63,0x63,0x63,0xC5,0x43,0x63,0x63,0x63,0x63,0x43,0x43,0x42,0x63,0x43,0x52,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x41,0x8F,0x8F,0x7F,0x7F,0x7F,0x7F
.byte 0x50,0x50,0x50,0x60,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x9F,0x9F,0x8F,0x8F,0x9F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x7F,0x7F,0x8F,0xCF,0xEF,0xF5,0xDF,0xCF,0xCF,0xCF,0xF5,0xCF,0xBF,0xAF,0x9F,0xDF,0xBF,0xCF,0xBF,0xCF,0xCF,0xAF,0xEF,0xF5,0xDF,0xDF,0xCF,0xAF,0x40,0x60,0x60,0x60,0xBF,0xBF,0xCE,0xBF,0xEE,0xEF,0xDF,0xCF,0xBF,0xBF,0xAF,0xBF,0xBF,0xCF,0xCF,0xDF,0xDF,0xF3,0xDF,0xDF,0xDF,0xCF,0xCF,0x71,0xBF,0x70,0xAF,0xAF,0x70,0xAF,0x70,0xAF,0xAF,0x70,0xAF,0x60,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x50,0xBF,0xF2,0xFF,0xFF,0xF5,0xF5,0xF3,0xF5,0xF4,0xF4,0xF4,0xF4,0xDF,0xF5,0xDF,0xF5,0xBF,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x9F,0xBF,0xF5,0xF5,0xCF,0xE5,0xF5,0xF5,0xF6,0xF5,0xE5,0xBF,0x73,0xBF,0xF5,0xCF,0x52,0x52,0x52,0x63,0x63,0x43,0x63,0xC5,0x63,0x63,0x43,0xC5,0x63,0xC5,0x43,0xC5,0x43,0x55,0x63,0x63,0x63,0xC5,0x43,0x63,0x64,0x43,0x43,0xC5,0x63,0xC5,0x43,0x63,0x43,0x63,0x43,0x43,0xC5,0x63,0x43,0x52,0x42,0x42,0x52,0x43,0x52,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F
.byte 0x50,0x50,0x9F,0x50,0x50,0x60,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0xAF,0x8F,0x8F,0x9F,0x8F,0x7F,0x8F,0x8F,0x7F,0x8F,0x8F,0x7F,0x8F,0x8F,0x8F,0x7F,0x8F,0x8F,0x8F,0x7F,0x7F,0xBF,0xEF,0xDF,0xCF,0xCF,0xBF,0xCF,0xBF,0xBF,0xCF,0xBF,0xDF,0xDF,0xAF,0xCF,0xCF,0xBF,0xAF,0xDF,0xDF,0xAF,0x9F,0x9F,0x9F,0xBF,0x9F,0x50,0xAF,0x60,0xAF,0x70,0xBF,0xBE,0xCF,0xDF,0xDF,0xCF,0xBF,0x70,0xBF,0xCF,0xCF,0xDF,0xDF,0xEF,0xEF,0xEF,0xDF,0xDF,0xCF,0xCF,0xBF,0x70,0xAF,0xAF,0x70,0xAF,0xAF,0xAF,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x9F,0x60,0x50,0xBF,0xF2,0xFF,0xF3,0xF5,0xF3,0xF5,0xF5,0xF4,0xF4,0xF4,0xF5,0xF4,0xF5,0xF4,0xDF,0xBF,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x8F,0x7F,0x8F,0x9F,0x8F,0x9F,0xF5,0xF5,0xF5,0xCF,0xE5,0xCF,0xE5,0xE5,0xF5,0xF7,0xE5,0xE5,0xF5,0xF7,0xE5,0xD5,0x52,0x63,0x63,0x43,0x43,0x43,0xC5,0x43,0x63,0x43,0x64,0x43,0x43,0x64,0x63,0x64,0x63,0x64,0x43,0x43,0x55,0x63,0x63,0x63,0x63,0x63,0x63,0x63,0x63,0x63,0x63,0x63,0x43,0x52,0x43,0x43,0x43,0x52,0x42,0x42,0x52,0x52,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x8F,0x8F,0x7F,0x7F,0x8F,0x7F,0x7F
.byte 0x50,0x50,0x60,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0xAF,0x9F,0x8F,0x9F,0x8F,0x7F,0x7F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x7F,0xBF,0xEF,0xEF,0xCF,0xBF,0xBF,0xAF,0xBF,0xDF,0xCF,0xBF,0xCF,0xBF,0xCF,0xDF,0xDF,0xCF,0xCF,0xDF,0xAF,0xAF,0xBF,0xBF,0xAF,0xAF,0x9F,0x50,0x60,0x50,0xAF,0xAF,0xAF,0xBF,0xBE,0xBF,0xCF,0xBF,0xBF,0xBF,0xCF,0xDF,0xDF,0xDF,0xEF,0xEF,0xEF,0xDF,0xDF,0xCF,0xCF,0x71,0xAF,0xAF,0x70,0xAF,0xAF,0x70,0xAF,0x70,0xBF,0x70,0xAF,0x70,0xAF,0x60,0x60,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0xAF,0x60,0x60,0x60,0x9F,0x50,0xBF,0xF3,0xF3,0xF3,0xF5,0xF3,0xF5,0xF3,0xF5,0xF5,0xF4,0xF5,0xDF,0xF4,0xDF,0xF5,0xBF,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x8F,0x8F,0x8F,0x8F,0x7F,0x7F,0x8F,0xBF,0xF5,0xF5,0xF5,0xF5,0xCF,0xE5,0xCF,0xF5,0xF5,0xE5,0xE5,0xE5,0xCF,0xF5,0xE6,0x52,0x63,0x63,0x43,0x43,0x63,0x63,0xC5,0x63,0xC5,0x43,0x64,0x43,0xC5,0x63,0xC5,0x63,0x55,0x63,0x55,0x63,0x55,0x63,0x63,0x43,0xC5,0x63,0x43,0x63,0xC5,0x63,0x43,0x43,0x43,0x43,0x43,0x52,0x52,0x8F,0x9F,0x9F,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x41,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F
.byte 0x50,0x50,0x50,0x60,0x50,0x50,0x60,0x50,0x50,0x50,0x50,0x50,0xAF,0xAF,0x9F,0x8F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x8F,0x7F,0x7F,0x8F,0x8F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x7F,0xAF,0xEF,0xF5,0xCF,0xAF,0xBF,0xCF,0xBF,0xAF,0xAF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xCF,0xBF,0xBF,0xAF,0x7F,0xAF,0xCF,0xAF,0xAF,0x50,0x50,0x9F,0x60,0xAF,0xAF,0xAF,0xBE,0xBE,0xCF,0xBF,0xBF,0xCF,0xDF,0xDF,0xEF,0xEF,0xEF,0xEF,0xDF,0xDF,0xCF,0xCF,0xBF,0xAF,0x70,0xAF,0xBF,0xBF,0xAF,0xBF,0xBF,0xAF,0x70,0xAF,0x70,0xAF,0x60,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0xAF,0x60,0xAF,0x60,0x60,0x60,0x9F,0x60,0x9F,0x60,0x50,0xBF,0xF3,0xFF,0xF3,0xF5,0xF3,0xF5,0xF5,0xF5,0xF4,0xDF,0xF4,0xF4,0xF5,0xDF,0xF5,0xBF,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x6F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x7F,0xAF,0xF5,0xF5,0xF5,0xF5,0xF5,0xF5,0xE5,0xF5,0xE5,0xCF,0xF6,0xE5,0xCF,0xD5,0x63,0x43,0x43,0xC5,0x43,0xC5,0x43,0x43,0x43,0x43,0x63,0xC5,0x43,0x43,0x63,0x63,0x63,0x55,0x63,0x43,0x43,0x63,0x43,0x43,0x43,0x43,0x63,0x43,0x63,0x43,0x63,0x63,0x42,0x43,0x43,0x63,0x63,0x52,0x52,0x52,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F
.byte 0x50,0x60,0x9F,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0xAF,0xAF,0x9F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x8F,0x8F,0x7F,0x7F,0x7F,0x7F,0x8F,0x8F,0x8F,0x7F,0xAF,0xEF,0xF5,0xBF,0xCF,0xAF,0xAF,0xF5,0xDF,0xAF,0xAF,0xDF,0xDF,0xBF,0xCF,0xCF,0xDF,0xCF,0x9F,0xCF,0xAF,0x8F,0xBF,0xBF,0xAF,0xCF,0x9F,0x50,0x9F,0x50,0xAF,0xAF,0xAF,0xBF,0xBE,0xCE,0xCF,0xCF,0xDF,0xDF,0xEF,0xEF,0xEF,0xEF,0xDF,0xDF,0xCF,0xCF,0x70,0xAF,0xBF,0xAF,0xBF,0xBF,0xBF,0xBF,0xBF,0x70,0xBF,0xAF,0x70,0xAF,0x60,0x60,0x60,0x60,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0x9F,0x60,0x60,0x60,0x60,0x9F,0x50,0xAF,0xF3,0xF3,0xF5,0xF5,0xF5,0xF5,0xF3,0xF5,0xF5,0xF5,0xF5,0xDF,0xF4,0xCF,0xF5,0xBF,0x8F,0x7F,0x7F,0x7F,0x6F,0x7F,0x7F,0x6F,0x6F,0x8F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F,0x7F,0x9F,0xE5,0xF5,0xF5,0xF5,0xF5,0xE5,0xCF,0xE5,0xE5,0xE5,0xE5,0xCF,0xD5,0x63,0x63,0xC5,0x43,0x63,0x43,0x63,0x43,0x55,0x43,0x43,0x55,0x43,0x43,0x43,0x55,0x43,0x64,0x64,0x43,0x43,0x55,0x63,0x43,0x43,0x43,0x43,0x43,0x43,0x63,0x63,0x63,0x43,0x42,0x43,0x43,0x63,0x42,0x42,0x52,0x52,0x9F,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F
.byte 0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0xAF,0xBF,0x9F,0x8F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x8F,0x7F,0x7F,0x7F,0x8F,0x8F,0x8F,0x7F,0x7F,0xAF,0xEF,0xEF,0xBF,0x9F,0xF5,0xBF,0x8F,0xBF,0xEF,0xBF,0xAF,0xAF,0xBF,0xDF,0xEF,0xEF,0xDF,0x9F,0xAF,0xCF,0xCF,0xBF,0x9F,0xBF,0xDF,0xBF,0x50,0x50,0x9F,0x60,0xAF,0xAF,0x9E,0xBF,0xCE,0xCF,0xDF,0xDF,0xDF,0xEF,0xEF,0xDF,0xDF,0xDF,0xCF,0xBF,0x70,0xAF,0xAF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0x60,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0x60,0x60,0x9F,0x60,0x9F,0x60,0x50,0x50,0xAF,0xDF,0xF4,0xF4,0xF4,0xF4,0xF5,0xF5,0xF5,0xF5,0xDF,0xF4,0xF5,0xCF,0xF5,0xCF,0xBF,0x9F,0x7F,0x8F,0x7F,0x6F,0x7F,0x8F,0x7F,0x8F,0x8F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0xAF,0xE5,0xF5,0xF5,0xF5,0xF5,0xE5,0xBF,0xE5,0xBF,0xD5,0x52,0xC5,0x43,0x63,0x43,0x43,0xC5,0x43,0x63,0x43,0x43,0x43,0x43,0x64,0xC5,0x43,0x43,0x43,0x43,0x55,0x63,0x55,0x43,0x55,0x43,0x43,0x43,0x43,0x43,0x42,0x43,0x43,0x63,0x43,0x42,0x42,0x43,0x42,0x43,0x42,0x52,0x63,0x42,0x52,0xAF,0xAF,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x7F,0x7F,0x7F,0x7F,0x8F
.byte 0x50,0x9F,0x60,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0xAF,0xAF,0x9F,0x8F,0x7F,0x7F,0x6F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0xAF,0xEF,0xFF,0xDF,0x7F,0x9F,0xDF,0xBF,0x9F,0xAF,0xF5,0xDF,0xBF,0xAF,0x9F,0xAF,0xDF,0xEF,0xCF,0x9F,0x9F,0xAF,0x9F,0xBF,0xCF,0xCF,0xCF,0xAF,0x40,0x9F,0xAF,0xAF,0xAF,0xAF,0xAE,0xBF,0xCE,0xDF,0xDF,0xDF,0xF3,0xDF,0xDF,0xCF,0xCF,0x70,0xAF,0xAF,0x70,0xAF,0x70,0xAF,0xBF,0x70,0xBF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0x9F,0x60,0x50,0x60,0x9F,0x60,0x9F,0x50,0xCF,0xF4,0xF4,0xF5,0xF4,0xF5,0xF5,0xF4,0xF5,0xF5,0xDF,0xF5,0xCF,0xCF,0xE5,0xBF,0x9F,0x7F,0x7F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x6F,0x8F,0xBF,0xE5,0xE5,0xF5,0xE5,0xCF,0xD5,0xCF,0xBF,0x63,0x43,0x43,0x63,0x63,0x43,0x43,0x43,0x43,0xC5,0x43,0x43,0x43,0x63,0x43,0x63,0x43,0x43,0x63,0x43,0x55,0x43,0x43,0x43,0x43,0x43,0x63,0x43,0x63,0x43,0x42,0x42,0x42,0x43,0x42,0x42,0x43,0x43,0x43,0x43,0x42,0x43,0x42,0x42,0x9F,0xAF,0x9F,0x9F,0x9F,0x9F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F
.byte 0x50,0x60,0x9F,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0xBF,0x9F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0xCF,0xFF,0xFF,0xF5,0x9F,0x7F,0x8F,0xCF,0xDF,0xAF,0x8F,0x9F,0xCF,0xF5,0xDF,0xBF,0x8F,0xBF,0xF5,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xF5,0xEF,0xBF,0x40,0x50,0x9F,0xAF,0xAF,0xAF,0xAF,0x9E,0xBF,0xDF,0xEF,0xEF,0xDF,0xDF,0xCF,0xBF,0xBF,0xAF,0x70,0xAF,0xAF,0xAF,0xBF,0xAF,0xBF,0xBF,0xAF,0x70,0xAF,0xAF,0x70,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xAF,0xBF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0x9F,0x60,0x9F,0x60,0x9F,0x60,0x9F,0x60,0x50,0xBF,0xF4,0xF4,0xF4,0xF4,0xF5,0xF4,0xF5,0xF5,0xF5,0xF5,0xDF,0xCF,0xCF,0xDF,0xBF,0x8F,0x7F,0x7F,0x7F,0x8F,0x7F,0x7F,0x7F,0x8F,0x8F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0xAF,0xCF,0xE5,0xE5,0xCF,0xE6,0xBF,0xD5,0x52,0x43,0x43,0xC5,0x43,0x63,0xC5,0x63,0x43,0x43,0xC5,0x43,0x43,0x43,0x63,0x43,0x43,0x43,0xC5,0x43,0x63,0x43,0x43,0x55,0x43,0x63,0x43,0x43,0x63,0xC5,0x63,0x43,0x42,0x42,0x42,0x42,0x43,0x43,0x43,0x43,0x43,0x42,0x43,0x43,0x42,0x9F,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x7F,0x7F,0x7F,0x8F,0x7F
.byte 0x9F,0x60,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0xAF,0xAF,0x9F,0x7F,0x7F,0x6F,0x7F,0x6F,0x7F,0x6F,0x7F,0x7F,0x7F,0x6F,0x6F,0x6F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F,0x7F,0x8F,0xCF,0xCF,0xE5,0xDF,0xCF,0x9F,0x7F,0x8F,0xAF,0xCF,0xCF,0xAF,0x9F,0xAF,0xDF,0xFF,0xDF,0xBF,0x9F,0xBF,0xBF,0xAF,0x9F,0xAF,0x9F,0xCF,0xFF,0xCF,0x9F,0x50,0x9F,0x9F,0xAF,0xAF,0x60,0xAE,0xBF,0xBE,0xDF,0xDF,0xCF,0xCF,0x71,0xAF,0x60,0xAF,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x70,0xAF,0xAF,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0x9F,0x60,0x50,0x60,0x9F,0x50,0xAF,0xF4,0xF4,0xF4,0xF5,0xF5,0xF5,0xF5,0xF5,0xDF,0xF5,0xF5,0xCF,0xBF,0xE5,0xCF,0x9F,0x7F,0x7F,0x6F,0x6F,0x6F,0x6F,0x8F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x9F,0xCF,0xE5,0xBF,0xE5,0xBF,0xAF,0x63,0x43,0x63,0x43,0x43,0x43,0x43,0x63,0x43,0x63,0x43,0x63,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x63,0x63,0x63,0x43,0x43,0x43,0xC5,0x43,0x63,0x43,0x63,0x63,0x63,0x43,0x42,0x42,0x42,0x42,0x43,0x42,0x43,0x43,0x43,0x42,0x43,0x42,0x52,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F
.byte 0x50,0x9F,0x50,0x50,0x50,0x50,0x50,0x50,0x9F,0x50,0xAF,0xAF,0x8F,0x7F,0x7F,0x6F,0x7F,0x6F,0x6F,0x7F,0x6F,0x7F,0x6F,0x6F,0x6F,0x6F,0x6F,0x6F,0x6F,0x7F,0x7F,0x6F,0x6F,0x6F,0x7F,0xAF,0xCF,0xCF,0xF5,0xEF,0xCF,0xAF,0x8F,0x7F,0x9F,0xCF,0xFF,0xFF,0xCF,0x8F,0xAF,0xCF,0xF5,0xDF,0xCF,0xCF,0xBF,0xF5,0xEF,0xBF,0x7F,0xAF,0xF4,0xBF,0x50,0x9F,0x50,0xAF,0x9E,0xAF,0xAF,0xAE,0xBF,0xCF,0xDF,0xCF,0x70,0xAF,0x60,0xAF,0x70,0xAF,0xAF,0xBF,0xBF,0xBF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x70,0xAF,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0xAF,0x70,0xAF,0x60,0xAF,0x60,0x9F,0x60,0x9F,0x60,0x9F,0x60,0x9F,0x60,0x9F,0x60,0x50,0x50,0xCF,0xF4,0xF4,0xF5,0xF3,0xF5,0xEF,0xF5,0xF5,0xF5,0xDF,0xE5,0xBF,0xCF,0xBF,0x9F,0x7F,0x7F,0x6F,0x6F,0x6F,0x6F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x7F,0x7F,0x7F,0x6F,0x6F,0x9F,0xE5,0xBF,0xAF,0x73,0xC5,0x63,0xC5,0x43,0x63,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x63,0xC5,0x43,0x63,0x43,0x43,0x43,0x43,0x43,0x63,0x63,0xC5,0x43,0x63,0x43,0x42,0x42,0x42,0x42,0x43,0x42,0x52,0x43,0x43,0x42,0x43,0x52,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F
.byte 0x60,0x9F,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0xAF,0xAF,0x7F,0x7F,0x6F,0x7F,0x7F,0x7F,0x7F,0x8F,0x8F,0x7F,0x6F,0x7F,0x7F,0x6F,0x6F,0x6F,0x6F,0x6F,0x5F,0x6F,0x8F,0x9F,0x8F,0xAF,0xDF,0xFF,0xEF,0xEF,0xFF,0xFF,0xDF,0xCF,0x9F,0x8F,0x8F,0xBF,0xFF,0xFF,0xBF,0x9F,0x9F,0xAF,0xAF,0x9F,0xAF,0xCF,0xF3,0xFF,0xCF,0x8F,0xAF,0xCF,0xAF,0x50,0x50,0x50,0xAF,0x60,0x9E,0x70,0xAE,0xCF,0xCF,0x70,0xAF,0x60,0xAF,0xAF,0xAF,0x70,0xBF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x70,0xAF,0xAF,0x70,0xAF,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0x60,0x60,0x9F,0x60,0x9F,0xAF,0xF4,0xF4,0xF5,0xF5,0xF5,0xF5,0xF5,0xF5,0xF5,0xDF,0xDF,0xCF,0xBF,0xAF,0x9F,0x7F,0x6F,0x6F,0x6F,0x6F,0x6F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x7F,0x7F,0x6F,0x6F,0x9F,0xD4,0xAF,0x42,0xC5,0x63,0x43,0x43,0x63,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x63,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x63,0x43,0x63,0x43,0x63,0x43,0x43,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x52,0x42,0x43,0x42,0x42,0x9F,0x9F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x8F
.byte 0x9F,0x60,0x50,0x50,0x50,0x50,0x9F,0x50,0x50,0x9F,0xAF,0x9F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x50,0x50,0x9F,0x8F,0x6F,0x7F,0x8F,0x7F,0x6F,0x6F,0x6F,0x6F,0x8F,0x9F,0x8F,0x8F,0x7F,0x7F,0xAF,0xDF,0xEF,0xF5,0xDF,0xEF,0xFF,0xFF,0xFF,0xDF,0x9F,0x7F,0x9F,0xDF,0xFF,0xFF,0xFF,0xEF,0xCF,0xBF,0xBF,0x9F,0x8F,0xCF,0xF3,0xAF,0x8F,0xBF,0xBF,0x9F,0x60,0x9F,0xAF,0xAF,0xAF,0xAF,0x9E,0xBF,0xBF,0x60,0xAF,0x60,0x60,0xAF,0x70,0xBF,0xBF,0xBF,0xBF,0x70,0xAF,0x60,0xAF,0xAF,0x70,0xAF,0xBF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0xAF,0x60,0xAF,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x9F,0x60,0x9F,0x60,0x9F,0x60,0x50,0xCF,0xF4,0xF4,0xF5,0xEF,0xF3,0xEF,0xF5,0xDF,0xF5,0xF5,0xCF,0xAF,0xAF,0x9F,0x7F,0x7F,0x6F,0x6F,0x6F,0x6F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x7F,0x6F,0x7F,0x7F,0x6F,0x6F,0x7F,0x9F,0x52,0x52,0x63,0x63,0x43,0x43,0xC5,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x42,0x42,0x43,0x43,0x43,0x43,0x43,0x63,0x42,0x43,0x43,0x42,0x42,0x42,0x42,0x42,0x52,0x63,0x42,0x52,0x42,0x42,0x9F,0x8F,0x8F,0x8F,0x8F,0x7F,0x7F,0x7F,0x8F,0x7F,0x7F
.byte 0x60,0x9F,0x50,0x50,0x50,0x50,0x50,0x50,0x50,0xAF,0x9F,0x8F,0x7F,0x6F,0x7F,0x7F,0x7F,0x9F,0x50,0x9F,0x50,0x7F,0x5F,0x6F,0x8F,0x8F,0x7F,0x7F,0x7F,0x7F,0x9F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0xCF,0xEF,0xEF,0xEF,0xEF,0xFF,0xFF,0xFF,0xFF,0xFF,0xCF,0x7F,0x7F,0x8F,0xAF,0xBF,0xF5,0xEF,0xFF,0xFF,0xFF,0xBF,0x7F,0xAF,0xDF,0x9F,0x51,0xAF,0x60,0x9F,0xAF,0x9F,0xAF,0x60,0xAF,0xBF,0xAE,0xBF,0xCF,0xBF,0xBF,0x70,0xAF,0xBF,0x70,0xBF,0x70,0xBF,0xBF,0xBF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xAF,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x9F,0x60,0x9F,0x50,0xBF,0xE4,0xDF,0xF4,0xF5,0xEF,0xF5,0xEF,0xF5,0xDF,0xDF,0xCF,0xAF,0x9F,0x9F,0x9F,0x7F,0x6F,0x6F,0x6F,0x6F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x6F,0x6F,0x7F,0x6F,0x6F,0x8F,0x42,0x63,0xC5,0x43,0x43,0x43,0x63,0x43,0x42,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x42,0x43,0x43,0x52,0x43,0x43,0x42,0x42,0x42,0x43,0x42,0x42,0x52,0xC5,0x52,0xC5,0x52,0x52,0x52,0x52,0x9F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F
.byte 0x9F,0x60,0x9F,0x50,0x50,0x50,0x50,0x9F,0x50,0x9F,0x9F,0x7F,0x7F,0x6F,0x7F,0x7F,0x40,0x9F,0x50,0x9F,0x8F,0x6F,0x6F,0x6F,0x6F,0x7F,0x7F,0x8F,0x7F,0x9F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x9F,0xEF,0xF5,0xEF,0xEF,0xEF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xAF,0x8F,0x7F,0x7F,0x7F,0x8F,0xAF,0xF5,0xFF,0xFF,0xCF,0x9F,0x41,0xAF,0x61,0x61,0x61,0x50,0xAF,0x60,0xAF,0xAF,0x60,0xAE,0xBF,0xBF,0xCF,0xDF,0xCF,0xBF,0x70,0xAF,0x70,0xAF,0x70,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0x70,0xAF,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0x9F,0x60,0x60,0x9F,0x60,0x50,0x9F,0xCF,0xE4,0xF5,0xF5,0xEF,0xEF,0xF5,0xF5,0xF5,0xDF,0xDF,0xAF,0x9F,0x9F,0x8F,0x7F,0x6F,0x6F,0x6F,0x8F,0x8F,0x7F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x6F,0x6F,0x6F,0x7F,0x52,0x42,0x42,0x63,0x43,0x43,0x63,0x43,0x43,0x43,0x42,0x55,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x42,0x43,0x43,0x43,0x42,0x43,0x42,0x43,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x52,0x52,0x52,0x52,0x52,0x52,0x52,0xC5,0x52,0x52,0x9F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F
.byte 0x60,0x9F,0x50,0x50,0x50,0x9F,0x50,0x50,0x50,0xAF,0x9F,0x7F,0x6F,0x7F,0x6F,0x8F,0x50,0x9F,0x50,0x9F,0x7F,0x6F,0x6F,0x6F,0x6F,0x6F,0x6F,0x6F,0x8F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x8F,0xCF,0xEF,0xEF,0xFF,0xFF,0xEF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xDF,0xAF,0x8F,0x7F,0x7F,0x7F,0x9F,0xF4,0xF3,0xBF,0x61,0x51,0x51,0x71,0x71,0x60,0x9F,0xAF,0x60,0x9F,0x60,0xAE,0xBF,0xAE,0xCF,0xF0,0xEF,0xDF,0xCF,0xBF,0x70,0xAF,0x60,0xAF,0x70,0xBF,0xBF,0xCF,0xCF,0x80,0xBF,0xAF,0x70,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0x60,0xAF,0x60,0x60,0x9F,0x60,0x50,0xAF,0xCF,0xF4,0xF5,0xEF,0xEF,0xEF,0xF5,0xEF,0xF5,0xCF,0xAF,0x8F,0x9F,0x8F,0x7F,0x7F,0x8F,0x9F,0x8F,0x7F,0x6F,0x6F,0x7F,0x7F,0x7F,0x8F,0x7F,0x7F,0x6F,0x7F,0x6F,0x7F,0x6F,0x7F,0x6F,0x6F,0x7F,0x42,0x52,0x9F,0x43,0x43,0x43,0x43,0xC5,0x43,0x43,0x43,0x42,0x43,0x43,0x63,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x42,0x43,0x42,0x43,0x43,0x43,0x43,0x42,0x43,0x42,0x43,0x42,0x42,0x7F,0x42,0x42,0x8F,0x42,0x8F,0x42,0xC5,0x52,0xC5,0x43,0x43,0x42,0x9F,0x52,0x43,0x52,0x42,0x8F,0x8F,0x8F,0x7F,0x8F,0x8F,0x7F,0x8F
.byte 0x9F,0x60,0x9F,0x50,0x50,0x50,0x50,0x9F,0x50,0x9F,0x8F,0x7F,0x6F,0x6F,0x7F,0x9F,0x50,0x9F,0x60,0x8F,0x6F,0x6F,0x6F,0x6F,0x6F,0x7F,0x6F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0xCF,0xEF,0xEF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF5,0xDF,0xF3,0xBF,0x7F,0x8F,0xCF,0x72,0xBF,0x72,0x61,0x61,0x72,0x71,0x60,0x9F,0xAF,0x60,0xAF,0xAF,0xAF,0xBF,0xDF,0xFF,0xF0,0xEF,0xDF,0xCF,0xBF,0x70,0xAF,0xAF,0xAF,0xBF,0xBF,0xBF,0xCF,0xBF,0xCF,0xBF,0xBF,0x60,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0x60,0x9F,0x60,0x60,0xAF,0x60,0x50,0xBF,0xE4,0xDF,0xF5,0xF5,0xEF,0xF5,0xDF,0xDF,0xDF,0xAF,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x6F,0x7F,0x6F,0x7F,0x7F,0x6F,0x6F,0x42,0x52,0xC5,0x42,0x63,0x43,0x63,0x63,0x43,0x43,0x43,0x42,0x43,0x43,0x43,0x43,0xC5,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x42,0x42,0x42,0x42,0x43,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x52,0x63,0x52,0x63,0x52,0x43,0x42,0x42,0x52,0x42,0x52,0x42,0x8F,0x8F,0x8F,0x7F,0x8F,0x8F,0x7F
.byte 0x60,0x9F,0x50,0x50,0x50,0x9F,0x50,0x50,0x50,0xAF,0x8F,0x7F,0x6F,0x7F,0x40,0x9F,0x9F,0x9F,0x9F,0x8F,0x6F,0x6F,0x6F,0x6F,0x6F,0x7F,0x8F,0x8F,0x6F,0x7F,0x7F,0x7F,0x6F,0x7F,0x6F,0x7F,0x6F,0x7F,0xCF,0xEF,0xEF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xDF,0x8F,0x41,0x71,0x61,0x71,0xC3,0x82,0x72,0x72,0x61,0x60,0xAF,0xAF,0x60,0xAF,0xBF,0xBF,0xEE,0xFF,0xFF,0xFF,0xF0,0xDF,0xDF,0xCF,0xBF,0x70,0xAF,0x70,0xBF,0xBF,0xBF,0xBF,0xCF,0xBF,0xBF,0xBF,0x70,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0x60,0xAF,0x50,0x60,0xAF,0x50,0x60,0xCF,0xE4,0xDF,0xF5,0xDF,0xF5,0xEF,0xF5,0xDF,0xBF,0x9F,0xAF,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x6F,0x7F,0x7F,0x6F,0x6F,0x7F,0x42,0x9F,0x63,0x43,0x43,0x63,0x43,0x43,0x43,0x43,0x42,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x43,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x8F,0x42,0x8F,0x42,0x43,0x63,0x43,0x63,0x63,0x63,0x63,0x52,0x42,0x8F,0x42,0x42,0x42,0x42,0x42,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F
.byte 0x9F,0x60,0x9F,0x50,0x50,0x50,0x9F,0x50,0x9F,0x9F,0x8F,0x7F,0x6F,0x7F,0x60,0x9F,0x40,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x8F,0x8F,0x7F,0x6F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x6F,0x6F,0x7F,0xCF,0xEF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xFF,0xEF,0xF5,0xF5,0xEF,0xFF,0xFF,0xFF,0xFF,0x9F,0x41,0x71,0x61,0x72,0x72,0x82,0x82,0x82,0x61,0x60,0xAF,0x60,0xAF,0x60,0xAE,0xCF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xDF,0xCF,0xCF,0xBF,0xAF,0xAF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0x70,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0xAF,0x60,0x60,0xAF,0x60,0x60,0xAF,0x60,0x60,0x9F,0x50,0xAF,0xCF,0xE4,0xDF,0xF5,0xDF,0xEF,0xDF,0xDF,0xCF,0xAF,0xAF,0x9F,0x41,0x9F,0x9F,0x41,0x8F,0x8F,0x8F,0x8F,0x8F,0x42,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x6F,0x6F,0x7F,0x42,0x43,0x52,0x43,0x43,0x63,0x43,0x43,0x43,0x42,0x43,0x43,0x63,0x63,0x43,0x43,0x63,0x43,0x43,0x43,0x43,0x43,0x43,0x42,0x42,0x42,0x43,0x42,0x42,0x42,0x43,0x42,0x7F,0x7F,0x42,0x7F,0x42,0x8F,0x42,0x42,0x52,0x42,0x42,0x43,0x52,0x43,0x63,0x63,0x52,0x63,0x63,0x43,0x42,0x8F,0x42,0x42,0x43,0x42,0x52,0x8F,0x8F,0x8F,0x8F,0x8F
.byte 0x60,0x9F,0x50,0x50,0x9F,0x50,0x50,0x9F,0x50,0x9F,0x8F,0x6F,0x7F,0x40,0x9F,0x50,0x9F,0x7F,0x6F,0x7F,0x7F,0x7F,0x8F,0x8F,0x8F,0x7F,0x7F,0x6F,0x7F,0x6F,0x7F,0x6F,0x7F,0x7F,0x6F,0x7F,0x6F,0x7F,0xBF,0xDF,0xEF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xF5,0xF5,0xF5,0xF5,0xDF,0xF5,0xF3,0xFF,0xF3,0xFF,0xFF,0xDF,0x7F,0x51,0x72,0x72,0x72,0x82,0x82,0x82,0x82,0x60,0xAF,0xAF,0x60,0xAF,0xBF,0xBF,0xEF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xDF,0xCF,0xCF,0xBF,0x70,0xAF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0x9F,0x60,0x60,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0x9F,0x60,0x60,0x60,0x50,0xBF,0xE4,0xCF,0xF4,0xF5,0xEF,0xF5,0xDF,0xCF,0xAF,0x9F,0xAF,0x51,0xAF,0x9F,0xAF,0xAF,0x9F,0x9F,0x9F,0x52,0x52,0x52,0x42,0x42,0x42,0x7F,0x42,0x7F,0x7F,0x6F,0x6F,0x7F,0x42,0x42,0x52,0x43,0x43,0x43,0x43,0x63,0x43,0x43,0x42,0x43,0x43,0x63,0x43,0x43,0x63,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x7F,0x42,0x7F,0x42,0x42,0x42,0x42,0x43,0x52,0x63,0x52,0x63,0x63,0x63,0x63,0xC5,0x52,0x52,0xC5,0x52,0x42,0x42,0x42,0x42,0x42,0x52,0x52,0x8F,0x8F,0x8F,0x8F
.byte 0x9F,0x50,0x9F,0x50,0x40,0x9F,0x50,0x50,0x9F,0x50,0x8F,0x6F,0x8F,0x50,0x9F,0x50,0x9F,0x50,0x7F,0x7F,0x6F,0x7F,0x7F,0x6F,0x7F,0x7F,0x7F,0x6F,0x7F,0x6F,0x7F,0x6F,0x7F,0x6F,0x7F,0x6F,0x7F,0x7F,0xBF,0xDF,0xDF,0xEF,0xEF,0xFF,0xEF,0xEF,0xF5,0xF5,0xDF,0xDF,0xCF,0xF5,0xF5,0xF5,0xF5,0xF5,0xF5,0xF5,0xF5,0xF5,0x9F,0x7F,0x61,0x82,0x72,0x82,0x82,0x82,0x82,0x71,0x60,0x9F,0xAF,0x60,0x9E,0xBF,0xDE,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xDF,0xCF,0xCF,0xBF,0xBF,0xAF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0xAF,0x60,0x60,0x60,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x60,0x50,0xBF,0xE4,0xCF,0xF5,0xEF,0xDF,0xDF,0xCF,0xAF,0x9F,0x9F,0x60,0xAF,0x51,0x9F,0x51,0x9F,0x9F,0x9F,0xAF,0x63,0x52,0x42,0x8F,0x42,0x7F,0x42,0x7F,0x7F,0x7F,0x6F,0x7F,0x8F,0x42,0x42,0x43,0x43,0x63,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x63,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x42,0x43,0x42,0x42,0x8F,0x42,0x8F,0x42,0x7F,0x42,0x8F,0x7F,0x7F,0x7F,0x42,0x7F,0x42,0x42,0x42,0x52,0x63,0x63,0xC5,0x52,0x43,0x52,0x63,0x52,0x63,0x63,0x52,0x63,0x52,0x52,0x42,0x8F,0x42,0x42,0x52,0x52,0x8F,0x41,0x8F
.byte 0x50,0x9F,0x50,0x40,0x50,0x50,0x9F,0x50,0x9F,0x9F,0x7F,0x6F,0x40,0x9F,0x50,0x9F,0x60,0x9F,0x9F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x6F,0x7F,0x7F,0x6F,0x7F,0x6F,0x7F,0x6F,0x6F,0x6F,0x6F,0x7F,0xBF,0xDF,0xDF,0xEF,0xEF,0xEF,0xEF,0xF5,0xDF,0xDF,0xF5,0xF5,0xF5,0xEF,0xFF,0xFF,0xFF,0xFF,0xEF,0xF5,0xF5,0xF5,0xAF,0x7F,0x41,0x72,0x72,0x82,0x82,0x72,0x82,0x82,0x61,0xBF,0xAF,0xAF,0xAF,0xBF,0xCF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xDF,0xDF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0x70,0xAF,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x50,0xBF,0xE4,0xCF,0xF5,0xEF,0xF5,0xCF,0xAF,0x9F,0x9F,0x9F,0x60,0xAF,0x9F,0xAF,0x51,0x9F,0x9F,0x51,0x63,0x52,0x42,0x9F,0x8F,0x42,0x8F,0x7F,0x7F,0x7F,0x7F,0x42,0x8F,0x7F,0x42,0x43,0x52,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x63,0x43,0x43,0x43,0x43,0x43,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x7F,0x42,0x7F,0x7F,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x52,0x52,0x52,0x52,0x52,0x63,0xD6,0x52,0x43,0x52,0x43,0x52,0xC5,0x52,0x52,0x42,0x7F,0x42,0x42,0xAF,0x52,0x42,0x8F
.byte 0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x50,0x9F,0x8F,0x7F,0x9F,0x50,0x9F,0x50,0x9F,0x50,0xAF,0x9F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x6F,0x7F,0x6F,0x7F,0x6F,0x6F,0x6F,0xBF,0xDF,0xDF,0xDF,0xEF,0xF5,0xEF,0xEF,0xEF,0xEF,0xEF,0xF5,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF3,0xF5,0xF5,0xDF,0x9F,0x6F,0x7F,0x61,0x72,0x82,0x82,0x72,0x82,0x82,0x82,0x71,0xAF,0xAF,0x60,0xAE,0xCF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xDF,0xDF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0x70,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0xAF,0x60,0x60,0xAF,0x60,0x60,0xAF,0x60,0x60,0xAF,0x60,0x60,0x60,0xBF,0xE4,0xCF,0xDF,0xDF,0xDF,0xBF,0x9F,0x8F,0x9F,0xAF,0x60,0x9F,0x9F,0xAF,0x9F,0x9F,0xAF,0x73,0x9F,0x63,0x9F,0x52,0x8F,0x42,0x8F,0x8F,0x7F,0x42,0x42,0x42,0x8F,0x42,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x42,0x42,0x42,0x7F,0x43,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x7F,0x6F,0x42,0x42,0x42,0x42,0x42,0x42,0x43,0x43,0x43,0x63,0x63,0x52,0x52,0xAF,0x73,0x52,0x43,0x42,0x52,0x52,0x63,0x52,0x42,0x42,0x42,0x42,0x42,0x52,0x42,0x42
.byte 0x50,0x9F,0x50,0x40,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x8F,0x7F,0x50,0x9F,0x60,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x7F,0x6F,0x6F,0x6F,0x6F,0x7F,0xBF,0xDF,0xFB,0xDF,0xDF,0xDF,0xDF,0xF5,0xEF,0xEF,0xF5,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF3,0xEF,0xF5,0xF5,0xCF,0x8F,0x6F,0x7F,0x51,0x72,0x72,0x82,0x72,0x82,0x72,0x82,0x71,0xBF,0xAF,0xAF,0xAF,0xBE,0xEF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xDF,0xDF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xCF,0xBF,0xBF,0xBF,0xAF,0xBF,0xAF,0xBF,0xAF,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0xAF,0x60,0x60,0xBF,0xCF,0xCF,0xCF,0xBF,0xBF,0x9F,0x8F,0x9F,0x60,0xAF,0x60,0x9F,0x51,0x9F,0x51,0x9F,0x63,0x52,0x9F,0x52,0x9F,0x42,0x8F,0x42,0x42,0x8F,0x52,0x42,0x42,0x8F,0x42,0x43,0x42,0x42,0x43,0x42,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x43,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x7F,0x7F,0x42,0x8F,0x42,0x52,0x52,0x9F,0x43,0x52,0x43,0x9F,0x43,0x63,0x63,0x63,0xAF,0x63,0x43,0x42,0x42,0x63,0x52,0x63,0x42,0x52,0x9F,0x42,0x42,0x42,0x8F,0x42
.byte 0x50,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x8F,0x50,0x9F,0x50,0x9F,0x60,0x9F,0x60,0x9F,0x60,0x9F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x6F,0x6F,0x7F,0xBF,0xCF,0xCF,0xCF,0xDF,0xDF,0xDF,0xDF,0xDF,0xF5,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF5,0xEF,0xF5,0xF5,0xBF,0x7F,0x7F,0x41,0x61,0x62,0x72,0x72,0x82,0x72,0x82,0x82,0x72,0x71,0xAF,0xAF,0xAF,0xAF,0xFE,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xDF,0xDF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0x60,0xAF,0x70,0xBF,0x70,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0xAF,0xBF,0xBF,0xAF,0xAF,0x9F,0x8F,0x7F,0xAF,0x60,0xAF,0xAF,0x9F,0x9F,0x9F,0x52,0xAF,0x63,0x63,0x52,0x43,0x8F,0x42,0x42,0x9F,0x9F,0x9F,0x43,0x42,0x42,0x42,0x43,0x42,0x43,0x43,0x43,0x43,0x43,0x42,0x43,0x43,0x43,0x43,0x43,0x43,0x63,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x52,0x9F,0x43,0x42,0x43,0x52,0x43,0x43,0x43,0x42,0x42,0x42,0x43,0x73,0x9F,0x43,0x52,0x42,0x63,0xAF,0x63,0x42,0x63,0x42,0x42,0x42,0x52,0x42,0x7F
.byte 0x9F,0x50,0x9F,0x50,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x60,0x9F,0x9F,0x50,0x9F,0x60,0x9F,0x50,0x9F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x7F,0x6F,0x7F,0x6F,0x9F,0xBF,0xCF,0xCF,0xFB,0xDF,0xDF,0xDF,0xF5,0xDF,0xDF,0xFF,0xFF,0xFF,0xFF,0xEF,0xF5,0xEF,0xF5,0xF5,0xF5,0xF5,0xBF,0x7F,0x41,0x41,0x61,0x72,0x72,0x72,0x82,0x72,0x82,0x82,0x81,0xBF,0xAF,0xAF,0x9E,0xAF,0xEE,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xEF,0xDF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xCF,0xBF,0xBF,0xBF,0xAF,0xBF,0xAF,0xAF,0xBF,0xAF,0x70,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0xAF,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0xAF,0x60,0x9F,0x60,0x9F,0xAF,0xAF,0x63,0x63,0xAB,0x63,0x42,0x42,0x63,0x42,0x9F,0xAF,0x52,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x63,0x43,0x42,0x43,0x42,0x42,0x42,0x43,0x43,0x43,0x43,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x8F,0x42,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x8F,0x42,0x52,0x42,0x42,0x42,0x43,0x42,0x52,0x9F,0x43,0x42,0x42,0x42,0x52,0x63,0x52,0x42,0x42,0x43,0x63,0x52,0x42,0x52,0x52,0x8F,0x42,0x42,0x52,0x42
.byte 0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x60,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x8F,0xAF,0xBF,0xBF,0xCF,0xDF,0xDF,0xFB,0xDF,0xCF,0xDF,0xEF,0xFF,0xFF,0xFF,0xF5,0xEF,0xEF,0xF5,0xF5,0xDF,0xDF,0xDF,0xAF,0x6F,0x7F,0x41,0x61,0x61,0x72,0x72,0x72,0x82,0x72,0x82,0x82,0x71,0xAF,0xBF,0xBF,0x9E,0xBF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xDF,0xDF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0x70,0xAF,0xBF,0xAF,0xBF,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0xAF,0x9F,0x8F,0x7F,0x7F,0x7F,0x9F,0xAF,0x60,0x9F,0x9F,0xAF,0x62,0x52,0x63,0x63,0x42,0x42,0x42,0x9B,0x52,0xAF,0x9F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x43,0x42,0x42,0x42,0x43,0x42,0x43,0x42,0x43,0x43,0x43,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x9F,0x42,0x9F,0x42,0x42,0x52,0x42,0x52,0x63,0x63,0x52,0x63,0x43,0x52,0x52,0x42,0x52,0x42,0x42,0x42,0x52,0x52,0x52,0x42,0x52,0x42,0x42,0x42,0x52,0x52
.byte 0x50,0x9F,0x50,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x60,0x9F,0x50,0x9F,0x50,0xAF,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x8F,0x8F,0x7F,0x7F,0x7F,0x7F,0x8F,0xBF,0xBF,0xBF,0xBF,0xBF,0xCF,0xDF,0xCF,0xDF,0xDF,0xF5,0xDF,0xEF,0xF5,0xEF,0xEF,0xF5,0xF5,0xDF,0xF5,0xF5,0xDF,0xCF,0x8F,0x6F,0x7F,0x41,0x61,0x62,0x72,0x72,0x72,0x82,0x82,0x72,0x82,0x71,0xAF,0xAF,0xBF,0xBF,0xBF,0xFE,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xEF,0xDF,0xDF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xBF,0xAF,0x70,0xBF,0xAF,0xBF,0xAF,0xAF,0x70,0xAF,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0xAF,0x60,0x60,0x60,0x9F,0x8F,0x7F,0x6F,0x7F,0x9F,0xAF,0x51,0xAF,0xAF,0xAF,0x63,0xC5,0x52,0x42,0x43,0x63,0x52,0xAF,0xAF,0x42,0x8F,0x52,0x42,0x43,0x9F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x43,0x42,0x43,0x42,0x43,0x42,0x43,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x9F,0x42,0x8F,0x42,0x42,0x42,0x42,0x9F,0x43,0x42,0x63,0x52,0x43,0x42,0x42,0x9F,0x43,0x42,0x42,0x42,0x42,0x52,0x52,0x52,0x52,0x52,0x42,0x42,0x42,0x42
.byte 0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x60,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x9F,0x8F,0x8F,0x9F,0x9F,0x9F,0x8F,0x7F,0x8F,0x9F,0xBF,0xCF,0xDF,0xCF,0xCF,0xDF,0xEF,0xDF,0xDF,0xF5,0xDF,0xDF,0xDF,0xCF,0xCF,0xF5,0xDF,0x8F,0x7F,0x7F,0x7F,0x41,0x61,0x61,0x72,0x72,0x82,0x72,0x82,0x72,0x72,0xBF,0xBF,0xAF,0xAF,0x9E,0xBF,0xCF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xDF,0xDF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0xBF,0xAF,0xBF,0x70,0xAF,0x70,0xBF,0xAF,0x70,0xAF,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x70,0x60,0x9F,0x8F,0x7F,0x6F,0x8F,0x9F,0xAF,0x61,0x52,0x52,0x52,0x43,0x9F,0x63,0x9F,0x9F,0xAF,0x9F,0x42,0x42,0x9B,0x43,0x43,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x43,0x42,0x43,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x45,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x6F,0x42,0x8F,0x52,0x9F,0x8F,0x8F,0x42,0x8F,0x42,0x42,0x42,0x52,0x42,0x43,0x42,0x42,0x9F,0x42,0x42,0x42,0x42,0x42,0x42,0x52,0x52,0x42,0x42,0x52,0x42,0x52,0x42,0x42
.byte 0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x7F,0x6F,0x6F,0x6F,0x6F,0x6F,0x6F,0x6F,0x6F,0x6F,0x7F,0x9F,0xAF,0xCF,0xDF,0xDF,0xDF,0xDF,0xDF,0xCF,0xCF,0xE5,0xCF,0xDF,0xCF,0xAF,0x6F,0x7F,0x7F,0x7F,0x7F,0x51,0x61,0x71,0x72,0x82,0x82,0xA3,0x82,0x72,0x71,0xBF,0xBF,0xBF,0xBF,0xAE,0xAF,0xDF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xFD,0xDF,0xDF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xBF,0x70,0xAF,0xBF,0xAF,0xBF,0xAF,0x70,0xAF,0x70,0xAF,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0xAF,0x60,0xAF,0x60,0x60,0x60,0xAF,0x40,0x7F,0x41,0xAF,0xAF,0x9F,0x52,0x9F,0x63,0x43,0x52,0x63,0xAF,0x73,0x9F,0x52,0x52,0x52,0x42,0x52,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x43,0x42,0x42,0x7F,0x42,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x9F,0x42,0x8F,0x52,0x9F,0x52,0x8F,0x8F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x52,0x52,0x42,0x42,0x42,0x42,0x42,0x63,0x9F,0x43,0x42,0x42,0x52,0x42,0x42
.byte 0x9F,0x60,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x7F,0x7F,0x7F,0x6F,0x7F,0x6F,0x7F,0x6F,0x6F,0x6F,0x6F,0x6F,0x6F,0x9F,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xCF,0xBF,0xBF,0x9F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x61,0x72,0x72,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0xBF,0xBF,0xAF,0xBF,0x9E,0xBF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xEF,0xDF,0xDF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0xBF,0xAF,0xAF,0xBF,0xAF,0x70,0xAF,0xBF,0xAF,0x70,0xAF,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x61,0xAF,0x41,0x8F,0x42,0x52,0xDA,0xAF,0x73,0xAF,0xC5,0x52,0x42,0xAB,0x43,0x42,0x8F,0x42,0x42,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x43,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x7F,0x42,0x7F,0x8F,0x8F,0x9F,0x8F,0x8F,0x52,0x9F,0x42,0x8F,0x42,0x9F,0x42,0x9F,0x42,0x9F,0x43,0x52,0x52,0x9F,0x42,0x42,0x42,0x42,0x43,0x52,0x52,0x42,0x42,0x52,0x52,0x42
.byte 0x50,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x9F,0x50,0x9F,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x8F,0x8F,0x6F,0x7F,0x7F,0x7F,0x6F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x6F,0x8F,0xAF,0xBF,0xBF,0xCF,0xBF,0xBF,0xBF,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x51,0x71,0x82,0x72,0x82,0x82,0x92,0x92,0x92,0x92,0x82,0x71,0xBF,0xAE,0xBF,0xBF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xFD,0xDF,0xDF,0xDF,0xCF,0xCF,0xBF,0xBF,0xBF,0xAF,0xBF,0xAF,0xBF,0xAF,0xBF,0xAF,0xAF,0xAF,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x50,0xAF,0x51,0xAF,0xAF,0x42,0x8F,0x9F,0x63,0x73,0xAF,0x63,0x73,0xAF,0x42,0x42,0x52,0x42,0x8F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x8F,0x42,0x8F,0x8F,0x8F,0x42,0x9F,0x52,0x9F,0x52,0x63,0x42,0x42,0x42,0x42,0x42,0x42,0x63,0x52,0x52,0x42,0x42,0x42,0x52,0x63,0x42,0x42,0x42,0x42,0x52,0x52
.byte 0x9F,0x60,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x50,0x9F,0x9F,0x9F,0x50,0x9F,0x9F,0x9F,0x50,0x9F,0x9F,0x50,0x9F,0x50,0x9F,0x60,0x9F,0x50,0x9F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x8F,0x9F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x7F,0x7F,0x7F,0x8F,0x51,0x72,0x82,0x82,0x82,0x92,0x82,0x92,0x82,0x92,0x92,0x81,0xBF,0xAF,0xAE,0xBF,0xFE,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xEF,0xFD,0xDF,0xDF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xAF,0xBF,0xAF,0xAF,0xAF,0xAF,0x70,0xAF,0xAF,0xAF,0x70,0xAF,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x9F,0x60,0xAF,0x50,0xAF,0x61,0x9F,0x42,0x42,0x9F,0xD5,0x52,0xC5,0x9F,0x63,0x52,0x42,0x9F,0x43,0x42,0x7F,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x42,0x52,0x52,0x42,0x42,0x42,0x42,0x9F,0x43,0x52,0x9F,0x63,0x9F,0x52,0x42,0x52,0x52,0x9F,0x43,0x42,0x52,0x42,0x42
.byte 0x50,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x50,0x9F,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x9F,0x50,0x9F,0x9F,0x50,0x9F,0x50,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x6F,0x7F,0x7F,0x6F,0x7F,0x6F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x40,0x51,0x71,0x82,0x82,0x92,0x92,0x92,0x82,0x92,0x92,0x82,0x82,0xBF,0xBF,0xBF,0xBF,0xEE,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xEF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xAF,0xBF,0xAF,0xBF,0xAF,0xAF,0xAF,0xAF,0x70,0xAF,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x50,0x9F,0x60,0xAF,0x9F,0x9F,0x42,0x8F,0x52,0xAF,0xD5,0x52,0x63,0x52,0xAB,0x52,0x43,0x52,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x8F,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x7F,0x7F,0x42,0x42,0x7F,0x42,0x6F,0x42,0x42,0x8F,0x8F,0x8F,0x8F,0x8F,0x42,0x8F,0x8F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x63,0x52,0x42,0x63,0x52,0x42,0x9F,0x43,0x52,0x42,0x42,0x52,0x42,0x42
.byte 0x9F,0x60,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x50,0x9F,0x9F,0x9F,0x50,0x9F,0x9F,0x50,0x9F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x7F,0x6F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x7F,0x6F,0x7F,0x7F,0x7F,0x7F,0x8F,0x51,0x61,0x61,0x72,0x82,0x82,0x92,0x92,0x92,0x92,0x82,0x82,0x81,0xBF,0xAF,0xAF,0x9E,0xCF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xDF,0xDF,0xDF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x70,0xAF,0x60,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0xAF,0x60,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0xAF,0x60,0xAF,0x50,0x9F,0xAF,0x51,0x9F,0x9F,0x42,0x52,0xD5,0x52,0xAF,0x63,0x52,0x52,0x42,0x63,0xAB,0x52,0x7F,0x8F,0x42,0x9F,0x42,0x42,0x42,0x8F,0x42,0x42,0x42,0x42,0x8F,0x42,0x7F,0x7F,0x42,0x42,0x42,0x8F,0x42,0x42,0x8F,0x42,0x42,0x8F,0x42,0x7F,0x8F,0x7F,0x42,0x7F,0x7F,0x42,0x8F,0x9F,0x8F,0x41,0x8F,0x8F,0x8F,0x8F,0x42,0x9F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x52,0x42,0x42,0x52,0x9F,0x43,0x42,0x8F,0x43,0x42,0x42,0x42,0x52,0x42
.byte 0x50,0x9F,0x50,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x50,0x9F,0x40,0x9F,0x40,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x50,0x9F,0x9F,0x50,0x9F,0x9F,0x9F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x6F,0x7F,0x6F,0x7F,0x7F,0x7F,0x8F,0x8F,0x40,0x8F,0x50,0x51,0x61,0x71,0x82,0x82,0x92,0x92,0x92,0x92,0x92,0x82,0x71,0xBF,0xBF,0xAF,0xAF,0xCF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xFD,0xDF,0xDF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xAF,0xBF,0xAF,0xAF,0xBF,0xAF,0xBF,0x70,0xAF,0xAF,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0xAF,0x60,0x60,0xAF,0x60,0x60,0x9F,0x60,0x9F,0xAF,0xAF,0xAF,0x9F,0x9F,0x8F,0x52,0xAF,0x63,0x52,0x9F,0x63,0x52,0x9B,0x52,0x52,0x42,0x42,0x42,0x42,0x42,0x42,0x8F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x8F,0x8F,0x8F,0x8F,0x42,0x7F,0x42,0x7F,0x42,0x9F,0x9F,0x8F,0x40,0x8F,0x8F,0x8F,0x8F,0x8F,0x42,0x8F,0x42,0x8F,0x42,0x42,0x8F,0x42,0x42,0x52,0x42,0x52,0x43,0x9F,0x42,0x42,0x52,0x43,0x42,0x52,0x52,0x42
.byte 0x9F,0x60,0x9F,0x9F,0x50,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x50,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x50,0x9F,0x9F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x6F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x6F,0x7F,0x7F,0x6F,0x7F,0x6F,0x7F,0x6F,0x7F,0x8F,0x41,0x8F,0x51,0x9F,0x51,0xAF,0x72,0x82,0x82,0x92,0x92,0x92,0x92,0x92,0x82,0x71,0xBF,0xBF,0xAF,0x9E,0xBF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xEF,0xDF,0xDF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0xAF,0x60,0xAF,0x50,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x8F,0x52,0x63,0x42,0xAF,0x52,0x9F,0x43,0x52,0x52,0x42,0x42,0x8F,0x42,0x42,0x9F,0x42,0x42,0x42,0x9F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x8F,0x7F,0x8F,0x8F,0x9F,0x8F,0x8F,0x7F,0x42,0x7F,0x7F,0x42,0x42,0x9F,0x8F,0x8F,0x41,0x8F,0x8F,0x41,0x8F,0x42,0x9F,0x42,0x42,0x8F,0x42,0x42,0x42,0x42,0x42,0x42,0x9F,0x52,0x42,0x52,0x42,0x42,0x52,0x42,0x42,0x9F,0x43
.byte 0x50,0x9F,0x50,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x40,0x9F,0x9F,0x9F,0x9F,0x9F,0x50,0x9F,0x9F,0x50,0x9F,0x9F,0x9F,0x9F,0x8F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x6F,0x7F,0x7F,0x7F,0x6F,0x7F,0x7F,0x6F,0x7F,0x6F,0x7F,0x6F,0x7F,0x7F,0x6F,0x7F,0x7F,0x7F,0x7F,0x40,0x9F,0x40,0x8F,0x9F,0x51,0x71,0x82,0x92,0x92,0x92,0x92,0x92,0x92,0x82,0x81,0xBF,0xBF,0xAF,0xAF,0xBF,0xEF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xDF,0xDF,0xDF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0xAF,0xAF,0x70,0xAF,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0x9F,0x50,0xAF,0xAF,0x51,0x9F,0x9F,0x8F,0x42,0x63,0x52,0x63,0x9F,0x52,0x9F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x52,0x52,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x8F,0x42,0x42,0x8F,0x8F,0x42,0x9F,0x42,0x8F,0x8F,0x8F,0x42,0x7F,0x42,0x8F,0x9F,0x9F,0x40,0x8F,0x41,0x8F,0x41,0x9F,0x42,0x42,0x8F,0x42,0x42,0x8F,0x8F,0x42,0x8F,0x42,0x42,0x42,0x9F,0x42,0x52,0x42,0x52,0x42,0x43,0x42,0x42,0x42
.byte 0x9F,0x60,0x9F,0x9F,0x50,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x50,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x8F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x6F,0x7F,0x6F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F,0x8F,0x7F,0x8F,0x40,0x8F,0x9F,0x72,0x82,0x92,0x92,0x92,0x92,0x92,0x92,0x82,0x71,0xBF,0xAF,0xAE,0xAF,0xAF,0xDE,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xDF,0xDF,0xDF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0x60,0xAF,0x60,0x60,0x60,0x60,0xAF,0x60,0x9F,0x60,0xAF,0xAF,0xAF,0x9F,0x9F,0x8F,0x41,0x42,0x9F,0x63,0x52,0x43,0x8F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x9B,0x52,0x42,0x42,0x52,0x42,0x43,0x9F,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x8F,0x42,0x8F,0x9F,0x8F,0x9F,0x42,0x8F,0x8F,0x8F,0x7F,0x42,0x8F,0x8F,0x9F,0x8F,0x41,0x8F,0x41,0x9F,0x41,0x8F,0x42,0x42,0x42,0x42,0x42,0x8F,0x8F,0x8F,0x42,0x42,0x42,0x42,0x42,0x42,0x8F,0x42,0x42,0x42,0x8F,0x42,0x42
.byte 0x50,0x9F,0x50,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x50,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x7F,0x6F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x8F,0x8F,0x40,0x61,0x72,0x82,0x92,0x92,0x92,0x92,0x92,0x92,0x82,0x71,0xBF,0xAF,0xAF,0x9E,0xAF,0xBF,0xFF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xEF,0xDF,0xDF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0xAF,0x60,0xAF,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x70,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0xAF,0x60,0x60,0x60,0x60,0xAF,0x60,0x60,0x60,0xAF,0x60,0x9F,0x60,0xAF,0xAF,0x50,0x9F,0x9F,0x8F,0x42,0x42,0xC5,0x9F,0x43,0x42,0x8F,0x42,0x8F,0x42,0x42,0x42,0x42,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x43,0x43,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x8F,0x42,0x8F,0x42,0x42,0x8F,0x42,0x8F,0x8F,0x8F,0x7F,0x42,0x8F,0x8F,0x8F,0x8F,0x41,0x9F,0x40,0x9F,0x41,0x42,0x8F,0x42,0x52,0x42,0x8F,0x8F,0x41,0x8F,0x8F,0x42,0x9F,0x42,0x8F,0x42,0x8F,0x42,0x42,0x42,0x42,0x8F,0x42
.byte 0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x41,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x6F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x40,0x8F,0x8F,0x51,0x61,0xC3,0x82,0x92,0x92,0x92,0x92,0x92,0x82,0x82,0x71,0xBF,0xAF,0xBF,0xAF,0xAF,0xBF,0xEF,0xFF,0xFF,0xFF,0xFF,0xEF,0xEF,0xEF,0xDF,0xDF,0xCF,0xCF,0xBF,0xBF,0xBF,0xAF,0xBF,0xAF,0x60,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0x60,0x60,0x9F,0x60,0x60,0x60,0xAF,0x60,0xAF,0x60,0x9F,0x60,0x9F,0xAF,0xAF,0x9F,0x51,0x9F,0x9F,0x42,0x9F,0x63,0x52,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x8F,0x42,0x8F,0x42,0x8F,0x42,0x42,0x8F,0x42,0x7F,0x8F,0x7F,0x8F,0x52,0x8F,0x9F,0x8F,0x40,0x41,0x9F,0x41,0x8F,0x8F,0x42,0x42,0x42,0x42,0x8F,0x9F,0x41,0x8F,0x41,0x8F,0x42,0x8F,0x8F,0x42,0x8F,0x42,0x42,0x42,0x42,0x42,0x42
.byte 0x50,0x9F,0x50,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x41,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x41,0x8F,0x7F,0x7F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x8F,0x8F,0x6F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x9F,0x9F,0x9F,0x41,0x9F,0x61,0xC3,0x82,0x82,0x92,0x92,0x92,0x92,0x92,0x92,0x82,0x71,0xBF,0xBF,0xAE,0xAF,0x9E,0xBF,0xDE,0xFF,0xFF,0xFF,0xEF,0xEF,0xEF,0xDF,0xDF,0xCF,0xCF,0xBF,0xBF,0xBF,0xAF,0xAF,0x70,0xAF,0xAF,0x60,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x70,0xAF,0x60,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0x60,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x50,0xAF,0xAF,0x60,0x9F,0x9F,0x9F,0x8F,0x52,0x52,0x52,0x42,0x42,0x9F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x8F,0x7F,0x8F,0x42,0x42,0x8F,0x42,0x42,0x8F,0x7F,0x8F,0x7F,0x42,0x9F,0x9F,0x9F,0x40,0x9F,0x40,0x40,0x8F,0x41,0x8F,0x42,0x42,0x8F,0x42,0x8F,0x9F,0x40,0x8F,0x9F,0x41,0x9F,0x40,0x9F,0x42,0x8F,0x42,0x8F,0x42,0x8F,0x42,0x42
.byte 0x50,0xAF,0x50,0x9F,0x50,0x9F,0x9F,0x41,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x8F,0x6F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x8F,0x8F,0x40,0x9F,0x51,0x51,0x61,0x72,0x72,0x82,0x82,0x82,0x92,0x92,0x92,0x92,0x92,0x82,0x82,0xBF,0xBF,0xAF,0xBF,0xBF,0xAF,0xBF,0xAE,0xEF,0xFF,0xFF,0xEF,0xEF,0xDF,0xDF,0xCF,0xCF,0xBF,0xBF,0xBF,0xBF,0xAF,0xAF,0xAF,0x60,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0x9F,0xAF,0xAF,0xAF,0x9F,0x9F,0x52,0x42,0x9F,0x9F,0x52,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x8F,0x8F,0x42,0x8F,0x8F,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x9F,0x9F,0x40,0x9F,0x40,0x9F,0x40,0x8F,0x41,0x8F,0x42,0x8F,0x8F,0x8F,0x9F,0x9F,0x41,0x40,0x8F,0x41,0x9F,0x40,0x8F,0x8F,0x42,0x42,0x42,0x42,0x42,0x42,0x42
.byte 0x50,0x9F,0x50,0x9F,0x9F,0x50,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x51,0x8F,0x7F,0x7F,0x7F,0x7F,0x8F,0x8F,0x40,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x8F,0x40,0x9F,0x51,0xAF,0x61,0x72,0x82,0x82,0x82,0x82,0x82,0x92,0x92,0x92,0x92,0x92,0x82,0x81,0xBF,0xAF,0xAF,0x9E,0xBF,0x9E,0xAF,0xBE,0xCF,0xFF,0xEF,0xDF,0xDF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0x60,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x60,0x9F,0x60,0x9F,0x60,0xAF,0x9F,0x60,0x9F,0x8F,0x8F,0x52,0x9F,0x8F,0x42,0x52,0x42,0x42,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x8F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x8F,0x42,0x8F,0x42,0x8F,0x8F,0x42,0x42,0x8F,0x42,0x7F,0x42,0x7F,0x42,0x9F,0x8F,0x9F,0x40,0x9F,0x40,0x40,0x8F,0x40,0x8F,0x42,0x8F,0x8F,0x42,0x9F,0x9F,0x9F,0x40,0x9F,0x40,0x9F,0x40,0x8F,0x41,0x7F,0x42,0x8F,0x42,0x8F,0x42,0x42
.byte 0x50,0x9F,0x60,0x9F,0x50,0x9F,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0xAF,0x61,0x9F,0x8F,0x41,0x8F,0x40,0x8F,0x8F,0x7F,0x7F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x8F,0x9F,0x50,0xAF,0x72,0x72,0x82,0x82,0x82,0x82,0x82,0x82,0x92,0x82,0x92,0x92,0x92,0x82,0x71,0xBF,0xBF,0xAF,0xAF,0xBF,0xAF,0xAF,0xBE,0xBF,0xDF,0xEF,0xDF,0xCF,0xCF,0xCF,0xBF,0xBF,0xBF,0x70,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x70,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0xAF,0x9F,0x9F,0x9F,0x8F,0x8F,0x62,0x9F,0x42,0x9F,0x43,0x42,0x42,0x42,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x8F,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x8F,0x42,0x8F,0x42,0x8F,0x42,0x8F,0x8F,0x42,0x42,0x42,0x8F,0x42,0x7F,0x42,0x42,0x8F,0x9F,0x40,0x8F,0x40,0x8F,0x40,0x9F,0x41,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0x40,0x8F,0x40,0x41,0x40,0x8F,0x40,0x8F,0x42,0x8F,0x42,0x42,0x8F,0x42,0x42
.byte 0x50,0x60,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x61,0xBF,0x61,0x61,0x9F,0x51,0x9F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x8F,0x8F,0x7F,0x40,0x9F,0x51,0x61,0x72,0x82,0xC3,0x82,0x82,0x82,0x82,0x82,0x92,0x92,0x92,0x92,0xB2,0xB2,0xC3,0xCF,0xCF,0xBF,0xAF,0xAF,0xAE,0xAF,0xAE,0xBE,0xCF,0xDF,0xCF,0xCF,0xBF,0xBF,0xBF,0x60,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xBF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x60,0x60,0x60,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x9F,0xAF,0x50,0xBF,0x9F,0x9F,0x9F,0xAF,0x9F,0x52,0x9F,0x8F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x43,0x7F,0x42,0x42,0x7F,0x42,0x7F,0x42,0x42,0x42,0x42,0x8F,0x8F,0x42,0x42,0x42,0x42,0x42,0x8F,0x42,0x42,0x42,0x42,0x7F,0x42,0x8F,0x8F,0x8F,0x40,0x9F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x8F,0x8F,0x41,0x8F,0x9F,0x9F,0x9F,0x40,0x8F,0x40,0x9F,0x40,0x8F,0x41,0x8F,0x7F,0x8F,0x42,0x42,0x8F,0x42
.byte 0x9F,0x50,0x60,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0xBF,0x71,0x72,0x71,0x71,0x61,0x51,0x9F,0x40,0x8F,0x7F,0x7F,0x7F,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x51,0x61,0x61,0x72,0x82,0x82,0x82,0x82,0x82,0x82,0x92,0xB2,0x92,0x92,0xB2,0xB2,0xB2,0x92,0xC3,0x82,0xB2,0x81,0xBF,0xAF,0xBF,0xAF,0xAF,0xAE,0xBF,0xCF,0xCF,0xBF,0xBF,0xBF,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xAF,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x9F,0xAF,0xAF,0x9F,0x9F,0xAF,0xAF,0x9F,0xAF,0x52,0x8F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x8F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x9F,0x8F,0x50,0x40,0x40,0x9F,0x40,0x8F,0x41,0x8F,0x8F,0x8F,0x9F,0x9F,0x9F,0x40,0x9F,0x40,0x40,0x9F,0x40,0x40,0x8F,0x41,0x8F,0x41,0x8F,0x42,0x42,0x8F
.byte 0x50,0x9F,0x60,0x9F,0x50,0x9F,0x9F,0x40,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x61,0xC3,0x82,0x82,0x82,0x72,0x71,0x51,0x9F,0x51,0x8F,0x40,0x8F,0x9F,0x9F,0x9F,0x9F,0x51,0xAF,0x61,0x72,0x72,0x72,0xC3,0x82,0x82,0x82,0x82,0xC3,0xB2,0xB2,0xB2,0x92,0xB2,0x92,0x92,0x92,0x92,0x92,0x82,0x82,0x71,0xBF,0xAF,0x9E,0xBF,0xBF,0xAE,0xBF,0xBF,0xBF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x60,0x9F,0x60,0xAF,0x9F,0xAF,0x9E,0xAF,0x9F,0x52,0x9F,0x8F,0x42,0x42,0x42,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x8F,0x8F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x9F,0x41,0x9F,0x40,0x8F,0x40,0x40,0x9F,0x40,0x8F,0x41,0x8F,0x9F,0x9F,0x9F,0x9F,0x40,0x9F,0x40,0x40,0x9F,0x40,0x40,0x8F,0x41,0x8F,0x8F,0x8F,0x42,0x42
.byte 0x50,0x9F,0x60,0x50,0x9F,0x50,0x9F,0x9F,0x9F,0x41,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x61,0xC3,0x81,0x82,0x82,0x82,0x72,0x61,0x61,0x61,0xAF,0x9F,0x51,0x9F,0x61,0xAF,0x61,0x61,0x61,0xC3,0x72,0x82,0x82,0x82,0x82,0xC3,0x82,0xC3,0x92,0xB2,0xB2,0x92,0x92,0x92,0x92,0x82,0x82,0x92,0x82,0x82,0x82,0x71,0xBF,0xAF,0xAF,0xAF,0x9E,0xBF,0xBF,0x70,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0xAF,0xAF,0x9F,0x9F,0xAF,0xAF,0x9F,0x52,0x9F,0x8F,0x8F,0x42,0x52,0x42,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x8F,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x9F,0x8F,0x9F,0x50,0x40,0x40,0x40,0x8F,0x40,0x8F,0x41,0x9F,0x9F,0x50,0x9F,0x8F,0x9F,0x40,0x40,0x9F,0x40,0x8F,0x40,0x8F,0x8F,0x8F,0x7F,0x42,0x8F,0x8F
.byte 0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x40,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0xAF,0x82,0x82,0x82,0x82,0x82,0x71,0x72,0x72,0x71,0x61,0x61,0x61,0xAF,0x61,0x61,0x61,0x72,0x72,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x92,0x92,0xB2,0x92,0x92,0x92,0x82,0xB3,0x82,0x82,0x92,0x82,0x82,0x81,0x71,0xAF,0xAF,0x9E,0xAF,0xAF,0xAE,0xBE,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x50,0xAF,0xBF,0x9F,0xAF,0x9E,0xAF,0x9F,0x52,0x8F,0x8F,0x8F,0x52,0x52,0x52,0x43,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x45,0x42,0x43,0x42,0x9F,0x42,0x42,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x52,0x52,0x8F,0x41,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x9F,0x9F,0x9F,0x9F,0x40,0x9F,0x40,0x8F,0x40,0x40,0x40,0x8F,0x40,0x8F,0x7F,0x7F,0x8F,0x8F,0x42,0x8F
.byte 0x50,0x50,0x9F,0x60,0x50,0x9F,0x50,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x9F,0x71,0xC3,0x82,0x81,0x72,0x72,0x72,0x72,0x72,0x72,0x72,0x72,0x72,0x72,0x72,0x72,0xC3,0x82,0x82,0x72,0x82,0x82,0x82,0x82,0x82,0x82,0xC3,0x92,0x92,0x92,0x82,0x92,0x82,0x82,0x82,0x82,0x82,0x82,0x81,0x71,0xBF,0xAF,0xAF,0xBF,0x9E,0xAF,0x9E,0xBF,0xAF,0x60,0x50,0xAF,0x60,0xAF,0x60,0xAF,0x70,0xAF,0x60,0xAF,0x70,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0xAF,0xBF,0x9E,0x9F,0xAF,0xAF,0x9F,0x42,0x8F,0x8F,0x8F,0x42,0x52,0x52,0x52,0x52,0x42,0x52,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x43,0x43,0x52,0x42,0x42,0x43,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x9F,0x8F,0x7F,0x9F,0x40,0x8F,0x40,0x40,0x40,0x9F,0x50,0x9F,0x9F,0x40,0x9F,0x40,0x8F,0x40,0x8F,0x40,0x40,0x8F,0x40,0x8F,0x7F,0x7F,0x42,0x8F,0x42,0x8F
.byte 0x9F,0x50,0x50,0x9F,0x50,0x50,0x9F,0x50,0x9F,0x40,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0xBF,0x82,0xC3,0x82,0x72,0x72,0x72,0x72,0x72,0x72,0x72,0x72,0x72,0x72,0x82,0x82,0x72,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0xB2,0x82,0xC3,0x92,0xB3,0x82,0x82,0x92,0x92,0x92,0x92,0x82,0x82,0x71,0x71,0xBF,0xAF,0x9E,0xAF,0xAF,0x9E,0xBF,0xAE,0xBF,0x50,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x50,0xAF,0xBF,0xAF,0x9F,0x9E,0x9F,0x42,0x42,0x42,0x8F,0x42,0x42,0x52,0x43,0x9F,0x43,0x43,0x42,0x42,0x43,0x42,0x43,0x42,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x45,0x42,0x42,0x42,0x43,0x42,0x43,0x42,0x43,0x52,0x43,0x42,0x45,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x9F,0x8F,0x8F,0x8F,0x40,0x8F,0x8F,0x40,0x9F,0x40,0x9F,0x9F,0x50,0x9F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x8F,0x7F,0x41,0x7F,0x8F,0x8F,0x8F,0x42
.byte 0x40,0x9F,0x50,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x40,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x61,0xD3,0x81,0xC3,0x72,0x72,0x82,0x72,0x82,0x72,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x72,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0xB2,0x82,0x82,0x92,0x82,0x92,0x92,0x92,0x82,0x82,0x82,0x71,0xBF,0xAF,0xAF,0xAF,0x9E,0xAF,0x9E,0x60,0xAF,0x9E,0xBF,0x60,0x50,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0xAF,0xAF,0x9F,0xBF,0xAF,0x9F,0xAF,0x9F,0x8F,0x42,0x8F,0x42,0x7F,0x42,0x52,0x43,0x52,0x52,0x43,0x42,0x43,0x42,0x43,0x43,0x42,0x42,0x43,0x42,0x43,0x42,0x42,0x45,0x42,0x45,0x42,0x45,0x42,0x42,0x42,0x43,0x42,0x43,0x42,0x43,0x52,0x43,0x42,0x45,0x42,0x45,0x42,0x42,0x42,0x42,0x7F,0x42,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x40,0x9F,0x9F,0x50,0x9F,0x9F,0x50,0x9F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x7F,0x7F,0x7F,0x41,0x8F,0x41,0x8F,0x42
.byte 0x40,0x40,0x9F,0x50,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x61,0xD3,0xC3,0x82,0x72,0x72,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x72,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0xB3,0x82,0x82,0x92,0x92,0x82,0x82,0x71,0xBF,0xAF,0x9F,0xAF,0xAF,0x9E,0xAF,0xAE,0x9E,0x9F,0xAF,0xAE,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xBF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xBF,0x70,0xAF,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x9F,0x60,0xAF,0x8E,0x9F,0x8E,0x8F,0x41,0x52,0x42,0x8F,0x42,0x42,0x52,0x52,0x42,0x43,0x52,0x43,0x42,0x43,0x43,0x43,0x43,0x42,0x43,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x45,0x42,0x42,0x42,0x43,0x42,0x43,0x52,0x43,0x43,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x52,0x9F,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x40,0x40,0x40,0x8F,0x40,0x9F,0x8F,0x40,0x8F,0x8F,0x40,0x8F,0x40,0x8F,0x41,0x8F,0x8F
.byte 0x8F,0x40,0x50,0x9F,0x50,0x50,0x50,0x9F,0x50,0x9F,0x40,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x71,0xD3,0x81,0x82,0x72,0x82,0x72,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x72,0x82,0x72,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x92,0x92,0x92,0x82,0x92,0x92,0xB2,0xC3,0xAF,0xAF,0x9F,0x9F,0x9E,0xAF,0x9E,0xAF,0xAF,0x9F,0xAF,0xAF,0xBF,0xBF,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x70,0xAF,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0xAF,0x70,0xAF,0x60,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0xAF,0x9F,0xAF,0xAF,0x9F,0xAF,0x8F,0x8F,0x52,0x8F,0x42,0x7F,0x42,0x63,0x42,0x43,0x52,0x43,0x42,0x43,0x43,0x42,0x43,0x43,0x42,0x43,0x43,0x42,0x43,0x42,0x42,0x42,0x45,0x42,0x45,0x42,0x42,0x42,0x42,0x42,0x43,0x42,0x43,0x52,0x43,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x52,0xAF,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x40,0x9F,0x50,0x9F,0x9F,0x40,0x8F,0x40,0x40,0x40,0x9F,0x8F,0x40,0x8F,0x40,0x40,0x8F,0x41,0x7F,0x41,0x8F
.byte 0x40,0x8F,0x50,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x40,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x71,0xC3,0x82,0x72,0x72,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x92,0x92,0x92,0x92,0x92,0x82,0x92,0xB2,0xB2,0xB2,0x71,0xAF,0xAF,0x40,0x9F,0x9E,0xAF,0xAF,0xBF,0xBF,0xAF,0xAF,0x9F,0x9F,0xAF,0xAF,0xAF,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xBF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xBF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x9F,0xAF,0x9F,0x9F,0x8E,0x8F,0x42,0x9F,0x9F,0x42,0x42,0x42,0x52,0x43,0x42,0x43,0x52,0x43,0x42,0x43,0x43,0x42,0x43,0x43,0x42,0x43,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x43,0x42,0x42,0x43,0x42,0x43,0x42,0x43,0x52,0x43,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x52,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x40,0x40,0x40,0x8F,0x40,0x9F,0x40,0x8F,0x40,0x40,0x8F,0x40,0x8F,0x8F,0x7F,0x42,0x8F
.byte 0x8F,0x40,0x8F,0x50,0x50,0x50,0x50,0x50,0x9F,0x50,0x9F,0x40,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x71,0xC3,0x82,0x72,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0xC3,0x82,0xC3,0x82,0xB2,0x82,0xC3,0x92,0x82,0xB2,0xB2,0x92,0x92,0x92,0x92,0x92,0x92,0xB2,0xC3,0x81,0xBF,0xAF,0x8E,0x40,0xAF,0xAE,0xBF,0xAF,0xAF,0xBF,0xAF,0x9E,0xAF,0xAF,0xAF,0x9F,0xAF,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xBF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xBF,0x70,0xAF,0x70,0xBF,0x60,0xBF,0x60,0xBF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x70,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x9F,0xAF,0x50,0xAF,0xAF,0x9F,0x9F,0xAF,0x7F,0x42,0x52,0x9F,0x42,0x8F,0x42,0x52,0x43,0x9F,0x43,0x43,0x52,0x43,0x42,0x43,0x43,0x42,0x43,0x42,0x43,0x42,0x43,0x42,0x42,0x42,0x42,0x45,0x42,0x42,0x43,0x42,0x42,0x43,0x42,0x43,0x42,0x43,0x43,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x9F,0x9F,0x9F,0x8F,0x7E,0x9F,0x9F,0x9F,0x9F,0x40,0x9F,0x9F,0x50,0x8F,0x40,0x40,0x9F,0x40,0x9F,0x8F,0x9F,0x40,0x40,0x8F,0x40,0x8F,0x42,0x8F,0x41
.byte 0x8F,0x40,0x40,0x9F,0x40,0x9F,0x50,0x50,0x50,0x9F,0x50,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x72,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0xB2,0x82,0xC3,0xB2,0xC3,0x92,0x92,0xB2,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0xB2,0x82,0xC3,0x71,0xAF,0x9F,0xAF,0xAE,0xBF,0xAF,0xAF,0x9E,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x70,0xAF,0xAF,0x70,0xBF,0x60,0xAF,0x70,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xBF,0x70,0xAF,0x70,0xAF,0x70,0xBF,0x60,0xBF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x9F,0x9F,0xAF,0x9F,0x9F,0x8E,0x8F,0x42,0x52,0x42,0x8F,0x42,0x42,0x43,0x52,0x43,0x52,0x42,0x42,0x43,0x42,0x42,0x42,0x45,0x42,0x43,0x43,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x43,0x42,0x43,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x40,0x40,0x8F,0x40,0x40,0x8F,0x9F,0x9F,0x8F,0x40,0x8F,0x40,0x8F,0x7F,0x7F,0x41,0x8F
.byte 0x8F,0x8F,0x40,0x40,0x40,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x40,0x9F,0x40,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x8F,0x9F,0x8F,0x8F,0x51,0xC3,0x82,0x82,0x82,0x82,0x82,0x72,0x82,0x82,0x82,0x72,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0xB2,0x82,0x82,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0xB2,0x82,0xC3,0x71,0xBF,0xAF,0xBF,0xAF,0xAF,0xAE,0x9F,0xAF,0xAF,0xAF,0xAF,0xAF,0x9E,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x70,0xBF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xBF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x9F,0xAF,0x50,0xAF,0x9F,0xAF,0x9F,0x9F,0xAF,0x7F,0x42,0x42,0x9F,0x42,0x7F,0x42,0x43,0x42,0xAB,0x63,0x42,0x43,0x42,0x43,0x42,0x43,0x42,0x43,0x42,0x43,0x42,0x43,0x42,0x42,0x42,0x43,0x42,0x43,0x42,0x43,0x42,0x42,0x43,0x42,0x42,0x43,0x42,0x42,0x42,0x45,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x9F,0x9F,0x9F,0x8F,0x8F,0x9F,0x9F,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x40,0x40,0x9F,0x40,0x9F,0x40,0x8F,0x8F,0x8F,0x40,0x8F,0x40,0x41,0x8F,0x41,0x40
.byte 0x40,0x8F,0x40,0x8F,0x40,0x9F,0x50,0x50,0x50,0x50,0x9F,0x50,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x71,0xC2,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x72,0x82,0x72,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0xB2,0x82,0xC3,0x81,0xBF,0x9F,0xAF,0xAF,0xBF,0xAF,0xAF,0x9F,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xBF,0x70,0xAF,0x70,0xBF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x60,0x9F,0x60,0xAF,0x9F,0x9F,0x9F,0xAF,0x9F,0x8F,0x8E,0x8F,0x42,0x42,0x8F,0x42,0x42,0x42,0x52,0x43,0x52,0x63,0x42,0x42,0x42,0x42,0x43,0x42,0x43,0x42,0x43,0x42,0x43,0x42,0x43,0x42,0x42,0x42,0x43,0x42,0x43,0x42,0x42,0x42,0x42,0x43,0x42,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x9F,0x9F,0x8F,0x7E,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x40,0x8F,0x40,0x9F,0x40,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x40,0x40,0x9F,0x40
.byte 0x8F,0x8F,0x40,0x8F,0x40,0x40,0x9F,0x50,0x9F,0x50,0x40,0x9F,0x40,0x9F,0x40,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x8F,0x9F,0x8F,0x9F,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x72,0x82,0x82,0x72,0x82,0x72,0x82,0x82,0x72,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x92,0x92,0x92,0x92,0x92,0xB2,0xB2,0x92,0x82,0x92,0xB2,0x82,0x82,0xBF,0xAF,0x9F,0xAF,0x9E,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9E,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xBF,0xBF,0xAF,0x70,0xAF,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xBF,0x70,0xBF,0x70,0xAF,0x70,0xAF,0x70,0xBF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0x60,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0x9F,0x9F,0x9F,0x8F,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x43,0x52,0x43,0x42,0x43,0x42,0x43,0x42,0x42,0x42,0x42,0x43,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x43,0x42,0x42,0x42,0x45,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x45,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x52,0x9F,0x9F,0x8F,0x8F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x40,0x40,0x9F,0x40,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x8F,0x40,0x40,0x8F,0x40,0x40,0x8F
.byte 0x8F,0x40,0x8F,0x40,0x8F,0x40,0x50,0x40,0x50,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x51,0xC3,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x72,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x92,0x92,0x92,0x92,0xB2,0xB2,0xB2,0x92,0x92,0x82,0x82,0x82,0x82,0x71,0xBF,0xBF,0xAF,0xAF,0xAF,0xAF,0x9E,0xAF,0xAF,0xAF,0x9E,0xAF,0xAF,0xAF,0xAF,0x9E,0xBF,0xAF,0xAF,0xAE,0xAF,0xBF,0x60,0xBF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xBF,0x70,0xBF,0x70,0xBF,0xAF,0x70,0xAF,0x70,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x50,0x9F,0x60,0x9F,0x9F,0x60,0x9F,0x9F,0xAF,0x9F,0x9F,0x9F,0x8F,0x42,0x42,0x8F,0x42,0x7F,0x43,0x52,0x42,0x9B,0x43,0x42,0x42,0x43,0x42,0x43,0x42,0x43,0x42,0x43,0x42,0x42,0x45,0x42,0x45,0x42,0x45,0x42,0x42,0x45,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x40,0x8F,0x40,0x9F,0x50,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x40,0x40,0x9F,0x40,0x40
.byte 0x8F,0x8F,0x40,0x8F,0x40,0x40,0x9F,0x40,0x50,0x50,0x40,0x9F,0x40,0x9F,0x40,0x9F,0x8F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0xAF,0x82,0xB2,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x92,0x92,0x92,0xB2,0xB2,0xB2,0xB2,0x92,0x92,0x82,0x92,0x82,0x82,0x82,0xBF,0xBF,0xAF,0xAF,0xAF,0x9F,0xAF,0xAF,0xAF,0x9E,0xAF,0xAF,0x9F,0xAF,0x9E,0xAF,0xAF,0xAF,0xAF,0x9E,0xBF,0xBF,0xBF,0xBF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x70,0xBF,0x70,0xBF,0x70,0xAF,0x70,0xAF,0x70,0xBF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0xAF,0x9F,0x8E,0x7F,0x42,0x9F,0x42,0x8F,0x42,0x42,0x42,0x43,0x52,0x42,0x42,0x42,0x43,0x42,0x43,0x42,0x42,0x43,0x42,0x43,0x42,0x42,0x45,0x42,0x45,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x45,0x42,0x42,0x45,0x42,0x45,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x9F,0xAF,0x9F,0x8F,0x7E,0x8F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x40,0x8F,0x40,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x8F,0x40,0x9F,0x40,0x40,0x8F,0x40
.byte 0x8F,0x40,0x8F,0x40,0x8F,0x40,0x40,0x9F,0x40,0x9F,0x50,0x50,0x9F,0x40,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x51,0x71,0xD3,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x72,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x92,0x92,0x92,0x92,0xB2,0x92,0x92,0x92,0x92,0x92,0x82,0x92,0x82,0x82,0x82,0x81,0xBF,0xBF,0x9E,0xAF,0x9E,0xAF,0x9E,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x9F,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9E,0xBF,0xBE,0xBF,0xBF,0x70,0xBF,0x70,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xBF,0x70,0xAF,0x70,0xBF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x9F,0x50,0xAF,0x50,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0x9F,0x9F,0x9F,0x7F,0x42,0x42,0x42,0x42,0x8F,0x52,0x42,0x42,0x52,0x52,0x42,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x43,0x42,0x43,0x42,0x45,0x42,0x42,0x45,0x42,0x42,0x45,0x42,0x45,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x52,0xAF,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x8F,0x8F,0x40,0x8F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x50,0x40,0x8F,0x40,0x8F
.byte 0x8F,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x40,0x40,0x50,0x9F,0x50,0x40,0x9F,0x40,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x9F,0x8F,0x8F,0xAF,0xD3,0xB2,0xB2,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x82,0x92,0x82,0x92,0x82,0x82,0x82,0x82,0x71,0xBF,0x9E,0xAF,0xAF,0xAF,0xAF,0xAF,0x8E,0xAF,0x9F,0x9E,0xAF,0xAF,0x9F,0x8E,0xAF,0xAF,0xAF,0x9E,0xAF,0x9F,0xAF,0xBE,0xBF,0xBF,0xBF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xBF,0x70,0xBF,0x70,0xBF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x50,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0x8F,0x9F,0x7F,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x52,0xAB,0x42,0x42,0x43,0x42,0x43,0x42,0x42,0x43,0x42,0x42,0x43,0x42,0x42,0x45,0x42,0x42,0x45,0x42,0x42,0x45,0x42,0x42,0x45,0x42,0x43,0x42,0x45,0x42,0x43,0x42,0x45,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x7F,0x52,0xAF,0x9F,0x8F,0x8F,0x8F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x8F,0x9F,0x9F,0x9F,0x9F,0x40,0x8F,0x40,0x40
.byte 0x40,0x8F,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x9F,0x40,0x50,0x9F,0x40,0x9F,0x40,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x9F,0x71,0xD3,0x81,0xB2,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x92,0x92,0x92,0x92,0x92,0x92,0x82,0x92,0x82,0x92,0x92,0x92,0x82,0x82,0x82,0x82,0x82,0x71,0xBF,0xAF,0xAF,0x9E,0xAF,0xAF,0xAF,0xAF,0x9E,0x9F,0xAF,0xAF,0x9E,0xAF,0xAF,0x9E,0xAF,0xAF,0xAF,0xAF,0x9F,0xAF,0xBF,0xBE,0xBF,0xAF,0xAF,0x70,0xBF,0x70,0xAF,0x70,0xBF,0x70,0xBF,0x70,0xBF,0x70,0xBF,0x70,0xBF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x9F,0x60,0x9F,0x50,0x9F,0x9F,0x50,0x9F,0x9F,0x9F,0x9F,0xAF,0xAF,0x8F,0x9F,0x8F,0x42,0x42,0x8F,0x42,0x7F,0x8F,0x42,0x42,0x52,0x63,0x42,0x42,0x42,0x43,0x42,0x43,0x42,0x42,0x43,0x42,0x42,0x43,0x42,0x42,0x45,0x42,0x42,0x45,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x9F,0x9F,0x9F,0x8F,0x8F,0x9F,0x8F,0x8F,0x9F,0x8F,0x9F,0x9F,0x40,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x40,0x8F,0x9F,0x9F,0x40,0x40,0x8F,0x40,0x8F
.byte 0x8F,0x40,0x8F,0x40,0x8F,0x40,0x40,0x40,0x40,0x40,0x50,0x40,0x9F,0x40,0x9F,0x40,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0xBF,0xD3,0xC2,0xC3,0x81,0x82,0x82,0x82,0x82,0x82,0x82,0xC3,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x92,0x92,0x92,0x92,0x82,0x92,0x92,0x82,0x92,0x82,0x92,0xB2,0xB2,0x92,0x82,0x82,0x72,0x61,0xAF,0xAF,0x9F,0x9F,0xAF,0x9F,0x8E,0xAF,0xAF,0xAF,0x8E,0xAF,0xAF,0x9E,0xAF,0x9E,0xAF,0x9E,0xAF,0x9E,0xAF,0xAF,0x9E,0xBF,0xAE,0xBE,0xBF,0xAF,0x70,0xBF,0x70,0xAF,0x70,0xBF,0x70,0xBF,0x70,0xBF,0x70,0xAF,0x70,0xBF,0x70,0xAF,0x60,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0x8F,0x9F,0x8F,0x7F,0x42,0x42,0x42,0x8F,0x42,0x8F,0x42,0x52,0x52,0x52,0x42,0x42,0x43,0x52,0x42,0x43,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x45,0x42,0x42,0x42,0x42,0x45,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x52,0x9F,0x7E,0x8F,0x8F,0x9F,0x9F,0x8F,0x8F,0x9F,0x8F,0x9F,0x8F,0x40,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x8F,0x8F,0x40,0x8F,0x40
.byte 0x8F,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x50,0x9F,0x40,0x9F,0x50,0x9F,0x40,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x9F,0xCF,0xD3,0x81,0xB2,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0xC3,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0xB2,0x92,0x92,0x82,0x82,0x72,0x61,0xAF,0xAF,0x9F,0x9F,0xAF,0xAF,0xAF,0xAF,0x8E,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9E,0xAF,0xAF,0x9E,0xAF,0xAF,0xAF,0xAF,0xAF,0xBE,0xBF,0xBF,0xAF,0xAF,0x70,0xBF,0x70,0xAF,0x70,0xBF,0x70,0xBF,0x70,0xBF,0x70,0xBF,0x60,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0x9F,0x9F,0x8F,0x7F,0x42,0x8F,0x42,0x8F,0x42,0x42,0x42,0x42,0x52,0x42,0x42,0x42,0x42,0x43,0x42,0x42,0x43,0x42,0x42,0x43,0x42,0x42,0x42,0x45,0x42,0x42,0x45,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x7E,0x9F,0x8F,0x9F,0x9F,0x8F,0x8F,0x9F,0x9F,0x9F,0x9F,0x8F,0x40,0x8F,0x9F,0x9F,0x40,0x9F,0x8F,0x40,0x8F,0x8F
.byte 0x40,0x8F,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x40,0x40,0x50,0x40,0x40,0x9F,0x40,0x8F,0x9F,0x8F,0x8F,0x9F,0x8F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x9F,0xAF,0xCF,0x81,0xD3,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x92,0x92,0x92,0x82,0x92,0x82,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0xB2,0xC3,0x92,0x82,0x82,0x72,0x61,0xAF,0x9E,0xAF,0x9F,0x8E,0xAF,0x8E,0xAF,0xAF,0xAF,0x8E,0xAF,0x9E,0xAF,0x9E,0xAF,0x9E,0xAF,0xAF,0x9E,0xAF,0x9E,0xBF,0x9E,0xAF,0xAE,0xAF,0xAF,0xAF,0x70,0xAF,0x70,0xBF,0x70,0xBF,0xAF,0x70,0xBF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0xAF,0x9F,0x8F,0x8F,0x7F,0x42,0x42,0x8F,0x42,0x7F,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x9B,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x45,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x42,0x9F,0x8F,0x7E,0x8F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x40,0x9F,0x8F,0x40,0x8F
.byte 0x8F,0x40,0x8F,0x40,0x8F,0x40,0x40,0x8F,0x40,0x40,0x9F,0x40,0x9F,0x40,0x9F,0x40,0x8F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x9F,0x8F,0x8F,0x9F,0x8F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0xBF,0xBF,0xC3,0x81,0xC3,0xC2,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0xB2,0x92,0x82,0x92,0x82,0x92,0x92,0x92,0xC3,0x92,0x92,0x82,0x92,0x92,0x92,0x82,0xB2,0x82,0x82,0x82,0x72,0x71,0xAF,0xAF,0x9E,0xAF,0xAF,0xAF,0xAF,0x8E,0x9F,0xAF,0xAF,0xAF,0xAF,0x9E,0x60,0x9E,0xAF,0x9E,0xAF,0xAF,0xAF,0xAF,0x9E,0xAF,0xAF,0xAE,0xBF,0xAE,0xAF,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xBF,0x70,0xAF,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x9F,0x60,0x9F,0x50,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0x9F,0x9F,0xAF,0x9F,0x9F,0x8F,0x7F,0x42,0x42,0x42,0x42,0x8F,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x52,0x52,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x8F,0x9F,0x8F,0x8F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x40,0x9F,0x8F,0x40,0x9F,0x40,0x40,0x8F,0x40,0x8F
.byte 0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x40,0x8F,0x40,0x40,0x40,0x40,0x40,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x8F,0x9F,0x8F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0xAF,0xBF,0xBF,0x81,0xC3,0x81,0x82,0xC3,0xC3,0x82,0x82,0xC3,0xD3,0xC3,0x82,0xB2,0xB2,0x82,0xC3,0x82,0x82,0x82,0x92,0x82,0x92,0x82,0x92,0x92,0x92,0x92,0x92,0x82,0x92,0x92,0x92,0x92,0xB2,0x82,0x92,0x82,0x82,0x72,0x71,0xBF,0xAF,0xAF,0x9E,0x9F,0x9E,0xAF,0xAF,0x9E,0x9F,0x9E,0xAF,0x8E,0xAF,0x9E,0xAF,0xAF,0xAF,0x9E,0xAF,0x9E,0xAF,0xAF,0xAE,0xBF,0x9E,0xAF,0xAE,0xAF,0x9F,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xBF,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x9F,0x60,0x9F,0x9F,0x9F,0x9F,0x50,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x60,0xAF,0xAF,0xAF,0x8F,0x8F,0x7F,0x42,0x42,0x8F,0x42,0x7F,0x8F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x42,0x9F,0x9F,0x8F,0x9F,0x9F,0x7E,0x40,0x7E,0x9F,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x40,0x9F,0x40,0x8F,0x40,0x8F
.byte 0x8F,0x40,0x9F,0x40,0x8F,0x40,0x8F,0x40,0x40,0x40,0x9F,0x40,0x9F,0x40,0x40,0x8F,0x40,0x8F,0x9F,0x8F,0x8F,0x8F,0x9F,0x8F,0x8F,0x9F,0x8F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0xAF,0xBF,0xBF,0x82,0x82,0xC3,0x82,0x82,0xC3,0xD3,0xD3,0xD2,0xC2,0xC2,0xC2,0xD2,0xD2,0xC2,0xB2,0xB2,0x92,0x82,0x82,0x92,0x82,0x92,0x92,0xB2,0xC3,0x92,0x82,0x92,0x82,0xC3,0x92,0x82,0x92,0x82,0x82,0x82,0x82,0x72,0x71,0xAF,0xAF,0x9E,0x9F,0xAF,0xAF,0x8E,0xAF,0xAF,0x8E,0x60,0x9E,0xAF,0xAF,0xAF,0x9E,0xAF,0x8E,0xAF,0xAF,0xAF,0x9E,0xAF,0x9E,0xBF,0xAE,0xBF,0x9E,0xBF,0xAF,0x40,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x50,0xAF,0x50,0x9F,0x50,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0x9F,0xAF,0x9F,0xAF,0xAF,0xAF,0x8F,0x8F,0x7F,0x42,0x42,0x42,0x8F,0x42,0x7F,0x42,0x8F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x9F,0x8F,0x7E,0x8F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x40,0x9F,0x40,0x9F,0x40,0x8F,0x40,0x8F,0x40
.byte 0x40,0x8F,0x40,0x9F,0x40,0x8F,0x40,0x8F,0x40,0x40,0x40,0x40,0x40,0x8F,0x40,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x8F,0x9F,0x8F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0xBF,0xAF,0x71,0x82,0xC3,0x81,0xC3,0x81,0xC3,0xD3,0xD3,0xC2,0xC3,0xC2,0xC2,0xD2,0xC1,0xC2,0xC2,0xC2,0xB2,0x92,0x92,0x82,0x92,0x92,0x92,0x92,0x92,0x82,0x92,0xC3,0x92,0x92,0x82,0x92,0x82,0x92,0x82,0x82,0x82,0x72,0x72,0xAF,0xAF,0xAF,0x9F,0x8E,0x9F,0xAF,0x9F,0x9E,0xAF,0x9E,0xAF,0xAF,0x8E,0xAF,0x9E,0xAF,0xAF,0x9E,0xAF,0x9E,0x60,0x9E,0xAF,0x9E,0xAF,0xAE,0xAF,0x9E,0xAF,0x8F,0x9F,0xAF,0x60,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x9F,0x60,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0x9F,0xAF,0x9F,0xAF,0x60,0xAF,0xAF,0x9F,0x8F,0x7F,0x42,0x8F,0x42,0x8F,0x42,0x7F,0x7F,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x7F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x8F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x40,0x8F,0x40,0x8F,0x8F,0x8F
.byte 0x9F,0x40,0x8F,0x40,0x8F,0x40,0x40,0x40,0x8F,0x40,0x9F,0x40,0x40,0x40,0x8F,0x40,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x8F,0x8F,0xAF,0xAE,0xAF,0x71,0xC3,0x81,0xC3,0x82,0xC3,0x81,0xC3,0xD3,0x81,0xB2,0xC2,0xC2,0xC2,0xC2,0xC2,0xC2,0xC2,0xB2,0xB2,0xB2,0xB2,0x92,0x92,0x92,0x82,0xB2,0x92,0x82,0x92,0xB2,0xB3,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x72,0x72,0x61,0xAF,0x8E,0xAF,0x9F,0xAF,0x8E,0xAF,0x9F,0x9F,0xAF,0x8E,0xAF,0xAF,0xAF,0xAF,0x9E,0xAF,0xAF,0x9E,0xAF,0x9E,0xAF,0x9E,0xAF,0xAE,0xAF,0xAF,0xAF,0x9E,0x40,0x8F,0xAF,0x70,0xAF,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x50,0xAF,0x50,0x9F,0x50,0x9F,0x9F,0x9F,0x9F,0xAF,0x9F,0xAF,0x60,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x8F,0x7F,0x7F,0x42,0x8F,0x42,0x7F,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x8F,0x9F,0x8F,0x8F,0x9F,0x7E,0x40,0x7E,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x40,0x8F,0x9F,0x40,0x9F,0x8F,0x9F,0x40,0x8F,0x40,0x8F,0x8F
.byte 0x40,0x9F,0x40,0x9F,0x40,0x8F,0x8F,0x40,0x40,0x40,0x40,0x9F,0x40,0x8F,0x40,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0xAF,0xBF,0x61,0x71,0x82,0xC3,0x82,0x82,0x82,0x82,0x82,0xC3,0x82,0xB2,0xC3,0xC2,0xC2,0xC2,0xB2,0xB2,0xB2,0xB2,0xB2,0xC2,0xB2,0xB2,0xB2,0xB2,0xB2,0xB2,0xC3,0xB2,0xC3,0x82,0xB2,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x72,0x72,0xBF,0xAF,0xAF,0x8E,0xAF,0xAF,0xAF,0x9E,0xAF,0x8E,0xAF,0xAF,0x8E,0xAF,0x9E,0xAF,0xAF,0x8E,0xAF,0xAF,0x9E,0xAF,0x9E,0xAF,0x9E,0xAF,0x9E,0xAF,0xAF,0x9E,0xAF,0x8F,0x60,0xAF,0x70,0xAF,0x70,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x51,0xAF,0x9F,0xAF,0x9F,0xAF,0x60,0xAF,0xAF,0xAF,0xAF,0x8F,0x7F,0x7F,0x42,0x42,0x7F,0x42,0x7F,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x9F,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x43,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x7F,0x42,0x9F,0x8F,0x8F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x9F,0x8F,0x9F,0x9F,0x8F,0x8F,0x40,0x8F,0x40,0x8F,0x8F
.byte 0x40,0x9F,0x40,0x40,0x8F,0x40,0x40,0x8F,0x8F,0x40,0x9F,0x40,0x40,0x9F,0x40,0x8F,0x40,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0xAF,0xBF,0x71,0x71,0x82,0x81,0xC3,0x82,0x82,0x71,0x82,0x82,0x82,0xB2,0xB2,0xC2,0xB2,0xB2,0xB2,0xB2,0x92,0x92,0xB2,0xB2,0xB2,0xB2,0xB2,0xB2,0xB2,0xC3,0xB2,0xC3,0x92,0xC3,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x72,0x72,0x61,0xAF,0x9F,0xAF,0x8E,0xAF,0x9E,0xAF,0x9F,0xAF,0x9F,0x9E,0x9F,0x9F,0xAF,0x8E,0xAF,0xAF,0x8E,0xAF,0xAF,0x9E,0x60,0x9E,0xAF,0x9E,0xAF,0xAE,0xAF,0xAF,0xBE,0x8F,0x8F,0xAF,0x70,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x50,0xAF,0x60,0x9F,0x50,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0xAF,0x9F,0xAF,0x60,0xAF,0xAF,0xAF,0x70,0xAF,0xAF,0x9F,0x8F,0x7F,0x42,0x7F,0x42,0x8F,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x52,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x9F,0x8F,0x8F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x40,0x9F,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x40,0x8F,0x8F,0x8F
.byte 0x9F,0x50,0x9F,0x40,0x8F,0x40,0x8F,0x40,0x40,0x8F,0x40,0x9F,0x40,0x40,0x8F,0x40,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x8F,0x8F,0x9F,0xAF,0xAF,0x71,0x72,0x82,0x82,0x82,0x82,0x82,0x82,0x72,0x82,0x82,0xB2,0xC2,0xB2,0xB2,0xB2,0xB2,0x92,0x92,0x92,0x92,0xB2,0xB2,0xB2,0xB2,0xC3,0xB2,0xB2,0xC3,0x92,0x82,0x82,0x82,0x82,0x82,0x82,0x92,0x82,0x82,0x82,0x72,0x72,0x71,0xAF,0x9F,0x9F,0xAF,0x8E,0xAF,0x9E,0xAF,0x8E,0xAF,0xAF,0xAF,0x9F,0x9E,0xAF,0x9E,0xAF,0xAF,0x8E,0x60,0x9E,0xAF,0xAF,0x9E,0xAF,0x9E,0xBF,0xAE,0x50,0xAE,0xAF,0x8F,0x9F,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x60,0xAF,0x60,0xAF,0x50,0xAF,0x50,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0x9F,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x8F,0x6F,0x8F,0x42,0x8F,0x42,0x7F,0x42,0x7F,0x42,0x7F,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x8F,0x8F,0x8F,0x9F,0x7E,0x40,0x7E,0x40,0x8F,0x8F,0x9F,0x8F,0x8F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F
.byte 0x40,0x9F,0x40,0x40,0x8F,0x40,0x8F,0x40,0x9F,0x40,0x9F,0x40,0x8F,0x40,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0xAF,0x60,0x71,0x71,0x72,0x82,0xC3,0x82,0x82,0x72,0x82,0x82,0x82,0x82,0xC2,0xB2,0xB2,0x92,0x92,0x92,0x92,0x92,0x92,0xB2,0x92,0xB2,0xB2,0xB2,0xC3,0x82,0x82,0x82,0xC3,0x82,0x82,0x92,0x92,0x82,0x92,0x82,0x82,0x82,0x72,0x72,0x71,0xAF,0x8E,0xAF,0x8E,0x60,0x8E,0xAF,0x9F,0xAF,0x8E,0xAF,0x8E,0xAF,0x9F,0x9E,0xAF,0x9E,0xAF,0xAF,0x8E,0xAF,0x8E,0xAF,0xAF,0x9E,0xAF,0xAE,0xAE,0xAF,0x9E,0xAE,0x40,0x8F,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x50,0xAF,0x60,0x9F,0x9F,0x50,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x60,0x9F,0xAF,0x60,0xAF,0xAF,0x70,0xAF,0xAF,0x9F,0x8F,0x7F,0x42,0x8F,0x42,0x42,0x7F,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x4A,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x7F,0x8F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F
.byte 0x9F,0x50,0x9F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x9F,0x40,0x40,0x40,0x8F,0x40,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0xAF,0xAF,0x9F,0x61,0x71,0x82,0x72,0x82,0x82,0x82,0x82,0x72,0x82,0x82,0xB2,0xC3,0xB2,0x82,0xB2,0x82,0x92,0x92,0x92,0xB2,0x92,0xB2,0x82,0x82,0x82,0x82,0x92,0x82,0x82,0x82,0x82,0x82,0xC3,0x92,0x92,0x82,0x82,0x82,0x82,0x72,0x72,0x71,0xBF,0xAF,0x9F,0x9F,0x8E,0xAF,0x8E,0x9F,0x9F,0xAF,0xAF,0xAF,0xAF,0x9F,0xAF,0x9E,0xAF,0x9E,0xAF,0xAF,0x9E,0x50,0x9E,0xAF,0x9E,0xAF,0x9E,0xBF,0xAE,0xAF,0xAF,0x9F,0x7F,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x9F,0x60,0x9F,0x60,0x9F,0x50,0x9F,0x40,0x9F,0x41,0x9F,0x9F,0x51,0x9F,0x9F,0xAF,0x9F,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x9F,0x8F,0x7F,0x7F,0x42,0x7F,0x42,0x7F,0x42,0x7F,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x8F,0x43,0x9F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x7F,0x8F,0x8F,0x9F,0x8F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F
.byte 0x40,0x9F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x9F,0x40,0x9F,0x40,0x8F,0x8F,0x8F,0x40,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0xAF,0xAF,0x9F,0x61,0x71,0x72,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0xB2,0x82,0x82,0x82,0x92,0x82,0x92,0xB2,0x92,0x92,0x92,0xB2,0x92,0x82,0x92,0x82,0x82,0x82,0x82,0x82,0x92,0x92,0x92,0x82,0x92,0x82,0x82,0x82,0x82,0x72,0x72,0xBF,0x9E,0x9F,0x8E,0x50,0x8E,0xAF,0xAF,0x8E,0x9F,0x9E,0xAF,0x8E,0x9F,0x9F,0xAF,0x9E,0xAF,0x8E,0xAF,0xAF,0x8E,0x9F,0xAF,0xAF,0x9E,0x70,0xAE,0xBF,0x9E,0xAF,0x9E,0x40,0x9F,0xAF,0x70,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x9F,0x60,0x9F,0x9F,0x9F,0x9F,0x9F,0x8F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0x60,0xAF,0x60,0xAF,0xAF,0x70,0xAF,0xAF,0x9F,0x8F,0x7F,0x7F,0x42,0x7F,0x42,0x7F,0x7F,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x7F,0x8F,0x9F,0x8F,0x7E,0x40,0x7E,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F
.byte 0x9F,0x50,0x9F,0x40,0x8F,0x40,0x8F,0x40,0x9F,0x8F,0x40,0x8F,0x9F,0x40,0x40,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0xAF,0x9F,0x9F,0x61,0x71,0x82,0x71,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x92,0x82,0x92,0x82,0x92,0x92,0x82,0x92,0x92,0xB2,0xB2,0x92,0x82,0xB2,0x82,0xC3,0x82,0x92,0x82,0x92,0x82,0x92,0x82,0x82,0x82,0x82,0x82,0x72,0x72,0x71,0xAF,0x9F,0x9F,0x9F,0x8E,0x9F,0x9F,0x9F,0x9F,0xAF,0xAF,0x9E,0xAF,0xAF,0x9F,0x9F,0x9F,0xAF,0xAF,0x8E,0x50,0x8E,0xAF,0x8E,0x60,0x9E,0x9E,0x9E,0xBF,0x9E,0x60,0x9E,0xBF,0x40,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0x9F,0x60,0x9F,0x50,0x9F,0x50,0x9F,0x40,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x60,0xAF,0x9F,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x8F,0x8F,0x7F,0x7F,0x42,0x7F,0x42,0x7F,0x42,0x8F,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x9F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x7F,0x9F,0x8F,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x8F,0x7F,0x8F,0x9F,0x8F,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x40
.byte 0x40,0x9F,0x40,0x40,0x8F,0x40,0x8F,0x8F,0x40,0x8F,0x8F,0x40,0x8F,0x9F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0xAF,0x9E,0x9F,0x9F,0x61,0x71,0x72,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0xB2,0x82,0xB2,0x82,0x92,0x82,0x92,0x82,0x82,0xB2,0x92,0x92,0xB2,0xC3,0xB2,0x82,0xC3,0x82,0x82,0x82,0x82,0x92,0x82,0x92,0x82,0x92,0x82,0x82,0x82,0x82,0x82,0x72,0x72,0xBF,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x8F,0x8F,0x9F,0x9E,0xAF,0xAF,0x8E,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x9E,0xAF,0xAF,0x9E,0xAF,0x9F,0xAF,0x9E,0xAF,0xAE,0xAE,0x40,0x9E,0xAF,0xAF,0x70,0xAF,0x70,0xAF,0x60,0xAF,0x60,0x9F,0x60,0x9F,0x50,0x9F,0x9F,0x40,0x9F,0x9F,0x9F,0x41,0x9F,0x9F,0x9F,0x9F,0xAF,0x9F,0xAF,0xAF,0x60,0xAF,0xAF,0x70,0xAF,0x60,0xAF,0xAF,0x9F,0x8F,0x7F,0x7F,0x42,0x42,0x7F,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x7F,0x8F,0x9F,0x8F,0x9F,0x8F,0x7E,0x40,0x7E,0x40,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F
.byte 0x40,0x40,0x8F,0x40,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x9F,0x40,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0xAF,0xAF,0x9F,0x9F,0x61,0x71,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0xB2,0x82,0xB2,0x82,0x82,0x92,0x82,0x92,0x82,0xB2,0x82,0xB2,0xC3,0xB2,0x82,0xB2,0x82,0x92,0x82,0x92,0x82,0x92,0x82,0x92,0x82,0x92,0x82,0xC3,0x82,0x82,0x82,0x72,0x71,0xBF,0x9E,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x7F,0x8F,0xAF,0x9E,0xAF,0x9F,0xAF,0x9F,0x8F,0x8E,0xAF,0x9F,0x9E,0xAF,0x8E,0xAF,0x9E,0xAF,0x9E,0xAF,0xAF,0x9E,0xBF,0x9F,0x40,0xBE,0x60,0xAF,0x70,0xAF,0x60,0xAF,0x60,0x9F,0x60,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x41,0x9F,0x41,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0xAF,0x60,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x60,0xAF,0x9F,0x8F,0x8F,0x7F,0x7F,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x7F,0x7F,0x8F,0x8F,0x8F,0x7E,0x40,0x9F,0x9F,0x9F,0x7E,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x40
.byte 0x40,0x8F,0x40,0x8F,0x40,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0xAF,0x9E,0x9F,0x9F,0x61,0x71,0x71,0x82,0x82,0x82,0x82,0x82,0x82,0xB2,0xC3,0x82,0x82,0xB2,0x82,0x92,0x82,0x82,0x82,0xB2,0xB2,0xB2,0x82,0xC3,0xB2,0x82,0x82,0x82,0x82,0x92,0x92,0x92,0x92,0x82,0x92,0x82,0x92,0x82,0x82,0x82,0x72,0x72,0x72,0xBF,0xAF,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0xAF,0xAF,0x8E,0x9F,0x9F,0x9F,0x9F,0xAF,0x8E,0x9F,0xAF,0x9E,0x60,0x9E,0x60,0x9E,0xAF,0x9E,0x9F,0xAF,0xAE,0xAE,0x40,0x9E,0x9F,0xAF,0x70,0xAF,0x60,0xAF,0x60,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x40,0x9F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0x60,0xAF,0xAF,0xAF,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0xAF,0xAF,0x9F,0x8F,0x8F,0x7F,0x7F,0x7F,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x42,0x8F,0x42,0x7F,0x8F,0x9F,0x8F,0x9F,0x8F,0x7E,0x40,0x9F,0x40,0x8F,0x9F,0x8F,0x8F,0x9F,0x9F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F
.byte 0x40,0x40,0x40,0x40,0x8F,0x40,0x9F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0xBF,0xAF,0x8F,0x9F,0xAF,0x71,0x82,0x71,0x82,0x82,0x82,0x82,0x82,0xB2,0xB2,0x82,0xB2,0x82,0x82,0x82,0x92,0x82,0x82,0xB2,0x82,0xB2,0xC3,0x82,0x82,0x82,0x92,0x82,0x92,0x92,0xB2,0x92,0x92,0x92,0x92,0x82,0x92,0x82,0x82,0x82,0x82,0x72,0x71,0xBF,0xAF,0x9F,0x9F,0x8F,0x8F,0x9F,0x9F,0x8F,0x8F,0x9F,0xAF,0xAF,0xAF,0x9F,0x9F,0x9F,0x8E,0xAF,0x8E,0x50,0x9E,0xAF,0x9E,0xAF,0x8E,0xAF,0xAF,0x8E,0xAF,0x9E,0xBE,0xAF,0x40,0xAF,0x8F,0xAF,0x60,0xAF,0x50,0x9F,0x60,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x40,0x9F,0x41,0x9F,0x9F,0x51,0x9F,0x9F,0x9F,0xAF,0x9F,0xAF,0x60,0xAF,0xAF,0xAF,0xAF,0xAF,0x60,0xAF,0x70,0xAF,0x8F,0x8F,0x7F,0x7F,0x7F,0x42,0x8F,0x42,0x42,0x42,0x42,0x7F,0x42,0x8F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x8F,0x8F,0x9F,0x8F,0x9F,0x8F,0x7E,0x9F,0x7E,0x8F,0x8F,0x9F,0x8F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x40,0x8F,0x8F,0x40
.byte 0x8F,0x8F,0x40,0x8F,0x40,0x40,0x40,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x40,0x40,0x8F,0x40,0x9F,0x8F,0x9F,0x41,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0xAF,0x9F,0x9F,0x9F,0x71,0x71,0x72,0x71,0x82,0x82,0x82,0x82,0x82,0xB2,0xB2,0x82,0x82,0x82,0x82,0x92,0x82,0xB2,0x82,0xB2,0x82,0x82,0xB2,0xC3,0x82,0x92,0x82,0x92,0x92,0xB2,0xB2,0xB2,0x92,0x92,0x92,0x92,0x82,0x82,0x82,0x82,0x82,0x72,0x72,0xCF,0xBF,0xAF,0x8F,0x8F,0x8F,0x8F,0xAF,0x9F,0x7F,0x8F,0x9F,0xAF,0x9F,0x9F,0x8F,0x9F,0xAF,0x8E,0x50,0x8E,0xAF,0x8E,0xAF,0x9E,0x60,0x9E,0xAF,0x9F,0xAF,0xAE,0xBF,0xAE,0x7F,0x9F,0x7F,0x40,0xAF,0x60,0x60,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x40,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0x9F,0xAF,0x60,0xAF,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0xAF,0xAF,0xAF,0xAF,0x8F,0x8F,0x8F,0x7F,0x7F,0x8F,0x42,0x42,0x7F,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x42,0x7F,0x42,0x7F,0x7F,0x8F,0x8F,0x9F,0x8F,0x8F,0x9F,0x40,0x9F,0x40,0x8F,0x9F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x7F,0x8F,0x8F
.byte 0x40,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x40,0x40,0x8F,0x40,0x40,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0x9F,0x9F,0xBF,0xCF,0x82,0x71,0x71,0x82,0x82,0x82,0x92,0x82,0xB2,0xB2,0x82,0x82,0x82,0x92,0xB2,0x82,0xB2,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x92,0x92,0x92,0x92,0x92,0xB2,0xB2,0x92,0x92,0x82,0x92,0x92,0x92,0x92,0x82,0x82,0x72,0x71,0xE3,0xDF,0xAF,0x9F,0x8F,0x8F,0x8F,0x8E,0x9F,0x8F,0x8F,0x9F,0x9F,0x9F,0x9F,0x8F,0x8E,0xAF,0x9E,0x9F,0x9F,0x8E,0x60,0x9E,0xAF,0x8E,0xAF,0x9E,0xAF,0x8E,0xBF,0x9E,0xBE,0x40,0x8F,0x8F,0x7F,0x9F,0x60,0x9F,0x60,0x9F,0x50,0x9F,0x50,0x9F,0x9F,0x40,0x9F,0x41,0x9F,0x51,0x9F,0x9F,0x60,0x9F,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x9F,0x8F,0x8F,0x7F,0x7F,0x42,0x8F,0x42,0x42,0x42,0x42,0x7F,0x42,0x8F,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x42,0x7F,0x9F,0x8F,0x8F,0x7E,0x40,0x7E,0x9F,0x7E,0x8F,0x8F,0x8F,0x9F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x7F,0x8F,0x40
.byte 0x8F,0x40,0x7F,0x40,0x40,0x40,0x40,0x8F,0x40,0x40,0x40,0x40,0x40,0x40,0x8F,0x40,0x40,0x40,0x9F,0x40,0x40,0x9F,0x40,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x8F,0xAF,0xCF,0xD3,0x71,0x61,0x61,0x71,0x82,0x82,0x81,0x92,0xB2,0xC2,0x82,0xB2,0xC3,0xB2,0x82,0xB2,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x82,0x92,0x82,0xC3,0x82,0x82,0x72,0x71,0xE3,0xDF,0xCF,0x9F,0x8F,0x8F,0x8F,0x9F,0x9E,0x8F,0x8F,0x8F,0x7F,0x8F,0x8F,0x9F,0x9F,0x8E,0xAF,0x9F,0x9F,0x9E,0xAF,0x8E,0x60,0x9E,0xAF,0x8E,0x60,0x8E,0xAF,0x9E,0xBE,0xAF,0x7F,0x8F,0x7F,0x9F,0x60,0x9F,0x50,0x9F,0x9F,0x50,0x9F,0x40,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0x9F,0xAF,0x60,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0xAF,0x60,0xAF,0xAF,0xAF,0x9F,0x8F,0x8F,0x8F,0x7F,0x7F,0x42,0x7F,0x8F,0x42,0x42,0x7F,0x42,0x42,0x8F,0x42,0x42,0x42,0x42,0x8F,0x42,0x42,0x7F,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x7F,0x8F,0x8F,0x8F,0x9F,0x8F,0x9F,0x8F,0x40,0x9F,0x8F,0x8F,0x8F,0x9F,0x8F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x8F
.byte 0x40,0x7F,0x40,0x7F,0x40,0x8F,0x40,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x40,0x40,0x8F,0x40,0x40,0x9F,0x40,0x8F,0x9F,0x40,0x8F,0x40,0x8F,0x8F,0x8F,0x9F,0x8F,0x8F,0xAF,0xBF,0xCF,0xBF,0xAF,0x61,0x71,0x82,0x82,0x82,0x92,0xB2,0xB2,0xC3,0x82,0xC2,0xC3,0xB2,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x82,0x92,0xB3,0x92,0x92,0x92,0x82,0x82,0x82,0x72,0xC3,0xCF,0xCF,0xCF,0x9F,0x8F,0x8F,0x8F,0xAF,0xAF,0x8E,0x9F,0x8F,0x7F,0x8F,0x8F,0x9F,0x8E,0x50,0x8E,0x9F,0x9F,0x8E,0x60,0x8E,0xAF,0x8E,0x60,0x8E,0xAF,0xAF,0x9E,0x70,0x9E,0x9E,0x7F,0xAF,0x7F,0x7F,0x9F,0x60,0x9F,0x50,0x9F,0x9F,0x40,0x9F,0x40,0x9F,0x40,0x9F,0x9F,0x50,0x9F,0x9F,0xAF,0x9F,0xAF,0x9F,0xAF,0xAF,0xAF,0xAF,0xAF,0xAF,0x60,0xAF,0xAF,0x60,0xAF,0x60,0x9F,0x8F,0x7F,0x8F,0x7F,0x7F,0x8F,0x42,0x7F,0x42,0x7F,0x42,0x7F,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x7F,0x42,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x7E,0x40,0x7E,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x7F,0x7F,0x8F,0x40
.byte 0x40,0x8F,0x40,0x8F,0x40,0x7F,0x40,0x8F,0x40,0x40,0x8F,0x40,0x40,0x8F,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x8F,0x40,0x8F,0x8F,0x8F,0x40,0x8F,0x9F,0x8F,0x8F,0xAF,0xAF,0xBF,0x61,0x9F,0xAF,0x71,0x82,0x82,0x92,0x92,0xB2,0xB2,0x82,0xC3,0xB2,0xC3,0xB2,0x82,0x82,0x82,0x82,0x82,0xB2,0x82,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x82,0x92,0x82,0x92,0xB3,0x92,0x82,0x82,0x72,0x71,0xBF,0xBF,0xBF,0x9F,0x8F,0x8F,0x8F,0x9F,0x9E,0xAF,0x8E,0x9F,0x9F,0x8F,0x9F,0x9F,0x9F,0x8E,0xAF,0x9F,0x9F,0x9E,0xAF,0x9E,0xAF,0x9F,0x8E,0xAF,0x8E,0x60,0x9E,0xAE,0xAF,0x9E,0x40,0x9F,0x8F,0x7F,0x8F,0x9F,0x50,0x9F,0x50,0x9F,0x40,0x9F,0x9F,0x9F,0x9F,0x51,0x9F,0x9F,0xAF,0x50,0xAF,0x60,0xAF,0xAF,0x60,0xAF,0xAF,0x60,0xAF,0xAF,0xAF,0x60,0xAF,0xAF,0x60,0xAF,0x60,0x8F,0x7F,0x8F,0x8F,0x7F,0x7F,0x8F,0x7F,0x42,0x42,0x7F,0x42,0x8F,0x42,0x8F,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x42,0x7F,0x42,0x7F,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x7F,0x42,0x7F,0x8F,0x8F,0x8F,0x9F,0x8F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x7F,0x7F,0x9F,0x8F
.byte 0x8F,0x40,0x7F,0x40,0x7F,0x40,0x7F,0x40,0x8F,0x40,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x8F,0x8F,0x9F,0x7F,0x8F,0x8E,0xAF,0xAF,0x9F,0x9F,0xAF,0x71,0x82,0x82,0x82,0xB2,0x82,0xC2,0x82,0x82,0xC3,0x82,0xB2,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x92,0x92,0x82,0x92,0x92,0x92,0x82,0x92,0x82,0x92,0x82,0x92,0x92,0x92,0x82,0xC3,0x82,0xC3,0x82,0x61,0xAF,0xBF,0xAF,0x9F,0x8F,0x8F,0x8F,0x9F,0x9E,0x9F,0x9E,0xAF,0x8E,0x9F,0x9F,0x8E,0x9F,0x9E,0x9F,0x9F,0x9F,0x8E,0xAF,0x8E,0xAF,0x8E,0x60,0x8E,0x9F,0x9E,0xAF,0x9E,0xBF,0xAE,0x9F,0x8F,0x8F,0x7F,0x8F,0x50,0x9F,0x50,0x9F,0x40,0x9F,0x40,0x9F,0x40,0x9F,0x9F,0x9F,0x50,0xAF,0x9F,0x9F,0xAF,0x9F,0xAF,0xAF,0xAF,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0xAF,0x60,0xAF,0x9F,0x7F,0x7F,0x8F,0x7F,0x7F,0x8F,0x8F,0x8F,0x7F,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x7F,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x42,0x7F,0x42,0x7F,0x42,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x7F,0x7F,0x8F,0x8F
.byte 0x7F,0x40,0x7F,0x40,0x7F,0x40,0x7F,0x40,0x7F,0x40,0x7F,0x40,0x7F,0x40,0x7F,0x40,0x40,0x40,0x40,0x40,0x40,0x8F,0x40,0x40,0x8F,0x40,0x8F,0x40,0x9F,0x9F,0x7F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x9F,0x71,0x72,0x82,0x92,0xB2,0xB2,0xB2,0xC3,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x92,0x92,0x82,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x82,0xB2,0x82,0x82,0x82,0xC3,0x81,0x72,0xAF,0xAF,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9E,0xAF,0x8E,0xAF,0x8E,0x9F,0x8E,0x9F,0xAF,0x8E,0x9F,0x8E,0x50,0x8E,0xAF,0x9E,0x60,0x8E,0xAF,0x8E,0x60,0x9E,0xAF,0x9E,0x9E,0xBE,0xAF,0x8F,0x9F,0x7F,0x7F,0x9F,0x50,0x9F,0x40,0x9F,0x9F,0x9F,0x9F,0x9F,0x50,0x9F,0x9F,0x9F,0x9F,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0xAF,0x60,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0x9F,0x8F,0x7F,0x7F,0x8F,0x7F,0x7F,0x9F,0x8F,0x42,0x7F,0x42,0x7F,0x42,0x8F,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x7F,0x42,0x7F,0x8F,0x8F,0x8F,0x9F,0x8F,0x7E,0x40,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x7F,0x7F,0x8F,0x8F,0x8F
.byte 0x40,0x7F,0x40,0x7F,0x40,0x7F,0x40,0x7F,0x40,0x7F,0x40,0x7F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x40,0x8F,0x40,0x40,0x8F,0x40,0x8F,0x9F,0x8F,0x7F,0x9F,0x9F,0x9F,0x8F,0x8F,0x9F,0x8F,0xAF,0x71,0x82,0xB2,0xB2,0x82,0xB2,0x82,0x82,0xC3,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0xC3,0x92,0x92,0x82,0x92,0x92,0x92,0x82,0x92,0x92,0xB3,0x92,0xC3,0x92,0xB2,0x92,0x82,0x82,0xC3,0x71,0x71,0xAF,0xAF,0x9F,0x7E,0x8F,0x8F,0x8F,0x9F,0xAF,0x8E,0x60,0x8E,0xAF,0x8E,0x50,0x8E,0xAF,0x8E,0x50,0x9F,0x7E,0x50,0x9E,0xAF,0x8E,0xAF,0x9E,0xAF,0x8E,0xAF,0xAF,0xAF,0xAE,0xAE,0x9E,0x9F,0x9F,0x7F,0x7F,0x8F,0x9F,0x40,0x9F,0x40,0x40,0x9F,0x50,0x9F,0x9F,0x50,0x9F,0x60,0x9F,0x9F,0x9F,0xAF,0x9F,0xAF,0xAF,0xAF,0xAF,0x60,0xAF,0xAF,0x60,0xAF,0xAF,0x60,0xAF,0x9F,0x60,0xAF,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x8F,0x8F,0x7F,0x7F,0x42,0x7F,0x42,0x42,0x8F,0x42,0x42,0x7F,0x42,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x7F,0x42,0x7F,0x42,0x7F,0x42,0x7F,0x42,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x7F,0x42,0x7F,0x42,0x42,0x7F,0x42,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x40,0x7E,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x8F
.byte 0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x40,0x7F,0x40,0x7F,0x40,0x7F,0x40,0x7F,0x40,0x40,0x8F,0x40,0x8F,0x40,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x9F,0x8F,0x7F,0x8E,0x9F,0x9F,0x8F,0x9F,0x9F,0x8F,0x40,0x71,0x82,0xB2,0x82,0x82,0xC3,0x82,0x82,0x82,0xC3,0x82,0xC3,0x82,0x82,0x82,0x82,0x82,0x92,0x82,0x92,0x92,0x82,0x92,0x92,0xC3,0x92,0x82,0x92,0x82,0x92,0xC3,0x92,0x82,0x82,0x82,0xC3,0x71,0x71,0xBF,0xAF,0x9F,0x8F,0x8F,0x7F,0x8F,0x8F,0x8E,0xAF,0x8E,0xAF,0x8E,0x50,0x8E,0xAF,0x8E,0xAF,0x8E,0x9F,0x9F,0x9F,0x8E,0xAF,0x8E,0x60,0x8E,0x60,0x8E,0x9F,0x8E,0xAF,0x9E,0xBF,0xAE,0x9E,0x50,0x8F,0x7F,0x7F,0x40,0x9F,0x40,0x9F,0x9F,0x40,0x9F,0x9F,0x9F,0x9F,0x9F,0xAF,0x9F,0x60,0x9F,0x9F,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0xAF,0x60,0xAF,0xAF,0x60,0xAF,0x9F,0x60,0x9F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x42,0x7F,0x42,0x7F,0x42,0x8F,0x42,0x42,0x8F,0x42,0x42,0x7F,0x7F,0x42,0x42,0x7F,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x7F,0x42,0x42,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x8F,0x8F
.byte 0x7F,0x40,0x7F,0x40,0x7F,0x40,0x7F,0x7F,0x7F,0x7F,0x40,0x7F,0x40,0x7F,0x40,0x40,0x8F,0x40,0x40,0x8F,0x40,0x40,0x40,0x40,0x8F,0x40,0x8F,0x40,0x9F,0x8F,0x7F,0x9F,0x9F,0x8F,0x8F,0x9F,0x8F,0x8F,0x8F,0x71,0xC3,0x82,0xB2,0x82,0x82,0xB2,0x82,0x82,0x82,0xC3,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x92,0x82,0x92,0x82,0x92,0x82,0x82,0x92,0x82,0xB2,0x82,0x82,0x82,0x82,0x82,0x71,0xC3,0x71,0xBF,0xAF,0x9F,0x7E,0x8F,0x7F,0x8F,0x8F,0x9F,0x9E,0x60,0x8E,0x9F,0x8E,0x9F,0x8E,0x60,0x8E,0x9F,0x9F,0x8E,0x50,0x9F,0x9F,0x8E,0xAF,0x9F,0x9F,0x9F,0x9F,0xAF,0x9E,0x70,0x9E,0xBF,0xAE,0x9F,0x7F,0x7F,0x8F,0x8F,0x50,0x9F,0x40,0x9F,0x9F,0x50,0x9F,0x60,0x9F,0x60,0x9F,0x9F,0xAF,0x50,0xAF,0x9F,0xAF,0x50,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0xAF,0x60,0xAF,0xAF,0x60,0xAF,0xAF,0xAF,0x8F,0x6F,0x7F,0x7F,0x7F,0x6F,0x8F,0x8F,0x7F,0x7F,0x7F,0x42,0x42,0x7F,0x42,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x7F,0x42,0x42,0x7F,0x42,0x7F,0x42,0x7F,0x42,0x7F,0x42,0x42,0x7F,0x42,0x7F,0x42,0x42,0x7F,0x42,0x7F,0x42,0x42,0x42,0x7F,0x42,0x6F,0x42,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F
.byte 0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x40,0x7F,0x40,0x7F,0x7F,0x40,0x7F,0x40,0x7F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x40,0x40,0x40,0x40,0x9F,0x7F,0x8F,0x8E,0x9F,0x9F,0x8F,0x9F,0x9F,0x7F,0x9F,0x82,0xB2,0xB2,0xB2,0xB2,0xC3,0xB2,0xC3,0xB2,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0xB2,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0xB2,0xB2,0x92,0x92,0x82,0x82,0x82,0x82,0x71,0xAF,0xBF,0xAF,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0x9E,0x8E,0xAF,0x8E,0x60,0x8E,0xAF,0x8E,0xAF,0x8E,0x9F,0x9F,0x8E,0x9F,0x9E,0x60,0x8E,0xAF,0x8E,0xAF,0x8E,0x60,0x9E,0xAE,0xAE,0xAE,0xAE,0xAF,0x8F,0x7F,0x7F,0x9F,0x9F,0x40,0x9F,0x50,0x9F,0x9F,0x9F,0xAF,0x9F,0xAF,0x60,0xAF,0x9F,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0xAF,0x60,0xAF,0x60,0xAF,0x60,0xAF,0x50,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x7F,0x8F,0x7F,0x7F,0x7F,0x42,0x42,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x42,0x7F,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x7F,0x42,0x42,0x42,0x42,0x7F,0x42,0x7F,0x42,0x42,0x7F,0x42,0x7F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x8F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F
.byte 0x6F,0x7F,0x6F,0x7F,0x7F,0x6F,0x7F,0x6F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x8F,0x7F,0x7F,0x8F,0x8F,0x8F,0x8F,0x7F,0x8F,0x7F,0x40,0x61,0x61,0x71,0x61,0x72,0x61,0x61,0x61,0x72,0x61,0x61,0x61,0x61,0x61,0x72,0x61,0x72,0x61,0x72,0x72,0x72,0x72,0x72,0x72,0x72,0x72,0x72,0x62,0x72,0x72,0x62,0x72,0x61,0x72,0x61,0x61,0x61,0x61,0x9F,0x9F,0x8F,0x8F,0x7F,0x7F,0x7F,0x7F,0x8F,0x9F,0x40,0x8F,0x8F,0x7E,0x40,0x7E,0x40,0x9F,0x8F,0x8F,0x8F,0x8F,0x8F,0x9F,0x9F,0x8F,0x9F,0x8F,0x8F,0x9F,0x9F,0x9F,0x9F,0x9F,0x50,0x8E,0x9F,0x7F,0x6F,0x7F,0x7F,0x8F,0x8F,0x8F,0x8F,0x40,0x8F,0x40,0x8F,0x40,0x8F,0x8F,0x40,0x8F,0x8F,0x8F,0x40,0x8F,0x9F,0x40,0x8F,0x40,0x9F,0x40,0x9F,0x40,0x8F,0x8F,0x8F,0x40,0x9F,0x40,0x9F,0x9F,0x7F,0x6F,0x6F,0x6F,0x6F,0x6F,0x7F,0x7F,0x6F,0x6F,0x6F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x7F,0x6F,0x7F,0x6F,0x7F,0x6F,0x6F,0x7F,0x6F,0x6F,0x6F,0x7F,0x6F,0x6F,0x6F,0x6F,0x7F,0x6F,0x6F,0x6F,0x6F,0x7F,0x6F,0x42,0x6F,0x6F,0x6F,0x6F,0x7F,0x7F,0x8F,0x7F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x8F,0x7F,0x7F,0x7F,0x7F,0x6F,0x7F,0x6F,0x6F,0x6F,0x6F,0x6F

.end

